@@ -49,6 +49,7 @@ import org.openscience.cdk.sgroup.SgroupType;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesGenerator;
 import org.openscience.cdk.smiles.SmilesParser;
+import org.openscience.cdk.tools.LoggingToolFactory;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 
 import java.io.BufferedReader;
@@ -310,7 +311,7 @@ public class Abbreviations implements Iterable<String> {
             frags.addAll(makeCut(cut, mol, atmidx, adjlist));
         }
 
-        Collections.sort(frags, new Comparator<IAtomContainer>() {
+        frags.sort(new Comparator<IAtomContainer>() {
             @Override
             public int compare(IAtomContainer a, IAtomContainer b) {
                 return -Integer.compare(a.getBondCount(), b.getBondCount());
@@ -527,7 +528,7 @@ public class Abbreviations implements Iterable<String> {
             sb.append(newSymbol(attach.getAtomicNumber(), hcount, newbonds.size() == 0));
             String prev  = null;
             int    count = 0;
-            Collections.sort(nbrSymbols, new Comparator<String>() {
+            nbrSymbols.sort(new Comparator<String>() {
                 @Override
                 public int compare(String o1, String o2) {
                     int cmp = Integer.compare(o1.length(), o2.length());
@@ -885,7 +886,8 @@ public class Abbreviations implements Iterable<String> {
                     if (add(line))
                         count++;
                 } catch (InvalidSmilesException e) {
-                    e.printStackTrace();
+                    LoggingToolFactory.createLoggingTool(Abbreviations.class)
+                                      .warn("Ignored Invalid SMILES", e);
                 }
             }
         }
