@@ -148,17 +148,17 @@ public final class DepictionGenerator {
      * Magic value for indicating automatic parameters. These can
      * be overridden by a caller.
      */
-    public static double AUTOMATIC = -1;
+    public static final double AUTOMATIC = -1;
 
     /**
      * Default margin for vector graphics formats.
      */
-    public static double DEFAULT_MM_MARGIN = 0.56;
+    public static final double DEFAULT_MM_MARGIN = 0.56;
 
     /**
      * Default margin for raster graphics formats.
      */
-    public static double DEFAULT_PX_MARGIN = 4;
+    public static final double DEFAULT_PX_MARGIN = 4;
 
     /**
      * The dimensions (width x height) of the depiction.
@@ -213,7 +213,7 @@ public final class DepictionGenerator {
     /**
      * Object that should be highlighted
      */
-    private Map<IChemObject, Color> highlight = new HashMap<>();
+    private final Map<IChemObject, Color> highlight = new HashMap<>();
 
     /**
      * Create a depiction generator using the standard sans-serif
@@ -276,11 +276,11 @@ public final class DepictionGenerator {
         final T param = (T) params.get(key);
         if (param == null)
             throw new IllegalArgumentException("No parameter registered: " + key + " " + params.keySet());
-        return (U) param.getValue();
+        return param.getValue();
     }
 
     private <T extends IGeneratorParameter<S>, S, U extends S> void setParam(Class<T> key, U val) {
-        T param = null;
+        T param;
         try {
             param = key.newInstance();
             param.setValue(val);
