@@ -41,7 +41,6 @@ import java.awt.geom.Path2D;
 import java.awt.geom.Rectangle2D;
 import java.awt.image.BufferedImage;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 
 /**
@@ -248,7 +247,7 @@ final class ReactionDepiction extends Depiction {
 
         // compound the zoom, fitting and scaling into a single value
         final double rescale = zoom * fitting * scale;
-        double mainCompOffset = 0;
+        double mainCompOffset;
 
         // shift product x-offset to make room for the arrow / side components
         mainCompOffset = fitting * sideRequired.h + nSideRow * padding - fitting * firstRowHeight / 2;
@@ -403,7 +402,7 @@ final class ReactionDepiction extends Depiction {
 
         // compound the zoom, fitting and scaling into a single value
         final double rescale = zoom * fitting * scale;
-        double mainCompOffset = 0;
+        double mainCompOffset;
 
         // shift product x-offset to make room for the arrow / side components
         mainCompOffset = fitting * sideRequired.h + nSideRow * padding - fitting * firstRowHeight / 2;
