@@ -50,12 +50,12 @@ public class SybylAtomTypeMatcher implements IAtomTypeMatcher {
     private final static String                                  SYBYL_ATOM_TYPE_LIST = "org/openscience/cdk/dict/data/sybyl-atom-types.owl";
     private final static String                                  CDK_TO_SYBYL_MAP     = "org/openscience/cdk/dict/data/cdk-sybyl-mappings.owl";
 
-    private AtomTypeFactory                                      factory;
-    private CDKAtomTypeMatcher                                   cdkMatcher;
-    private AtomTypeMapper                                       mapper;
+    private final AtomTypeFactory                                      factory;
+    private final CDKAtomTypeMatcher                                   cdkMatcher;
+    private final AtomTypeMapper                                       mapper;
 
-    private static Map<IChemObjectBuilder, SybylAtomTypeMatcher> factories            = new Hashtable<IChemObjectBuilder, SybylAtomTypeMatcher>(
-                                                                                              1);
+    private static final Map<IChemObjectBuilder, SybylAtomTypeMatcher> factories            = new Hashtable<>(
+            1);
 
     private SybylAtomTypeMatcher(IChemObjectBuilder builder) {
         InputStream stream = this.getClass().getClassLoader().getResourceAsStream(SYBYL_ATOM_TYPE_LIST);
@@ -112,16 +112,18 @@ public class SybylAtomTypeMatcher implements IAtomTypeMatcher {
     @Override
     public IAtomType findMatchingAtomType(IAtomContainer atomContainer, IAtom atom) throws CDKException {
         IAtomType type = cdkMatcher.findMatchingAtomType(atomContainer, atom);
-        if ("Cr".equals(atom.getSymbol())) {
-            // if only I had good descriptions of the Sybyl atom types
-            int neighbors = atomContainer.getConnectedBondsCount(atom);
-            if (neighbors > 4 && neighbors <= 6)
-                return factory.getAtomType("Cr.oh");
-            else if (neighbors > 0) return factory.getAtomType("Cr.th");
-        } else if ("Co".equals(atom.getSymbol())) {
-            // if only I had good descriptions of the Sybyl atom types
-            int neibors = atomContainer.getConnectedBondsCount(atom);
-            if (neibors == 6) return factory.getAtomType("Co.oh");
+        if (atom.getAtomicNumber() != null) {
+            if (atom.getAtomicNumber() == IElement.Cr) {
+                // if only I had good descriptions of the Sybyl atom types
+                int neighbors = atomContainer.getConnectedBondsCount(atom);
+                if (neighbors > 4 && neighbors <= 6)
+                    return factory.getAtomType("Cr.oh");
+                else if (neighbors > 0) return factory.getAtomType("Cr.th");
+            } else if (atom.getAtomicNumber() == IElement.Co) {
+                // if only I had good descriptions of the Sybyl atom types
+                int neibors = atomContainer.getConnectedBondsCount(atom);
+                if (neibors == 6) return factory.getAtomType("Co.oh");
+            }
         }
         if (type == null)
             return null;
@@ -142,7 +144,7 @@ public class SybylAtomTypeMatcher implements IAtomTypeMatcher {
         if (neighbors.size() != 1) return false;
         IBond neighbor = neighbors.get(0);
         IAtom neighborAtom = neighbor.getOther(atom);
-        if ("C".equals(neighborAtom.getSymbol())) {
+        if (neighborAtom.getAtomicNumber() == IElement.C) {
             if (neighbor.getOrder() == IBond.Order.SINGLE) {
                 if (countAttachedBonds(atomContainer, neighborAtom, IBond.Order.DOUBLE, "O") == 1) return true;
             } else if (neighbor.getOrder() == IBond.Order.DOUBLE) {
@@ -157,7 +159,7 @@ public class SybylAtomTypeMatcher implements IAtomTypeMatcher {
         if (neighbors.size() != 3) return false;
         int oxygenCount = 0;
         for (IAtom neighbor : neighbors)
-            if ("O".equals(neighbor.getSymbol())) oxygenCount++;
+            if (neighbor.getAtomicNumber() == IElement.O) oxygenCount++;
         return (oxygenCount == 2);
     }
 
