@@ -23,6 +23,7 @@
 package org.openscience.cdk;
 
 import org.openscience.cdk.exception.NoSuchAtomException;
+import org.openscience.cdk.exception.NoSuchBondException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
@@ -39,9 +40,6 @@ import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.isomorphism.matchers.IQueryAtom;
 import org.openscience.cdk.isomorphism.matchers.IQueryBond;
 import org.openscience.cdk.sgroup.Sgroup;
-import org.openscience.cdk.stereo.DoubleBondStereochemistry;
-import org.openscience.cdk.stereo.ExtendedTetrahedral;
-import org.openscience.cdk.stereo.TetrahedralChirality;
 import org.openscience.cdk.tools.manipulator.SgroupManipulator;
 
 import java.util.ArrayList;
@@ -213,6 +211,23 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
         return null;
     }
 
+
+    private BondRef getBondRef(IBond bond) {
+        BondRef ref = getBondRefUnsafe(bond);
+        if (ref == null)
+            throw new NoSuchBondException("Atom is not a member of this AtomContainer");
+        return ref;
+    }
+
+    private IChemObject getRef(IChemObject cobj) {
+        if (cobj instanceof IAtom)
+            return getAtomRef((IAtom)cobj);
+        else if (cobj instanceof IBond)
+            return getBondRef((IBond)cobj);
+        else
+            throw new IllegalArgumentException("Atom or Bond must be provided");
+    }
+
     private BaseBondRef newBondRef(IBond bond) {
         BaseAtomRef beg = bond.getBegin() == null ? null : getAtomRef(bond.getBegin());
         BaseAtomRef end = bond.getEnd() == null ? null : getAtomRef(bond.getEnd());
@@ -251,7 +266,12 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
      */
     @Override
     public void addStereoElement(IStereoElement element) {
-        stereo.add(element);
+        // important! we need to re-wrap any Atom/Bond refs with "our" own ones
+        Map<IChemObject,IChemObject> remap = new HashMap<>();
+        remap.put(element.getFocus(), getRef(element.getFocus()));
+        for (Object cobj : element.getCarriers())
+            remap.put((IChemObject) cobj, getRef((IChemObject)cobj));
+        stereo.add(element.map(remap));
         notifyChanged();
     }
 
@@ -261,7 +281,9 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
     @Override
     public void setStereoElements(List<IStereoElement> elements) {
         this.stereo.clear();
-        this.stereo.addAll(elements);
+        for (IStereoElement<?,?> se : elements) {
+            addStereoElement(se);
+        }
         notifyChanged();
     }
 
@@ -279,6 +301,71 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
         }
     }
 
+    private boolean isStale(IAtom atom) {
+        return indexOf(atom) < 0;
+    }
+
+    private boolean isStale(IBond bond) {
+        return indexOf(bond) < 0 ||
+                indexOf(bond.getBegin()) < 0 ||
+                indexOf(bond.getEnd()) < 0;
+    }
+
+    // helper for atom or bond
+    private boolean isStale(IChemObject cobj) {
+        if (cobj instanceof IAtom)
+            return isStale((IAtom)cobj);
+        else if (cobj instanceof IBond)
+            return isStale((IBond)cobj);
+        else return true;
+    }
+
+    // stereo is valid if all atoms/bonds are valid
+    private boolean isStale(IStereoElement<?,?> se) {
+        if (isStale(se.getFocus()))
+            return true;
+        for (IChemObject a : se.getCarriers())
+            if (isStale(a))
+                return true;
+        return false;
+    }
+
+    // Sgroup is valid if all atoms/bonds are valid
+    private boolean isStale(Sgroup sgroup) {
+        for (IAtom a : sgroup.getAtoms())
+            if (indexOf(a) < 0)
+                return true;
+        for (IBond b : sgroup.getBonds())
+            if (isStale(b))
+                return true;
+        return false;
+    }
+
+    private void validateStereoAndSgroups() {
+        // remove any Stereochemistry and Sgroups which now have "stale" atoms
+        if (!stereo.isEmpty()) {
+            List<IStereoElement<?, ?>> staleStereo = new ArrayList<>();
+            for (IStereoElement<?, ?> se : stereo) {
+                if (isStale(se))
+                    staleStereo.add(se);
+            }
+            stereo.removeAll(staleStereo);
+        }
+        List<Sgroup> sgroups = getProperty(CDKConstants.CTAB_SGROUPS);
+        if (sgroups != null) {
+            List<Sgroup> staleSgroups = new ArrayList<>();
+            for (Sgroup sgroup : sgroups) {
+                if (isStale(sgroup))
+                    staleSgroups.add(sgroup);
+            }
+            if (!staleSgroups.isEmpty()) {
+                sgroups = new ArrayList<>(sgroups); // ensure mutable
+                sgroups.removeAll(staleSgroups);
+                setProperty(CDKConstants.CTAB_SGROUPS, sgroups);
+            }
+        }
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -321,6 +408,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
                 addToEndpoints(bonds[i]);
         }
 
+        validateStereoAndSgroups();
         notifyChanged();
     }
 
@@ -350,6 +438,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
             Arrays.fill(this.bonds, newbonds.length, numBonds, null);
         }
         numBonds = newbonds.length;
+        validateStereoAndSgroups();
         notifyChanged();
     }
 
@@ -389,11 +478,23 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
         for (int i = 0; i < this.stereo.size(); i++) {
             IStereoElement se = stereo.get(i);
             if (se.contains(org)) {
-                Map<IAtom, IAtom> amap = Collections.<IAtom,IAtom>singletonMap(org, rep);
+                Map<IAtom, IAtom> amap = Collections.singletonMap(org, rep);
                 Map<IBond, IBond> bmap = Collections.emptyMap();
                 this.stereo.set(i, se.map(amap, bmap));
             }
         }
+
+        // update Sgroups
+        List<Sgroup> sgroups = getProperty(CDKConstants.CTAB_SGROUPS);
+        if (sgroups != null) {
+            for (Sgroup sgroup : sgroups) {
+                if (sgroup.getAtoms().contains(org)) {
+                    sgroup.removeAtom(org);
+                    sgroup.addAtom(rep);
+                }
+            }
+        }
+
         org.removeListener(this);
         rep.addListener(this);
         notifyChanged();
@@ -444,13 +545,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
      */
     @Override
     public Iterable<IAtom> atoms() {
-        return new Iterable<IAtom>() {
-
-            @Override
-            public Iterator<IAtom> iterator() {
-                return new AtomIterator();
-            }
-        };
+        return AtomIterator::new;
     }
 
     /**
@@ -458,13 +553,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
      */
     @Override
     public Iterable<IBond> bonds() {
-        return new Iterable<IBond>() {
-
-            @Override
-            public Iterator<IBond> iterator() {
-                return new BondIterator();
-            }
-        };
+        return BondIterator::new;
     }
 
     /**
@@ -472,13 +561,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
      */
     @Override
     public Iterable<ILonePair> lonePairs() {
-        return new Iterable<ILonePair>() {
-
-            @Override
-            public Iterator<ILonePair> iterator() {
-                return new LonePairIterator();
-            }
-        };
+        return LonePairIterator::new;
     }
 
     /**
@@ -486,12 +569,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
      */
     @Override
     public Iterable<ISingleElectron> singleElectrons() {
-        return new Iterable<ISingleElectron>() {
-            @Override
-            public Iterator<ISingleElectron> iterator() {
-                return new SingleElectronIterator();
-            }
-        };
+        return SingleElectronIterator::new;
     }
 
     /**
@@ -499,12 +577,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
      */
     @Override
     public Iterable<IElectronContainer> electronContainers() {
-        return new Iterable<IElectronContainer>() {
-            @Override
-            public Iterator<IElectronContainer> iterator() {
-                return new ElectronContainerIterator();
-            }
-        };
+        return ElectronContainerIterator::new;
     }
 
     /**
@@ -859,18 +932,11 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
         for (IBond bond : this.bonds())
             bond.setFlag(CDKConstants.VISITED, true);
 
-        // do stereo elements first
-        for (IStereoElement se : that.stereoElements()) {
-            if (se instanceof TetrahedralChirality &&
-                !((TetrahedralChirality) se).getChiralAtom().getFlag(CDKConstants.VISITED)) {
-                this.addStereoElement(se);
-            } else if (se instanceof DoubleBondStereochemistry &&
-                       !((DoubleBondStereochemistry) se).getStereoBond().getFlag(CDKConstants.VISITED)) {
-                this.addStereoElement(se);
-            } else if (se instanceof ExtendedTetrahedral &&
-                       !((ExtendedTetrahedral) se).focus().getFlag(CDKConstants.VISITED)) {
-                this.addStereoElement(se);
-            }
+        // Determine which stereo elements are new (unvisited)
+        List<IStereoElement<?,?>> newStereo = new ArrayList<>();
+        for (IStereoElement<?,?> se : that.stereoElements()) {
+            if (!se.getFocus().getFlag(CDKConstants.VISITED))
+                newStereo.add(se);
         }
 
         // append atoms/bonds not visited
@@ -897,6 +963,10 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
             if (this.indexOf(lp) < 0)
                 addLonePair(lp);
         }
+        // now add the new stereo elements last (needs atom/bond remap)
+        for (IStereoElement<?,?> se : newStereo) {
+            this.addStereoElement(se);
+        }
 
         notifyChanged();
     }
@@ -1183,11 +1253,27 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
             }
             numLonePairs = newNumLonePairs;
 
-            List<IStereoElement> atomElements = new ArrayList<>();
-            for (IStereoElement element : stereo) {
-                if (element.contains(atom)) atomElements.add(element);
+            // consider any stereochemistry involving this atom is now invalid
+            List<IStereoElement<?,?>> stereoToRemove = new ArrayList<>();
+            for (IStereoElement<?,?> element : stereo) {
+                if (element.contains(atom)) stereoToRemove.add(element);
+            }
+            stereo.removeAll(stereoToRemove);
+
+            // consider any sgroups involving this atom is now invalid
+            List<Sgroup> sgroups = getProperty(CDKConstants.CTAB_SGROUPS);
+            if (sgroups != null) {
+                List<Sgroup> sgrpToRemove = new ArrayList<>();
+                for (Sgroup sgroup : sgroups) {
+                    if (sgroup.getAtoms().contains(atom))
+                        sgrpToRemove.add(sgroup);
+                }
+                if (!sgrpToRemove.isEmpty()) {
+                    sgroups = new ArrayList<>(sgroups); // ensure mutable
+                    sgroups.removeAll(sgrpToRemove);
+                    setProperty(CDKConstants.CTAB_SGROUPS, sgroups);
+                }
             }
-            stereo.removeAll(atomElements);
             
             removeAtomOnly(atomref.getIndex());
         }
@@ -1514,6 +1600,8 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
 
         @Override
         public IAtom next() {
+            if (idx >= numAtoms)
+                throw new NoSuchElementException();
             return atoms[idx++];
         }
 
@@ -1534,6 +1622,8 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
 
         @Override
         public IBond next() {
+            if (idx >= numBonds)
+                throw new NoSuchElementException();
             return bonds[idx++];
         }
 
@@ -1555,6 +1645,8 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
 
         @Override
         public ILonePair next() {
+            if (idx >= numLonePairs)
+                throw new NoSuchElementException();
             return lonepairs[idx++];
         }
 
@@ -1576,6 +1668,8 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
 
         @Override
         public ISingleElectron next() {
+            if (idx >= numSingleElectrons)
+                throw new NoSuchElementException();
             return electrons[idx++];
         }
 
@@ -1603,7 +1697,7 @@ final class AtomContainer2 extends ChemObject implements IAtomContainer {
                 return lonepairs[(idx++) - numBonds];
             else if (idx < numBonds + numLonePairs + numSingleElectrons)
                 return electrons[(idx++) - (numBonds + numLonePairs)];
-            return null;
+            throw new NoSuchElementException();
         }
 
         @Override
