@@ -19,14 +19,12 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtom;
-import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.ILonePair;
 import org.openscience.cdk.test.interfaces.AbstractLonePairTest;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the LonePair class.
@@ -35,33 +33,27 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @cdk.module test-data
  */
-public class LonePairTest extends AbstractLonePairTest {
+class LonePairTest extends AbstractLonePairTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new LonePair();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(LonePair::new);
     }
 
     @Test
-    public void testLonePair() {
+    void testLonePair() {
         ILonePair lp = new LonePair();
-        Assert.assertNull(lp.getAtom());
-        Assert.assertEquals(2, lp.getElectronCount().intValue());
+        Assertions.assertNull(lp.getAtom());
+        Assertions.assertEquals(2, lp.getElectronCount().intValue());
     }
 
     @Test
-    public void testLonePair_IAtom() {
+    void testLonePair_IAtom() {
         IAtom atom = new Atom("N");
         ILonePair lp = new LonePair(atom);
-        Assert.assertEquals(2, lp.getElectronCount().intValue());
-        Assert.assertEquals(atom, lp.getAtom());
-        Assert.assertTrue(lp.contains(atom));
+        Assertions.assertEquals(2, lp.getElectronCount().intValue());
+        Assertions.assertEquals(atom, lp.getAtom());
+        Assertions.assertTrue(lp.contains(atom));
     }
 
 }
