@@ -22,85 +22,77 @@ package org.openscience.cdk;
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
 
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractPseudoAtomTest;
-import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IPseudoAtom;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
 
 /**
  * Checks the functionality of the AtomTypeFactory
  *
  * @cdk.module test-data
  */
-public class PseudoAtomTest extends AbstractPseudoAtomTest {
+class PseudoAtomTest extends AbstractPseudoAtomTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new PseudoAtom();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(PseudoAtom::new);
     }
 
     @Test
-    public void testPseudoAtom() {
+    void testPseudoAtom() {
         IPseudoAtom a = new PseudoAtom();
-        Assert.assertEquals("R", a.getSymbol());
-        Assert.assertNull(a.getPoint3d());
-        Assert.assertNull(a.getPoint2d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("R", a.getSymbol());
+        Assertions.assertNull(a.getPoint3d());
+        Assertions.assertNull(a.getPoint2d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 
     @Test
-    public void testPseudoAtom_IElement() {
+    void testPseudoAtom_IElement() {
         IElement element = newChemObject().getBuilder().newInstance(IElement.class);
         IPseudoAtom a = new PseudoAtom(element);
-        Assert.assertEquals("R", a.getSymbol());
-        Assert.assertNull(a.getPoint3d());
-        Assert.assertNull(a.getPoint2d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("R", a.getSymbol());
+        Assertions.assertNull(a.getPoint3d());
+        Assertions.assertNull(a.getPoint2d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 
     @Test
-    public void testPseudoAtom_String() {
+    void testPseudoAtom_String() {
         String label = "Arg255";
         IPseudoAtom a = new PseudoAtom(label);
-        Assert.assertEquals("R", a.getSymbol());
-        Assert.assertEquals(label, a.getLabel());
-        Assert.assertNull(a.getPoint3d());
-        Assert.assertNull(a.getPoint2d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("R", a.getSymbol());
+        Assertions.assertEquals(label, a.getLabel());
+        Assertions.assertNull(a.getPoint3d());
+        Assertions.assertNull(a.getPoint2d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 
     @Test
-    public void testPseudoAtom_String_Point2d() {
+    void testPseudoAtom_String_Point2d() {
         Point2d point = new Point2d(1.0, 2.0);
         String label = "Arg255";
         IPseudoAtom a = new PseudoAtom(label, point);
-        Assert.assertEquals("R", a.getSymbol());
-        Assert.assertEquals(label, a.getLabel());
-        Assert.assertEquals(point, a.getPoint2d());
-        Assert.assertNull(a.getPoint3d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("R", a.getSymbol());
+        Assertions.assertEquals(label, a.getLabel());
+        Assertions.assertEquals(point, a.getPoint2d());
+        Assertions.assertNull(a.getPoint3d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 
     @Test
-    public void testPseudoAtom_String_Point3d() {
+    void testPseudoAtom_String_Point3d() {
         Point3d point = new Point3d(1.0, 2.0, 3.0);
         String label = "Arg255";
         IPseudoAtom a = new PseudoAtom(label, point);
-        Assert.assertEquals("R", a.getSymbol());
-        Assert.assertEquals(label, a.getLabel());
-        Assert.assertEquals(point, a.getPoint3d());
-        Assert.assertNull(a.getPoint2d());
-        Assert.assertNull(a.getFractionalPoint3d());
+        Assertions.assertEquals("R", a.getSymbol());
+        Assertions.assertEquals(label, a.getLabel());
+        Assertions.assertEquals(point, a.getPoint3d());
+        Assertions.assertNull(a.getPoint2d());
+        Assertions.assertNull(a.getFractionalPoint3d());
     }
 }
