@@ -19,13 +19,11 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.openscience.cdk.interfaces.IChemObject;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.test.interfaces.AbstractRingSetTest;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the RingSet class.
@@ -34,23 +32,17 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @see org.openscience.cdk.RingSet
  */
-public class RingSetTest extends AbstractRingSetTest {
+class RingSetTest extends AbstractRingSetTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new RingSet();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(RingSet::new);
     }
 
     @Test
-    public void testRingSet() {
+    void testRingSet() {
         IRingSet rs = new RingSet();
-        Assert.assertNotNull(rs);
+        Assertions.assertNotNull(rs);
     }
 
 }
