@@ -19,51 +19,43 @@
  */
 package org.openscience.cdk.debug;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractPDBPolymerTest;
-import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IMonomer;
 import org.openscience.cdk.interfaces.IPDBAtom;
 import org.openscience.cdk.interfaces.IPDBPolymer;
 import org.openscience.cdk.interfaces.IStrand;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the {@link DebugPDBPolymer}.
  *
  * @cdk.module test-datadebug
  */
-public class DebugPDBPolymerTest extends AbstractPDBPolymerTest {
+class DebugPDBPolymerTest extends AbstractPDBPolymerTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new DebugPDBPolymer();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(DebugPDBPolymer::new);
     }
 
     @Test
-    public void testDebugPDBPolymer() {
+    void testDebugPDBPolymer() {
         IPDBPolymer pdbPolymer = new DebugPDBPolymer();
-        Assert.assertNotNull(pdbPolymer);
-        Assert.assertEquals(pdbPolymer.getMonomerCount(), 0);
+        Assertions.assertNotNull(pdbPolymer);
+        Assertions.assertEquals(pdbPolymer.getMonomerCount(), 0);
 
         IStrand oStrand1 = pdbPolymer.getBuilder().newInstance(IStrand.class);
         oStrand1.setStrandName("A");
         IStrand oStrand2 = pdbPolymer.getBuilder().newInstance(IStrand.class);
         oStrand2.setStrandName("B");
         IMonomer oMono1 = pdbPolymer.getBuilder().newInstance(IMonomer.class);
-        oMono1.setMonomerName(new String("TRP279"));
+        oMono1.setMonomerName("TRP279");
         IMonomer oMono2 = pdbPolymer.getBuilder().newInstance(IMonomer.class);
-        oMono2.setMonomerName(new String("HOH"));
+        oMono2.setMonomerName("HOH");
         IMonomer oMono3 = pdbPolymer.getBuilder().newInstance(IMonomer.class);
-        oMono3.setMonomerName(new String("GLYA16"));
+        oMono3.setMonomerName("GLYA16");
         IPDBAtom oPDBAtom1 = pdbPolymer.getBuilder().newInstance(IPDBAtom.class, "C");
         IPDBAtom oPDBAtom2 = pdbPolymer.getBuilder().newInstance(IPDBAtom.class, "C");
         IPDBAtom oPDBAtom3 = pdbPolymer.getBuilder().newInstance(IPDBAtom.class, "C");
@@ -75,30 +67,30 @@ public class DebugPDBPolymerTest extends AbstractPDBPolymerTest {
         pdbPolymer.addAtom(oPDBAtom3, oMono1, oStrand1);
         pdbPolymer.addAtom(oPDBAtom4, oMono2, oStrand2);
         pdbPolymer.addAtom(oPDBAtom5, oMono3, oStrand2);
-        Assert.assertNotNull(pdbPolymer.getAtom(0));
-        Assert.assertNotNull(pdbPolymer.getAtom(1));
-        Assert.assertNotNull(pdbPolymer.getAtom(2));
-        Assert.assertNotNull(pdbPolymer.getAtom(3));
-        Assert.assertNotNull(pdbPolymer.getAtom(4));
-        Assert.assertEquals(oPDBAtom1, pdbPolymer.getAtom(0));
-        Assert.assertEquals(oPDBAtom2, pdbPolymer.getAtom(1));
-        Assert.assertEquals(oPDBAtom3, pdbPolymer.getAtom(2));
-        Assert.assertEquals(oPDBAtom4, pdbPolymer.getAtom(3));
-        Assert.assertEquals(oPDBAtom5, pdbPolymer.getAtom(4));
+        Assertions.assertNotNull(pdbPolymer.getAtom(0));
+        Assertions.assertNotNull(pdbPolymer.getAtom(1));
+        Assertions.assertNotNull(pdbPolymer.getAtom(2));
+        Assertions.assertNotNull(pdbPolymer.getAtom(3));
+        Assertions.assertNotNull(pdbPolymer.getAtom(4));
+        Assertions.assertEquals(oPDBAtom1, pdbPolymer.getAtom(0));
+        Assertions.assertEquals(oPDBAtom2, pdbPolymer.getAtom(1));
+        Assertions.assertEquals(oPDBAtom3, pdbPolymer.getAtom(2));
+        Assertions.assertEquals(oPDBAtom4, pdbPolymer.getAtom(3));
+        Assertions.assertEquals(oPDBAtom5, pdbPolymer.getAtom(4));
 
-        Assert.assertNull(pdbPolymer.getMonomer("0815", "A"));
-        Assert.assertNull(pdbPolymer.getMonomer("0815", "B"));
-        Assert.assertNull(pdbPolymer.getMonomer("0815", ""));
-        Assert.assertNull(pdbPolymer.getStrand(""));
-        Assert.assertNotNull(pdbPolymer.getMonomer("TRP279", "A"));
-        Assert.assertEquals(oMono1, pdbPolymer.getMonomer("TRP279", "A"));
-        Assert.assertEquals(pdbPolymer.getMonomer("TRP279", "A").getAtomCount(), 1);
-        Assert.assertNotNull(pdbPolymer.getMonomer("HOH", "B"));
-        Assert.assertEquals(oMono2, pdbPolymer.getMonomer("HOH", "B"));
-        Assert.assertEquals(pdbPolymer.getMonomer("HOH", "B").getAtomCount(), 1);
-        Assert.assertEquals(pdbPolymer.getStrand("B").getAtomCount(), 2);
-        Assert.assertEquals(pdbPolymer.getStrand("B").getMonomerCount(), 2);
-        Assert.assertNull(pdbPolymer.getStrand("C"));
-        Assert.assertNotNull(pdbPolymer.getStrand("B"));
+        Assertions.assertNull(pdbPolymer.getMonomer("0815", "A"));
+        Assertions.assertNull(pdbPolymer.getMonomer("0815", "B"));
+        Assertions.assertNull(pdbPolymer.getMonomer("0815", ""));
+        Assertions.assertNull(pdbPolymer.getStrand(""));
+        Assertions.assertNotNull(pdbPolymer.getMonomer("TRP279", "A"));
+        Assertions.assertEquals(oMono1, pdbPolymer.getMonomer("TRP279", "A"));
+        Assertions.assertEquals(pdbPolymer.getMonomer("TRP279", "A").getAtomCount(), 1);
+        Assertions.assertNotNull(pdbPolymer.getMonomer("HOH", "B"));
+        Assertions.assertEquals(oMono2, pdbPolymer.getMonomer("HOH", "B"));
+        Assertions.assertEquals(pdbPolymer.getMonomer("HOH", "B").getAtomCount(), 1);
+        Assertions.assertEquals(pdbPolymer.getStrand("B").getAtomCount(), 2);
+        Assertions.assertEquals(pdbPolymer.getStrand("B").getMonomerCount(), 2);
+        Assertions.assertNull(pdbPolymer.getStrand("C"));
+        Assertions.assertNotNull(pdbPolymer.getStrand("B"));
     }
 }
