@@ -18,23 +18,23 @@
  */
 package org.openscience.cdk.dict;
 
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
 
 /**
  * @cdk.module test-dict
  */
-public class DictionaryTest extends AbstractDictionaryTest {
+class DictionaryTest extends AbstractDictionaryTest {
 
-    @Before
-    public void setTestClass() {
+    @BeforeEach
+    void setTestClass() {
         super.setTestClass(new Dictionary());
     }
 
-    @After
-    public void testTestClass() {
-        Assert.assertTrue(getTestClass().getClass().getName().endsWith(".Dictionary"));
+    @AfterEach
+    void testTestClass() {
+        Assertions.assertTrue(getTestClass().getClass().getName().endsWith(".Dictionary"));
     }
 
 }
