@@ -163,7 +163,8 @@ public final class Mappings implements Iterable<int[]> {
     private final Iterable<int[]> iterable;
 
     /** Query and target structures. */
-    private IAtomContainer        query, target;
+    private final IAtomContainer        query;
+    private final IAtomContainer target;
 
     /**
      * Create a fluent mappings instance for the provided query / target and an
@@ -270,12 +271,13 @@ public final class Mappings implements Iterable<int[]> {
     }
 
     /**
-     * Filter the mappings for those which cover a unique set of atoms in the
+     * Filter the mappings for those which cover a unique atoms in the
      * target. The unique atom mappings are a subset of the unique bond
      * matches.
      *
      * @return fluent-api instance
      * @see #uniqueBonds()
+     * @see #exclusiveAtoms()
      */
     public Mappings uniqueAtoms() {
         // we need the unique predicate to be reset for each new iterator -
@@ -283,6 +285,27 @@ public final class Mappings implements Iterable<int[]> {
         return new Mappings(query, target, () -> stream().filter(new UniqueAtomMatches()).iterator());
     }
 
+    /**
+     * Filter the mappings for those which cover an exclusive set of atoms in
+     * the target. If a match overlaps with another one it is not returned. For
+     * example suppose we had the query {@code C~O} and matched against a
+     * carboxylic acid {@code *C(O)=O}, there are <b>2</b> unique matches but
+     * only <b>1</b> exclusive match. If we had two -CO2 groups
+     * ({@code c1ccc(C(O)=O)cc1C(O)=O} there are {@cdoe 4} unique matches and
+     * {@code 2} exclusive matches.
+     * The exclusive atom mappings are therefore a subset of the unique atom
+     * matches.
+     *
+     * @return fluent-api instance
+     * @see #uniqueAtoms()
+     * @see org.openscience.cdk.isomorphism.ExclusiveAtomMatches
+     */
+    public Mappings exclusiveAtoms() {
+        // we need the unique predicate to be reset for each new iterator -
+        // otherwise multiple iterations are always filtered (seen before)
+        return new Mappings(query, target, () -> stream().filter(new ExclusiveAtomMatches()).iterator());
+    }
+
     /**
      * Filter the mappings for those which cover a unique set of bonds in the
      * target.
