@@ -443,7 +443,7 @@ final class QueryStereoFilter implements Predicate<int[]> {
     }
 
     // could be moved into the IStereoElement to allow faster introspection
-    private static enum Type {
+    private enum Type {
         Tetrahedral, Geometric
     }
 }
