@@ -21,14 +21,13 @@ package org.openscience.cdk.graph.invariant;
 
 import java.io.InputStream;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.ChemObject;
 import org.openscience.cdk.aromaticity.Aromaticity;
-import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
@@ -52,24 +51,24 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
  *
  * @cdk.module test-reaction
  */
-public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
+class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
     private static IChemObjectBuilder      builder;
     private static LonePairElectronChecker lpcheck;
 
-    private static ILoggingTool            logger = LoggingToolFactory
+    private static final ILoggingTool            logger = LoggingToolFactory
                                                           .createLoggingTool(ConjugatedPiSystemsDetectorTest.class);
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         builder = SilentChemObjectBuilder.getInstance();
         lpcheck = new LonePairElectronChecker();
     }
 
     @Test
-    public void testDetectButadiene() throws Exception {
+    void testDetectButadiene() throws Exception {
         logger.info("Entering testDetectButadiene.");
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         String filename = "butadiene.cml";
         mol = readCMLMolecule(filename);
 
@@ -78,17 +77,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac.getAtomCount());
-        Assert.assertEquals(3, ac.getBondCount());
+        Assertions.assertEquals(4, ac.getAtomCount());
+        Assertions.assertEquals(3, ac.getBondCount());
 
         for (int i = 0; i < ac.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac.getAtom(i)));
         }
 
         for (int i = 0; i < ac.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac.getBond(i)));
         }
     }
 
@@ -98,9 +97,9 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testDetectNaphtalene() throws Exception {
+    void testDetectNaphtalene() throws Exception {
         logger.info("Entering testDetectNaphtalene.");
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         String filename = "naphtalene.cml";
         mol = readCMLMolecule(filename);
 
@@ -109,17 +108,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac = acSet.getAtomContainer(0);
-        Assert.assertEquals(10, ac.getAtomCount());
-        Assert.assertEquals(11, ac.getBondCount());
+        Assertions.assertEquals(10, ac.getAtomCount());
+        Assertions.assertEquals(11, ac.getBondCount());
 
         for (int i = 0; i < ac.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac.getAtom(i)));
         }
 
         for (int i = 0; i < ac.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac.getBond(i)));
         }
     }
 
@@ -129,9 +128,9 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testDetectToluene() throws Exception {
+    void testDetectToluene() throws Exception {
         logger.info("Entering testDetectToluene.");
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         String filename = "toluene.cml";
         mol = readCMLMolecule(filename);
 
@@ -140,17 +139,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac = acSet.getAtomContainer(0);
-        Assert.assertEquals(6, ac.getAtomCount());
-        Assert.assertEquals(6, ac.getBondCount());
+        Assertions.assertEquals(6, ac.getAtomCount());
+        Assertions.assertEquals(6, ac.getBondCount());
 
         for (int i = 0; i < ac.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac.getAtom(i)));
         }
 
         for (int i = 0; i < ac.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac.getBond(i)));
         }
     }
 
@@ -160,9 +159,9 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testNonConnectedPiSystems() throws Exception {
+    void testNonConnectedPiSystems() throws Exception {
         logger.info("Entering testNonConnectedPiSystems.");
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         String filename = "nonConnectedPiSystems.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLReader reader = new MDLReader(ins);
@@ -173,29 +172,29 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(2, acSet.getAtomContainerCount());
+        Assertions.assertEquals(2, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac1.getAtomCount());
-        Assert.assertEquals(3, ac1.getBondCount());
+        Assertions.assertEquals(4, ac1.getAtomCount());
+        Assertions.assertEquals(3, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac1.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
 
         IAtomContainer ac2 = acSet.getAtomContainer(1);
-        Assert.assertEquals(4, ac2.getAtomCount());
-        Assert.assertEquals(3, ac2.getBondCount());
+        Assertions.assertEquals(4, ac2.getAtomCount());
+        Assertions.assertEquals(3, ac2.getBondCount());
 
         for (int i = 0; i < ac2.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac2.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac2.getAtom(i)));
         }
 
         for (int i = 0; i < ac2.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac2.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac2.getBond(i)));
         }
     }
 
@@ -205,9 +204,9 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testPiSystemWithCarbokation() throws Exception {
+    void testPiSystemWithCarbokation() throws Exception {
         logger.info("Entering testPiSystemWithCarbokation.");
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         String filename = "piSystemWithCarbokation.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLReader reader = new MDLReader(ins);
@@ -219,26 +218,26 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(2, acSet.getAtomContainerCount());
+        Assertions.assertEquals(2, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac1.getAtomCount());
-        Assert.assertEquals(3, ac1.getBondCount());
+        Assertions.assertEquals(4, ac1.getAtomCount());
+        Assertions.assertEquals(3, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++)
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
 
         for (int i = 0; i < ac1.getBondCount(); i++)
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
 
         IAtomContainer ac2 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac2.getAtomCount());
-        Assert.assertEquals(3, ac2.getBondCount());
+        Assertions.assertEquals(4, ac2.getAtomCount());
+        Assertions.assertEquals(3, ac2.getBondCount());
 
         for (int i = 0; i < ac2.getAtomCount(); i++)
-            Assert.assertTrue(mol.contains(ac2.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac2.getAtom(i)));
 
         for (int i = 0; i < ac2.getBondCount(); i++)
-            Assert.assertTrue(mol.contains(ac2.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac2.getBond(i)));
 
     }
 
@@ -248,9 +247,9 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testPiSystemWithCumulativeDB() throws Exception {
+    void testPiSystemWithCumulativeDB() throws Exception {
         logger.info("Entering testPiSystemWithCumulativeDB.");
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         String filename = "piSystemCumulative.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLReader reader = new MDLReader(ins);
@@ -262,29 +261,29 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(2, acSet.getAtomContainerCount());
+        Assertions.assertEquals(2, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac1.getAtomCount());
-        Assert.assertEquals(3, ac1.getBondCount());
+        Assertions.assertEquals(4, ac1.getAtomCount());
+        Assertions.assertEquals(3, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac1.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
 
         IAtomContainer ac2 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac2.getAtomCount());
-        Assert.assertEquals(3, ac2.getBondCount());
+        Assertions.assertEquals(4, ac2.getAtomCount());
+        Assertions.assertEquals(3, ac2.getBondCount());
 
         for (int i = 0; i < ac2.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac2.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
 
     }
@@ -297,8 +296,8 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testAceticAcid() throws Exception {
-        IAtomContainer mol = null;
+    void testAceticAcid() throws Exception {
+        IAtomContainer mol;
         mol = (new SmilesParser(builder)).parseSmiles("CC(=O)O");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         addImplicitHydrogens(mol);
@@ -307,17 +306,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(3, ac1.getAtomCount());
-        Assert.assertEquals(2, ac1.getBondCount());
+        Assertions.assertEquals(3, ac1.getAtomCount());
+        Assertions.assertEquals(2, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac1.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
 
     }
@@ -328,8 +327,8 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testNN_dimethylaniline_cation() throws Exception {
-        IAtomContainer mol = null;
+    void testNN_dimethylaniline_cation() throws Exception {
+        IAtomContainer mol;
         String filename = "NN_dimethylaniline.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
@@ -343,10 +342,10 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(6, ac1.getAtomCount());
-        Assert.assertEquals(5, ac1.getBondCount());
+        Assertions.assertEquals(6, ac1.getAtomCount());
+        Assertions.assertEquals(5, ac1.getBondCount());
 
     }
 
@@ -356,7 +355,7 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void test1_fluorobutadienene() throws Exception {
+    void test1_fluorobutadienene() throws Exception {
         IAtomContainer mol = (new SmilesParser(builder)).parseSmiles("FC=CC=C");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         addImplicitHydrogens(mol);
@@ -365,10 +364,10 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(5, ac1.getAtomCount());
-        Assert.assertEquals(4, ac1.getBondCount());
+        Assertions.assertEquals(5, ac1.getAtomCount());
+        Assertions.assertEquals(4, ac1.getBondCount());
 
     }
 
@@ -380,8 +379,8 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testEthyne_difluoro() throws Exception {
-        IAtomContainer mol = null;
+    void testEthyne_difluoro() throws Exception {
+        IAtomContainer mol;
         mol = (new SmilesParser(builder)).parseSmiles("FC#CF");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         addImplicitHydrogens(mol);
@@ -390,10 +389,10 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac1.getAtomCount());
-        Assert.assertEquals(3, ac1.getBondCount());
+        Assertions.assertEquals(4, ac1.getAtomCount());
+        Assertions.assertEquals(3, ac1.getBondCount());
 
     }
 
@@ -405,7 +404,7 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void test3Aminomethane_cation() throws Exception {
+    void test3Aminomethane_cation() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         mol.addAtom(builder.newInstance(IAtom.class, "N"));
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -435,10 +434,10 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac1.getAtomCount());
-        Assert.assertEquals(3, ac1.getBondCount());
+        Assertions.assertEquals(4, ac1.getAtomCount());
+        Assertions.assertEquals(3, ac1.getBondCount());
 
     }
 
@@ -450,24 +449,24 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     private IAtomContainer readCMLMolecule(String filename) throws Exception {
-        IAtomContainer mol = null;
+        IAtomContainer mol;
         logger.debug("Filename: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         CMLReader reader = new CMLReader(ins);
 
-        IChemFile file = (IChemFile) reader.read(new ChemFile());
-        Assert.assertNotNull(file);
-        Assert.assertEquals(1, file.getChemSequenceCount());
+        IChemFile file = reader.read(new ChemFile());
+        Assertions.assertNotNull(file);
+        Assertions.assertEquals(1, file.getChemSequenceCount());
         IChemSequence sequence = file.getChemSequence(0);
-        Assert.assertNotNull(sequence);
-        Assert.assertEquals(1, sequence.getChemModelCount());
+        Assertions.assertNotNull(sequence);
+        Assertions.assertEquals(1, sequence.getChemModelCount());
         IChemModel chemModel = sequence.getChemModel(0);
-        Assert.assertNotNull(chemModel);
+        Assertions.assertNotNull(chemModel);
         IAtomContainerSet moleculeSet = chemModel.getMoleculeSet();
-        Assert.assertNotNull(moleculeSet);
-        Assert.assertEquals(1, moleculeSet.getAtomContainerCount());
+        Assertions.assertNotNull(moleculeSet);
+        Assertions.assertEquals(1, moleculeSet.getAtomContainerCount());
         mol = moleculeSet.getAtomContainer(0);
-        Assert.assertNotNull(mol);
+        Assertions.assertNotNull(mol);
 
         return mol;
 
@@ -481,8 +480,8 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *@return    Description of the Return Value
      */
     @Test
-    public void testCyanoallene() throws Exception {
-        IAtomContainer mol = null;
+    void testCyanoallene() throws Exception {
+        IAtomContainer mol;
         mol = (new SmilesParser(builder)).parseSmiles("C=C=CC#N");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         addImplicitHydrogens(mol);
@@ -491,17 +490,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(4, ac1.getAtomCount());
-        Assert.assertEquals(3, ac1.getBondCount());
+        Assertions.assertEquals(4, ac1.getAtomCount());
+        Assertions.assertEquals(3, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac1.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
 
     }
@@ -510,7 +509,7 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *  A unit test for JUnit with [H]C([H])=C([H])[C+]([H])[H]
      */
     @Test
-    public void testChargeWithProtonExplicit() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testChargeWithProtonExplicit() throws java.lang.Exception {
         SmilesParser sp = new SmilesParser(builder);
         IAtomContainer mol = sp.parseSmiles("[H]C([H])=C([H])[C+]([H])[H]");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -519,17 +518,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(3, ac1.getAtomCount());
-        Assert.assertEquals(2, ac1.getBondCount());
+        Assertions.assertEquals(3, ac1.getAtomCount());
+        Assertions.assertEquals(2, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac1.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
     }
 
@@ -537,7 +536,7 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
      *  A unit test for JUnit with [H]C([H])=C([H])[C+]([H])[H]
      */
     @Test
-    public void testChargeWithProtonImplicit() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testChargeWithProtonImplicit() throws java.lang.Exception {
         SmilesParser sp = new SmilesParser(builder);
         IAtomContainer mol = sp.parseSmiles("C=C[C+]");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -546,17 +545,17 @@ public class ConjugatedPiSystemsDetectorTest extends CDKTestCase {
 
         IAtomContainerSet acSet = ConjugatedPiSystemsDetector.detect(mol);
 
-        Assert.assertEquals(1, acSet.getAtomContainerCount());
+        Assertions.assertEquals(1, acSet.getAtomContainerCount());
         IAtomContainer ac1 = acSet.getAtomContainer(0);
-        Assert.assertEquals(3, ac1.getAtomCount());
-        Assert.assertEquals(2, ac1.getBondCount());
+        Assertions.assertEquals(3, ac1.getAtomCount());
+        Assertions.assertEquals(2, ac1.getBondCount());
 
         for (int i = 0; i < ac1.getAtomCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getAtom(i)));
+            Assertions.assertTrue(mol.contains(ac1.getAtom(i)));
         }
 
         for (int i = 0; i < ac1.getBondCount(); i++) {
-            Assert.assertTrue(mol.contains(ac1.getBond(i)));
+            Assertions.assertTrue(mol.contains(ac1.getBond(i)));
         }
     }
 }
