@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.reaction.type;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.atomtype.CDKAtomTypeMatcher;
@@ -38,6 +38,7 @@ import org.openscience.cdk.reaction.IReactionProcess;
 import org.openscience.cdk.reaction.ReactionProcessTest;
 import org.openscience.cdk.reaction.type.parameters.IParameterReact;
 import org.openscience.cdk.reaction.type.parameters.SetReactionCenter;
+import org.openscience.cdk.tools.LoggingToolFactory;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 
 import java.util.ArrayList;
@@ -54,12 +55,12 @@ import java.util.List;
  */
 public class PiBondingMovementReactionTest extends ReactionProcessTest {
 
-    private IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
+    private final IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
 
     /**
      *  The JUnit setup method
      */
-    public PiBondingMovementReactionTest() throws Exception {
+    PiBondingMovementReactionTest() throws Exception {
         setReaction(PiBondingMovementReaction.class);
     }
 
@@ -67,9 +68,9 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
      *  The JUnit setup method
      */
     @Test
-    public void testPiBondingMovementReaction() {
+    void testPiBondingMovementReaction() {
         IReactionProcess type = new PiBondingMovementReaction();
-        Assert.assertNotNull(type);
+        Assertions.assertNotNull(type);
     }
 
     /**
@@ -113,13 +114,13 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
         type.setParameterList(paramList);
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(1, setOfReactions.getReactionCount());
-        Assert.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
+        Assertions.assertEquals(1, setOfReactions.getReactionCount());
+        Assertions.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
 
         IAtomContainer product2 = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
 
         IQueryAtomContainer queryAtom = QueryAtomContainerCreator.createSymbolAndChargeQueryContainer(product2);
-        Assert.assertTrue(new UniversalIsomorphismTester().isIsomorph(molecule, queryAtom));
+        Assertions.assertTrue(new UniversalIsomorphismTester().isIsomorph(molecule, queryAtom));
 
     }
 
@@ -131,7 +132,7 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
      * InChI=1/C8H10/c1-7-5-3-4-6-8(7)2/h3-6H,1-2H3
      */
     @Test
-    public void testAutomaticSearchCentreActiveExample1() throws Exception {
+    void testAutomaticSearchCentreActiveExample1() throws Exception {
         IReactionProcess type = new PiBondingMovementReaction();
         // C1=C(C)-C(C)=C-C=C1
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
@@ -167,8 +168,8 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
         type.setParameterList(paramList);
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(1, setOfReactions.getReactionCount());
-        Assert.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
+        Assertions.assertEquals(1, setOfReactions.getReactionCount());
+        Assertions.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
 
         IAtomContainer product2 = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
 
@@ -196,7 +197,7 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
         makeSureAtomTypesAreRecognized(molecule2);
 
         IQueryAtomContainer queryAtom = QueryAtomContainerCreator.createSymbolAndChargeQueryContainer(product2);
-        Assert.assertTrue(new UniversalIsomorphismTester().isIsomorph(molecule2, queryAtom));
+        Assertions.assertTrue(new UniversalIsomorphismTester().isIsomorph(molecule2, queryAtom));
 
     }
 
@@ -214,7 +215,7 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
      * InChI=1/C11H10/c1-9-6-7-10-4-2-3-5-11(10)8-9/h2-8H,1H3
      */
     @Test
-    public void testDoubleRingConjugated() throws Exception {
+    void testDoubleRingConjugated() throws Exception {
         IReactionProcess type = new PiBondingMovementReaction();
         // C1=CC(=CC2=C1C=CC=C2)C
         IAtomContainerSet setOfReactants = getExampleReactants();
@@ -227,13 +228,13 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
         type.setParameterList(paramList);
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(2, setOfReactions.getReactionCount());
-        Assert.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
+        Assertions.assertEquals(2, setOfReactions.getReactionCount());
+        Assertions.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
 
         IAtomContainer product1 = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
         IAtomContainer molecule1 = getExpectedProducts().getAtomContainer(0);
 
-        Assert.assertEquals(1, setOfReactions.getReaction(1).getProductCount());
+        Assertions.assertEquals(1, setOfReactions.getReaction(1).getProductCount());
 
         IAtomContainer product2 = setOfReactions.getReaction(1).getProducts().getAtomContainer(0);
         //C1=CC(=CC2=CC=CC=C12)C
@@ -268,7 +269,7 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
 
         // order depends on ring perception order (may change between versions) we check both
         // combinations just in case
-        Assert.assertTrue((matches(molecule2, product1) && matches(molecule1, product2))
+        Assertions.assertTrue((matches(molecule2, product1) && matches(molecule1, product2))
                 || (matches(molecule1, product1) && matches(molecule2, product2)));
 
     }
@@ -284,7 +285,7 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
      *
      */
     @Test
-    public void testDoubleRingConjugated2() throws Exception {
+    void testDoubleRingConjugated2() throws Exception {
         IReactionProcess type = new PiBondingMovementReaction();
         // C1=CC(=CC2=C1C=CC=C2)C
 
@@ -307,15 +308,15 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
         type.setParameterList(paramList);
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(1, setOfReactions.getReactionCount());
-        Assert.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
+        Assertions.assertEquals(1, setOfReactions.getReactionCount());
+        Assertions.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
 
         IAtomContainer product2 = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
 
         IAtomContainer molecule2 = getExpectedProducts().getAtomContainer(0);
 
         IQueryAtomContainer queryAtom = QueryAtomContainerCreator.createSymbolAndChargeQueryContainer(product2);
-        Assert.assertTrue(new UniversalIsomorphismTester().isIsomorph(molecule2, queryAtom));
+        Assertions.assertTrue(new UniversalIsomorphismTester().isIsomorph(molecule2, queryAtom));
 
     }
 
@@ -359,7 +360,8 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
             AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
             makeSureAtomTypesAreRecognized(molecule);
         } catch (Exception e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(getClass())
+                              .error("Unexpected Error:", e);
         }
 
         setOfReactants.addAtomContainer(molecule);
@@ -406,7 +408,8 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
             AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
             makeSureAtomTypesAreRecognized(molecule);
         } catch (Exception e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(getClass())
+                              .error("Unexpected Error:", e);
         }
 
         setOfProducts.addAtomContainer(molecule);
@@ -424,7 +427,7 @@ public class PiBondingMovementReactionTest extends ReactionProcessTest {
         CDKAtomTypeMatcher matcher = CDKAtomTypeMatcher.getInstance(molecule.getBuilder());
         while (atoms.hasNext()) {
             IAtom nextAtom = atoms.next();
-            Assert.assertNotNull("Missing atom type for: " + nextAtom, matcher.findMatchingAtomType(molecule, nextAtom));
+            Assertions.assertNotNull(matcher.findMatchingAtomType(molecule, nextAtom), "Missing atom type for: " + nextAtom);
         }
     }
 }
