@@ -494,7 +494,7 @@ public class Atom extends AtomType implements IAtom, Serializable, Cloneable {
      */
     @Override
     public String toString() {
-        StringBuffer stringContent = new StringBuffer(64);
+        StringBuilder stringContent = new StringBuilder(64);
         stringContent.append("Atom(").append(hashCode());
         if (getSymbol() != null) {
             stringContent.append(", S:").append(getSymbol());
