@@ -22,19 +22,16 @@
  */
 package org.openscience.cdk.silent;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractAtomContainerTest;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
-import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.ILonePair;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertNull;
 import static org.hamcrest.MatcherAssert.assertThat;
 
 /**
@@ -42,28 +39,22 @@ import static org.hamcrest.MatcherAssert.assertThat;
  *
  * @cdk.module test-silent
  */
-public class AtomContainer2Test extends AbstractAtomContainerTest {
+class AtomContainer2Test extends AbstractAtomContainerTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new AtomContainer2();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(AtomContainer2::new);
     }
 
 
     @Test
-    public void testAtomContainer_int_int_int_int() {
+    void testAtomContainer_int_int_int_int() {
         // create an empty container with predefined
         // array lengths
         IAtomContainer container = new AtomContainer2(5, 6, 1, 2);
 
-        Assert.assertEquals(0, container.getAtomCount());
-        Assert.assertEquals(0, container.getElectronContainerCount());
+        Assertions.assertEquals(0, container.getAtomCount());
+        Assertions.assertEquals(0, container.getElectronContainerCount());
 
         // test whether the ElectronContainer is correctly initialized
         IAtom c1 = container.getBuilder().newInstance(IAtom.class, "C");
@@ -77,12 +68,12 @@ public class AtomContainer2Test extends AbstractAtomContainerTest {
     }
 
     @Test
-    public void testAtomContainer() {
+    void testAtomContainer() {
         // create an empty container with in the constructor defined array lengths
         IAtomContainer container = new AtomContainer2();
 
-        Assert.assertEquals(0, container.getAtomCount());
-        Assert.assertEquals(0, container.getBondCount());
+        Assertions.assertEquals(0, container.getAtomCount());
+        Assertions.assertEquals(0, container.getBondCount());
 
         // test whether the ElectronContainer is correctly initialized
         IAtom c1 = container.getBuilder().newInstance(IAtom.class, "C");
@@ -96,7 +87,7 @@ public class AtomContainer2Test extends AbstractAtomContainerTest {
     }
 
     @Test
-    public void testAtomContainer_IAtomContainer() {
+    void testAtomContainer_IAtomContainer() {
         IAtomContainer acetone = newChemObject().getBuilder().newInstance(IAtomContainer.class);
         IAtom c1 = acetone.getBuilder().newInstance(IAtom.class, "C");
         IAtom c2 = acetone.getBuilder().newInstance(IAtom.class, "C");
@@ -114,8 +105,8 @@ public class AtomContainer2Test extends AbstractAtomContainerTest {
         acetone.addBond(b3);
 
         IAtomContainer container = new AtomContainer2(acetone);
-        Assert.assertEquals(4, container.getAtomCount());
-        Assert.assertEquals(3, container.getBondCount());
+        Assertions.assertEquals(4, container.getAtomCount());
+        Assertions.assertEquals(3, container.getBondCount());
     }
 
     // Overwrite default methods: no notifications are expected!
@@ -199,7 +190,7 @@ public class AtomContainer2Test extends AbstractAtomContainerTest {
     }
 
     @Test
-    public void testAtomAdjacencyOnClone() throws CloneNotSupportedException {
+    void testAtomAdjacencyOnClone() throws CloneNotSupportedException {
         IAtomContainer org = (IAtomContainer) newChemObject();
         IAtom          a1 = org.getBuilder().newAtom();
         IAtom          a2 = org.getBuilder().newAtom();
@@ -216,7 +207,7 @@ public class AtomContainer2Test extends AbstractAtomContainerTest {
     }
 
     @Test
-    public void testAtomGetBond() {
+    void testAtomGetBond() {
         IAtomContainer mol = (IAtomContainer) newChemObject();
         IAtom          a1 = mol.getBuilder().newAtom();
         IAtom          a2 = mol.getBuilder().newAtom();
@@ -233,6 +224,6 @@ public class AtomContainer2Test extends AbstractAtomContainerTest {
                    is(mol.getAtom(0).getBond(mol.getAtom(1))));
         assertThat(mol.getBond(1),
                    is(mol.getAtom(1).getBond(mol.getAtom(2))));
-        assertNull(mol.getAtom(0).getBond(mol.getAtom(2)));
+        Assertions.assertNull(mol.getAtom(0).getBond(mol.getAtom(2)));
     }
 }
