@@ -30,6 +30,7 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IBond.Order;
+import org.openscience.cdk.interfaces.IElement;
 
 import javax.vecmath.Point2d;
 
@@ -217,8 +218,8 @@ public class BondTools {
 
         if (container.getBond(atom, parent) != null) {
             if (container.getBond(atom, parent).getOrder() == Order.DOUBLE
-                    && (lengthAtom == 3 || (lengthAtom == 2 && "N".equals(atom.getSymbol())))
-                    && (lengthParent == 3 || (lengthParent == 2 && "N".equals(parent.getSymbol())))) {
+                    && (lengthAtom == 3 || (lengthAtom == 2 && atom.getAtomicNumber() == IElement.N))
+                    && (lengthParent == 3 || (lengthParent == 2 && parent.getAtomicNumber() == IElement.N))) {
                 List<IAtom> atoms = container.getConnectedAtomsList(atom);
                 IAtom one = null;
                 IAtom two = null;
@@ -230,9 +231,9 @@ public class BondTools {
                     }
                 }
                 String[] morgannumbers = MorganNumbersTools.getMorganNumbersWithElementSymbol(container);
-                if ((one != null && two == null && "N".equals(atom.getSymbol()) && Math.abs(giveAngleBothMethods(
+                if ((one != null && two == null && atom.getAtomicNumber() == IElement.N && Math.abs(giveAngleBothMethods(
                         parent, atom, one, true)) > Math.PI / 10)
-                        || (!"N".equals(atom.getSymbol()) && one != null && two != null && !morgannumbers[container
+                        || (atom.getAtomicNumber() != IElement.N && one != null && two != null && !morgannumbers[container
                                 .indexOf(one)].equals(morgannumbers[container.indexOf(two)]))) {
                     return (true);
                 } else {
@@ -264,7 +265,7 @@ public class BondTools {
 
         int lengthAtom = container.getConnectedAtomsList(a).size() + hcount;
 
-        if (lengthAtom != 3 && (lengthAtom != 2 && !"N".equals(a.getSymbol()))) {
+        if (lengthAtom != 3 && (lengthAtom != 2 && a.getAtomicNumber() != IElement.N)) {
             return (false);
         }
         List<IAtom> atoms = container.getConnectedAtomsList(a);
@@ -286,11 +287,11 @@ public class BondTools {
         }
         String[] morgannumbers = MorganNumbersTools.getMorganNumbersWithElementSymbol(container);
         if (one != null
-                && ((!"N".equals(a.getSymbol())
+                && ((a.getAtomicNumber() != IElement.N
                         && two != null
                         && !morgannumbers[container.indexOf(one)].equals(morgannumbers[container
                                 .indexOf(two)]) && doubleBond && doubleBondConfiguration[container.indexOf(container.getBond(
-                        a, nextAtom))]) || (doubleBond && "N".equals(a.getSymbol()) && Math.abs(giveAngleBothMethods(
+                        a, nextAtom))]) || (doubleBond && a.getAtomicNumber() == IElement.N && Math.abs(giveAngleBothMethods(
                         nextAtom, a, parent, true)) > Math.PI / 10))) {
             return (true);
         } else {
@@ -421,7 +422,7 @@ public class BondTools {
         }
         if (differentAtoms != atoms.size()) {
             long[] morgannumbers = MorganNumbersTools.getMorganNumbers(container);
-            List<String> differentSymbols = new ArrayList<String>();
+            List<String> differentSymbols = new ArrayList<>();
             for (IAtom atom : atoms) {
                 if (!differentSymbols.contains(atom.getSymbol())) {
                     differentSymbols.add(atom.getSymbol());
@@ -441,7 +442,7 @@ public class BondTools {
             List<Long>[] symbolsMorganNumbers = new ArrayList[symbolsWithDifferentMorganNumbers.length];
             for (int i = 0; i < symbolsWithDifferentMorganNumbers.length; i++) {
                 symbolsWithDifferentMorganNumbers[i] = true;
-                symbolsMorganNumbers[i] = new ArrayList<Long>();
+                symbolsMorganNumbers[i] = new ArrayList<>();
             }
             for (IAtom atom : atoms) {
                 int elementNumber = differentSymbols.indexOf(atom.getSymbol());
@@ -510,7 +511,7 @@ public class BondTools {
      */
     public static boolean stereosAreOpposite(IAtomContainer container, IAtom atom) {
         List<IAtom> atoms = container.getConnectedAtomsList(atom);
-        TreeMap<Double, Integer> hm = new TreeMap<Double, Integer>();
+        TreeMap<Double, Integer> hm = new TreeMap<>();
         for (int i = 1; i < atoms.size(); i++) {
             hm.put(giveAngle(atom, atoms.get(0), atoms.get(i)), i);
         }
@@ -559,7 +560,7 @@ public class BondTools {
                         up++;
                     } else if (stereo == IBond.Stereo.DOWN) {
                         down++;
-                    } else if (stereo == IBond.Stereo.NONE && "H".equals(conAtom.getSymbol())) {
+                    } else if (stereo == IBond.Stereo.NONE && conAtom.getAtomicNumber() == IElement.H) {
                         h = conAtom;
                         hs++;
                     } else {
