@@ -30,6 +30,7 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemModel;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IReaction;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.sgroup.Sgroup;
@@ -48,6 +49,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Comparator;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -71,7 +73,7 @@ import java.util.TreeMap;
  */
 public final class GeometryUtil {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(GeometryUtil.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(GeometryUtil.class);
 
     /**
      * Provides the coverage of coordinates for this molecule.
@@ -79,7 +81,7 @@ public final class GeometryUtil {
      * @see GeometryUtil#get2DCoordinateCoverage(org.openscience.cdk.interfaces.IAtomContainer)
      * @see GeometryUtil#get3DCoordinateCoverage(org.openscience.cdk.interfaces.IAtomContainer)
      */
-    public static enum CoordinateCoverage {
+    public enum CoordinateCoverage {
 
         /**
          * All atoms have coordinates.
@@ -151,8 +153,8 @@ public final class GeometryUtil {
      */
     public static void scaleMolecule(IAtomContainer atomCon, double[] areaDim, double fillFactor) {
         double[] molDim = get2DDimension(atomCon);
-        double widthFactor = (double) areaDim[0] / (double) molDim[0];
-        double heightFactor = (double) areaDim[1] / (double) molDim[1];
+        double widthFactor = areaDim[0] / molDim[0];
+        double heightFactor = areaDim[1] / molDim[1];
         double scaleFactor = Math.min(widthFactor, heightFactor) * fillFactor;
         scaleMolecule(atomCon, scaleFactor);
     }
@@ -481,6 +483,8 @@ public final class GeometryUtil {
      */
     public static void translate2DCentreOfMassTo(IAtomContainer atomCon, Point2d p) {
         Point2d com = get2DCentreOfMass(atomCon);
+        if (com == null)
+            throw new IllegalArgumentException("Null centre of mass, due to unset exact mass?");
         Vector2d translation = new Vector2d(p.x - com.x, p.y - com.y);
         for (IAtom atom : atomCon.atoms()) {
             if (atom.getPoint2d() != null) {
@@ -508,6 +512,8 @@ public final class GeometryUtil {
                 length++;
             }
         }
+        if (length == 0)
+            return new Point2d(0,0);
         return new Point2d(xsum / (double) length, ysum / (double) length);
     }
 
@@ -532,6 +538,8 @@ public final class GeometryUtil {
             }
             ++length;
         }
+        if (length == 0)
+            return new Point2d(0,0);
         return new Point2d(xsum / (double) length, ysum / (double) length);
     }
 
@@ -578,7 +586,8 @@ public final class GeometryUtil {
             xsum += mass * a.getPoint2d().x;
             ysum += mass * a.getPoint2d().y;
         }
-
+        if (totalmass == 0)
+            return new Point2d(0,0);
         return new Point2d(xsum / totalmass, ysum / totalmass);
     }
 
@@ -601,6 +610,8 @@ public final class GeometryUtil {
                 counter++;
             }
         }
+        if (counter == 0)
+            return new Point2d(0,0);
         return new Point2d(centerX / (counter), centerY / (counter));
     }
 
@@ -657,7 +668,8 @@ public final class GeometryUtil {
             ysum += mass * a.getPoint3d().y;
             zsum += mass * a.getPoint3d().z;
         }
-
+        if (totalmass == 0)
+            return new Point3d(0,0,0);
         return new Point3d(xsum / totalmass, ysum / totalmass, zsum / totalmass);
     }
 
@@ -682,6 +694,8 @@ public final class GeometryUtil {
                 counter++;
             }
         }
+        if (counter == 0)
+            return new Point3d(0,0,0);
         return new Point3d(centerX / (counter), centerY / (counter), centerZ / (counter));
     }
 
@@ -1017,6 +1031,8 @@ public final class GeometryUtil {
                 bondLengthSum += getLength2D(bond);
             }
         }
+        if (bondCounter == 0)
+            return 0;
         return bondLengthSum / bondCounter;
     }
 
@@ -1272,6 +1288,8 @@ public final class GeometryUtil {
                         + Math.pow(atom1.getPoint2d().y - atom2.getPoint2d().y, 2));
             }
         }
+        if (counter == 0)
+            return 1;
         bondlength = bondlength / counter;
         ratio = desiredBondLength / bondlength;
         return ratio;
@@ -1343,7 +1361,7 @@ public final class GeometryUtil {
         if (originalPoint == null) {
             throw new CDKException("No point3d, but findClosestInSpace is working on point3ds");
         }
-        Map<Double, IAtom> atomsByDistance = new TreeMap<Double, IAtom>();
+        Map<Double, IAtom> atomsByDistance = new TreeMap<>();
         for (IAtom atom : container.atoms()) {
             if (!atom.equals(startAtom)) {
                 if (atom.getPoint3d() == null) {
@@ -1356,7 +1374,7 @@ public final class GeometryUtil {
         // FIXME: should there not be some sort here??
         Set<Double> keySet = atomsByDistance.keySet();
         Iterator<Double> keyIter = keySet.iterator();
-        List<IAtom> returnValue = new ArrayList<IAtom>();
+        List<IAtom> returnValue = new ArrayList<>();
         int i = 0;
         while (keyIter.hasNext() && i < max) {
             returnValue.add(atomsByDistance.get(keyIter.next()));
@@ -1416,8 +1434,8 @@ public final class GeometryUtil {
                 firstAC = secondAC.clone();
                 secondAC = tmp.clone();
             } catch (CloneNotSupportedException e) {
-                // TODO Auto-generated catch block
-                e.printStackTrace();
+                LoggingToolFactory.createLoggingTool(GeometryUtil.class)
+                                  .warn("Unexpected Error:", e);
             }
         }
     }
@@ -1427,7 +1445,7 @@ public final class GeometryUtil {
         IAtom firstAtom = firstAC.getAtom(posFirstAtom);
         IAtom secondAtom = secondAC.getAtom(posSecondAtom);
         // XXX: floating point comparision!
-        return firstAtom.getSymbol().equals(secondAtom.getSymbol())
+        return firstAtom.getAtomicNumber().equals(secondAtom.getAtomicNumber())
                 && firstAC.getConnectedAtomsList(firstAtom).size() == secondAC.getConnectedAtomsList(secondAtom).size()
                 && firstAtom.getBondOrderSum().equals(secondAtom.getBondOrderSum())
                 && firstAtom.getMaxBondOrder() == secondAtom.getMaxBondOrder();
@@ -1459,8 +1477,8 @@ public final class GeometryUtil {
         List<IAtom> connectedAtoms;
         double sum = 0;
         double n = 0;
-        double distance1 = 0;
-        double distance2 = 0;
+        double distance1;
+        double distance2;
         setVisitedFlagsToFalse(firstAtomContainer);
         setVisitedFlagsToFalse(secondAtomContainer);
         while (firstAtoms.hasNext()) {
@@ -1469,15 +1487,14 @@ public final class GeometryUtil {
             centerAtomSecondMolecule = secondAtomContainer.getAtom(mappedAtoms.get(firstAtomContainer
                     .indexOf(centerAtomFirstMolecule)));
             connectedAtoms = firstAtomContainer.getConnectedAtomsList(centerAtomFirstMolecule);
-            for (int i = 0; i < connectedAtoms.size(); i++) {
-                IAtom conAtom = connectedAtoms.get(i);
+            for (IAtom conAtom : connectedAtoms) {
                 //this step is built to know if the program has already calculate a bond length (so as not to have duplicate values)
                 if (!conAtom.getFlag(CDKConstants.VISITED)) {
                     if (Coords3d) {
                         distance1 = centerAtomFirstMolecule.getPoint3d().distance(conAtom.getPoint3d());
                         distance2 = centerAtomSecondMolecule.getPoint3d().distance(
                                 secondAtomContainer.getAtom(mappedAtoms.get(firstAtomContainer.indexOf(conAtom)))
-                                        .getPoint3d());
+                                                   .getPoint3d());
                         sum = sum + Math.pow((distance1 - distance2), 2);
                         n++;
                     } else {
@@ -1493,6 +1510,8 @@ public final class GeometryUtil {
         }
         setVisitedFlagsToFalse(firstAtomContainer);
         setVisitedFlagsToFalse(secondAtomContainer);
+        if (n == 0)
+            return 0;
         return Math.sqrt(sum / n);
     }
 
@@ -1542,6 +1561,8 @@ public final class GeometryUtil {
                 }
             }//if
         }
+        if (n == 0)
+            return 0;
         return Math.sqrt(sum / n);
     }
 
@@ -1584,7 +1605,7 @@ public final class GeometryUtil {
             Map<Integer, Integer> mappedAtoms, boolean Coords3d) throws CDKException {
         //logger.debug("**** GT getAllAtomRMSD ****");
         double sum = 0;
-        double RMSD;
+        double rmsd;
         Iterator<Integer> firstAtoms = mappedAtoms.keySet().iterator();
         int firstAtomNumber;
         int secondAtomNumber;
@@ -1611,8 +1632,11 @@ public final class GeometryUtil {
                 throw new CDKException(ex.getMessage(), ex);
             }
         }
-        RMSD = Math.sqrt(sum / n);
-        return RMSD;
+        if (n == 0)
+            rmsd = 0;
+        else
+            rmsd = Math.sqrt(sum / n);
+        return rmsd;
     }
 
     /**
@@ -1630,7 +1654,7 @@ public final class GeometryUtil {
             Map<Integer, Integer> mappedAtoms, boolean hetAtomOnly, boolean Coords3d) {
         //logger.debug("**** GT getAllAtomRMSD ****");
         double sum = 0;
-        double RMSD;
+        double rmsd;
         Iterator<Integer> firstAtoms = mappedAtoms.keySet().iterator();
         int firstAtomNumber;
         int secondAtomNumber;
@@ -1640,7 +1664,7 @@ public final class GeometryUtil {
             secondAtomNumber = mappedAtoms.get(firstAtomNumber);
             IAtom firstAtom = firstAtomContainer.getAtom(firstAtomNumber);
             if (hetAtomOnly) {
-                if (!firstAtom.getSymbol().equals("H") && !firstAtom.getSymbol().equals("C")) {
+                if (firstAtom.getAtomicNumber() != IElement.H && firstAtom.getAtomicNumber() != IElement.C) {
                     if (Coords3d) {
                         sum = sum
                                 + Math.pow(
@@ -1656,7 +1680,7 @@ public final class GeometryUtil {
                     }
                 }
             } else {
-                if (!firstAtom.getSymbol().equals("H")) {
+                if (firstAtom.getAtomicNumber() != IElement.H) {
                     if (Coords3d) {
                         sum = sum
                                 + Math.pow(
@@ -1674,8 +1698,8 @@ public final class GeometryUtil {
             }
 
         }
-        RMSD = Math.sqrt(sum / n);
-        return RMSD;
+        rmsd = n == 0 ? 0 : Math.sqrt(sum / n);
+        return rmsd;
     }
 
     /**
@@ -1696,6 +1720,8 @@ public final class GeometryUtil {
                 bondLengthSum += atom1.getPoint3d().distance(atom2.getPoint3d());
             }
         }
+        if (bondCounter == 0)
+            return bondLengthSum;
         return bondLengthSum / bondCounter;
     }
 
@@ -1752,6 +1778,8 @@ public final class GeometryUtil {
             containercount++;
             bondlenghtsum += getBondLengthAverage(container);
         }
+        if (containercount == 0)
+            return 0;
         return bondlenghtsum / containercount;
     }
 
@@ -1853,4 +1881,101 @@ public final class GeometryUtil {
         }
     }
 
+    private static class PolarAtomComparator implements Comparator<IAtom> {
+        private final Point2d center;
+
+        public PolarAtomComparator(Point2d center) {
+            this.center = center;
+            if (center == null)
+                throw new NullPointerException("Center point cannot be null!");
+        }
+
+        @Override
+        public int compare(IAtom aAtom, IAtom bAtom) {
+            Point2d a = aAtom.getPoint2d();
+            Point2d b = bAtom.getPoint2d();
+            if (a == null || b == null)
+                throw new IllegalArgumentException("Missing 2D coordinated!");
+
+            double deltaXa = a.x - center.x;
+            double deltaXb = b.x - center.x;
+
+            if (deltaXa >= 0 && deltaXb < 0) return -1;
+            if (deltaXa < 0 && deltaXb >= 0) return +1;
+
+            double deltaYa = a.y - center.y;
+            double deltaYb = b.y - center.y;
+
+            if (deltaXa == 0 && deltaXb == 0) {
+                if (deltaYa >= 0 || deltaYb >= 0)
+                    return a.y > b.y ? -1 : +1;
+                return b.y > a.y ? -1 : +1;
+            }
+
+            // compute the cross product of vectors (center -> a) x (center -> b)
+            double det = (deltaXa) * (deltaYb) - (deltaXb) * (deltaYa);
+            if (det < 0) return -1;
+            if (det > 0) return +1;
+
+            // points a and b are on the same line from the center
+            // check which point is closer to the center
+            double d1 = (deltaXa) * (deltaXa) + (deltaYa) * (deltaYa);
+            double d2 = (deltaXb) * (deltaXb) + (deltaYb) * (deltaYb);
+            return Double.compare(d1, d2);
+        }
+    }
+
+    private static final class PolarBondComparator implements Comparator<IBond> {
+
+        private final IAtom centerAtom;
+        private final PolarAtomComparator polarAtomCompare;
+
+        private PolarBondComparator(IAtom atom) {
+            this.centerAtom = atom;
+            if (centerAtom == null)
+                throw new NullPointerException("Central atom cannot be null!");
+            this.polarAtomCompare = new PolarAtomComparator(centerAtom.getPoint2d());
+        }
+
+        /**
+         * Returns the polar ordering of bonds a and b relative to some central
+         * point.
+         * @param a one bond
+         * @param b another bond
+         * @return -1 a is less than b, 0 a == b, +1 a is greater than b
+         * @see <a href="http://stackoverflow.com/a/6989383">Sort points in clockwise order, ciamej</a>
+         */
+        @Override
+        public int compare(IBond a, IBond b) {
+            IAtom aAtom = a.getOther(centerAtom);
+            IAtom bAtom = b.getOther(centerAtom);
+            if (aAtom == null || bAtom == null)
+                throw new IllegalArgumentException("Bond is not connected to central atom!");
+            return polarAtomCompare.compare(aAtom, bAtom);
+        }
+    }
+
+    /**
+     * Sort the bonds using polar/radial coords around a central atom in 2D.
+     * @param central the central atom
+     */
+    public static Comparator<IBond> polarBondComparator(final IAtom central) {
+        return new PolarBondComparator(central);
+    }
+
+    /**
+     * Sort the atoms using polar/radial coords around a central point in 2D.
+     * @param central the central atom
+     */
+    public static Comparator<IAtom> polarAtomComparator(final Point2d central) {
+        return new PolarAtomComparator(central);
+    }
+
+    /**
+     * Sort the atoms using polar/radial coords around a central atom in 2D.
+     * @param central the central atom
+     */
+    public static Comparator<IAtom> polarAtomComparator(final IAtom central) {
+        return polarAtomComparator(central.getPoint2d());
+    }
 }
