@@ -27,9 +27,9 @@ package org.openscience.cdk.graph.rebond;
  */
 public class Point implements Bspt.Tuple {
 
-    double x;
-    double y;
-    double z;
+    final double x;
+    final double y;
+    final double z;
 
     public Point(double x, double y, double z) {
         this.x = x;
