@@ -24,6 +24,7 @@
 
 package org.openscience.cdk.stereo;
 
+import org.openscience.cdk.geometry.GeometryUtil;
 import org.openscience.cdk.graph.Cycles;
 import org.openscience.cdk.graph.GraphUtil;
 import org.openscience.cdk.interfaces.IAtom;
@@ -32,6 +33,8 @@ import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IDoubleBondStereochemistry;
 import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.interfaces.ITetrahedralChirality;
+import org.openscience.cdk.tools.ILoggingTool;
+import org.openscience.cdk.tools.LoggingToolFactory;
 
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
@@ -46,6 +49,8 @@ import java.util.Set;
 import static org.openscience.cdk.graph.GraphUtil.EdgeToBondMap;
 import static org.openscience.cdk.interfaces.IBond.Stereo.DOWN;
 import static org.openscience.cdk.interfaces.IBond.Stereo.DOWN_INVERTED;
+import static org.openscience.cdk.interfaces.IBond.Stereo.UP;
+import static org.openscience.cdk.interfaces.IBond.Stereo.UP_INVERTED;
 import static org.openscience.cdk.interfaces.IDoubleBondStereochemistry.Conformation;
 import static org.openscience.cdk.interfaces.ITetrahedralChirality.Stereo;
 
@@ -91,13 +96,18 @@ public abstract class StereoElementFactory {
     /** A bond map for fast access to bond labels between two atom indices. */
     protected final EdgeToBondMap bondMap;
 
-    
+
     protected final Set<Projection> projections = EnumSet.noneOf(Projection.class);
 
+    protected boolean strict;
+
+    protected final ILoggingTool logger
+            = LoggingToolFactory.createLoggingTool(StereoElementFactory.class);
+
     /**
      * Verify if created stereochemistry are actually stereo-centres.
      */
-    private boolean check = false;
+    protected boolean check = false;
 
     /**
      * Internal constructor.
@@ -209,7 +219,7 @@ public abstract class StereoElementFactory {
             centers.checkSymmetry();
         }
 
-        List<IStereoElement> elements = new ArrayList<IStereoElement>();
+        List<IStereoElement> elements = new ArrayList<>();
 
         // projection recognition (note no action in constructors)
         FischerRecognition fischerRecon = new FischerRecognition(container, graph, bondMap, centers);
@@ -450,14 +460,14 @@ public abstract class StereoElementFactory {
 
     /**
      * Indicate that stereochemistry drawn as a certain projection should be
-     * interpreted. 
+     * interpreted.
      *
      * <pre>{@code
-     * StereoElementFactory factory = 
+     * StereoElementFactory factory =
      *   StereoElementFactory.using2DCoordinates(container)
      *                       .interpretProjections(Projection.Fischer, Projection.Haworth);
      * }</pre>
-     * 
+     *
      * @param projections types of projection
      * @return self
      * @see org.openscience.cdk.stereo.Projection
@@ -473,6 +483,21 @@ public abstract class StereoElementFactory {
         return this;
     }
 
+    /**
+     * Enables stricter stereochemistry checking, specifically tetrahedral
+     * centres may not be created from inverse down wedges (i.e. Daylight
+     * style depictions). This also sets that all stereocentres are tested
+     * for asymmetry.
+     *
+     * @return stereo element factory.
+     */
+    public StereoElementFactory withStrictMode()
+    {
+        this.check = true;
+        this.strict = true;
+        return this;
+    }
+
     /**
      * Create a stereo element factory for creating stereo elements using 2D
      * coordinates and depiction labels (up/down, wedge/hatch).
@@ -544,16 +569,23 @@ public abstract class StereoElementFactory {
 
             if (hasUnspecifiedParity(focus)) return null;
 
+            if (check) {
+                if (!stereocenters.isStereocenter(v))
+                    return null;
+            }
+
             IAtom[] neighbors = new IAtom[4];
             int[] elevation = new int[4];
 
-            neighbors[3] = focus;
+            neighbors[3] = focus; // implicit neighbour if needed
 
             boolean nonplanar = false;
             int n = 0;
 
+            List<IBond> bonds = new ArrayList<>();
             for (int w : graph[v]) {
                 IBond bond = bondMap.get(v, w);
+                bonds.add(bond);
 
                 // wavy bond
                 if (isUnspecified(bond)) return null;
@@ -561,43 +593,58 @@ public abstract class StereoElementFactory {
                 neighbors[n] = container.getAtom(w);
                 elevation[n] = elevationOf(focus, bond);
 
-                if (elevation[n] != 0) nonplanar = true;
+                if (elevation[n] != 0)
+                    nonplanar = true;
 
                 n++;
             }
 
-            // too few/many neighbors
-            if (n < 3 || n > 4) return null;
+            // too few neighbors
+            if (n < 3) return null;
 
-            // TODO: verify valid wedge/hatch configurations using similar procedure
-            // to NonPlanarBonds in the cdk-sdg package.
+            if (strict) {
+                if (!verifyWedgePattern(focus, n, bonds))
+                    return null;
+            }
 
             // no up/down bonds present - check for inverted down/hatch
-            if (!nonplanar) {
+            if (!nonplanar && !strict) {
                 int[] ws = graph[v];
                 for (int i = 0; i < ws.length; i++) {
                     int w = ws[i];
                     IBond bond = bondMap.get(v, w);
 
                     // we have already previously checked whether 'v' is at the
-                    // 'point' and so these must be inverse (fat-end @
-                    // stereocenter) ala Daylight
+                    // 'point' and so these must be inverse (fat-end of hatched
+                    // wedge is a stereocenter) ala Daylight
                     if (bond.getStereo() == DOWN || bond.getStereo() == DOWN_INVERTED) {
 
                         // we stick to the 'point' end convention but can
                         // interpret if the bond isn't connected to another
                         // stereocenter - otherwise it's ambiguous!
-                        if (stereocenters.isStereocenter(w)) continue;
+                        if (stereocenters.stereocenterType(w) != Stereocenters.Stereocenter.Non) {
+                            stereocenters.checkSymmetry();
+                            if (stereocenters.isStereocenter(w)) {
+                                logger.error("Ambiguous down wedge bond between atom indexes ", w, " and ", v);
+                                return null;
+                            }
+                        }
 
+                        logger.warn("Inverse wedge bond used for stereo at atom index ", v);
                         elevation[i] = -1;
                         nonplanar = true;
                     }
+                    // stereo at the "fat-end" of the bold wedge?
+                    else if (bond.getStereo() == UP || bond.getStereo() == UP_INVERTED) {
+                        logger.warn("Ignoring inverted up wedge bond connected to atom idx=", w);
+                        return null;
+                    }
                 }
-
-                // still no bonds to use
-                if (!nonplanar) return null;
             }
 
+            // still no bonds to use
+            if (!nonplanar) return null;
+
             int parity = parity(focus, neighbors, elevation);
 
             if (parity == 0) return null;
@@ -607,6 +654,114 @@ public abstract class StereoElementFactory {
             return new TetrahedralChirality(focus, neighbors, winding);
         }
 
+        private boolean isOkay(int a, int b) {
+            return a == 0 || b == 0 || a == b;
+        }
+
+        // check some obvious stereo chemistry errors, see the InChI
+        // technical manual "Definition of 2D drawing correctness"
+        private boolean verifyWedgePattern(IAtom focus, int n, List<IBond> bonds) {
+            bonds.sort(GeometryUtil.polarBondComparator(focus));
+            if (n == 3) {
+                double angle = getMaxSweep(focus, bonds);
+                double delta = angle - Math.PI;
+                double threshold = 0.01;
+                // largest angle between 2 neighbours is > 180 => wedges should
+                // alternate
+                if (delta > threshold) {
+                    int ref = 0;
+                    for (IBond bond : bonds) {
+                        int curr = elevationOf(focus, bond);
+                        if (!isOkay(ref, curr)) {
+                            logger.error("Invalid wedge pattern, up/down bonds should be mixed when there is an acute angle!");
+                            return false;
+                        } else
+                            ref = curr;
+                        ref = -ref;
+                    }
+                }
+                // larges angle between 2 neighbours is < 180 => all wedges
+                // should be the same
+                else if (delta < -threshold) {
+                    int ref = 0;
+                    for (IBond bond : bonds) {
+                        int curr = elevationOf(focus, bond);
+                        if (!isOkay(ref, curr)) {
+                            logger.error("Invalid wedge pattern, up/down bonds should be same when there is not an acute angle!");
+                            return false;
+                        } else
+                            ref = curr;
+                    }
+                } else {
+                    // 180-degrees, check where the wedge is
+                    if (bonds.size() != 3)
+                        throw new IllegalArgumentException("3 bonds only!");
+                    Vector2d v1 = toUnitVector(focus, bonds.get(0).getOther(focus));
+                    Vector2d v2 = toUnitVector(focus, bonds.get(1).getOther(focus));
+                    Vector2d v3 = toUnitVector(focus, bonds.get(2).getOther(focus));
+                    String ambiuousStereoMesg = "Ambiguous stereochemistry - 3 neighbours and two";
+                    if (Math.abs(signedAngle(v1,v2) - Math.PI) < threshold) {
+                        if (elevationOf(focus, bonds.get(0)) == 0 &&
+                            elevationOf(focus, bonds.get(1)) == 0 &&
+                            elevationOf(focus, bonds.get(2)) != 0) {
+                            logger.error(ambiuousStereoMesg);
+                            return false;
+                        }
+                    } else if (Math.abs(signedAngle(v2,v3) - Math.PI) < threshold) {
+                        if (elevationOf(focus, bonds.get(0)) != 0 &&
+                            elevationOf(focus, bonds.get(1)) == 0 &&
+                            elevationOf(focus, bonds.get(2)) == 0) {
+                            logger.error(ambiuousStereoMesg);
+                            return false;
+                        }
+                    } else if (Math.abs(signedAngle(v3,v1) - Math.PI) < threshold) {
+                        if (elevationOf(focus, bonds.get(0)) == 0 &&
+                            elevationOf(focus, bonds.get(1)) != 0 &&
+                            elevationOf(focus, bonds.get(2)) == 0) {
+                            logger.error(ambiuousStereoMesg);
+                            return false;
+                        }
+                    }
+                }
+            } else { // n == 4
+                int ref = 0;
+                for (IBond bond : bonds) {
+                    int curr = elevationOf(focus, bond);
+                    if (curr != 0) {
+                        if (ref != 0 && ref != curr) {
+                            logger.error("Badly drawn stereochemistry with 4 neighbours, up/down bonds should alternate!");
+                            return false;
+                        }
+                        else {
+                            ref = curr;
+                        }
+                    }
+                    ref = -ref; // flip for next check
+                }
+            }
+            return true;
+        }
+
+        private double signedAngle(Vector2d a, Vector2d b) {
+            double angle = Math.atan2(a.x*b.y-a.y*b.x, a.x*b.x+a.y*b.y);
+            return angle >= 0 ? (2*Math.PI)-angle : -angle;
+        }
+
+        private double max(double a, double b, double c) {
+            return Math.max(a, Math.max(b, c));
+        }
+
+        private double getMaxSweep(IAtom atom, List<IBond> bonds) {
+            if (bonds.size() != 3)
+                throw new IllegalArgumentException("3 bonds only!");
+            Vector2d v1 = toUnitVector(atom, bonds.get(0).getOther(atom));
+            Vector2d v2 = toUnitVector(atom, bonds.get(1).getOther(atom));
+            Vector2d v3 = toUnitVector(atom, bonds.get(2).getOther(atom));
+            return max(signedAngle(v1, v2),
+                       signedAngle(v2, v3),
+                       signedAngle(v3, v1));
+        }
+
         private static boolean isWedged(IBond bond) {
             switch (bond.getStereo()) {
                 case UP:
@@ -835,7 +990,7 @@ public abstract class StereoElementFactory {
 
             IBond   focus    = dbs.get(dbs.size()/2);
             IBond[] carriers = new IBond[2];
-            int     config   = 0;
+            int     config;
 
             IAtom begAtom = dbs.get(0).getOther(getShared(dbs.get(0), dbs.get(1)));
             IAtom endAtom = dbs.get(dbs.size()-1).getOther(getShared(dbs.get(dbs.size()-1), dbs.get(dbs.size()-2)));
@@ -964,6 +1119,12 @@ public abstract class StereoElementFactory {
             return new Point2d(v2d);
         }
 
+        private Vector2d toUnitVector(IAtom from, IAtom to) {
+            if (from.equals(to))
+                return new Vector2d(0, 0);
+            return new Vector2d(toUnitVector(from.getPoint2d(), to.getPoint2d()));
+        }
+
         /**
          * Compute the signed volume of the tetrahedron from the planar points
          * and elevations.
@@ -1082,9 +1243,6 @@ public abstract class StereoElementFactory {
             // too few/many neighbors
             if (n < 3 || n > 4) return null;
 
-            // TODO: verify valid wedge/hatch configurations using similar procedure
-            // to NonPlanarBonds in the cdk-sdg package
-
             int parity = parity(neighbors);
 
             Stereo winding = parity > 0 ? Stereo.ANTI_CLOCKWISE : Stereo.CLOCKWISE;
@@ -1210,7 +1368,7 @@ public abstract class StereoElementFactory {
             IAtom focus = container.getAtom(v);
 
             if (hasUnspecifiedParity(focus)) return null;
-            
+
             if (container.getConnectedBondsCount(focus) != 2)
         	    return null;
 
@@ -1261,7 +1419,7 @@ public abstract class StereoElementFactory {
 
             IBond   focus    = dbs.get(dbs.size()/2);
             IBond[] carriers = new IBond[2];
-            int     config   = 0;
+            int     config;
 
             IAtom begAtom = dbs.get(0).getOther(getShared(dbs.get(0),
                                                           dbs.get(1)));
