@@ -24,15 +24,9 @@
  */
 package org.openscience.cdk.tools;
 
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.Comparator;
-import java.util.List;
-
 import org.openscience.cdk.CDKConstants;
-import org.openscience.cdk.config.Isotopes;
 import org.openscience.cdk.config.IsotopeFactory;
+import org.openscience.cdk.config.Isotopes;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.graph.Cycles;
 import org.openscience.cdk.graph.invariant.CanonicalLabeler;
@@ -40,10 +34,15 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IIsotope;
-import org.openscience.cdk.interfaces.IRing;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.smiles.InvPair;
 
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Comparator;
+import java.util.List;
+import java.util.Objects;
+
 /**
  * Generates HOSE codes {@cdk.cite BRE78}.
  * IMPORTANT: Your molecule must contain implicit or explicit hydrogens
@@ -57,21 +56,21 @@ import org.openscience.cdk.smiles.InvPair;
  */
 public class HOSECodeGenerator implements java.io.Serializable {
 
-    private static ILoggingTool logger               = LoggingToolFactory.createLoggingTool(HOSECodeGenerator.class);
+    private static final ILoggingTool logger               = LoggingToolFactory.createLoggingTool(HOSECodeGenerator.class);
 
     private static final long   serialVersionUID     = -4353471818831864513L;
 
     /**
      *  Container for the nodes in a sphere.
      */
-    protected List<TreeNode>    sphereNodes          = null;
-    protected List<IAtom>       sphereNodesWithAtoms = null;
+    protected List<TreeNode>    sphereNodes;
+    private final List<IAtom>       sphereNodesWithAtoms;
 
     /**
      *  Container for the node in the next sphere Assembled in a recursive method
      *  and then passed to the next recursion to become "sphereNodes".
      */
-    protected List<TreeNode>    nextSphereNodes      = null;
+    private List<TreeNode>    nextSphereNodes;
     /**
      *  Counter for the sphere in which we currently work.
      */
@@ -79,19 +78,19 @@ public class HOSECodeGenerator implements java.io.Serializable {
     /**
      *  How many spheres are we supposed inspect.
      */
-    protected int               maxSphere            = 0;
+    private int               maxSphere            = 0;
 
     /**
      *  Here we store the spheres that we assemble, in order to parse them into a
      *  code later.
      */
     protected List<TreeNode>[]  spheres              = null;
-    protected List<IAtom>[]     spheresWithAtoms     = null;
+    private List<IAtom>[]     spheresWithAtoms     = null;
 
     /**
      *  The HOSECode string that we assemble
      */
-    protected StringBuffer      HOSECode             = null;
+    protected StringBuffer      HOSECode;
 
     /**
      *  The molecular structure on which we work
@@ -102,49 +101,87 @@ public class HOSECodeGenerator implements java.io.Serializable {
      *  Delimiters used to separate spheres in the output string. Bremser uses the
      *  sequence"(//)" for the first four spheres.
      */
-    protected String[]          sphereDelimiters     = {"(", "/", "/", ")", "/", "/", "/", "/", "/", "/", "/", "/"};
+    private final String[]          sphereDelimiters     = {"(", "/", "/", ")", "/", "/", "/", "/", "/", "/", "/", "/"};
     /**
      *  The bond symbols used for bond orders "single", "double", "triple" and
      *  "aromatic"
      */
-    protected String            bondSymbols[]        = {"", "", "=", "%", "*"};
+    protected String[] bondSymbols = {"", "", "=", "%", "*"};
 
     protected String            centerCode           = null;
 
-    public TreeNode             rootNode             = null;
+    private TreeNode             rootNode             = null;
 
     boolean                     debug                = false;
 
-    private IAtomContainer      acold                = null;
+    private final IAtomContainer      acold                = null;
     private IRingSet            soar                 = null;
 
     /**
      *  The rank order for the given element symbols.
      */
 
-    static final String[]       rankedSymbols        = {"C", "O", "N", "S", "P", "Si", "B", "F", "Cl", "Br", ";", "I",
+    private static final String[]       rankedSymbols        = {"C", "O", "N", "S", "P", "Si", "B", "F", "Cl", "Br", ";", "I",
             "#", "&", ","                            };
 
     /**
      *  The ranking values to be used for the symbols above.
      */
-    static final int[]          symbolRankings       = {9000, 8900, 8800, 8700, 8600, 8500, 8400, 8300, 8200, 8100,
+    private static final int[]          symbolRankings       = {9000, 8900, 8800, 8700, 8600, 8500, 8400, 8300, 8200, 8100,
             8000, 7900, 1200, 1100, 1000             };
 
     /**
-     *  The bond rankings to be used for the four bond order possibilities.
+     * The bond rankings to be used for the four bond order possibilities.
      */
 
-    static final int[]          bondRankings         = {0, 0, 200000, 300000, 100000};
+    private static final int[] bondRankings = {0, 0, 200000, 300000, 100000};
+
+    /** Configure with no special treatment (default). */
+    private static final int DEFAULT_MODE = 0;
+
+    /** Ignored parent ordering be considered when sorting spheres (legacy mode)
+     *  for compatibility with existing ML/AI models. */
+    public static final int LEGACY_MODE  = 1;
+
+    private final int flags;
 
     /**
-     *  Constructor for the HOSECodeGenerator.
+     * Constructor for the HOSECodeGenerator.
+     *
+     * <h1>Important!</h1>
+     * A critical bug was discovered in
+     * the implementation (see <a href="https://github.com/cdk/cdk/pull/828">PR
+     * 828</a>) which gave the wrong nesting in "some" cases. Fixing this
+     * behaviour invalidates any ML/AI models trained on the incorrect values.
+     * If you have a model built with the old algorithm that can not be
+     * retrained set {@code legacyMode=true}.
+     *
+     * @param flags (default: false)
+     * @see <a href="https://github.com/cdk/cdk/pull/828">PR 828</a>
+     */
+    public HOSECodeGenerator(int flags) {
+        this.flags = flags;
+        sphereNodes = new ArrayList<>();
+        sphereNodesWithAtoms = new ArrayList<>();
+        nextSphereNodes = new ArrayList<>();
+        HOSECode = new StringBuffer();
+    }
+
+    /**
+     * Constructor for the HOSECodeGenerator.
+     *
+     * <h1>Important!</h1>
+     * A critical bug was discovered in
+     * the implementation (see <a href="https://github.com/cdk/cdk/pull/828">PR
+     * 828</a>) which gave the wrong nesting in "some" cases. Fixing this
+     * behaviour invalidates any ML/AI models trained on the incorrect values.
+     * If you have a model built with the old algorithm that can not be
+     * retrained set {@cdoe new HOSECodeGenerator(HOSECodeGenerator.LEGACY_MODE)}.
+     *
+     * @see <a href="https://github.com/cdk/cdk/pull/828">PR 828</a>
      */
     public HOSECodeGenerator() {
-        sphereNodes = new ArrayList<TreeNode>();
-        sphereNodesWithAtoms = new ArrayList<IAtom>();
-        nextSphereNodes = new ArrayList<TreeNode>();
-        HOSECode = new StringBuffer();
+        this(DEFAULT_MODE);
     }
 
     private IsotopeFactory isotopeFac = null;
@@ -181,7 +218,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
             ac.getAtom(i).setFlag(CDKConstants.VISITED, false);
         }
         root.setFlag(CDKConstants.VISITED, true);
-        rootNode = new TreeNode(root.getSymbol(), null, root, (double) 0, atomContainer.getConnectedBondsCount(root), 0);
+        rootNode = new TreeNode(root.getSymbol(), null, root, 0, atomContainer.getConnectedBondsCount(root), 0);
         /*
          * All we need to observe is how the ranking of substituents in the
          * subsequent spheres of the root nodes influences the ranking of the
@@ -248,7 +285,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
             ac.getAtom(i).setFlag(CDKConstants.VISITED, false);
         }
         root.setFlag(CDKConstants.VISITED, true);
-        rootNode = new TreeNode(root.getSymbol(), null, root, (double) 0, atomContainer.getConnectedBondsCount(root), 0);
+        rootNode = new TreeNode(root.getSymbol(), null, root, 0, atomContainer.getConnectedBondsCount(root), 0);
         /*
          * All we need to observe is how the ranking of substituents in the
          * subsequent spheres of the root nodes influences the ranking of the
@@ -265,7 +302,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
     }
 
     private void createCenterCode(IAtom root, IAtomContainer ac, boolean ringsize) {
-        int partnerCount = 0;
+        int partnerCount;
         partnerCount = atomContainer.getConnectedBondsCount(root)
                 + (root.getImplicitHydrogenCount() == CDKConstants.UNSET ? 0 : root.getImplicitHydrogenCount());
         centerCode = root.getSymbol() + "-" + partnerCount + createChargeCode(root)
@@ -277,18 +314,18 @@ public class HOSECodeGenerator implements java.io.Serializable {
             soar = Cycles.sssr(ac).toRingSet();
         }
         boolean[] bool = new boolean[1000];
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         for (int i = 0; i < soar.getRings(root).getAtomContainerCount(); i++) {
-            if (((IRing) soar.getRings(root).getAtomContainer(i)).getAtomCount() < bool.length)
-                bool[((IRing) soar.getRings(root).getAtomContainer(i)).getAtomCount()] = true;
+            if (soar.getRings(root).getAtomContainer(i).getAtomCount() < bool.length)
+                bool[soar.getRings(root).getAtomContainer(i).getAtomCount()] = true;
         }
         for (int i = 0; i < bool.length; i++) {
-            if (bool[i]) sb.append(i + "");
+            if (bool[i]) sb.append(i);
         }
         if (sb.toString().isEmpty())
             return "";
         else
-            return "-" + sb.toString();
+            return "-" + sb;
     }
 
     private String createChargeCode(IAtom atom) {
@@ -325,15 +362,15 @@ public class HOSECodeGenerator implements java.io.Serializable {
      */
     private void breadthFirstSearch(IAtom root, boolean addTreeNode) throws CDKException {
         sphere = 0;
-        TreeNode tempNode = null;
+        TreeNode tempNode;
         List<IAtom> conAtoms = atomContainer.getConnectedAtomsList(root);
         IAtom atom;
-        IBond bond = null;
+        IBond bond;
         sphereNodes.clear();
         sphereNodesWithAtoms.clear();
-        for (int i = 0; i < conAtoms.size(); i++) {
+        for (IAtom conAtom : conAtoms) {
             try {
-                atom = conAtoms.get(i);
+                atom = conAtom;
                 if (atom.getSymbol().equals("H")) continue;
                 bond = atomContainer.getBond(root, atom);
                 /*
@@ -341,11 +378,12 @@ public class HOSECodeGenerator implements java.io.Serializable {
                  * atom as source
                  */
                 if (bond.getFlag(CDKConstants.ISAROMATIC)) {
-                    tempNode = new TreeNode(atom.getSymbol(), new TreeNode(root.getSymbol(), null, root, (double) 0, 0,
-                            (long) 0), atom, 4, atomContainer.getConnectedBondsCount(atom), 0);
+                    tempNode = new TreeNode(atom.getSymbol(), new TreeNode(root.getSymbol(), null, root, 0, 0,
+                                                                           0), atom, 4, atomContainer.getConnectedBondsCount(atom), 0);
                 } else {
-                    tempNode = new TreeNode(atom.getSymbol(), new TreeNode(root.getSymbol(), null, root, (double) 0, 0,
-                            (long) 0), atom, bond.getOrder().numeric(), atomContainer.getConnectedBondsCount(atom), 0);
+                    tempNode = new TreeNode(atom.getSymbol(), new TreeNode(root.getSymbol(), null, root, 0, 0,
+                                                                           0), atom, bond.getOrder()
+                                                                                         .numeric(), atomContainer.getConnectedBondsCount(atom), 0);
                 }
 
                 sphereNodes.add(tempNode);
@@ -357,7 +395,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
                 throw new CDKException("Error in HOSECodeGenerator->breadthFirstSearch.", exc);
             }
         }
-        Collections.sort(sphereNodes, new TreeNodeComparator());
+        sphereNodes.sort(new TreeNodeComparator());
         nextSphere(sphereNodes);
     }
 
@@ -376,15 +414,15 @@ public class HOSECodeGenerator implements java.io.Serializable {
         /*
          * From here we start assembling the next sphere
          */
-        IAtom node = null;
-        IAtom toNode = null;
-        List<IAtom> conAtoms = null;
-        TreeNode treeNode = null;
-        nextSphereNodes = new ArrayList<TreeNode>();
-        IBond bond = null;
-        for (int i = 0; i < sphereNodes.size(); i++) {
-            treeNode = (TreeNode) sphereNodes.get(i);
-            if (!("&;#:,".indexOf(treeNode.symbol) >= 0)) {
+        IAtom node;
+        IAtom toNode;
+        List<IAtom> conAtoms;
+        TreeNode treeNode;
+        nextSphereNodes = new ArrayList<>();
+        IBond bond;
+        for (TreeNode sphereNode : sphereNodes) {
+            treeNode = sphereNode;
+            if (!("&;#:,".contains(treeNode.symbol))) {
                 node = treeNode.atom;
                 if (node.getSymbol().equals("H")) continue;
 
@@ -392,8 +430,8 @@ public class HOSECodeGenerator implements java.io.Serializable {
                 if (conAtoms.size() == 1) {
                     nextSphereNodes.add(new TreeNode(",", treeNode, null, 0, 0, treeNode.score));
                 } else {
-                    for (int j = 0; j < conAtoms.size(); j++) {
-                        toNode = conAtoms.get(j);
+                    for (IAtom conAtom : conAtoms) {
+                        toNode = conAtom;
                         if (!toNode.equals(treeNode.source.atom)) {
                             bond = atomContainer.getBond(node, toNode);
                             if (bond.getFlag(CDKConstants.ISAROMATIC)) {
@@ -401,14 +439,14 @@ public class HOSECodeGenerator implements java.io.Serializable {
                                         .getConnectedBondsCount(toNode), treeNode.score));
                             } else {
                                 nextSphereNodes.add(new TreeNode(toNode.getSymbol(), treeNode, toNode, bond.getOrder()
-                                        .numeric(), atomContainer.getConnectedBondsCount(toNode), treeNode.score));
+                                                                                                           .numeric(), atomContainer.getConnectedBondsCount(toNode), treeNode.score));
                             }
                         }
                     }
                 }
             }
         }
-        Collections.sort(nextSphereNodes, new TreeNodeComparator());
+        nextSphereNodes.sort(new TreeNodeComparator());
         if (sphere < maxSphere) {
             sphere++;
             nextSphere(nextSphereNodes);
@@ -418,7 +456,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
     public String makeBremserCompliant(String code) {
         int sepIndex = code.indexOf(';');
         if (sepIndex >= 0) {
-            code = code.substring(sepIndex + 1, code.length());
+            code = code.substring(sepIndex + 1);
         }
         return code;
     }
@@ -430,54 +468,47 @@ public class HOSECodeGenerator implements java.io.Serializable {
      *@exception  org.openscience.cdk.exception.CDKException  Thrown if something goes wrong
      */
     private void createCode() throws CDKException {
-        List<TreeNode> sphereNodes = null;
-        TreeNode tn = null;
         for (int f = 0; f < atomContainer.getAtomCount(); f++) {
             atomContainer.getAtom(f).setFlag(CDKConstants.VISITED, false);
         }
-
         for (int f = 0; f < maxSphere; f++) {
-            sphereNodes = spheres[maxSphere - f];
-            for (int g = 0; g < sphereNodes.size(); g++) {
-                tn = sphereNodes.get(g);
+            for (TreeNode tn : spheres[maxSphere - f]) {
                 if (tn.source != null) {
                     tn.source.ranking += tn.degree;
                 }
-
             }
         }
 
-        for (int f = 0; f < maxSphere; f++) {
-            sphereNodes = spheres[f];
-            calculateNodeScores(sphereNodes);
-            sortNodesByScore(sphereNodes);
-        }
-
-        for (int f = 0; f < maxSphere; f++) {
-            sphereNodes = spheres[f];
-            for (int g = 0; g < sphereNodes.size(); g++) {
-                tn = (TreeNode) sphereNodes.get(g);
-                tn.score += tn.ranking;
-            }
-            sortNodesByScore(sphereNodes);
-        }
-        for (int f = 0; f < maxSphere; f++) {
-            sphereNodes = spheres[f];
-            for (int g = 0; g < sphereNodes.size(); g++) {
-                tn = (TreeNode) sphereNodes.get(g);
-                String localscore = tn.score + "";
-                while (localscore.length() < 6) {
-                    localscore = "0" + localscore;
+        if ((flags&LEGACY_MODE) != 0) {
+            for (int f = 0; f < maxSphere; f++)
+                calculateNodeScores(spheres[f]);
+            for (int f = 0; f < maxSphere; f++)
+                for (TreeNode tn : spheres[f])
+                    tn.score += tn.ranking;
+            for (int f = 0; f < maxSphere; f++) {
+                for (TreeNode tn : spheres[f]) {
+                    StringBuilder localscore = new StringBuilder(tn.score + "");
+                    while (localscore.length() < 6) {
+                        localscore.insert(0, "0");
+                    }
+                    tn.stringscore = tn.source.stringscore + "" + localscore;
                 }
-                tn.stringscore = tn.source.stringscore + "" + localscore;
+                sortNodesByScore(spheres[f]);
             }
-            sortNodesByScore(sphereNodes);
         }
+        else {
+            for (int f = 0; f < maxSphere; f++) {
+                calculateNodeScores(spheres[f]);
+                for (TreeNode tn : spheres[f])
+                    tn.score += tn.ranking;
+                sortNodesByScore(spheres[f]);
+            }
+        }
+
         HOSECode.append(centerCode);
         for (int f = 0; f < maxSphere; f++) {
             sphere = f + 1;
-            sphereNodes = spheres[f];
-            String s = getSphereCode(sphereNodes);
+            String s = getSphereCode(spheres[f]);
             HOSECode.append(s);
         }
     }
@@ -493,17 +524,17 @@ public class HOSECodeGenerator implements java.io.Serializable {
         if (sphereNodes == null || sphereNodes.size() < 1) {
             return sphereDelimiters[sphere - 1];
         }
-        TreeNode treeNode = null;
-        StringBuffer code = new StringBuffer();
+        TreeNode treeNode;
+        StringBuilder code = new StringBuilder();
         /*
          * append the tree node code to the HOSECode in their now determined
          * order, using commas to separate nodes from different branches
          */
         IAtom branch = sphereNodes.get(0).source.atom;
-        StringBuffer tempCode = null;
-        for (int i = 0; i < sphereNodes.size(); i++) {
-            treeNode = sphereNodes.get(i);
-            tempCode = new StringBuffer();
+        StringBuilder tempCode;
+        for (TreeNode sphereNode : sphereNodes) {
+            treeNode = sphereNode;
+            tempCode = new StringBuilder();
             if (!treeNode.source.stopper && !treeNode.source.atom.equals(branch)) {
                 branch = treeNode.source.atom;
                 code.append(',');
@@ -521,7 +552,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
                     tempCode.append('&');
                     treeNode.stopper = true;
                 }
-                code.append(tempCode + createChargeCode(treeNode.atom));
+                code.append(tempCode).append(createChargeCode(treeNode.atom));
                 treeNode.hSymbol = tempCode.toString();
             }
             if (treeNode.atom != null) treeNode.atom.setFlag(CDKConstants.VISITED, true);
@@ -582,9 +613,9 @@ public class HOSECodeGenerator implements java.io.Serializable {
      *@exception  org.openscience.cdk.exception.CDKException  Thrown if something goes wrong.
      */
     private void calculateNodeScores(List<TreeNode> sphereNodes) throws CDKException {
-        TreeNode treeNode = null;
-        for (int i = 0; i < sphereNodes.size(); i++) {
-            treeNode = (TreeNode) sphereNodes.get(i);
+        TreeNode treeNode;
+        for (TreeNode sphereNode : sphereNodes) {
+            treeNode = sphereNode;
             treeNode.score += getElementRank(treeNode.symbol);
             if (treeNode.bondType <= 4) {
                 treeNode.score += bondRankings[(int) treeNode.bondType];
@@ -601,29 +632,21 @@ public class HOSECodeGenerator implements java.io.Serializable {
      *@param  sphereNodes  A vector with sphere nodes to be sorted.
      */
     private void sortNodesByScore(List<TreeNode> sphereNodes) {
-        TreeNode obj;
-        boolean changed;
-        if (sphereNodes.size() == 0) return;
-        /*
-         * Now we sort by score
-         */
-        do {
-            changed = false;
-            for (int i = 0; i < sphereNodes.size() - 1; i++) {
-                if (((TreeNode) sphereNodes.get(i + 1)).stringscore
-                        .compareTo(((TreeNode) sphereNodes.get(i)).stringscore) > 0) {
-                    obj = sphereNodes.get(i + 1);
-                    sphereNodes.remove(i + 1);
-                    sphereNodes.add(i, obj);
-                    changed = true;
-                }
-            }
-        } while (changed);
+
+        if ((flags&LEGACY_MODE) != 0) {
+            sphereNodes.sort((a, b) -> b.stringscore.compareTo(a.stringscore));
+        } else {
+            sphereNodes.sort((a, b) -> {
+                // compare the parent node (source) first then the child string score
+                int cmp = Integer.compare(b.source.sortOrder, a.source.sortOrder);
+                if (cmp != 0) return cmp;
+                return Long.compare(b.score, a.score);
+            });
+        }
+
         /* Having sorted a sphere, we label the nodes with their sort order */
-        TreeNode temp = null;
         for (int i = 0; i < sphereNodes.size(); i++) {
-            temp = ((TreeNode) sphereNodes.get(i));
-            temp.sortOrder = sphereNodes.size() - i;
+            sphereNodes.get(i).sortOrder = sphereNodes.size() - i;
         }
     }
 
@@ -663,7 +686,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
             IAtom atom = node.getAtom();
             if (atom == null) return Long.MIN_VALUE;
             // cast can be removed in master
-            Long label = (Long) atom.getProperty(InvPair.CANONICAL_LABEL);
+            Long label = atom.getProperty(InvPair.CANONICAL_LABEL);
             if (label == null) return Long.MIN_VALUE;
             return label;
         }
@@ -686,8 +709,8 @@ public class HOSECodeGenerator implements java.io.Serializable {
         int            degree;
         long           score;
         int            ranking;
-        int            sortOrder   = 1;
-        List<TreeNode> childs      = null;
+        int            sortOrder;
+        List<TreeNode> childs;
         String         hSymbol     = null;
         boolean        stopper     = false;
         String         stringscore = "";
@@ -712,7 +735,7 @@ public class HOSECodeGenerator implements java.io.Serializable {
             this.bondType = bondType;
             ranking = 0;
             sortOrder = 1;
-            childs = new ArrayList<TreeNode>();
+            childs = new ArrayList<>();
         }
 
         public IAtom getAtom() {
@@ -728,19 +751,14 @@ public class HOSECodeGenerator implements java.io.Serializable {
          */
         @Override
         public boolean equals(Object o) {
-            try {
-                if (this.atom.equals(((TreeNode) o).atom)) {
-                    return true;
-                }
-            } catch (Exception exc) {
-                /*
-                 * we do nothing here because anything that could seriously
-                 * happen here is the we got something which is not a TreeNode
-                 * and then got a class cast exception. Thus we can just wait
-                 * until the end of the method returns a "false"
-                 */
-            }
-            return false;
+            if (!(o instanceof TreeNode))
+                return false;
+            return this.atom.equals(((TreeNode) o).atom);
+        }
+
+        @Override
+        public int hashCode() {
+            return Objects.hashCode(atom);
         }
 
         @Override
@@ -761,9 +779,9 @@ public class HOSECodeGenerator implements java.io.Serializable {
 
     public List<IAtom> getNodesInSphere(int sphereNumber) {
         sphereNodes = spheres[sphereNumber - 1];
-        List<IAtom> atoms = new ArrayList<IAtom>();
-        for (int g = 0; g < sphereNodes.size(); g++) {
-            atoms.add(((TreeNode) sphereNodes.get(g)).atom);
+        List<IAtom> atoms = new ArrayList<>();
+        for (TreeNode sphereNode : sphereNodes) {
+            atoms.add(sphereNode.atom);
         }
         return (atoms);
     }
