@@ -24,20 +24,9 @@ package org.openscience.cdk.tools.manipulator;
 
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.ReactionRole;
-import org.openscience.cdk.interfaces.IAtom;
-import org.openscience.cdk.interfaces.IAtomContainer;
-import org.openscience.cdk.interfaces.IAtomContainerSet;
-import org.openscience.cdk.interfaces.IBond;
-import org.openscience.cdk.interfaces.IChemObject;
-import org.openscience.cdk.interfaces.IChemObjectBuilder;
-import org.openscience.cdk.interfaces.IDoubleBondStereochemistry;
-import org.openscience.cdk.interfaces.IElectronContainer;
-import org.openscience.cdk.interfaces.ILonePair;
-import org.openscience.cdk.interfaces.IMapping;
-import org.openscience.cdk.interfaces.IReaction;
-import org.openscience.cdk.interfaces.ISingleElectron;
-import org.openscience.cdk.interfaces.IStereoElement;
-import org.openscience.cdk.interfaces.ITetrahedralChirality;
+import org.openscience.cdk.atomtype.CDKAtomTypeMatcher;
+import org.openscience.cdk.exception.CDKException;
+import org.openscience.cdk.interfaces.*;
 import org.openscience.cdk.stereo.ExtendedTetrahedral;
 
 import java.util.ArrayList;
@@ -49,10 +38,12 @@ import java.util.Map;
 import java.util.Set;
 
 /**
+ * Provides a variety of methods to manipulate and convert from/to {@link IReaction}.
  * @cdk.module standard
  * @cdk.githash
  *
  * @see ChemModelManipulator
+ * @author uli-f
  */
 public class ReactionManipulator {
 
@@ -139,10 +130,10 @@ public class ReactionManipulator {
     }
 
     /**
-     * Get all molecule of a {@link IReaction}: reactants + products.
+     * Returns all components of an {@link IReaction}, that is, reactants, agents and products.
      *
-     * @param reaction  The IReaction
-     * @return The IAtomContainerSet
+     * @param reaction all components of this reaction are returned
+     * @return IAtomContainerSet containing all components of the reaction provided as an argument
      */
     public static IAtomContainerSet getAllMolecules(IReaction reaction) {
         IAtomContainerSet moleculeSet = reaction.getBuilder().newInstance(IAtomContainerSet.class);
@@ -155,10 +146,10 @@ public class ReactionManipulator {
     }
 
     /**
-     * get all products of a IReaction
+     * Returns all products of an {@link IReaction}.
      *
-     * @param reaction  The IReaction
-     * @return The IAtomContainerSet
+     * @param reaction all products of this reaction are returned
+     * @return IAtomContainerSet containing all products of the reaction provided as an argument
      */
     public static IAtomContainerSet getAllProducts(IReaction reaction) {
         IAtomContainerSet moleculeSet = reaction.getBuilder().newInstance(IAtomContainerSet.class);
@@ -170,10 +161,10 @@ public class ReactionManipulator {
     }
 
     /**
-     * get all reactants of a IReaction
+     * Returns all reactants of an {@link IReaction}.
      *
-     * @param reaction  The IReaction
-     * @return The IAtomContainerSet
+     * @param reaction all reactants of this reaction are returned
+     * @return IAtomContainerSet containing all reactants of the reaction provided as an argument
      */
     public static IAtomContainerSet getAllReactants(IReaction reaction) {
         IAtomContainerSet moleculeSet = reaction.getBuilder().newInstance(IAtomContainerSet.class);
@@ -184,6 +175,12 @@ public class ReactionManipulator {
         return moleculeSet;
     }
 
+    /**
+     * Returns all agents of an {@link IReaction}.
+     *
+     * @param reaction all agents of this reaction are returned
+     * @return IAtomContainerSet containing all agents of the reaction provided as an argument
+     */
     public static IAtomContainerSet getAllAgents(IReaction reaction) {
         IAtomContainerSet moleculeSet = reaction.getBuilder().newInstance(IAtomContainerSet.class);
         IAtomContainerSet agents = reaction.getAgents();
@@ -194,8 +191,8 @@ public class ReactionManipulator {
     }
 
     /**
-     * Returns a new Reaction object which is the reverse of the given
-     * Reaction.
+     * Returns a new {@link IReaction} which is the reverse of the given reaction.
+     *
      * @param reaction the reaction being considered
      * @return the reverse reaction
      */
@@ -222,16 +219,17 @@ public class ReactionManipulator {
     }
 
     /**
-     * Returns all the AtomContainer's of a Reaction.
-     * @param reaction The reaction being considered
-     * @return a list of the IAtomContainer objects comprising the reaction
+     * Returns all {@link IAtomContainer IAtomContainers} of the given reaction.
+     *
+     * @param reaction the reaction whose <code>IAtomContainers</code> are returned
+     * @return list of <code>IAtomContainers</code> comprising the reaction
      */
     public static List<IAtomContainer> getAllAtomContainers(IReaction reaction) {
         return MoleculeSetManipulator.getAllAtomContainers(getAllMolecules(reaction));
     }
 
     public static List<String> getAllIDs(IReaction reaction) {
-        List<String> idList = new ArrayList<String>();
+        List<String> idList = new ArrayList<>();
         if (reaction.getID() != null) idList.add(reaction.getID());
         IAtomContainerSet reactants = reaction.getReactants();
         for (int i = 0; i < reactants.getAtomContainerCount(); i++) {
@@ -274,7 +272,7 @@ public class ReactionManipulator {
     }
 
     public static List<IChemObject> getAllChemObjects(IReaction reaction) {
-        ArrayList<IChemObject> list = new ArrayList<IChemObject>();
+        ArrayList<IChemObject> list = new ArrayList<>();
         list.add(reaction);
         IAtomContainerSet reactants = reaction.getReactants();
         for (int i = 0; i < reactants.getAtomContainerCount(); i++) {
@@ -288,17 +286,18 @@ public class ReactionManipulator {
     }
 
     /**
-     * get the IAtom which is mapped
+     * Returns the {@link IAtom} that is mapped.
      *
-     * @param reaction   The IReaction which contains the mapping
-     * @param chemObject The IChemObject which will be searched its mapped IChemObject
-     * @return           The mapped IChemObject
+     * @param reaction   reaction that contains the mapping
+     * @param chemObject IChemObject which will be searched for the mapped IChemObject
+     * @return           mapped IChemObject
      */
     public static IChemObject getMappedChemObject(IReaction reaction, IChemObject chemObject) {
         for (IMapping mapping : reaction.mappings()) {
             if (mapping.getChemObject(0).equals(chemObject)) {
                 return mapping.getChemObject(1);
-            } else if (mapping.getChemObject(1).equals(chemObject)) return mapping.getChemObject(0);
+            } else if (mapping.getChemObject(1).equals(chemObject))
+                return mapping.getChemObject(0);
         }
         return null;
     }
@@ -306,9 +305,9 @@ public class ReactionManipulator {
     /**
      * Assigns a reaction role and group id to all atoms in a molecule.
      *
-     * @param mol molecule
+     * @param mol the molecule whose atoms are assigned to a role and a group id.
      * @param role role to assign
-     * @param grpId group id
+     * @param grpId group id to assign
      */
     private static void assignRoleAndGrp(IAtomContainer mol, ReactionRole role, int grpId) {
         for (IAtom atom : mol.atoms()) {
@@ -318,10 +317,13 @@ public class ReactionManipulator {
     }
 
     /**
-     * <p>Converts a reaction to an 'inlined' reaction stored as a molecule. All
-     * reactants, agents, products are added to the molecule as disconnected
+     * Converts a reaction to an 'inlined' reaction stored as a molecule.
+     *
+     * <p>
+     * All reactants, agents, products are added to the molecule as disconnected
      * components with atoms flagged as to their role {@link ReactionRole} and
-     * component group.</p>
+     * component group.
+     * </p>
      * <p>
      * The inlined reaction, stored in a molecule can be converted back to an explicit
      * reaction with {@link #toReaction}. Data stored on the individual components (e.g.
@@ -356,7 +358,7 @@ public class ReactionManipulator {
     }
 
     /**
-     * <p>Converts an 'inlined' reaction stored in a molecule back to a reaction.</p>
+     * Converts an 'inlined' reaction stored in a molecule back to a reaction.
      *
      * @param mol molecule to convert
      * @return reaction
@@ -472,8 +474,8 @@ public class ReactionManipulator {
     }
 
     /**
-     * Collect the set of bonds that mapped in both a reactant and a product. The method uses
-     * the {@link CDKConstants#ATOM_ATOM_MAPPING} property of atoms.
+     * Collect the set of bonds that mapped in both a reactant and a product.
+     * The method uses the {@link CDKConstants#ATOM_ATOM_MAPPING} property of atoms.
      *
      * @param reaction reaction
      * @return mapped bonds
@@ -527,4 +529,76 @@ public class ReactionManipulator {
         }
         return mapped;
     }
+
+    /**
+     * Convenience method to perceive atom types for all {@link IAtom IAtoms} of all components of the provided {@link IReaction}.
+     * This method uses the {@link CDKAtomTypeMatcher}. If the
+     * matcher finds a matching atom type, the <code>IAtom</code> will be configured
+     * to have the same properties as the <code>IAtomType</code>. If no matching atom
+     * type is found, no configuration is performed.
+     * <br>
+     * <b>This method overwrites existing values.</b>
+     *
+     * @param reaction the reaction whose atom types are to be perceived
+     * @throws CDKException
+     * @see AtomTypeManipulator#configure(IAtom, IAtomType)
+     */
+    public static void perceiveAtomTypesAndConfigureAtoms(IReaction reaction) throws CDKException {
+        if (reaction == null) {
+            return;
+        }
+
+        for (IAtomContainer atomContainer: getAllMolecules(reaction).atomContainers()) {
+            AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(atomContainer);
+        }
+    }
+
+    /**
+     * Convenience method to perceive atom types for all {@link IAtom IAtoms} of all components of the provided {@link IReaction}.
+     * This method uses the {@link CDKAtomTypeMatcher}. If the
+     * matcher finds a matching atom type, the <code>IAtom</code> will be configured
+     * to have the same properties as the <code>IAtomType</code>. If no matching atom
+     * type is found, no configuration is performed.
+     * <br>
+     * <b>This method only sets <code>null</code> values.</b>
+     *
+     * @param reaction the reaction whose atom types are to be perceived
+     * @throws CDKException
+     * @see AtomTypeManipulator#configureUnsetProperties(IAtom, IAtomType)
+     */
+    public static void perceiveAtomTypesAndConfigureUnsetProperties(IReaction reaction) throws CDKException {
+        if (reaction == null) {
+            return;
+        }
+
+        for (IAtomContainer atomContainer: getAllMolecules(reaction).atomContainers()) {
+            AtomContainerManipulator.percieveAtomTypesAndConfigureUnsetProperties(atomContainer);
+        }
+    }
+
+    /**
+     * This method will reset all atom properties related to atom configuration to the value {@link CDKConstants#UNSET}.
+     * <br>
+     * This method reverses most of the effects of
+     * {@link #perceiveAtomTypesAndConfigureAtoms(org.openscience.cdk.interfaces.IReaction)}
+     * and after a call to this method all atoms will be "unconfigured".
+     * <br>
+     * Note that this method is not a complete reversal of {@link #perceiveAtomTypesAndConfigureAtoms(org.openscience.cdk.interfaces.IReaction)}
+     * since the atomic symbol of the atoms remain unchanged. Also, all flags that were set
+     * by the configuration method (such as {@link CDKConstants#IS_HYDROGENBOND_ACCEPTOR} or
+     * {@link CDKConstants#ISAROMATIC}) will be set to False.
+     *
+     * @param reaction the reaction whose atoms confiuration properties are to be cleared
+     * @see #perceiveAtomTypesAndConfigureAtoms(org.openscience.cdk.interfaces.IReaction)
+     */
+    public static void clearAtomConfigurations(IReaction reaction) {
+        if (reaction == null) {
+            return;
+        }
+
+        for (IAtomContainer atomContainer: ReactionManipulator.getAllMolecules(reaction).atomContainers()) {
+            AtomContainerManipulator.clearAtomConfigurations(atomContainer);
+        }
+    }
+
 }
