@@ -25,9 +25,9 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
@@ -50,9 +50,9 @@ import org.openscience.cdk.tools.manipulator.AtomTypeManipulator;
  *
  * @cdk.module test-atomtype
  */
-public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
+class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
 
-    private static Map<String, Integer> testedAtomTypes = new HashMap<String, Integer>();
+    private static final Map<String, Integer> testedAtomTypes = new HashMap<>();
 
     static {
         // do not complain about a few non-tested atom types
@@ -73,44 +73,44 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testGetInstance_IChemObjectBuilder() {
+    void testGetInstance_IChemObjectBuilder() {
         IAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(SilentChemObjectBuilder.getInstance());
-        Assert.assertNotNull(matcher);
+        Assertions.assertNotNull(matcher);
     }
 
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom() throws Exception {
         IAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(SilentChemObjectBuilder.getInstance());
-        Assert.assertNotNull(matcher);
+        Assertions.assertNotNull(matcher);
         IAtomContainer ethane = TestMoleculeFactory.makeAlkane(2);
         String[] expectedTypes = {"C.3", "C.3"};
         assertAtomTypes(testedAtomTypes, expectedTypes, ethane);
     }
 
     @Test
-    public void testFindMatchingAtomType_IAtomContainer() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer() throws Exception {
         String filename = "atomtyping.mol2";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(ins);
-        IAtomContainer mol = (IAtomContainer) reader.read(new AtomContainer());
+        IAtomContainer mol = reader.read(new AtomContainer());
 
         // just check consistency; other methods do perception testing
         SybylAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(DefaultChemObjectBuilder.getInstance());
         IAtomType[] types = matcher.findMatchingAtomTypes(mol);
         for (int i = 0; i < types.length; i++) {
             IAtomType type = matcher.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertEquals(type.getAtomTypeName(), types[i].getAtomTypeName());
+            Assertions.assertEquals(type.getAtomTypeName(), types[i].getAtomTypeName());
         }
     }
 
     @Test
-    public void testAtomTyping() throws Exception {
+    void testAtomTyping() throws Exception {
         String filename = "atomtyping.mol2";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(ins);
-        IAtomContainer molecule = (IAtomContainer) reader.read(new AtomContainer());
-        Assert.assertNotNull(molecule);
-        IAtomContainer reference = (IAtomContainer) molecule.clone();
+        IAtomContainer molecule = reader.read(new AtomContainer());
+        Assertions.assertNotNull(molecule);
+        IAtomContainer reference = molecule.clone();
 
         // test if the perceived atom types match that
         percieveAtomTypesAndConfigureAtoms(molecule);
@@ -118,8 +118,8 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
         Iterator<IAtom> atoms = molecule.atoms().iterator();
         while (atoms.hasNext() && refAtoms.hasNext()) {
             // work around aromaticity, which we skipped for now
-            Assert.assertEquals("Perceived atom type does not match atom type in file", refAtoms.next()
-                    .getAtomTypeName(), atoms.next().getAtomTypeName());
+            Assertions.assertEquals(refAtoms.next()
+                                            .getAtomTypeName(), atoms.next().getAtomTypeName(), "Perceived atom type does not match atom type in file");
         }
     }
 
@@ -127,19 +127,19 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
      * Uses findMatchingAtomType(IAtomContainer, IAtom) type.
      */
     @Test
-    public void testBenzene() throws Exception {
+    void testBenzene() throws Exception {
         IAtomContainer benzene = TestMoleculeFactory.makeBenzene();
 
         // test if the perceived atom types match that
         SybylAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(benzene.getBuilder());
         IAtomType[] types = matcher.findMatchingAtomTypes(benzene);
         for (IAtomType type : types) {
-            Assert.assertEquals("C.ar", type.getAtomTypeName());
+            Assertions.assertEquals("C.ar", type.getAtomTypeName());
         }
     }
 
     @Test
-    public void testAdenine() throws Exception {
+    void testAdenine() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeAdenine();
         String[] expectedTypes = {"C.ar", "C.ar", "C.ar", "N.ar", "N.ar", "N.ar", "N.ar", "N.3", "C.ar", "C.ar"};
         SybylAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(mol.getBuilder());
@@ -153,25 +153,25 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
      * Uses findMatchingAtomType(IAtomContainer) type.
      */
     @Test
-    public void testBenzene_AtomContainer() throws Exception {
+    void testBenzene_AtomContainer() throws Exception {
         IAtomContainer benzene = TestMoleculeFactory.makeBenzene();
 
         // test if the perceived atom types match that
         SybylAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(benzene.getBuilder());
         IAtomType[] types = matcher.findMatchingAtomTypes(benzene);
         for (IAtomType type : types) {
-            Assert.assertEquals("C.ar", type.getAtomTypeName());
+            Assertions.assertEquals("C.ar", type.getAtomTypeName());
         }
     }
 
     @Test
-    public void testAtomTyping4() throws Exception {
+    void testAtomTyping4() throws Exception {
         String filename = "atomtyping4.mol2";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(ins);
-        IAtomContainer molecule = (IAtomContainer) reader.read(new AtomContainer());
-        Assert.assertNotNull(molecule);
-        IAtomContainer reference = (IAtomContainer) molecule.clone();
+        IAtomContainer molecule = reader.read(new AtomContainer());
+        Assertions.assertNotNull(molecule);
+        IAtomContainer reference = molecule.clone();
 
         // test if the perceived atom types match that
         percieveAtomTypesAndConfigureAtoms(molecule);
@@ -180,8 +180,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
         while (atoms.hasNext() && refAtoms.hasNext()) {
             // work around aromaticity, which we skipped for now
             IAtom refAtom = refAtoms.next();
-            Assert.assertEquals("Perceived atom type does not match atom type in file", refAtom.getAtomTypeName(),
-                    atoms.next().getAtomTypeName());
+            Assertions.assertEquals(refAtom.getAtomTypeName(), atoms.next().getAtomTypeName(), "Perceived atom type does not match atom type in file");
         }
     }
 
@@ -189,24 +188,24 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
      * @cdk.bug 2445178
      */
     @Test
-    public void testNonExistingType() throws Exception {
+    void testNonExistingType() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom();
         mol.addAtom(atom);
         SybylAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(mol.getBuilder());
         IAtomType type = matcher.findMatchingAtomType(mol, atom);
-        Assert.assertNotNull(type);
+        Assertions.assertNotNull(type);
         org.hamcrest.MatcherAssert.assertThat(type.getAtomTypeName(), is("X"));
     }
 
     @Test
-    public void testAtomTyping2() throws Exception {
+    void testAtomTyping2() throws Exception {
         String filename = "atomtyping2.mol2";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(ins);
-        IAtomContainer molecule = (IAtomContainer) reader.read(new AtomContainer());
-        Assert.assertNotNull(molecule);
-        IAtomContainer reference = (IAtomContainer) molecule.clone();
+        IAtomContainer molecule = reader.read(new AtomContainer());
+        Assertions.assertNotNull(molecule);
+        IAtomContainer reference = molecule.clone();
 
         // test if the perceived atom types match that
         percieveAtomTypesAndConfigureAtoms(molecule);
@@ -215,19 +214,18 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
         while (atoms.hasNext() && refAtoms.hasNext()) {
             // work around aromaticity, which we skipped for now
             IAtom refAtom = refAtoms.next();
-            Assert.assertEquals("Perceived atom type does not match atom type in file", refAtom.getAtomTypeName(),
-                    atoms.next().getAtomTypeName());
+            Assertions.assertEquals(refAtom.getAtomTypeName(), atoms.next().getAtomTypeName(), "Perceived atom type does not match atom type in file");
         }
     }
 
     @Test
-    public void testAtomTyping3() throws Exception {
+    void testAtomTyping3() throws Exception {
         String filename = "atomtyping3.mol2";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(ins);
-        IAtomContainer molecule = (IAtomContainer) reader.read(new AtomContainer());
-        Assert.assertNotNull(molecule);
-        IAtomContainer reference = (IAtomContainer) molecule.clone();
+        IAtomContainer molecule = reader.read(new AtomContainer());
+        Assertions.assertNotNull(molecule);
+        IAtomContainer reference = molecule.clone();
 
         // test if the perceived atom types match that
         percieveAtomTypesAndConfigureAtoms(molecule);
@@ -236,16 +234,13 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
         while (atoms.hasNext() && refAtoms.hasNext()) {
             // work around aromaticity, which we skipped for now
             IAtom refAtom = refAtoms.next();
-            Assert.assertEquals("Perceived atom type does not match atom type in file", refAtom.getAtomTypeName(),
-                    atoms.next().getAtomTypeName());
+            Assertions.assertEquals(refAtom.getAtomTypeName(), atoms.next().getAtomTypeName(), "Perceived atom type does not match atom type in file");
         }
     }
 
     private void percieveAtomTypesAndConfigureAtoms(IAtomContainer container) throws Exception {
         SybylAtomTypeMatcher matcher = SybylAtomTypeMatcher.getInstance(container.getBuilder());
-        Iterator<IAtom> atoms = container.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = atoms.next();
+        for (IAtom atom : container.atoms()) {
             atom.setAtomTypeName(null);
             IAtomType matched = matcher.findMatchingAtomType(container, atom);
             if (matched != null) AtomTypeManipulator.configure(atom, matched);
@@ -259,7 +254,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testDummy() throws Exception {
+    void testDummy() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new PseudoAtom("R");
         mol.addAtom(atom);
@@ -269,7 +264,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testEthene() throws Exception {
+    void testEthene() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -282,7 +277,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testImine() throws Exception {
+    void testImine() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         IAtom atom2 = new Atom("N");
@@ -295,7 +290,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testPropyne() throws Exception {
+    void testPropyne() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -311,7 +306,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     } 
     
     @Test
-    public void testAllene() throws Exception {
+    void testAllene() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         IAtom atom2 = new Atom("C");
@@ -327,7 +322,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testHalogenatedMethane() throws Exception {
+    void testHalogenatedMethane() throws Exception {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.addAtom(new Atom("F"));
@@ -344,7 +339,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testMnF4() throws Exception {
+    void testMnF4() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("F");
         IAtom atom2 = new Atom("Mn");
@@ -367,7 +362,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testAmide() throws Exception {
+    void testAmide() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("C");
@@ -383,7 +378,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testCarboxylicAcid() throws Exception {
+    void testCarboxylicAcid() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("C");
@@ -399,7 +394,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testCarboxylate() throws Exception {
+    void testCarboxylate() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("C");
@@ -416,7 +411,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testMethylAmine() throws Exception {
+    void testMethylAmine() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("N");
         IAtom atom2 = new Atom("C");
@@ -429,7 +424,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testMethylNitro_Charged() throws Exception {
+    void testMethylNitro_Charged() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         mol.addAtom(atom);
@@ -450,7 +445,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testAmmonia() throws Exception {
+    void testAmmonia() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("H");
         IAtom atom2 = new Atom("N");
@@ -473,7 +468,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testMethanol() throws Exception {
+    void testMethanol() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("C");
@@ -486,7 +481,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testDMSO() throws Exception {
+    void testDMSO() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("S");
@@ -505,7 +500,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testDMSOO() throws Exception {
+    void testDMSOO() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom1 = new Atom("O");
@@ -527,7 +522,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testCarbokation() throws Exception {
+    void testCarbokation() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("H");
         IAtom atom2 = new Atom("C");
@@ -547,7 +542,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testSilicon() throws Exception {
+    void testSilicon() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "Si");
         mol.addAtom(a1);
@@ -622,7 +617,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testThioAmide() throws Exception {
+    void testThioAmide() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("S");
         IAtom atom2 = new Atom("C");
@@ -638,7 +633,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testSalts() throws Exception {
+    void testSalts() throws Exception {
         IAtomContainer mol = new AtomContainer();
 
         IAtom atom = new Atom("Na");
@@ -684,7 +679,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testH2S() throws Exception {
+    void testH2S() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom s = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "S");
         IAtom h1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "H");
@@ -705,7 +700,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testFerrocene() throws Exception {
+    void testFerrocene() throws Exception {
         IAtomContainer ferrocene = new AtomContainer();
         ferrocene.addAtom(new Atom("C"));
         ferrocene.addAtom(new Atom("C"));
@@ -738,7 +733,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testHCN() throws Exception {
+    void testHCN() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("N");
         IAtom atom2 = new Atom("C");
@@ -751,7 +746,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testAniline() throws Exception {
+    void testAniline() throws Exception {
         IAtomContainer benzene = TestMoleculeFactory.makeBenzene();
         IAtom nitrogen = benzene.getBuilder().newInstance(IAtom.class, "N");
         benzene.addAtom(nitrogen);
@@ -767,7 +762,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testLithiumMethanoxide() throws Exception {
+    void testLithiumMethanoxide() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("C");
@@ -783,7 +778,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testTinCompound() throws Exception {
+    void testTinCompound() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         IAtom atom2 = new Atom("Sn");
@@ -805,7 +800,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testZincChloride() throws Exception {
+    void testZincChloride() throws Exception {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("Zn"));
         mol.addAtom(new Atom("Cl"));
@@ -821,7 +816,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
      * @cdk.inchi InChI=1/H2Se/h1H2
      */
     @Test
-    public void testH2Se() throws Exception {
+    void testH2Se() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom se = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Se");
         IAtom h1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "H");
@@ -842,7 +837,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testPhosphate() throws Exception {
+    void testPhosphate() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         IAtom atom2 = new Atom("P");
@@ -864,7 +859,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void test_Mo_4() throws Exception {
+    void test_Mo_4() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom a1 = new Atom("Mo");
         mol.addAtom(a1);
@@ -886,7 +881,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testCrth() throws Exception {
+    void testCrth() throws Exception {
         IAtomContainer mol = new AtomContainer();
         // this is made up
         IAtom a1 = new Atom("Cr");
@@ -902,7 +897,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testCroh() throws Exception {
+    void testCroh() throws Exception {
         IAtomContainer mol = new AtomContainer();
         // this is made up, and may be wrong; info on the web is sparse, and PubChem has no
         // octa-coordinate structure; lone pairs involved?
@@ -919,7 +914,7 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
     }
 
     @Test
-    public void testCooh() throws Exception {
+    void testCooh() throws Exception {
         IAtomContainer mol = new AtomContainer();
         // this is made up, and may be wrong; info on the web is sparse, and PubChem has no
         // octa-coordinate structure; lone pairs involved?
@@ -935,8 +930,8 @@ public class SybylAtomTypeMatcherTest extends AbstractSybylAtomTypeTest {
         assertAtomTypes(testedAtomTypes, expectedTypes, mol);
     }
 
-    @AfterClass
-    public static void testTestedAtomTypes() throws Exception {
+    @AfterAll
+    static void testTestedAtomTypes() throws Exception {
         countTestedAtomTypes(testedAtomTypes, factory);
     }
 }
