@@ -18,9 +18,8 @@
  */
 package org.openscience.cdk;
 
-import org.hamcrest.CoreMatchers;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.not;
@@ -30,12 +29,12 @@ import static org.hamcrest.CoreMatchers.not;
  *
  * @cdk.module test-core
  */
-public class CDKTest {
+class CDKTest {
 
     @Test
-    public void testGetVersion() {
+    void testGetVersion() {
         String version = CDK.getVersion();
-        Assert.assertNotNull(version);
+        Assertions.assertNotNull(version);
         // see for the expected behavior: http://stackoverflow.com/a/3697482/217943
         org.hamcrest.MatcherAssert.assertThat("The CDK version in build.props is not properly overwritten by Maven.",
                           version,
