@@ -23,7 +23,8 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.ICDKObject;
@@ -34,11 +35,7 @@ import java.util.Iterator;
 import java.util.List;
 
 import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
@@ -57,31 +54,35 @@ public class DynamicFactoryTest {
     /**
      * Ensure a negative size throws an exception.
      */
-    @Test(expected = IllegalArgumentException.class)
-    public void testConstructor() {
-        new DynamicFactory(-1);
+    @Test
+    void testConstructor() {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {new DynamicFactory(-1);});
     }
 
-    /**
+                                 /**
      * Check we can't register an interface.
      */
-    @Test(expected = IllegalArgumentException.class)
-    public void testRegister_Interface() throws Exception {
-
-        DynamicFactory factory = new DynamicFactory(0);
-        factory.register(IAtom.class);
-
-    }
-
-    @Test(expected = IllegalArgumentException.class)
-    public void testRegister_AbstractClass() throws Exception {
-
-        DynamicFactory factory = new DynamicFactory(0);
-        factory.register(MockedAtom.class);
+    @Test
+    void testRegister_Interface() throws Exception {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    DynamicFactory factory = new DynamicFactory(0);
+                                    factory.register(IAtom.class);
+                                });
     }
 
     @Test
-    public void testRegister() throws Exception {
+    void testRegister_AbstractClass() throws Exception {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    DynamicFactory factory = new DynamicFactory(0);
+                                    factory.register(MockedAtom.class);
+                                });
+    }
+
+    @Test
+    void testRegister() throws Exception {
 
         DynamicFactory.InterfaceProvider accessor = mock(DynamicFactory.InterfaceProvider.class);
         IAtom mock = mock(MockedAtom.class);
@@ -90,16 +91,16 @@ public class DynamicFactoryTest {
 
         DynamicFactory factory = new DynamicFactory(accessor, 5);
 
-        assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
+        Assertions.assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
 
         factory.register(mock.getClass());
 
-        assertFalse(factory.implementorsOf(IAtom.class).isEmpty());
+        Assertions.assertFalse(factory.implementorsOf(IAtom.class).isEmpty());
 
     }
 
     @Test
-    public void testRegister_NonCDKInterface() throws Exception {
+    void testRegister_NonCDKInterface() throws Exception {
 
         DynamicFactory.InterfaceProvider accessor = mock(DynamicFactory.InterfaceProvider.class);
         IAtom mock = mock(MockedAtom.class);
@@ -110,47 +111,47 @@ public class DynamicFactoryTest {
 
         DynamicFactory factory = new DynamicFactory(accessor, 5);
 
-        assertFalse(factory.register(mock.getClass()));
+        Assertions.assertFalse(factory.register(mock.getClass()));
 
     }
 
     @Test
-    public void testRegister_Explicit() throws Exception {
+    void testRegister_Explicit() throws Exception {
 
         IAtom mock = mock(MockedAtom.class);
 
         DynamicFactory factory = new DynamicFactory(5);
 
-        assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
+        Assertions.assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
 
         // register the mock class
         factory.register(IAtom.class, mock.getClass());
 
-        assertFalse(factory.implementorsOf(IAtom.class).isEmpty());
+        Assertions.assertFalse(factory.implementorsOf(IAtom.class).isEmpty());
 
         // Atom is a subclass of Element so we can actually register it as
         // element too
 
-        assertTrue(factory.implementorsOf(IElement.class).isEmpty());
+        Assertions.assertTrue(factory.implementorsOf(IElement.class).isEmpty());
 
         factory.register(IElement.class, mock.getClass());
 
-        assertFalse(factory.implementorsOf(IElement.class).isEmpty());
+        Assertions.assertFalse(factory.implementorsOf(IElement.class).isEmpty());
 
     }
 
     @Test
-    public void testRegister_PrivateConstructor() throws Exception {
+    void testRegister_PrivateConstructor() throws Exception {
 
         DynamicFactory factory = new DynamicFactory(5);
 
-        assertTrue(factory.implementorsOf(ICDKObject.class).isEmpty());
+        Assertions.assertTrue(factory.implementorsOf(ICDKObject.class).isEmpty());
 
         // register the mock class
         factory.register(ICDKObject.class, DynamicFactoryTestMock.class);
 
         Iterator<?> it = factory.suggest(ICDKObject.class);
-        List<Object> list = new ArrayList<Object>(5);
+        List<Object> list = new ArrayList<>(5);
         while (it.hasNext()) {
             list.add(it.next());
         }
@@ -160,27 +161,27 @@ public class DynamicFactoryTest {
     }
 
     @Test
-    public void testRegister_Constructor() throws Exception {
+    void testRegister_Constructor() throws Exception {
 
         DynamicFactory factory = new DynamicFactory(5);
 
-        assertTrue(factory.register(ICDKObject.class, DynamicFactoryTestMock.class.getConstructor(String.class)));
+        Assertions.assertTrue(factory.register(ICDKObject.class, DynamicFactoryTestMock.class.getConstructor(String.class)));
 
     }
 
     @SuppressWarnings("unchecked")
     // mocking generics
     @Test
-    public void testRegister_Constructor_Modifier() throws Exception {
+    void testRegister_Constructor_Modifier() throws Exception {
 
         DynamicFactory factory = new DynamicFactory(5);
 
         DynamicFactory.CreationModifier modifier = mock(DynamicFactory.CreationModifier.class);
 
-        assertTrue(factory.register(ICDKObject.class, DynamicFactoryTestMock.class.getConstructor(String.class),
-                modifier));
+        Assertions.assertTrue(factory.register(ICDKObject.class, DynamicFactoryTestMock.class.getConstructor(String.class),
+                                               modifier));
 
-        assertNotNull(factory.ofClass(ICDKObject.class, "empty"));
+        Assertions.assertNotNull(factory.ofClass(ICDKObject.class, "empty"));
 
         // verify the modifier was invoked once
         verify(modifier).modify(any());
@@ -193,24 +194,25 @@ public class DynamicFactoryTest {
      *
      * @throws Exception
      */
-    @Test(expected = IllegalArgumentException.class)
-    public void testRegister_Duplicate() throws Exception {
+    @Test
+    void testRegister_Duplicate() throws Exception {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    DynamicFactory factory = new DynamicFactory(5);
 
-        DynamicFactory factory = new DynamicFactory(5);
+                                    IAtom atom = mock(MockedAtom.class);
+                                    IAtom pseudo = mock(MockedPseudoAtom.class);
 
-        IAtom atom = mock(MockedAtom.class);
-        IAtom pseudo = mock(MockedPseudoAtom.class);
-
-        assertTrue(factory.register(ICDKObject.class, pseudo.getClass()));
-
-        // should throw an exception the mocked atom also has a constructor with
-        // a single String parameter
-        assertFalse(factory.register(ICDKObject.class, atom.getClass()));
+                                    Assertions.assertTrue(factory.register(ICDKObject.class, pseudo.getClass()));
 
+                                    // should throw an exception the mocked atom also has a constructor with
+                                    // a single String parameter
+                                    Assertions.assertFalse(factory.register(ICDKObject.class, atom.getClass()));
+                                });
     }
 
     @Test
-    public void testOfClass_Instantiator() throws Exception {
+    void testOfClass_Instantiator() throws Exception {
 
         DynamicFactory factory = new DynamicFactory(5);
 
@@ -222,18 +224,18 @@ public class DynamicFactoryTest {
             }
         });
 
-        assertNotNull(factory.ofClass(IAtom.class));
+        Assertions.assertNotNull(factory.ofClass(IAtom.class));
 
     }
 
     @Test
-    public void testOfClass() throws Exception {
+    void testOfClass() throws Exception {
 
         IAtom mock = mock(MockedAtom.class);
 
         DynamicFactory factory = new DynamicFactory(5);
 
-        assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
+        Assertions.assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
 
         // register the mock class
         factory.register(IAtom.class, mock.getClass());
@@ -241,7 +243,7 @@ public class DynamicFactoryTest {
         // ofClass needs to know the inner class is coming from 'this'
         IAtom instance = factory.ofClass(IAtom.class, this);
 
-        assertNotNull(instance);
+        Assertions.assertNotNull(instance);
 
     }
 
@@ -249,46 +251,48 @@ public class DynamicFactoryTest {
      * Check we get an exception when we try to build from a non-interface.
      * @throws Exception
      */
-    @Test(expected = IllegalArgumentException.class)
-    public void testOfConcrete_Params() throws Exception {
+    @Test
+    void testOfConcrete_Params() throws Exception {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    IAtom mock = mock(MockedAtom.class);
 
-        IAtom mock = mock(MockedAtom.class);
+                                    DynamicFactory factory = new DynamicFactory(5);
 
-        DynamicFactory factory = new DynamicFactory(5);
+                                    Assertions.assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
 
-        assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
-
-        // register the mock class
-        factory.register(IAtom.class, mock.getClass());
-
-        // ofClass -> illegal argument, non-interface
-        IAtom instance = factory.ofClass(mock.getClass(), this);
-
-    }
-
-    @Test(expected = IllegalArgumentException.class)
-    public void testOfConcrete() throws Exception {
-
-        DynamicFactory factory = new DynamicFactory(5);
-
-        assertTrue(factory.implementorsOf(ICDKObject.class).isEmpty());
-
-        // register the mock class
-        factory.register(ICDKObject.class, DynamicFactoryTestMock.class);
-
-        // ofClass -> illegal argument, non-interface
-        ICDKObject instance = factory.ofClass(DynamicFactoryTestMock.class);
+                                    // register the mock class
+                                    factory.register(IAtom.class, mock.getClass());
 
+                                    // ofClass -> illegal argument, non-interface
+                                    IAtom instance = factory.ofClass(mock.getClass(), this);
+                                });
     }
 
     @Test
-    public void testOfClass_WithParams() throws Exception {
+    void testOfConcrete() throws Exception {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    DynamicFactory factory = new DynamicFactory(5);
+
+                                    Assertions.assertTrue(factory.implementorsOf(ICDKObject.class).isEmpty());
+
+                                    // register the mock class
+                                    factory.register(ICDKObject.class, DynamicFactoryTestMock.class);
+
+                                    // ofClass -> illegal argument, non-interface
+                                    ICDKObject instance = factory.ofClass(DynamicFactoryTestMock.class);
+                                });
+    }
+
+    @Test
+    void testOfClass_WithParams() throws Exception {
 
         IAtom mock = mock(MockedAtom.class);
 
         DynamicFactory factory = new DynamicFactory(5);
 
-        assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
+        Assertions.assertTrue(factory.implementorsOf(IAtom.class).isEmpty());
 
         // register the mock class
         factory.register(IAtom.class, mock.getClass());
@@ -296,9 +300,9 @@ public class DynamicFactoryTest {
         // ofClass needs to know the inner class is coming from 'this'
         IAtom instance = factory.ofClass(IAtom.class, this, "C");
 
-        assertNotNull(instance);
+        Assertions.assertNotNull(instance);
 
-        assertEquals("C", instance.getSymbol());
+        Assertions.assertEquals("C", instance.getSymbol());
 
     }
 
@@ -306,21 +310,21 @@ public class DynamicFactoryTest {
      * Kind of already tested in other methods.
      */
     @Test
-    public void testSuggest() throws Exception {
+    void testSuggest() throws Exception {
 
         DynamicFactory factory = new DynamicFactory(5);
 
         IAtom atom = mock(MockedAtom.class);
 
-        assertFalse(factory.suggest(IAtom.class).hasNext());
+        Assertions.assertFalse(factory.suggest(IAtom.class).hasNext());
 
         factory.register(IAtom.class, atom.getClass());
 
-        assertTrue(factory.suggest(IAtom.class).hasNext());
+        Assertions.assertTrue(factory.suggest(IAtom.class).hasNext());
     }
 
     @Test
-    public void testImplementationsOf() throws Exception {
+    void testImplementationsOf() throws Exception {
 
         DynamicFactory factory = new DynamicFactory(5);
 
@@ -340,35 +344,35 @@ public class DynamicFactoryTest {
     }
 
     @Test
-    public void testKey_Default() {
+    void testKey_Default() {
 
         DynamicFactory.ConstructorKey key = DynamicFactory.key(IAtom.class);
 
-        assertEquals(IAtom.class, key.intf());
-        assertEquals(0, key.n());
+        Assertions.assertEquals(IAtom.class, key.intf());
+        Assertions.assertEquals(0, key.n());
 
     }
 
     @Test
-    public void testKey_Parameters() {
+    void testKey_Parameters() {
 
         DynamicFactory.ConstructorKey key = DynamicFactory.key(IBond.class, IAtom.class, IAtom.class);
 
-        assertEquals(IBond.class, key.intf());
-        assertEquals(2, key.n());
-        assertEquals(IAtom.class, key.type(0));
-        assertEquals(IAtom.class, key.type(1));
+        Assertions.assertEquals(IBond.class, key.intf());
+        Assertions.assertEquals(2, key.n());
+        Assertions.assertEquals(IAtom.class, key.type(0));
+        Assertions.assertEquals(IAtom.class, key.type(1));
 
     }
 
     @Test
-    public void testKey_ArrayParameters() {
+    void testKey_ArrayParameters() {
 
         DynamicFactory.ConstructorKey key = DynamicFactory.key(IBond.class, IAtom[].class);
-        assertEquals(IBond.class, key.intf());
-        assertEquals(1, key.n());
-        assertTrue(key.type(0).isArray());
-        assertEquals(IAtom[].class, key.type(0));
+        Assertions.assertEquals(IBond.class, key.intf());
+        Assertions.assertEquals(1, key.n());
+        Assertions.assertTrue(key.type(0).isArray());
+        Assertions.assertEquals(IAtom[].class, key.type(0));
 
     }
 
@@ -376,21 +380,21 @@ public class DynamicFactoryTest {
      * Ensures primitive types are converted.
      */
     @Test
-    public void testKey_Primitives() {
+    void testKey_Primitives() {
 
         DynamicFactory.ConstructorKey key = DynamicFactory.key(IAtom.class, boolean.class, byte.class, char.class,
                 short.class, int.class, float.class, long.class, double.class);
 
-        assertEquals(IAtom.class, key.intf());
-        assertEquals(8, key.n());
-        assertEquals(Boolean.class, key.type(0));
-        assertEquals(Byte.class, key.type(1));
-        assertEquals(Character.class, key.type(2));
-        assertEquals(Short.class, key.type(3));
-        assertEquals(Integer.class, key.type(4));
-        assertEquals(Float.class, key.type(5));
-        assertEquals(Long.class, key.type(6));
-        assertEquals(Double.class, key.type(7));
+        Assertions.assertEquals(IAtom.class, key.intf());
+        Assertions.assertEquals(8, key.n());
+        Assertions.assertEquals(Boolean.class, key.type(0));
+        Assertions.assertEquals(Byte.class, key.type(1));
+        Assertions.assertEquals(Character.class, key.type(2));
+        Assertions.assertEquals(Short.class, key.type(3));
+        Assertions.assertEquals(Integer.class, key.type(4));
+        Assertions.assertEquals(Float.class, key.type(5));
+        Assertions.assertEquals(Long.class, key.type(6));
+        Assertions.assertEquals(Double.class, key.type(7));
 
     }
 
@@ -400,7 +404,7 @@ public class DynamicFactoryTest {
      * converted to actual varargs - this test checks both cases.
      */
     @Test
-    public void testOfClass_Wrapping() {
+    void testOfClass_Wrapping() {
 
         DynamicFactory factory = new DynamicFactory(5);
 
@@ -414,14 +418,14 @@ public class DynamicFactoryTest {
         });
 
         // uniform parameter array
-        assertNotNull(factory.ofClass(ICDKObject.class, new IAtom[]{mock(IAtom.class), mock(IAtom.class),
+        Assertions.assertNotNull(factory.ofClass(ICDKObject.class, new IAtom[]{mock(IAtom.class), mock(IAtom.class),
                 mock(IAtom.class)}));
 
         // is equivalent to just using varargs...
-        assertNotNull(factory.ofClass(ICDKObject.class, mock(IAtom.class), mock(IAtom.class), mock(IAtom.class)));
+        Assertions.assertNotNull(factory.ofClass(ICDKObject.class, mock(IAtom.class), mock(IAtom.class), mock(IAtom.class)));
 
         // unless we double wrap it (which resolves to the same instantiator)
-        assertNotNull(factory.ofClass(ICDKObject.class, new Object[]{new IAtom[]{mock(IAtom.class), mock(IAtom.class),
+        Assertions.assertNotNull(factory.ofClass(ICDKObject.class, new Object[]{new IAtom[]{mock(IAtom.class), mock(IAtom.class),
                 mock(IAtom.class)}}));
 
     }
@@ -433,7 +437,7 @@ public class DynamicFactoryTest {
      */
     @Test
     @SuppressWarnings("unchecked")
-    public void testRegister_WithModifier() {
+    void testRegister_WithModifier() {
 
         DynamicFactory factory = new DynamicFactory(5);
 
@@ -443,7 +447,7 @@ public class DynamicFactoryTest {
         // ignore compiler warnings here... we're mocking so don't have a set type
         factory.register(IAtom.class, mock.getClass(), modifier);
 
-        assertNotNull(factory.ofClass(IAtom.class));
+        Assertions.assertNotNull(factory.ofClass(IAtom.class));
 
         // verify the modify method was called once
         verify(modifier, times(1)).modify(any());
@@ -456,9 +460,9 @@ public class DynamicFactoryTest {
 
         private String symbol;
 
-        public MockedAtom() {}
+        MockedAtom() {}
 
-        public MockedAtom(String symbol) {
+        MockedAtom(String symbol) {
             this.symbol = symbol;
         }
 
@@ -475,7 +479,7 @@ public class DynamicFactoryTest {
 
     public abstract class MockedPseudoAtom implements IAtom {
 
-        public MockedPseudoAtom(String ignored) {}
+        MockedPseudoAtom(String ignored) {}
 
         @Override
         public abstract IAtom clone() throws CloneNotSupportedException;
@@ -483,7 +487,7 @@ public class DynamicFactoryTest {
 
     public abstract class MockedElement implements IElement {
 
-        public MockedElement(IElement element) {}
+        MockedElement(IElement element) {}
 
         @Override
         public abstract IAtom clone() throws CloneNotSupportedException;
