@@ -1,20 +1,24 @@
 package org.openscience.cdk.graph;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.AtomContainer;
+import org.openscience.cdk.exception.InvalidSmilesException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.io.MDLV2000Reader;
+import org.openscience.cdk.silent.SilentChemObjectBuilder;
+import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.templates.TestMoleculeFactory;
 
+import java.util.Arrays;
 import java.util.Iterator;
 
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 import static org.openscience.cdk.templates.TestMoleculeFactory.makeAnthracene;
 import static org.openscience.cdk.templates.TestMoleculeFactory.makeBicycloRings;
 import static org.openscience.cdk.templates.TestMoleculeFactory.makeBiphenyl;
@@ -29,10 +33,10 @@ import static org.openscience.cdk.templates.TestMoleculeFactory.makeNaphthalene;
  * @author John May
  * @cdk.module test-core
  */
-public class CyclesTest {
+class CyclesTest {
 
     @Test
-    public void all() throws Exception {
+    void all() throws Exception {
         checkSize(Cycles.all(makeBiphenyl()), 2);
         checkSize(Cycles.all(makeBicycloRings()), 3);
         checkSize(Cycles.all(makeNaphthalene()), 3);
@@ -42,7 +46,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void mcb() throws Exception {
+    void mcb() throws Exception {
         checkSize(Cycles.mcb(makeBiphenyl()), 2);
         checkSize(Cycles.mcb(makeBicycloRings()), 2);
         checkSize(Cycles.mcb(makeNaphthalene()), 2);
@@ -52,7 +56,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void relevant() throws Exception {
+    void relevant() throws Exception {
         checkSize(Cycles.relevant(makeBiphenyl()), 2);
         checkSize(Cycles.relevant(makeBicycloRings()), 3);
         checkSize(Cycles.relevant(makeNaphthalene()), 2);
@@ -62,7 +66,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void essential() throws Exception {
+    void essential() throws Exception {
         checkSize(Cycles.essential(makeBiphenyl()), 2);
         checkSize(Cycles.essential(makeBicycloRings()), 0);
         checkSize(Cycles.essential(makeNaphthalene()), 2);
@@ -71,7 +75,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void tripletShort() throws Exception {
+    void tripletShort() throws Exception {
         checkSize(Cycles.tripletShort(makeBiphenyl()), 2);
         checkSize(Cycles.tripletShort(makeBicycloRings()), 3);
         checkSize(Cycles.tripletShort(makeNaphthalene()), 3);
@@ -81,7 +85,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void edgeShort() throws Exception {
+    void edgeShort() throws Exception {
         checkSize(Cycles.edgeShort(makeBiphenyl()), 2);
         checkSize(Cycles.edgeShort(makeBicycloRings()), 3);
         checkSize(Cycles.edgeShort(makeNaphthalene()), 2);
@@ -91,7 +95,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void vertexShort() throws Exception {
+    void vertexShort() throws Exception {
         checkSize(Cycles.vertexShort(makeBiphenyl()), 2);
         checkSize(Cycles.vertexShort(makeBicycloRings()), 3);
         checkSize(Cycles.vertexShort(makeNaphthalene()), 2);
@@ -101,7 +105,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void cdkAromaticSet() throws Exception {
+    void cdkAromaticSet() throws Exception {
         checkSize(Cycles.cdkAromaticSet().find(makeBiphenyl()), 2);
         checkSize(Cycles.cdkAromaticSet().find(makeBicycloRings()), 3);
         checkSize(Cycles.cdkAromaticSet().find(makeNaphthalene()), 3);
@@ -111,7 +115,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void allOrVertexShort() throws Exception {
+    void allOrVertexShort() throws Exception {
         checkSize(Cycles.allOrVertexShort().find(makeBiphenyl()), 2);
         checkSize(Cycles.allOrVertexShort().find(makeBicycloRings()), 3);
         checkSize(Cycles.allOrVertexShort().find(makeNaphthalene()), 3);
@@ -122,7 +126,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void cdkAromaticSet_withGraph() throws Exception {
+    void cdkAromaticSet_withGraph() throws Exception {
         checkSize(Cycles.cdkAromaticSet().find(makeBiphenyl(), GraphUtil.toAdjList(makeBiphenyl()), Integer.MAX_VALUE),
                 2);
         checkSize(
@@ -143,7 +147,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void allOrVertexShort_withGraph() throws Exception {
+    void allOrVertexShort_withGraph() throws Exception {
         checkSize(Cycles.allOrVertexShort()
                 .find(makeBiphenyl(), GraphUtil.toAdjList(makeBiphenyl()), Integer.MAX_VALUE), 2);
         checkSize(
@@ -165,7 +169,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void allUpToLength() throws Exception {
+    void allUpToLength() throws Exception {
         checkSize(Cycles.all(6).find(makeBiphenyl(), GraphUtil.toAdjList(makeBiphenyl()), Integer.MAX_VALUE), 2);
         checkSize(Cycles.all(6).find(makeBicycloRings(), GraphUtil.toAdjList(makeBicycloRings()), Integer.MAX_VALUE), 3);
         checkSize(Cycles.all(6).find(makeNaphthalene(), GraphUtil.toAdjList(makeNaphthalene()), Integer.MAX_VALUE), 2);
@@ -173,7 +177,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void pathsAreCopy() throws Exception {
+    void pathsAreCopy() throws Exception {
         Cycles cs = Cycles.all(makeAnthracene());
         int[][] org = cs.paths();
         org[0][0] = -203; // modify
@@ -181,11 +185,11 @@ public class CyclesTest {
     }
 
     @Test
-    public void toRingSet() throws Exception {
+    void toRingSet() throws Exception {
         IAtomContainer biphenyl = makeBiphenyl();
         IRingSet rs = Cycles.vertexShort(biphenyl).toRingSet();
         Iterator<IAtomContainer> it = rs.atomContainers().iterator();
-        assertTrue(it.hasNext());
+        Assertions.assertTrue(it.hasNext());
         IAtomContainer r1 = it.next();
 
         assertThat(r1.getAtom(0), is(biphenyl.getAtom(0)));
@@ -202,7 +206,7 @@ public class CyclesTest {
         assertThat(r1.getBond(4), is(biphenyl.getBond(4)));
         assertThat(r1.getBond(5), is(biphenyl.getBond(5)));
 
-        assertTrue(it.hasNext());
+        Assertions.assertTrue(it.hasNext());
         IAtomContainer r2 = it.next();
 
         assertThat(r2.getAtom(0), is(biphenyl.getAtom(6)));
@@ -221,7 +225,7 @@ public class CyclesTest {
     }
 
     @Test
-    public void markAtomsAndBonds() throws Exception {
+    void markAtomsAndBonds() throws Exception {
         IAtomContainer biphenyl = makeBiphenyl();
         Cycles.markRingAtomsAndBonds(biphenyl);
         int cyclicAtoms = 0;
@@ -239,14 +243,14 @@ public class CyclesTest {
     }
 
     @Test
-    public void or() throws Exception {
+    void or() throws Exception {
         CycleFinder cf = Cycles.or(Cycles.all(), Cycles.all(3));
         IAtomContainer fullerene = fullerene();
         checkSize(cf.find(fullerene, fullerene.getAtomCount()), 120);
     }
 
     @Test
-    public void unchorded() throws Exception {
+    void unchorded() throws Exception {
         IAtomContainer container = TestMoleculeFactory.makeAnthracene();
         checkSize(Cycles.unchorded(Cycles.all()).find(container), 3);
     }
@@ -265,4 +269,135 @@ public class CyclesTest {
     static void checkSize(Cycles cs, int nCycles) {
         assertThat(cs.numberOfCycles(), is(nCycles));
     }
+
+    private static IAtomContainer loadSmiles(String smi) throws InvalidSmilesException {
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles(smi);
+        return mol;
+    }
+
+    private static void assertRingSizes(String smi, int ... expected) throws InvalidSmilesException {
+        SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        IAtomContainer mol = smipar.parseSmiles(smi);
+        Cycles.markRingAtomsAndBonds(mol);
+        int[] actual = new int[mol.getAtomCount()];
+        Cycles.smallRingSizes(mol, actual);
+        assertThat(Arrays.toString(actual), actual, is(expected));
+    }
+
+    @Test
+    void testSmallRings() throws InvalidSmilesException {
+        assertRingSizes("C1CCCCC1", 6, 6, 6, 6, 6, 6);
+        assertRingSizes("C1CCCC1", 5, 5, 5, 5, 5);
+        // spiro
+        assertRingSizes("C1CCCCC11CCCC1", 6, 6, 6, 6, 6, 5, 5, 5, 5, 5);
+        // fused
+        assertRingSizes("CCC12CCC2CCCC1", 0, 0, 4, 4, 4, 4, 6, 6, 6, 6);
+        assertRingSizes("[nH]1ccc2c1cccc2", 5, 5, 5, 5, 5, 6, 6, 6, 6);
+        // compound
+        assertRingSizes("Clc4cccc(N3CCN(CCCCOc2ccc1c(NC(=O)CC1)c2)CC3)c4Cl",
+                0, 6, 6, 6, 6, 6, 6, 6, 6, 6, 0, 0, 0, 0, 0, 6, 6, 6, 6, 6, 6, 6, 0, 6, 6, 6, 6, 6, 6, 0);
+    }
+
+    @Test
+    void testSmallRing_atom_simple() throws InvalidSmilesException {
+        IAtomContainer mol = loadSmiles("C1CCCCC1");
+        Cycles.markRingAtomsAndBonds(mol); // required
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(0)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(2)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(5)));
+
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(0), 4));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(2), 4));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(5), 4));
+
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(0), 6));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(2), 6));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(5), 6));
+
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(0), 7));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(2), 7));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(5), 7));
+    }
+
+    @Test
+    void testSmallRing_atom_acyclic() throws InvalidSmilesException {
+        IAtomContainer mol = loadSmiles("CCCC");
+        Cycles.markRingAtomsAndBonds(mol); // required
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(0)));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(1)));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(2)));
+    }
+
+    @Test
+    void testSmallRing_atom_indole() throws InvalidSmilesException {
+        IAtomContainer mol = loadSmiles("[nH]1ccc2c1cccc2");
+        Cycles.markRingAtomsAndBonds(mol); // required
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(0)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(1)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(2)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(3)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(4)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(5)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(6)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(7)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getAtom(8)));
+    }
+
+    @Test
+    void testSmallRing_atom_indole_lim() throws InvalidSmilesException {
+        IAtomContainer mol = loadSmiles("[nH]1ccc2c1cccc2");
+        Cycles.markRingAtomsAndBonds(mol); // required
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(0), 5));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(1), 5));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(2), 5));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(3), 5));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getAtom(4), 5));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(5), 5));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(6), 5));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(7), 5));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(8), 5));
+        // limit = 4
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(0), 4));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(1), 4));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(2), 4));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(3), 4));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getAtom(4), 4));
+    }
+
+    @Test
+    void testSmallRing_bond_indole() throws InvalidSmilesException {
+        IAtomContainer mol = loadSmiles("[nH]1ccc2c1cccc2");
+        Cycles.markRingAtomsAndBonds(mol); // required
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(0)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(1)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(2)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(3)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(4)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getBond(5)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getBond(6)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getBond(7)));
+        Assertions.assertEquals(6, Cycles.smallRingSize(mol.getBond(8)));
+    }
+
+    @Test
+    void testSmallRing_bond_spiro() throws InvalidSmilesException {
+        IAtomContainer mol = loadSmiles("C1CCCC11CCC1");
+        Cycles.markRingAtomsAndBonds(mol); // required
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(0)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(1)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(2)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(3)));
+        Assertions.assertEquals(5, Cycles.smallRingSize(mol.getBond(4)));
+        Assertions.assertEquals(4, Cycles.smallRingSize(mol.getBond(5)));
+        Assertions.assertEquals(4, Cycles.smallRingSize(mol.getBond(6)));
+        Assertions.assertEquals(4, Cycles.smallRingSize(mol.getBond(7)));
+        Assertions.assertEquals(4, Cycles.smallRingSize(mol.getBond(8)));
+        // limit=4
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getBond(3), 4));
+        Assertions.assertEquals(4, Cycles.smallRingSize(mol.getBond(7), 4));
+        // limit=3
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getBond(3), 3));
+        Assertions.assertEquals(0, Cycles.smallRingSize(mol.getBond(7), 3));
+    }
 }
