@@ -24,7 +24,8 @@
 
 package org.openscience.cdk.aromaticity;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
@@ -44,10 +45,10 @@ import static org.openscience.cdk.interfaces.IBond.Order.UNSET;
 /**
  * @author John May
  */
-public class KekulizationTest {
+class KekulizationTest {
 
     @Test
-    public void benzene() throws Exception {
+    void benzene() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -66,7 +67,7 @@ public class KekulizationTest {
 
     // when a double bond is already set, it is not moved
     @Test
-    public void benzeneWithExistingDoubleBond() throws Exception {
+    void benzeneWithExistingDoubleBond() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -84,7 +85,7 @@ public class KekulizationTest {
     }
 
     @Test
-    public void pyrrole() throws Exception {
+    void pyrrole() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("N", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -100,7 +101,7 @@ public class KekulizationTest {
     }
 
     @Test
-    public void pyrroleWithExplicitHydrogen() throws Exception {
+    void pyrroleWithExplicitHydrogen() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("N", 0, true));
         m.addAtom(atom("C", 1, true));
@@ -118,25 +119,27 @@ public class KekulizationTest {
     }
 
     /** Hydrogens must be present - otherwise the kekulisation is ambiguous. */
-    @Test(expected = CDKException.class)
-    public void pyrroleWithMissingHydrogen() throws Exception {
-        IAtomContainer m = new AtomContainer(5, 5, 0, 0);
-        m.addAtom(atom("N", 0, true));
-        m.addAtom(atom("C", 1, true));
-        m.addAtom(atom("C", 1, true));
-        m.addAtom(atom("C", 1, true));
-        m.addAtom(atom("C", 1, true));
-        m.addBond(bond(m, 0, 1, UNSET, true));
-        m.addBond(bond(m, 1, 2, UNSET, true));
-        m.addBond(bond(m, 2, 3, UNSET, true));
-        m.addBond(bond(m, 3, 4, UNSET, true));
-        m.addBond(bond(m, 4, 0, UNSET, true));
-        assertBondOrders(m);
+    @Test
+    void pyrroleWithMissingHydrogen() throws Exception {
+        Assertions.assertThrows(CDKException.class, () -> {
+            IAtomContainer m = new AtomContainer(5, 5, 0, 0);
+            m.addAtom(atom("N", 0, true));
+            m.addAtom(atom("C", 1, true));
+            m.addAtom(atom("C", 1, true));
+            m.addAtom(atom("C", 1, true));
+            m.addAtom(atom("C", 1, true));
+            m.addBond(bond(m, 0, 1, UNSET, true));
+            m.addBond(bond(m, 1, 2, UNSET, true));
+            m.addBond(bond(m, 2, 3, UNSET, true));
+            m.addBond(bond(m, 3, 4, UNSET, true));
+            m.addBond(bond(m, 4, 0, UNSET, true));
+            assertBondOrders(m);
+        });
     }
 
     /** @cdk.inchi InChI=1S/C10H8/c1-2-5-9-7-4-8-10(9)6-3-1/h1-8H */
     @Test
-    public void azulene() throws Exception {
+    void azulene() throws Exception {
         IAtomContainer m = new AtomContainer(10, 11, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -164,7 +167,7 @@ public class KekulizationTest {
 
     /** @cdk.inchi InChI=1S/C5H5NO/c7-6-4-2-1-3-5-6/h1-5H */
     @Test
-    public void pyridineOxide() throws Exception {
+    void pyridineOxide() throws Exception {
         IAtomContainer m = new AtomContainer(7, 7, 0, 0);
         m.addAtom(atom("O", 0, false));
         m.addAtom(atom("N", 0, true));
@@ -187,7 +190,7 @@ public class KekulizationTest {
 
     /** @cdk.inchi InChI=1S/C5H5NO/c7-6-4-2-1-3-5-6/h1-5H */
     @Test
-    public void pyridineOxideNonChargeSeparated() throws Exception {
+    void pyridineOxideNonChargeSeparated() throws Exception {
         IAtomContainer m = new AtomContainer(7, 7, 0, 0);
         m.addAtom(atom("O", 0, false));
         m.addAtom(atom("N", 0, true));
@@ -207,7 +210,7 @@ public class KekulizationTest {
     }
 
     @Test
-    public void furane() throws Exception {
+    void furane() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("O", 0, true));
         m.addAtom(atom("C", 1, true));
@@ -228,7 +231,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1S/C4H4Te/c1-2-4-5-3-1/h1-4H
      */
     @Test
-    public void tellurophene() throws Exception {
+    void tellurophene() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("Te", 0, true));
         m.addAtom(atom("C", 1, true));
@@ -247,7 +250,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1S/C5H5/c1-2-4-5-3-1/h1-5H/q-1
      */
     @Test
-    public void carbonAnion() throws Exception {
+    void carbonAnion() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -267,7 +270,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1S/C7H7/c1-2-4-6-7-5-3-1/h1-7H/q+1
      */
     @Test
-    public void tropylium() throws Exception {
+    void tropylium() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -293,7 +296,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1S/C5H5Se/c1-2-4-6-5-3-1/h1-5H/q+1
      */
     @Test
-    public void seleniumCation() throws Exception {
+    void seleniumCation() throws Exception {
         IAtomContainer m = new AtomContainer(6, 6, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -317,7 +320,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1/C11H9N3O3S/c1-18(17)9-5-3-2-4-8(9)14-6-7(10(15)16)12-11(14)13-18/h2-6H,1H3,(H,15,16)
      */
     @Test
-    public void sixValentSulphur() throws Exception {
+    void sixValentSulphur() throws Exception {
         IAtomContainer m = new AtomContainer(18, 20, 0, 0);
         m.addAtom(atom("C", 3, false));
         m.addAtom(atom("S", 0, true));
@@ -365,7 +368,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1S/C12H10/c1-3-7-11(8-4-1)12-9-5-2-6-10-12/h1-10H
      */
     @Test
-    public void biphenyl() throws Exception {
+    void biphenyl() throws Exception {
         IAtomContainer m = new AtomContainer(12, 13, 0, 0);
         m.addAtom(atom("C", 1, true));
         m.addAtom(atom("C", 1, true));
@@ -400,7 +403,7 @@ public class KekulizationTest {
      * @cdk.inchi InChI=1S/C6H4O2/c7-5-1-2-6(8)4-3-5/h1-4H
      */
     @Test
-    public void quinone() throws Exception {
+    void quinone() throws Exception {
         IAtomContainer m = new AtomContainer(8, 8, 0, 0);
         m.addAtom(atom("O", 0, true));
         m.addAtom(atom("C", 0, true));
@@ -425,7 +428,7 @@ public class KekulizationTest {
      * InChI=1S/C13H10/c1-3-7-12-10(5-1)9-11-6-2-4-8-13(11)12/h1-8H,9H2
      */
     @Test
-    public void fluorene() throws Exception {
+    void fluorene() throws Exception {
         IAtomContainer m = new AtomContainer(13, 15, 0, 0);
         m.addAtom(atom("C", 2, false));
         m.addAtom(atom("C", 0, true));
@@ -461,7 +464,7 @@ public class KekulizationTest {
 
     /** @cdk.inchi InChI=1S/C5H5B/c1-2-4-6-5-3-1/h1-5H */
     @Test
-    public void borinine() throws Exception {
+    void borinine() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("B", 0, true));
         m.addAtom(atom("C", 1, true));
@@ -479,7 +482,8 @@ public class KekulizationTest {
     }
 
     // e.g. CHEMBL422679
-    @Test public void sulfurCation() throws Exception {
+    @Test
+    void sulfurCation() throws Exception {
         IAtomContainer m = new AtomContainer(5, 5, 0, 0);
         m.addAtom(atom("S", 1, true));
         m.addAtom(atom("C", 1, true));
