@@ -18,14 +18,13 @@
  */
 package org.openscience.cdk.atomtype;
 
-import java.util.Iterator;
-
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.CDKConstants;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
@@ -41,23 +40,23 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 /**
  * @cdk.module test-standard
  */
-public class EStateAtomTypeMatcherTest extends CDKTestCase {
+class EStateAtomTypeMatcherTest extends CDKTestCase {
 
-    static EStateAtomTypeMatcher matcher;
-    IAtomContainer               mol = null;
+    private static EStateAtomTypeMatcher matcher;
+    private IAtomContainer               mol = null;
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         matcher = new EStateAtomTypeMatcher();
     }
 
-    public EStateAtomTypeMatcherTest() {
+    EStateAtomTypeMatcherTest() {
         super();
     }
 
     @Test
-    public void testEStateAtomTypeMatcher() {
-        Assert.assertNotNull(matcher);
+    void testEStateAtomTypeMatcher() {
+        Assertions.assertNotNull(matcher);
     }
 
     IRingSet getRings() {
@@ -76,7 +75,7 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
     }
 
     @Test
-    public void testFindMatchingAtomType_IAtomContainer() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         final IAtomType.Hybridization thisHybridization = IAtomType.Hybridization.SP3;
@@ -87,12 +86,12 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         IAtomType[] types = matcher.findMatchingAtomTypes(mol);
         for (int i = 0; i < types.length; i++) {
             IAtomType type = matcher.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertEquals(type.getAtomTypeName(), types[i].getAtomTypeName());
+            Assertions.assertEquals(type.getAtomTypeName(), types[i].getAtomTypeName());
         }
     }
 
     @Test
-    public void testSP3Atoms() {
+    void testSP3Atoms() {
         //Testing with CC(C)(C)CC
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
@@ -175,18 +174,18 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b19);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SsCH3", a1));
-        Assert.assertTrue(testAtom("SssssC", a2));
-        Assert.assertTrue(testAtom("SsCH3", a3));
-        Assert.assertTrue(testAtom("SsCH3", a4));
-        Assert.assertTrue(testAtom("SssCH2", a5));
-        Assert.assertTrue(testAtom("SsCH3", a6));
-        Assert.assertTrue(testAtom("SsH", a7));
-        Assert.assertTrue(testAtom("SsH", a8));
+        Assertions.assertTrue(testAtom("SsCH3", a1));
+        Assertions.assertTrue(testAtom("SssssC", a2));
+        Assertions.assertTrue(testAtom("SsCH3", a3));
+        Assertions.assertTrue(testAtom("SsCH3", a4));
+        Assertions.assertTrue(testAtom("SssCH2", a5));
+        Assertions.assertTrue(testAtom("SsCH3", a6));
+        Assertions.assertTrue(testAtom("SsH", a7));
+        Assertions.assertTrue(testAtom("SsH", a8));
     }
 
     @Test
-    public void testSP2Atoms() {
+    void testSP2Atoms() {
         //Test with C=CC=N
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
@@ -225,15 +224,15 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b8);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SdCH2", a1));
-        Assert.assertTrue(testAtom("SdsCH", a2));
-        Assert.assertTrue(testAtom("SdsCH", a3));
-        Assert.assertTrue(testAtom("SdNH", a4));
-        Assert.assertTrue(testAtom("SsH", a9));
+        Assertions.assertTrue(testAtom("SdCH2", a1));
+        Assertions.assertTrue(testAtom("SdsCH", a2));
+        Assertions.assertTrue(testAtom("SdsCH", a3));
+        Assertions.assertTrue(testAtom("SdNH", a4));
+        Assertions.assertTrue(testAtom("SsH", a9));
     }
 
     @Test
-    public void testSPAtoms() {
+    void testSPAtoms() {
         //Testing with  C#CCC#N
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
@@ -268,15 +267,15 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b7);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("StCH", a1));
-        Assert.assertTrue(testAtom("StsC", a2));
-        Assert.assertTrue(testAtom("SssCH2", a3));
-        Assert.assertTrue(testAtom("StsC", a4));
-        Assert.assertTrue(testAtom("StN", a5));
+        Assertions.assertTrue(testAtom("StCH", a1));
+        Assertions.assertTrue(testAtom("StsC", a2));
+        Assertions.assertTrue(testAtom("SssCH2", a3));
+        Assertions.assertTrue(testAtom("StsC", a4));
+        Assertions.assertTrue(testAtom("StN", a5));
     }
 
     @Test
-    public void testAromaticAtoms() {
+    void testAromaticAtoms() {
         //Testing with C1=CN=CC=C1C
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
@@ -343,17 +342,17 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b14);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SaaCH", a1));
-        Assert.assertTrue(testAtom("SaaCH", a2));
-        Assert.assertTrue(testAtom("SaaN", a3));
-        Assert.assertTrue(testAtom("SaaCH", a4));
-        Assert.assertTrue(testAtom("SaaCH", a5));
-        Assert.assertTrue(testAtom("SsaaC", a6));
-        Assert.assertTrue(testAtom("SsCH3", a7));
+        Assertions.assertTrue(testAtom("SaaCH", a1));
+        Assertions.assertTrue(testAtom("SaaCH", a2));
+        Assertions.assertTrue(testAtom("SaaN", a3));
+        Assertions.assertTrue(testAtom("SaaCH", a4));
+        Assertions.assertTrue(testAtom("SaaCH", a5));
+        Assertions.assertTrue(testAtom("SsaaC", a6));
+        Assertions.assertTrue(testAtom("SsCH3", a7));
     }
 
     @Test
-    public void testBenzeneFromSmiles() throws Exception {
+    void testBenzeneFromSmiles() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         mol = sp.parseSmiles("C1=CC=CC=C1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -361,17 +360,15 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         AtomContainerManipulator.convertImplicitToExplicitHydrogens(mol);
 
         matcher.setRingSet(getRings());
-        Iterator<IAtom> atoms = mol.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = atoms.next();
-            if (atom.getSymbol().equals("C")) {
-                Assert.assertTrue(testAtom("SaaCH", atom));
+        for (IAtom atom : mol.atoms()) {
+            if (atom.getAtomicNumber() == IElement.C) {
+                Assertions.assertTrue(testAtom("SaaCH", atom));
             }
         }
     }
 
     @Test
-    public void testNaphthalene() {
+    void testNaphthalene() {
         //Testing with C1=CC2C=CC=CC=2C=C1
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
@@ -460,20 +457,20 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b19);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SaaCH", a1));
-        Assert.assertTrue(testAtom("SaaCH", a2));
-        Assert.assertTrue(testAtom("SaaaC", a3));
-        Assert.assertTrue(testAtom("SaaCH", a4));
-        Assert.assertTrue(testAtom("SaaCH", a5));
-        Assert.assertTrue(testAtom("SaaCH", a6));
-        Assert.assertTrue(testAtom("SaaCH", a7));
-        Assert.assertTrue(testAtom("SaaaC", a8));
-        Assert.assertTrue(testAtom("SaaCH", a9));
-        Assert.assertTrue(testAtom("SaaCH", a10));
+        Assertions.assertTrue(testAtom("SaaCH", a1));
+        Assertions.assertTrue(testAtom("SaaCH", a2));
+        Assertions.assertTrue(testAtom("SaaaC", a3));
+        Assertions.assertTrue(testAtom("SaaCH", a4));
+        Assertions.assertTrue(testAtom("SaaCH", a5));
+        Assertions.assertTrue(testAtom("SaaCH", a6));
+        Assertions.assertTrue(testAtom("SaaCH", a7));
+        Assertions.assertTrue(testAtom("SaaaC", a8));
+        Assertions.assertTrue(testAtom("SaaCH", a9));
+        Assertions.assertTrue(testAtom("SaaCH", a10));
     }
 
     @Test
-    public void testChargedAtoms() {
+    void testChargedAtoms() {
         //Testing with C[N+]
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "C");
@@ -509,12 +506,12 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b7);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SsCH3", a1));
-        Assert.assertTrue(testAtom("SsNpH3", a2));
+        Assertions.assertTrue(testAtom("SsCH3", a1));
+        Assertions.assertTrue(testAtom("SsNpH3", a2));
     }
 
     @Test
-    public void testNaCl() {
+    void testNaCl() {
         //Testing with [Na+].[Cl-]
         mol = new AtomContainer();
         IAtom a1 = mol.getBuilder().newInstance(IAtom.class, "Na");
@@ -525,8 +522,8 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addAtom(a2);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SNap", a1));
-        Assert.assertTrue(testAtom("SClm", a2));
+        Assertions.assertTrue(testAtom("SNap", a1));
+        Assertions.assertTrue(testAtom("SClm", a2));
 
         //Testing with different presentation - [Na]Cl
         mol = new AtomContainer();
@@ -538,8 +535,8 @@ public class EStateAtomTypeMatcherTest extends CDKTestCase {
         mol.addBond(b1);
 
         matcher.setRingSet(getRings());
-        Assert.assertTrue(testAtom("SsNa", a1));
-        Assert.assertTrue(testAtom("SsCl", a2));
+        Assertions.assertTrue(testAtom("SsNa", a1));
+        Assertions.assertTrue(testAtom("SsCl", a2));
     }
 
 }
