@@ -18,37 +18,37 @@
  */
 package org.openscience.cdk.tools;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @cdk.module test-standard
  */
-public class ElementComparatorTest extends CDKTestCase {
+class ElementComparatorTest extends CDKTestCase {
 
-    public ElementComparatorTest() {
+    ElementComparatorTest() {
         super();
     }
 
     @Test
-    public void testElementComparator() {
+    void testElementComparator() {
         ElementComparator comp = new ElementComparator();
-        Assert.assertNotNull(comp);
+        Assertions.assertNotNull(comp);
     }
 
     /**
      * @cdk.bug 1638375
      */
     @Test
-    public void testCompare_Object_Object() {
+    void testCompare_Object_Object() {
         ElementComparator comp = new ElementComparator();
 
-        Assert.assertTrue(comp.compare("C", "H") < 0);
-        Assert.assertTrue(comp.compare("H", "O") < 0);
-        Assert.assertTrue(comp.compare("N", "O") < 0);
-        Assert.assertEquals(0, comp.compare("Cl", "Cl"));
-        Assert.assertTrue(comp.compare("Cl", "C") > 0);
+        Assertions.assertTrue(comp.compare("C", "H") < 0);
+        Assertions.assertTrue(comp.compare("H", "O") < 0);
+        Assertions.assertTrue(comp.compare("N", "O") < 0);
+        Assertions.assertEquals(0, comp.compare("Cl", "Cl"));
+        Assertions.assertTrue(comp.compare("Cl", "C") > 0);
     }
 
 }
