@@ -22,197 +22,197 @@
  */
 package org.openscience.cdk.tools;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @author     egonw
  * @cdk.module test-standard
  */
-public class FormatStringBufferTest extends CDKTestCase {
+class FormatStringBufferTest extends CDKTestCase {
 
     private FormatStringBuffer fsb;
 
-    public FormatStringBufferTest() {
+    FormatStringBufferTest() {
         super();
     }
 
-    @Before
-    public void setUp() {
+    @BeforeEach
+    void setUp() {
         fsb = new FormatStringBuffer("[%s]");
     }
 
     @Test
-    public void testFormat_String() {
+    void testFormat_String() {
         fsb.reset("[%s]").format("test");
-        Assert.assertEquals("[test]", fsb.toString());
+        Assertions.assertEquals("[test]", fsb.toString());
 
         fsb.reset("[%5s]").format("test");
-        Assert.assertEquals("[ test]", fsb.toString());
+        Assertions.assertEquals("[ test]", fsb.toString());
     }
 
     @Test
-    public void testToString() {
+    void testToString() {
         fsb.reset("[%-5s]").format("test");
-        Assert.assertEquals("[test ]", fsb.toString());
+        Assertions.assertEquals("[test ]", fsb.toString());
 
         fsb.reset("[%5.2s]").format("test");
-        Assert.assertEquals("[   te]", fsb.toString());
+        Assertions.assertEquals("[   te]", fsb.toString());
 
         fsb.reset("[%-5.2s]").format("test");
-        Assert.assertEquals("[te   ]", fsb.toString());
+        Assertions.assertEquals("[te   ]", fsb.toString());
     }
 
     @Test
-    public void testFormat_char() {
+    void testFormat_char() {
         fsb.reset("[%c]").format('A');
-        Assert.assertEquals("[A]", fsb.toString());
+        Assertions.assertEquals("[A]", fsb.toString());
 
         fsb.reset("[%2c]").format('A');
-        Assert.assertEquals("[ A]", fsb.toString());
+        Assertions.assertEquals("[ A]", fsb.toString());
 
         fsb.reset("[%-2c]").format('A');
-        Assert.assertEquals("[A ]", fsb.toString());
+        Assertions.assertEquals("[A ]", fsb.toString());
     }
 
     @Test
-    public void testFormat_double() {
+    void testFormat_double() {
         fsb.reset("[%f]").format(3.1415);
-        Assert.assertEquals("[3.1415]", fsb.toString());
+        Assertions.assertEquals("[3.1415]", fsb.toString());
 
         fsb.reset("[%g]").format(3.1415);
-        Assert.assertEquals("[3.1415]", fsb.toString());
+        Assertions.assertEquals("[3.1415]", fsb.toString());
 
         fsb.reset("[%+f]").format(3.1415);
-        Assert.assertEquals("[+3.1415]", fsb.toString());
+        Assertions.assertEquals("[+3.1415]", fsb.toString());
 
         fsb.reset("[%+10f]").format(3.1415);
-        Assert.assertEquals("[   +3.1415]", fsb.toString());
+        Assertions.assertEquals("[   +3.1415]", fsb.toString());
 
         fsb.reset("[%-+10f]").format(3.1415);
-        Assert.assertEquals("[+3.1415   ]", fsb.toString());
+        Assertions.assertEquals("[+3.1415   ]", fsb.toString());
 
         fsb.reset("[%.3f]").format(3.1415);
-        Assert.assertEquals("[3.142]", fsb.toString());
+        Assertions.assertEquals("[3.142]", fsb.toString());
 
         fsb.reset("[%e]").format(3.1415);
-        Assert.assertEquals("[3.1415e00]", fsb.toString());
+        Assertions.assertEquals("[3.1415e00]", fsb.toString());
 
         fsb.reset("[%+e]").format(3.1415);
-        Assert.assertEquals("[+3.1415e00]", fsb.toString());
+        Assertions.assertEquals("[+3.1415e00]", fsb.toString());
 
         fsb.reset("[%+11e]").format(3.1415);
-        Assert.assertEquals("[ +3.1415e00]", fsb.toString());
+        Assertions.assertEquals("[ +3.1415e00]", fsb.toString());
 
         fsb.reset("[%-+11e]").format(3.1415);
-        Assert.assertEquals("[+3.1415e00 ]", fsb.toString());
+        Assertions.assertEquals("[+3.1415e00 ]", fsb.toString());
 
         fsb.reset("[%.3e]").format(3.1415);
-        Assert.assertEquals("[3.142e00]", fsb.toString());
+        Assertions.assertEquals("[3.142e00]", fsb.toString());
 
         fsb.reset("[%E]").format(3.1415);
-        Assert.assertEquals("[3.1415E00]", fsb.toString());
+        Assertions.assertEquals("[3.1415E00]", fsb.toString());
     }
 
     @Test
-    public void testFormat_int() {
+    void testFormat_int() {
         fsb.reset("[%d]").format(600);
-        Assert.assertEquals("[600]", fsb.toString());
+        Assertions.assertEquals("[600]", fsb.toString());
 
         fsb.reset("[%5d]").format(600);
-        Assert.assertEquals("[  600]", fsb.toString());
+        Assertions.assertEquals("[  600]", fsb.toString());
 
         fsb.reset("[%5d]").format(-600);
-        Assert.assertEquals("[ -600]", fsb.toString());
+        Assertions.assertEquals("[ -600]", fsb.toString());
 
         fsb.reset("[%05d]").format(600);
-        Assert.assertEquals("[00600]", fsb.toString());
+        Assertions.assertEquals("[00600]", fsb.toString());
 
         fsb.reset("[%05d]").format(-600);
-        Assert.assertEquals("[-0600]", fsb.toString());
+        Assertions.assertEquals("[-0600]", fsb.toString());
 
         fsb.reset("[%x]").format(10);
-        Assert.assertEquals("[a]", fsb.toString());
+        Assertions.assertEquals("[a]", fsb.toString());
 
         fsb.reset("[%X]").format(10);
-        Assert.assertEquals("[A]", fsb.toString());
+        Assertions.assertEquals("[A]", fsb.toString());
 
         fsb.reset("[%o]").format(10);
-        Assert.assertEquals("[12]", fsb.toString());
+        Assertions.assertEquals("[12]", fsb.toString());
 
         fsb.reset("[%4X]").format(10);
-        Assert.assertEquals("[   A]", fsb.toString());
+        Assertions.assertEquals("[   A]", fsb.toString());
 
         fsb.reset("[%#4x]").format(10);
-        Assert.assertEquals("[ 0xa]", fsb.toString());
+        Assertions.assertEquals("[ 0xa]", fsb.toString());
 
         fsb.reset("[%#4o]").format(10);
-        Assert.assertEquals("[ 012]", fsb.toString());
+        Assertions.assertEquals("[ 012]", fsb.toString());
 
         fsb.reset("[%#04x]").format(10);
-        Assert.assertEquals("[0x0a]", fsb.toString());
+        Assertions.assertEquals("[0x0a]", fsb.toString());
 
         fsb.reset("[%#04o]").format(10);
-        Assert.assertEquals("[0012]", fsb.toString());
+        Assertions.assertEquals("[0012]", fsb.toString());
 
         fsb.reset();
-        Assert.assertEquals("[%#04o]", fsb.toString());
+        Assertions.assertEquals("[%#04o]", fsb.toString());
     }
 
     @Test
-    public void testFormat_long() {
+    void testFormat_long() {
         fsb.reset("[%d]").format((long) 600);
-        Assert.assertEquals("[600]", fsb.toString());
+        Assertions.assertEquals("[600]", fsb.toString());
 
         fsb.reset("[%5d]").format((long) 600);
-        Assert.assertEquals("[  600]", fsb.toString());
+        Assertions.assertEquals("[  600]", fsb.toString());
 
         fsb.reset("[%5d]").format((long) -600);
-        Assert.assertEquals("[ -600]", fsb.toString());
+        Assertions.assertEquals("[ -600]", fsb.toString());
 
         fsb.reset("[%05d]").format((long) 600);
-        Assert.assertEquals("[00600]", fsb.toString());
+        Assertions.assertEquals("[00600]", fsb.toString());
 
         fsb.reset("[%05d]").format((long) -600);
-        Assert.assertEquals("[-0600]", fsb.toString());
+        Assertions.assertEquals("[-0600]", fsb.toString());
 
         fsb.reset("[%x]").format((long) 10);
-        Assert.assertEquals("[a]", fsb.toString());
+        Assertions.assertEquals("[a]", fsb.toString());
 
         fsb.reset("[%X]").format((long) 10);
-        Assert.assertEquals("[A]", fsb.toString());
+        Assertions.assertEquals("[A]", fsb.toString());
 
         fsb.reset("[%o]").format((long) 10);
-        Assert.assertEquals("[12]", fsb.toString());
+        Assertions.assertEquals("[12]", fsb.toString());
 
         fsb.reset("[%4X]").format((long) 10);
-        Assert.assertEquals("[   A]", fsb.toString());
+        Assertions.assertEquals("[   A]", fsb.toString());
 
         fsb.reset("[%#4x]").format((long) 10);
-        Assert.assertEquals("[ 0xa]", fsb.toString());
+        Assertions.assertEquals("[ 0xa]", fsb.toString());
 
         fsb.reset("[%#4o]").format((long) 10);
-        Assert.assertEquals("[ 012]", fsb.toString());
+        Assertions.assertEquals("[ 012]", fsb.toString());
 
         fsb.reset("[%#04x]").format((long) 10);
-        Assert.assertEquals("[0x0a]", fsb.toString());
+        Assertions.assertEquals("[0x0a]", fsb.toString());
 
         fsb.reset("[%#04o]").format((long) 10);
-        Assert.assertEquals("[0012]", fsb.toString());
+        Assertions.assertEquals("[0012]", fsb.toString());
     }
 
     @Test
-    public void testReset() {
+    void testReset() {
         fsb.reset();
-        Assert.assertEquals("[%s]", fsb.toString());
+        Assertions.assertEquals("[%s]", fsb.toString());
     }
 
     @Test
-    public void testReset_String() {
+    void testReset_String() {
         fsb.reset("[%#04o]").format((long) 10);
         fsb.reset();
-        Assert.assertEquals("[%#04o]", fsb.toString());
+        Assertions.assertEquals("[%#04o]", fsb.toString());
     }
 }
