@@ -19,12 +19,11 @@
 package org.openscience.cdk.tools.manipulator;
 
 import java.io.InputStream;
-import java.util.Iterator;
 import java.util.List;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.test.CDKTestCase;
@@ -43,37 +42,37 @@ import org.openscience.cdk.io.MDLRXNReader;
 /**
  * @cdk.module test-standard
  */
-public class ReactionSetManipulatorTest extends CDKTestCase {
+class ReactionSetManipulatorTest extends CDKTestCase {
 
     private IChemObjectBuilder builder;
     private ReactionSet        set;
 
-    public ReactionSetManipulatorTest() {
+    ReactionSetManipulatorTest() {
         super();
     }
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         builder = DefaultChemObjectBuilder.getInstance();
         String filename1 = "reaction-1.rxn";
         InputStream ins1 = this.getClass().getResourceAsStream(filename1);
         MDLRXNReader reader1 = new MDLRXNReader(ins1);
-        set = (ReactionSet) reader1.read(new ReactionSet());
+        set = reader1.read(new ReactionSet());
         reader1.close();
     }
 
     @Test
-    public void testGetAllMolecules_IReactionSet() {
+    void testGetAllMolecules_IReactionSet() {
         IReactionSet reactionSet = builder.newInstance(IReactionSet.class);
         reactionSet.addReaction(builder.newInstance(IReaction.class)); // 1
         reactionSet.addReaction(builder.newInstance(IReaction.class)); // 2
 
-        Assert.assertEquals(0, ReactionSetManipulator.getAllMolecules(reactionSet).getAtomContainerCount());
+        Assertions.assertEquals(0, ReactionSetManipulator.getAllMolecules(reactionSet).getAtomContainerCount());
 
     }
 
     @Test
-    public void testGetAllMolecules_IReactionSet2() {
+    void testGetAllMolecules_IReactionSet2() {
         IReactionSet reactionSet = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
@@ -85,76 +84,64 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction2.addReactant(molecule);
         reactionSet.addReaction(reaction2);
 
-        Assert.assertEquals(3, ReactionSetManipulator.getAllMolecules(reactionSet).getAtomContainerCount());
+        Assertions.assertEquals(3, ReactionSetManipulator.getAllMolecules(reactionSet).getAtomContainerCount());
 
     }
 
     @Test
-    public void testGetAtomCount_IReactionSet() throws Exception {
-        Assert.assertEquals(19, ReactionSetManipulator.getAtomCount(set));
+    void testGetAtomCount_IReactionSet() throws Exception {
+        Assertions.assertEquals(19, ReactionSetManipulator.getAtomCount(set));
     }
 
     @Test
-    public void testGetBondCount_IReactionSet() throws Exception {
-        Assert.assertEquals(18, ReactionSetManipulator.getBondCount(set));
+    void testGetBondCount_IReactionSet() throws Exception {
+        Assertions.assertEquals(18, ReactionSetManipulator.getBondCount(set));
     }
 
     @Test
-    public void testGetAllAtomContainers_IReactionSet() throws Exception {
-        Assert.assertEquals(3, ReactionSetManipulator.getAllAtomContainers(set).size());
+    void testGetAllAtomContainers_IReactionSet() throws Exception {
+        Assertions.assertEquals(3, ReactionSetManipulator.getAllAtomContainers(set).size());
     }
 
     @Test
-    public void testGetRelevantReaction_IReactionSet_IAtom() {
-        Iterator<IAtomContainer> atomContainers = ReactionSetManipulator.getAllAtomContainers(set).iterator();
-        while (atomContainers.hasNext()) {
-            IAtomContainer container = atomContainers.next();
+    void testGetRelevantReaction_IReactionSet_IAtom() {
+        for (IAtomContainer container : ReactionSetManipulator.getAllAtomContainers(set)) {
             IAtom anAtom = container.getAtom(0);
-            Assert.assertEquals(set.getReaction(0), ReactionSetManipulator.getRelevantReaction(set, anAtom));
+            Assertions.assertEquals(set.getReaction(0), ReactionSetManipulator.getRelevantReaction(set, anAtom));
         }
     }
 
     @Test
-    public void testGetRelevantReaction_IReactionSet_IBond() {
-        Iterator<IAtomContainer> atomContainers = ReactionSetManipulator.getAllAtomContainers(set).iterator();
-        while (atomContainers.hasNext()) {
-            IAtomContainer container = atomContainers.next();
+    void testGetRelevantReaction_IReactionSet_IBond() {
+        for (IAtomContainer container : ReactionSetManipulator.getAllAtomContainers(set)) {
             IBond aBond = container.getBond(0);
-            Assert.assertEquals(set.getReaction(0), ReactionSetManipulator.getRelevantReaction(set, aBond));
+            Assertions.assertEquals(set.getReaction(0), ReactionSetManipulator.getRelevantReaction(set, aBond));
         }
     }
 
     @Test
-    public void testGetRelevantAtomContainer_IReactionSet_IAtom() {
-        Iterator<IAtomContainer> atomContainers = ReactionSetManipulator.getAllAtomContainers(set).iterator();
-        while (atomContainers.hasNext()) {
-            IAtomContainer container = atomContainers.next();
+    void testGetRelevantAtomContainer_IReactionSet_IAtom() {
+        for (IAtomContainer container : ReactionSetManipulator.getAllAtomContainers(set)) {
             IAtom anAtom = container.getAtom(0);
-            Assert.assertEquals(container, ReactionSetManipulator.getRelevantAtomContainer(set, anAtom));
+            Assertions.assertEquals(container, ReactionSetManipulator.getRelevantAtomContainer(set, anAtom));
         }
     }
 
     @Test
-    public void testGetRelevantAtomContainer_IReactionSet_IBond() {
-        Iterator<IAtomContainer> atomContainers = ReactionSetManipulator.getAllAtomContainers(set).iterator();
-        while (atomContainers.hasNext()) {
-            IAtomContainer container = atomContainers.next();
+    void testGetRelevantAtomContainer_IReactionSet_IBond() {
+        for (IAtomContainer container : ReactionSetManipulator.getAllAtomContainers(set)) {
             IBond aBond = container.getBond(0);
-            Assert.assertEquals(container, ReactionSetManipulator.getRelevantAtomContainer(set, aBond));
+            Assertions.assertEquals(container, ReactionSetManipulator.getRelevantAtomContainer(set, aBond));
         }
     }
 
     @Test
-    public void testSetAtomProperties_IReactionSet_Object_Object() throws Exception {
+    void testSetAtomProperties_IReactionSet_Object_Object() throws Exception {
         ReactionSetManipulator.setAtomProperties(set, "test", "ok");
-        Iterator<IAtomContainer> atomContainers = ReactionSetManipulator.getAllAtomContainers(set).iterator();
-        while (atomContainers.hasNext()) {
-            IAtomContainer container = atomContainers.next();
-            Iterator<IAtom> atoms = container.atoms().iterator();
-            while (atoms.hasNext()) {
-                IAtom atom = atoms.next();
-                Assert.assertNotNull(atom.getProperty("test"));
-                Assert.assertEquals("ok", atom.getProperty("test"));
+        for (IAtomContainer container : ReactionSetManipulator.getAllAtomContainers(set)) {
+            for (IAtom atom : container.atoms()) {
+                Assertions.assertNotNull(atom.getProperty("test"));
+                Assertions.assertEquals("ok", atom.getProperty("test"));
             }
         }
         // reset things
@@ -162,15 +149,15 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
     }
 
     @Test
-    public void testGetAllChemObjects_IReactionSet() {
+    void testGetAllChemObjects_IReactionSet() {
         List<IChemObject> allObjects = ReactionSetManipulator.getAllChemObjects(set);
         // does not recurse beyond the IAtomContainer, so:
         // set, reaction, 2xreactant, 1xproduct
-        Assert.assertEquals(5, allObjects.size());
+        Assertions.assertEquals(5, allObjects.size());
     }
 
     @Test
-    public void testRemoveElectronContainer_IReactionSet_IElectronContainer() {
+    void testRemoveElectronContainer_IReactionSet_IElectronContainer() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction = builder.newInstance(IReaction.class);
         set.addReaction(reaction);
@@ -178,8 +165,8 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
         mol.addBond(0, 1, Order.SINGLE);
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         reaction.addReactant(mol);
         reaction.addReactant(builder.newInstance(IAtomContainer.class));
         reaction.addReactant(builder.newInstance(IAtomContainer.class));
@@ -187,13 +174,13 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction.addProduct(builder.newInstance(IAtomContainer.class));
         ReactionSetManipulator.removeElectronContainer(set, mol.getBond(0));
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(0, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(0, mol.getBondCount());
 
     }
 
     @Test
-    public void testRemoveAtomAndConnectedElectronContainers_IReactionSet_IAtom() {
+    void testRemoveAtomAndConnectedElectronContainers_IReactionSet_IAtom() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction = builder.newInstance(IReaction.class);
         set.addReaction(reaction);
@@ -201,8 +188,8 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
         mol.addBond(0, 1, Order.SINGLE);
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         reaction.addReactant(mol);
         reaction.addReactant(builder.newInstance(IAtomContainer.class));
         reaction.addReactant(builder.newInstance(IAtomContainer.class));
@@ -210,12 +197,12 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction.addProduct(builder.newInstance(IAtomContainer.class));
         ReactionSetManipulator.removeAtomAndConnectedElectronContainers(set, mol.getAtom(0));
 
-        Assert.assertEquals(1, mol.getAtomCount());
-        Assert.assertEquals(0, mol.getBondCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(0, mol.getBondCount());
     }
 
     @Test
-    public void testGetAllIDs_IReactionSet() {
+    void testGetAllIDs_IReactionSet() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         set.addReaction(reaction1);
@@ -232,12 +219,12 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         set.addReaction(reaction2);
 
         List<String> ids = ReactionSetManipulator.getAllIDs(set);
-        Assert.assertNotNull(ids);
-        Assert.assertEquals(6, ids.size());
+        Assertions.assertNotNull(ids);
+        Assertions.assertEquals(6, ids.size());
     }
 
     @Test
-    public void testGetRelevantReactions_IReactionSet_IAtomContainer() {
+    void testGetRelevantReactions_IReactionSet_IAtomContainer() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         set.addReaction(reaction1);
@@ -258,19 +245,19 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction3.addProduct(builder.newInstance(IAtomContainer.class));
         set.addReaction(reaction3);
 
-        Assert.assertEquals(3, set.getReactionCount());
+        Assertions.assertEquals(3, set.getReactionCount());
         IReactionSet reactionSet2 = ReactionSetManipulator.getRelevantReactions(set, mol1b);
-        Assert.assertEquals(2, reactionSet2.getReactionCount());
-        Assert.assertEquals(reaction1, reactionSet2.getReaction(0));
-        Assert.assertEquals(reaction2, reactionSet2.getReaction(1));
+        Assertions.assertEquals(2, reactionSet2.getReactionCount());
+        Assertions.assertEquals(reaction1, reactionSet2.getReaction(0));
+        Assertions.assertEquals(reaction2, reactionSet2.getReaction(1));
         IReactionSet reactionSet1 = ReactionSetManipulator.getRelevantReactions(set, mol1a);
-        Assert.assertEquals(1, reactionSet1.getReactionCount());
-        Assert.assertEquals(reaction1, reactionSet1.getReaction(0));
+        Assertions.assertEquals(1, reactionSet1.getReactionCount());
+        Assertions.assertEquals(reaction1, reactionSet1.getReaction(0));
 
     }
 
     @Test
-    public void testGetRelevantReactionsAsReactant_IReactionSet_IAtomContainer() {
+    void testGetRelevantReactionsAsReactant_IReactionSet_IAtomContainer() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         set.addReaction(reaction1);
@@ -291,19 +278,19 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction3.addProduct(builder.newInstance(IAtomContainer.class));
         set.addReaction(reaction3);
 
-        Assert.assertEquals(3, set.getReactionCount());
+        Assertions.assertEquals(3, set.getReactionCount());
         IReactionSet reactionSet2 = ReactionSetManipulator.getRelevantReactionsAsReactant(set, mol1b);
-        Assert.assertEquals(2, reactionSet2.getReactionCount());
-        Assert.assertEquals(reaction1, reactionSet2.getReaction(0));
-        Assert.assertEquals(reaction2, reactionSet2.getReaction(1));
+        Assertions.assertEquals(2, reactionSet2.getReactionCount());
+        Assertions.assertEquals(reaction1, reactionSet2.getReaction(0));
+        Assertions.assertEquals(reaction2, reactionSet2.getReaction(1));
         IReactionSet reactionSet1 = ReactionSetManipulator.getRelevantReactionsAsReactant(set, mol1a);
-        Assert.assertEquals(1, reactionSet1.getReactionCount());
-        Assert.assertEquals(reaction1, reactionSet1.getReaction(0));
+        Assertions.assertEquals(1, reactionSet1.getReactionCount());
+        Assertions.assertEquals(reaction1, reactionSet1.getReaction(0));
 
     }
 
     @Test
-    public void testGetRelevantReactionsAsProduct_IReactionSet_IAtomContainer() {
+    void testGetRelevantReactionsAsProduct_IReactionSet_IAtomContainer() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         set.addReaction(reaction1);
@@ -324,17 +311,17 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction3.addProduct(mol1a);
         set.addReaction(reaction3);
 
-        Assert.assertEquals(3, set.getReactionCount());
+        Assertions.assertEquals(3, set.getReactionCount());
         IReactionSet reactionSet2 = ReactionSetManipulator.getRelevantReactionsAsProduct(set, mol1b);
-        Assert.assertEquals(0, reactionSet2.getReactionCount());
+        Assertions.assertEquals(0, reactionSet2.getReactionCount());
         IReactionSet reactionSet1 = ReactionSetManipulator.getRelevantReactionsAsProduct(set, mol1a);
-        Assert.assertEquals(1, reactionSet1.getReactionCount());
-        Assert.assertEquals(reaction3, reactionSet1.getReaction(0));
+        Assertions.assertEquals(1, reactionSet1.getReactionCount());
+        Assertions.assertEquals(reaction3, reactionSet1.getReaction(0));
 
     }
 
     @Test
-    public void testGetReactionByReactionID_IReactionSet_String() {
+    void testGetReactionByReactionID_IReactionSet_String() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         reaction1.setID("1");
@@ -357,12 +344,12 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction3.addReactant(builder.newInstance(IAtomContainer.class));
         reaction3.addProduct(mol1a);
         set.addReaction(reaction3);
-        Assert.assertEquals(reaction1, ReactionSetManipulator.getReactionByReactionID(set, "1"));
-        Assert.assertNull(ReactionSetManipulator.getReactionByAtomContainerID(set, "4"));
+        Assertions.assertEquals(reaction1, ReactionSetManipulator.getReactionByReactionID(set, "1"));
+        Assertions.assertNull(ReactionSetManipulator.getReactionByAtomContainerID(set, "4"));
     }
 
     @Test
-    public void testGetReactionByAtomContainerID_IReactionSet_String() {
+    void testGetReactionByAtomContainerID_IReactionSet_String() {
         IReactionSet set = builder.newInstance(IReactionSet.class);
         IReaction reaction1 = builder.newInstance(IReaction.class);
         set.addReaction(reaction1);
@@ -384,8 +371,8 @@ public class ReactionSetManipulatorTest extends CDKTestCase {
         reaction3.addReactant(builder.newInstance(IAtomContainer.class));
         reaction3.addProduct(builder.newInstance(IAtomContainer.class));
         set.addReaction(reaction3);
-        Assert.assertEquals(reaction1, ReactionSetManipulator.getReactionByAtomContainerID(set, "1"));
-        Assert.assertEquals(reaction2, ReactionSetManipulator.getReactionByAtomContainerID(set, "2"));
-        Assert.assertNull(ReactionSetManipulator.getReactionByAtomContainerID(set, "3"));
+        Assertions.assertEquals(reaction1, ReactionSetManipulator.getReactionByAtomContainerID(set, "1"));
+        Assertions.assertEquals(reaction2, ReactionSetManipulator.getReactionByAtomContainerID(set, "2"));
+        Assertions.assertNull(ReactionSetManipulator.getReactionByAtomContainerID(set, "3"));
     }
 }
