@@ -22,8 +22,8 @@
  */
 package org.openscience.cdk.fingerprint;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
@@ -48,7 +48,7 @@ import static org.hamcrest.CoreMatchers.is;
 /**
  * @cdk.module test-standard
  */
-public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinterTest {
+abstract class AbstractFixedLengthFingerprinterTest extends AbstractFingerprinterTest {
 
     // logical 'AND' or two bit sets (orginals are not modified)
     static BitSet and(BitSet a, BitSet b) {
@@ -61,7 +61,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
      * @cdk.bug 706786
      */
     @Test
-    public void testBug706786() throws Exception {
+    void testBug706786() throws Exception {
         // inlined molecules - note this test fails if implicit hydrogens are
         // included. generally MACCS and ESTATE can't be used for substructure filter
         // check those subclasses which check the bits are set
@@ -84,7 +84,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
      * @cdk.bug 853254
      */
     @Test
-    public void testBug853254() throws Exception {
+    void testBug853254() throws Exception {
         IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
         String filename = "bug853254-2.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -108,7 +108,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
         BitSet superBS = fingerprinter.getBitFingerprint(superstructure).asBitSet();
         BitSet subBS = fingerprinter.getBitFingerprint(substructure).asBitSet();
         boolean isSubset = FingerprinterTool.isSubset(superBS, subBS);
-        Assert.assertTrue(isSubset);
+        Assertions.assertTrue(isSubset);
     }
 
     /**
@@ -117,7 +117,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
      * @cdk.bug 934819
      */
     @Test
-    public void testBug934819() throws Exception {
+    void testBug934819() throws Exception {
         // inlined molecules - note this test fails if implicit hydrogens are
         // included. generally PubCheMFingerprint can't be used for substructure filter
         IAtomContainer superStructure = bug934819_2();
@@ -141,17 +141,17 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
      * @cdk.bug 771485
      */
     @Test
-    public void testBug771485() throws Exception {
+    void testBug771485() throws Exception {
         IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
         String filename = "bug771485-1.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        IAtomContainer structure1 = (IAtomContainer) reader.read(builder.newAtomContainer());
+        IAtomContainer structure1 = reader.read(builder.newAtomContainer());
 
         filename = "bug771485-2.mol";
         ins = this.getClass().getResourceAsStream(filename);
         reader = new MDLV2000Reader(ins, Mode.STRICT);
-        IAtomContainer structure2 = (IAtomContainer) reader.read(builder.newAtomContainer());
+        IAtomContainer structure2 = reader.read(builder.newAtomContainer());
 
         // these molecules are different resonance forms of the same molecule
         // make sure aromaticity is detected. although some fingerprinters do this
@@ -176,7 +176,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
         BitSet superBS = fingerprinter.getBitFingerprint(structure2).asBitSet();
         BitSet subBS = fingerprinter.getBitFingerprint(structure1).asBitSet();
         boolean isSubset = FingerprinterTool.isSubset(superBS, subBS);
-        Assert.assertTrue(isSubset);
+        Assertions.assertTrue(isSubset);
     }
 
     /**
@@ -186,7 +186,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
      * @cdk.bug 934819
      */
     @Test
-    public void testBug931608() throws Exception {
+    void testBug931608() throws Exception {
         IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
         String filename = "bug931608-1.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -211,7 +211,7 @@ public abstract class AbstractFixedLengthFingerprinterTest extends AbstractFinge
         // cardinality gives us the number of "true" bits in the
         // result of the XOR operation.
         int cardinality = bs1.cardinality();
-        Assert.assertEquals(0, cardinality);
+        Assertions.assertEquals(0, cardinality);
     }
 
     /**
