@@ -24,12 +24,14 @@ package org.openscience.cdk.fingerprint;
 
 import java.io.InputStream;
 import java.util.BitSet;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 
 import javax.vecmath.Point2d;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
@@ -42,13 +44,15 @@ import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.io.MDLV2000Reader;
 import org.openscience.cdk.ringsearch.RingPartitioner;
+import org.openscience.cdk.silent.SilentChemObjectBuilder;
+import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.templates.TestMoleculeFactory;
 import org.openscience.cdk.tools.diff.AtomContainerDiff;
 
 /**
  * @cdk.module test-fingerprint
  */
-public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
+class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
 
     @Override
     public IFingerprinter getBitFingerprinter() {
@@ -56,28 +60,28 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
     }
 
     @Test
-    public void testExtendedFingerprinter() throws java.lang.Exception {
+    void testExtendedFingerprinter() throws java.lang.Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter();
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
     }
 
     @Test
-    public void testgetBitFingerprint_IAtomContainer() throws java.lang.Exception {
+    void testgetBitFingerprint_IAtomContainer() throws java.lang.Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter();
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        Assert.assertTrue(FingerprinterTool.isSubset(bs, bs1));
-        Assert.assertFalse(FingerprinterTool.isSubset(bs1, bs));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs1, bs));
     }
 
     @Test
-    public void testgetBitFingerprint_IAtomContainer_IRingSet_List() throws java.lang.Exception {
+    void testgetBitFingerprint_IAtomContainer_IRingSet_List() throws java.lang.Exception {
         ExtendedFingerprinter fingerprinter = new ExtendedFingerprinter();
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         IRingSet rs = Cycles.sssr(mol).toRingSet();
@@ -85,41 +89,41 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
         BitSet bs = fingerprinter.getBitFingerprint(mol, rs, rslist).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        Assert.assertTrue(FingerprinterTool.isSubset(bs, bs1));
-        Assert.assertFalse(FingerprinterTool.isSubset(bs1, bs));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs1, bs));
     }
 
     @Test
-    public void testGetSize() throws java.lang.Exception {
+    void testGetSize() throws java.lang.Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter(512);
-        Assert.assertNotNull(fingerprinter);
-        Assert.assertEquals(512, fingerprinter.getSize());
+        Assertions.assertNotNull(fingerprinter);
+        Assertions.assertEquals(512, fingerprinter.getSize());
     }
 
     @Test
-    public void testExtendedFingerprinter_int() throws java.lang.Exception {
+    void testExtendedFingerprinter_int() throws java.lang.Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter(512);
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        Assert.assertTrue(FingerprinterTool.isSubset(bs, bs1));
-        Assert.assertFalse(FingerprinterTool.isSubset(bs1, bs));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs1, bs));
     }
 
     @Test
-    public void testExtendedFingerprinter_int_int() throws java.lang.Exception {
+    void testExtendedFingerprinter_int_int() throws java.lang.Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter(512, 7);
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        Assert.assertTrue(FingerprinterTool.isSubset(bs, bs1));
-        Assert.assertFalse(FingerprinterTool.isSubset(bs1, bs));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs1, bs));
     }
 
     /*
@@ -128,7 +132,7 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
      * default
      */
     @Test
-    public void testDifferentRingFinders() throws Exception {
+    void testDifferentRingFinders() throws Exception {
         IFingerprinter fingerprinter = new ExtendedFingerprinter();
         IAtomContainer ac1 = new AtomContainer();
         Atom atom1 = new Atom("C");
@@ -172,8 +176,8 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
         ac2.addBond(bond7);
         BitSet bs = fingerprinter.getBitFingerprint(ac1).asBitSet();
         BitSet bs1 = fingerprinter.getBitFingerprint(ac2).asBitSet();
-        Assert.assertTrue(FingerprinterTool.isSubset(bs1, bs));
-        Assert.assertFalse(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs1, bs));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs, bs1));
     }
 
     /*
@@ -182,7 +186,7 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
      * fingerprint
      */
     @Test
-    public void testCondensedSingle() throws Exception {
+    void testCondensedSingle() throws Exception {
         IAtomContainer molcondensed = new AtomContainer();
         IAtom a1 = molcondensed.getBuilder().newInstance(IAtom.class, "C");
         a1.setPoint2d(new Point2d(421.99999999999994, 860.0));
@@ -379,8 +383,8 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
         BitSet bs1 = fingerprinter.getBitFingerprint(molsingle).asBitSet();
         BitSet bs2 = fingerprinter.getBitFingerprint(molcondensed).asBitSet();
 
-        Assert.assertFalse(FingerprinterTool.isSubset(bs1, bs2));
-        Assert.assertTrue(FingerprinterTool.isSubset(bs2, bs1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs1, bs2));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs2, bs1));
 
     }
 
@@ -389,9 +393,9 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
      * before the change in r11932
      */
     @Test
-    public void testChebi() throws Exception {
-        IAtomContainer searchmol = null;
-        IAtomContainer findmol = null;
+    void testChebi() throws Exception {
+        IAtomContainer searchmol;
+        IAtomContainer findmol;
         String filename = "chebisearch.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
@@ -407,8 +411,8 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
         BitSet subBS = fingerprinter.getBitFingerprint(searchmol).asBitSet();
         boolean isSubset = FingerprinterTool.isSubset(superBS, subBS);
         boolean isSubset2 = FingerprinterTool.isSubset(subBS, superBS);
-        Assert.assertFalse(isSubset);
-        Assert.assertFalse(isSubset2);
+        Assertions.assertFalse(isSubset);
+        Assertions.assertFalse(isSubset2);
     }
 
     /**
@@ -417,23 +421,110 @@ public class ExtendedFingerprinterTest extends AbstractFixedLengthFingerprinterT
      * @throws CloneNotSupportedException
      */
     @Test
-    public void testMoleculeInvariance() throws Exception, CloneNotSupportedException {
+    void testMoleculeInvariance() throws Exception, CloneNotSupportedException {
         IAtomContainer mol = TestMoleculeFactory.makePyrrole();
-        IAtomContainer clone = (IAtomContainer) mol.clone();
+        IAtomContainer clone = mol.clone();
 
         // should pass since we have not explicitly detected aromaticity
         for (IAtom atom : mol.atoms()) {
-            Assert.assertFalse(atom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertFalse(atom.getFlag(CDKConstants.ISAROMATIC));
         }
 
         String diff1 = AtomContainerDiff.diff(mol, clone);
-        Assert.assertEquals("", diff1);
+        Assertions.assertEquals("", diff1);
 
         ExtendedFingerprinter fprinter = new ExtendedFingerprinter();
         BitSet fp = fprinter.getBitFingerprint(mol).asBitSet();
-        Assert.assertNotNull(fp);
+        Assertions.assertNotNull(fp);
 
         String diff2 = AtomContainerDiff.diff(mol, clone);
-        Assert.assertTrue("There was a difference\n" + diff2, diff2.equals(""));
+        Assertions.assertTrue(diff2.equals(""), "There was a difference\n" + diff2);
+    }
+
+    @Test public void testGetRawFingerprint() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        ExtendedFingerprinter fpr = new ExtendedFingerprinter(1024, 7); // 7 bonds
+        fpr.setPathLimit(2000);
+        final String smi  = "CC(=O)OC1=CC=CC=C1C(=O)O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("RNCT:1", 1);
+        expected.put("RCNT_MAX:1", 1);
+        expected.put("MASS_RANGE:1", 1);
+        expected.put("C", 9);
+        expected.put("O", 4);
+        expected.put("O=C", 2);
+        expected.put("C-C", 2);
+        expected.put("O-C", 3);
+        expected.put("C:C", 6);
+        expected.put("O-C:C", 2);
+        expected.put("O=C-O", 2);
+        expected.put("C:C-C", 2);
+        expected.put("O-C-C", 2);
+        expected.put("C:C:C", 6);
+        expected.put("O=C-C", 2);
+        expected.put("C-O-C", 1);
+        expected.put("C:C:C-C", 2);
+        expected.put("C:C:C:C", 6);
+        expected.put("O-C:C-C", 1);
+        expected.put("O-C:C:C", 2);
+        expected.put("O=C-O-C", 1);
+        expected.put("C:C-O-C", 2);
+        expected.put("C-O-C-C", 1);
+        expected.put("O=C-C:C", 2);
+        expected.put("O-C-C:C", 2);
+        expected.put("O-C-C:C:C", 2);
+        expected.put("C:C:C:C:C", 6);
+        expected.put("O-C:C:C:C", 2);
+        expected.put("C:C-O-C-C", 2);
+        expected.put("C:C:C:C-C", 2);
+        expected.put("O=C-C:C:C", 2);
+        expected.put("C:C:C-O-C", 2);
+        expected.put("C-O-C:C-C", 1);
+        expected.put("O=C-C:C-O", 1);
+        expected.put("O-C:C-C-O", 1);
+        expected.put("O=C-O-C:C", 2);
+        expected.put("C:C:C:C:C:C", 6);
+        expected.put("O-C:C:C:C:C", 2);
+        expected.put("O=C-C:C:C:C", 2);
+        expected.put("O-C-C:C:C:C", 2);
+        expected.put("C:C:C:C:C-C", 2);
+        expected.put("O=C-C:C-O-C", 1);
+        expected.put("O-C-C:C-O-C", 1);
+        expected.put("O=C-O-C:C:C", 2);
+        expected.put("C-C:C-O-C-C", 1);
+        expected.put("O=C-O-C:C-C", 1);
+        expected.put("C:C:C-O-C-C", 2);
+        expected.put("C:C:C:C-O-C", 2);
+        expected.put("O=C-C:C-O-C-C", 1);
+        expected.put("O=C-O-C:C-C-O", 1);
+        expected.put("O=C-O-C:C-C=O", 1);
+        expected.put("O-C-C:C-O-C-C", 1);
+        expected.put("C:C:C:C:C-O-C", 2);
+        expected.put("O=C-C:C:C:C:C", 2);
+        expected.put("C:C:C:C-O-C-C", 2);
+        expected.put("O-C-C:C:C:C:C", 2);
+        expected.put("O=C-O-C:C:C:C", 2);
+        expected.put("C:C:C:C:C:C-C", 2);
+        expected.put("O-C:C:C:C:C:C", 2);
+        expected.put("O-C:C:C:C:C:C-C", 1);
+        expected.put("O-C-C:C:C:C:C:C", 2);
+        expected.put("C:C:C:C:C-O-C-C", 2);
+        expected.put("C:C:C:C:C:C-O-C", 2);
+        expected.put("O=C-O-C:C:C:C:C", 2);
+        expected.put("O=C-C:C:C:C:C:C", 2);
+        Assertions.assertEquals(expected, actual);
+    }
+
+    @Test
+    public void testGetCountFingerprint() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        ExtendedFingerprinter fpr = new ExtendedFingerprinter(1024, 7); // 7 bonds
+        fpr.setPathLimit(2000);
+        final String smi  = "CC(=O)OC1=CC=CC=C1C(=O)O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        ICountFingerprint actual = fpr.getCountFingerprint(mol);
+        Assertions.assertEquals(65, actual.numOfPopulatedbins());
     }
 }
