@@ -33,9 +33,9 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
 import org.openscience.cdk.exception.CDKException;
@@ -44,6 +44,7 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.tools.CDKHydrogenAdder;
+import org.openscience.cdk.tools.LoggingToolFactory;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 
 import static org.hamcrest.CoreMatchers.is;
@@ -53,26 +54,26 @@ import static org.hamcrest.CoreMatchers.is;
  */
 public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTest {
 
-    SmilesParser parser;
+    private SmilesParser parser;
 
     @Override
     public IFingerprinter getBitFingerprinter() {
         return new PubchemFingerprinter(DefaultChemObjectBuilder.getInstance());
     }
 
-    @Before
-    public void setup() {
+    @BeforeEach
+    void setup() {
         parser = new SmilesParser(SilentChemObjectBuilder.getInstance());
     }
 
     @Test
-    public void testGetSize() throws Exception {
+    void testGetSize() throws Exception {
         IFingerprinter printer = new PubchemFingerprinter(DefaultChemObjectBuilder.getInstance());
-        Assert.assertEquals(881, printer.getSize());
+        Assertions.assertEquals(881, printer.getSize());
     }
 
     @Test
-    public void testFingerprint() throws Exception {
+    void testFingerprint() throws Exception {
         IFingerprinter printer = new PubchemFingerprinter(DefaultChemObjectBuilder.getInstance());
         CDKHydrogenAdder adder = CDKHydrogenAdder.getInstance(DefaultChemObjectBuilder.getInstance());
 
@@ -94,14 +95,13 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         BitSet bs1 = printer.getBitFingerprint(mol1).asBitSet();
         BitSet bs2 = printer.getBitFingerprint(mol2).asBitSet();
 
-        Assert.assertEquals(881, printer.getSize());
+        Assertions.assertEquals(881, printer.getSize());
 
-        Assert.assertFalse("c1ccccc1CC was detected as a subset of c1ccccc1CCc1ccccc1",
-                FingerprinterTool.isSubset(bs1, bs2));
+        Assertions.assertFalse(FingerprinterTool.isSubset(bs1, bs2), "c1ccccc1CC was detected as a subset of c1ccccc1CCc1ccccc1");
     }
 
     @Test
-    public void testfp2() throws Exception {
+    void testfp2() throws Exception {
         IFingerprinter printer = new PubchemFingerprinter(DefaultChemObjectBuilder.getInstance());
 
         IAtomContainer mol1 = parser.parseSmiles("CC(N)CCCN");
@@ -120,8 +120,8 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         BitSet bs2 = printer.getBitFingerprint(mol2).asBitSet();
         BitSet bs3 = printer.getBitFingerprint(mol3).asBitSet();
 
-        Assert.assertTrue(FingerprinterTool.isSubset(bs1, bs2));
-        Assert.assertTrue(FingerprinterTool.isSubset(bs2, bs3));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs1, bs2));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs2, bs3));
     }
 
     /**
@@ -131,7 +131,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
      * @cdk.inchi InChI=1S/C13H24O10S/c1-20-12-8(18)6(16)10(4(2-14)21-12)23-13-9(19)7(17)11(24)5(3-15)22-13/h4-19,24H,2-3H2,1H3/t4-,5-,6-,7-,8-,9-,10-,11-,12-,13+/m1/s1
      */
     @Test
-    public void testCID2518130() throws CDKException {
+    void testCID2518130() throws CDKException {
         IAtomContainer mol = parser.parseSmiles("COC1C(C(C(C(O1)CO)OC2C(C(C(C(O2)CO)S)O)O)O)O");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         CDKHydrogenAdder adder = CDKHydrogenAdder.getInstance(mol.getBuilder());
@@ -144,7 +144,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         BitSet ref = PubchemFingerprinter
                 .decode("AAADceBwPABAAAAAAAAAAAAAAAAAAAAAAAAkSAAAAAAAAAAAAAAAGgQACAAACBS0wAOCCAAABgQAAAAAAAAAAAAAAAAAAAAAAAAREAIAAAAiQAAFAAAHAAHAYAwAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA==");
 
-        Assert.assertEquals(ref, fp);
+        Assertions.assertEquals(ref, fp);
     }
 
     /**
@@ -154,7 +154,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
      * @cdk.inchi InChI=1S/C32H26N/c1-5-13-26(14-6-1)21-22-31-23-30(28-17-9-3-10-18-28)24-32(29-19-11-4-12-20-29)33(31)25-27-15-7-2-8-16-27/h1-24H,25H2/q+1/b22-21+
      */
     @Test
-    public void testCID5934166() throws CDKException {
+    void testCID5934166() throws CDKException {
         IAtomContainer mol = parser.parseSmiles("C1=CC=C(C=C1)C[N+]2=C(C=C(C=C2C=CC3=CC=CC=C3)C4=CC=CC=C4)C5=CC=CC=C5");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         CDKHydrogenAdder adder = CDKHydrogenAdder.getInstance(mol.getBuilder());
@@ -167,7 +167,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         BitSet ref = PubchemFingerprinter
                 .decode("AAADceB+AAAAAAAAAAAAAAAAAAAAAAAAAAA8YMGCAAAAAAAB1AAAHAAAAAAADAjBHgQwgJMMEACgAyRiRACCgCAhAiAI2CA4ZJgIIOLAkZGEIAhggADIyAcQgMAOgAAAAAAAAAAAAAAAAAAAAAAAAAAAAA==");
 
-        Assert.assertEquals(ref, fp);
+        Assertions.assertEquals(ref, fp);
     }
 
     /**
@@ -177,7 +177,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
        * @cdk.inchi  InChI=1S/C14H10Cl3N3O3/c1-6(7-2-4-8(21)5-3-7)19-20-11-9(15)12(14(22)23)18-13(17)10(11)16/h2-5,19,21H,1H2,(H,18,20)(H,22,23)
        */
     @Test
-    public void testCID25181289() throws CDKException {
+    void testCID25181289() throws CDKException {
         IAtomContainer mol = parser.parseSmiles("C=C(C1=CC=C(C=C1)O)NNC2=C(C(=NC(=C2Cl)Cl)C(=O)O)Cl");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         CDKHydrogenAdder adder = CDKHydrogenAdder.getInstance(mol.getBuilder());
@@ -190,11 +190,11 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         BitSet ref = PubchemFingerprinter
                 .decode("AAADccBzMAAGAAAAAAAAAAAAAAAAAAAAAAA8QAAAAAAAAAABwAAAHgIYCAAADA6BniAwzpJqEgCoAyTyTASChCAnJiIYumGmTtgKJnLD1/PEdQhkwBHY3Qe82AAOIAAAAAAAAABAAAAAAAAAAAAAAAAAAA==");
 
-        Assert.assertEquals(ref, fp);
+        Assertions.assertEquals(ref, fp);
     }
 
     @Test
-    public void testGetFingerprintAsBytes() throws CDKException {
+    void testGetFingerprintAsBytes() throws CDKException {
 
         IAtomContainer mol = parser.parseSmiles("C=C(C1=CC=C(C=C1)O)NNC2=C(C(=NC(=C2Cl)Cl)C(=O)O)Cl");
 
@@ -210,12 +210,12 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         byte[] actual = printer.getFingerprintAsBytes();
         byte[] expected = Arrays.copyOf(toByteArray(fp), actual.length);
 
-        Assert.assertArrayEquals(expected, actual);
+        Assertions.assertArrayEquals(expected, actual);
 
     }
 
     // adapted from: http://stackoverflow.com/questions/6197411/converting-from-bitset-to-byte-array
-    public static byte[] toByteArray(BitSet bits) {
+    static byte[] toByteArray(BitSet bits) {
         byte[] bytes = new byte[bits.length() / 8 + 1];
         for (int i = 0; i < bits.length(); i++) {
             if (bits.get(i)) {
@@ -225,25 +225,28 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         return bytes;
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testDecode_invalid() {
-        PubchemFingerprinter.decode("a");
+    @Test
+    void testDecode_invalid()
+    {
+        Assertions.assertThrows(IllegalArgumentException.class, () -> {
+            PubchemFingerprinter.decode("a");
+        });
     }
 
     @Test
-    public void testDecode() {
+    void testDecode() {
         BitSet bitSet = PubchemFingerprinter
                 .decode("AAADcYBgAAAAAAAAAAAAAAAAAAAAAAAAAAAwAAAAAAAAAAABAAAAGAAAAAAACACAEAAwAIAAAACAACBCAAACAAAgAAAIiAAAAIgIICKAERCAIAAggAAIiAcAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA==");
         int[] setBits = new int[]{0, 9, 10, 178, 179, 255, 283, 284, 332, 344, 355, 370, 371, 384, 416, 434, 441, 446,
                 470, 490, 516, 520, 524, 552, 556, 564, 570, 578, 582, 584, 595, 599, 603, 608, 618, 634, 640, 660,
                 664, 668, 677, 678, 679};
         for (int set : setBits) {
-            Assert.assertTrue("bit " + set + " was not set", bitSet.get(set));
+            Assertions.assertTrue(bitSet.get(set), "bit " + set + " was not set");
         }
     }
 
     @Test
-    public void testBenzene() throws CDKException {
+    void testBenzene() throws CDKException {
         IAtomContainer mol = parser.parseSmiles("c1ccccc1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         CDKHydrogenAdder adder = CDKHydrogenAdder.getInstance(mol.getBuilder());
@@ -256,7 +259,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
         BitSet ref = PubchemFingerprinter
                 .decode("AAADcYBgAAAAAAAAAAAAAAAAAAAAAAAAAAAwAAAAAAAAAAABAAAAGAAAAAAACACAEAAwAIAAAACAACBCAAACAAAgAAAIiAAAAIgIICKAERCAIAAggAAIiAcAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA==");
 
-        Assert.assertEquals(ref, fp);
+        Assertions.assertEquals(ref, fp);
 
     }
 
@@ -265,7 +268,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
      * @cdk.bug 3510588
      */
     @Test
-    public void testMultithreadedUsage() throws Exception {
+    void testMultithreadedUsage() throws Exception {
         IAtomContainer mol1 = parser.parseSmiles("C=C(C1=CC=C(C=C1)O)NNC2=C(C(=NC(=C2Cl)Cl)C(=O)O)Cl");
         IAtomContainer mol2 = parser
                 .parseSmiles("C1=CC=C(C=C1)C[N+]2=C(C=C(C=C2C=CC3=CC=CC=C3)C4=CC=CC=C4)C5=CC=CC=C5");
@@ -288,7 +291,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
 
         class FpRunner implements Callable<BitSet> {
 
-            IAtomContainer mol;
+            final IAtomContainer mol;
 
             FpRunner(IAtomContainer mol) {
                 this.mol = mol;
@@ -301,7 +304,8 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
                 try {
                     fp = fpr.getBitFingerprint(mol).asBitSet();
                 } catch (CDKException e) {
-                    e.printStackTrace(); //To change body of catch statement use File | Settings | File Templates.
+                    LoggingToolFactory.createLoggingTool(PubchemFingerprinterTest.class)
+                                      .warn("FP Error:", e);
                 }
                 return fp;
             }
@@ -309,19 +313,19 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
 
         // now lets run some threads
         ExecutorService executor = Executors.newFixedThreadPool(2);
-        List<FpRunner> tasks = new ArrayList<FpRunner>();
+        List<FpRunner> tasks = new ArrayList<>();
         tasks.add(new FpRunner(mol1));
         tasks.add(new FpRunner(mol2));
         List<Future<BitSet>> ret = executor.invokeAll(tasks);
 
         BitSet fb1 = ret.get(0).get();
-        Assert.assertNotNull(fb1);
+        Assertions.assertNotNull(fb1);
 
         BitSet fb2 = ret.get(1).get();
-        Assert.assertNotNull(fb2);
+        Assertions.assertNotNull(fb2);
 
-        Assert.assertEquals(bs1, fb1);
-        Assert.assertEquals(bs2, fb2);
+        Assertions.assertEquals(bs1, fb1);
+        Assertions.assertEquals(bs2, fb2);
     }
 
     /**
@@ -333,7 +337,7 @@ public class PubchemFingerprinterTest extends AbstractFixedLengthFingerprinterTe
      */
     @Test
     @Override
-    public void testBug934819() throws Exception {
+    void testBug934819() throws Exception {
 
         IAtomContainer subStructure = bug934819_1();
         IAtomContainer superStructure = bug934819_2();
