@@ -18,11 +18,10 @@
  */
 package org.openscience.cdk.qsar.descriptors.atomic;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.DefaultChemObjectBuilder;
-import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
@@ -39,16 +38,16 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
  *
  * @cdk.module test-qsaratomic
  */
-public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
+class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
 
-    private IChemObjectBuilder      builder = SilentChemObjectBuilder.getInstance();
-    private LonePairElectronChecker lpcheck = new LonePairElectronChecker();
+    private final IChemObjectBuilder      builder = SilentChemObjectBuilder.getInstance();
+    private final LonePairElectronChecker lpcheck = new LonePairElectronChecker();
 
     /**
      *  Constructor for the PiElectronegativityDescriptorTest object
      *
      */
-    public PiElectronegativityDescriptorTest() {}
+    PiElectronegativityDescriptorTest() {}
 
     /**
      *  A unit test suite for JUnit
@@ -56,8 +55,8 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *@return    The test suite
      */
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         setDescriptor(PiElectronegativityDescriptor.class);
     }
 
@@ -65,7 +64,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Methyl Fluoride
      */
     @Test
-    public void testPiElectronegativityDescriptor_Methyl_Fluoride() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Methyl_Fluoride() throws
             java.lang.Exception {
         double[] testResult = {3.9608, 0.0, 0.0, 0.0, 0.0};/*
                                                             * from Petra online:
@@ -92,10 +91,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.03);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.03);
             }
         }
     }
@@ -104,7 +103,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Methyl Chloride
      */
     @Test
-    public void testPiElectronegativityDescriptor_Methyl_Chloride() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Methyl_Chloride() throws
             java.lang.Exception {
         double[] testResult = {4.7054, 0.0, 0.0, 0.0, 0.0};/*
                                                             * from Petra
@@ -132,10 +131,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.01);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.01);
             }
         }
     }
@@ -144,7 +143,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Methyl iodide
      */
     @Test
-    public void testPiElectronegativityDescriptor_Methyl_Iodide() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Methyl_Iodide() throws
             java.lang.Exception {
         double[] testResult = {4.1951, 0.0, 0.0, 0.0, 0.0};/*
                                                             * from Petra
@@ -172,10 +171,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.01);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.01);
             }
         }
     }
@@ -184,7 +183,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Methyl Bromide
      */
     @Test
-    public void testPiElectronegativityDescriptor_Methyl_Bromide() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Methyl_Bromide() throws
             java.lang.Exception {
         double[] testResult = {3.8922, 0.0, 0.0, 0.0, 0.0};/*
                                                             * from Petra online:
@@ -211,10 +210,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.03);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.03);
             }
         }
     }
@@ -223,7 +222,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Methyl Alcohol
      */
     @Test
-    public void testPiElectronegativityDescriptor_Methyl_Alcohol() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Methyl_Alcohol() throws
             java.lang.Exception {
         double[] testResult = {3.1138, 0.0, 0.0, 0.0, 0.0};/*
                                                             * from Petra online:
@@ -250,10 +249,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.01);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.01);
             }
         }
     }
@@ -262,7 +261,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Formaldehyde
      */
     @Test
-    public void testPiElectronegativityDescriptor_Formaldehyde() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Formaldehyde() throws
             java.lang.Exception {
         double[] testResult = {6.3012, 8.0791, 0.0, 0.0, 0.0};/*
                                                                * from Petra
@@ -290,10 +289,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.55);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.55);
             }
         }
     }
@@ -302,7 +301,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Ethylene
      */
     @Test
-    public void testPiElectronegativityDescriptor_Ethylene() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Ethylene() throws
             java.lang.Exception {
 
         double[] testResult = {5.1519, 5.1519, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};/*
@@ -347,10 +346,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
 
             //	        logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.02);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.02);
             }
         }
     }
@@ -359,7 +358,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Fluoroethylene
      */
     @Test
-    public void testPiElectronegativityDescriptor_Fluoroethylene() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Fluoroethylene() throws
             java.lang.Exception {
         double[] testResult = {4.7796, 5.9414, 5.0507, 0.0, 0.0, 0.0};/*
                                                                        * from
@@ -392,10 +391,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //	        logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.7);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.7);
             }
         }
     }
@@ -404,7 +403,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Formic Acid
      */
     @Test
-    public void testPiElectronegativityDescriptor_FormicAcid() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_FormicAcid() throws
             java.lang.Exception {
         double[] testResult = {6.8954, 7.301, 4.8022, 0.0, 0.0};/*
                                                                  * from Petra
@@ -432,10 +431,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //			logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 2);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 2);
             }
         }
     }
@@ -444,7 +443,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with Methoxyethylene
      */
     @Test
-    public void testPiElectronegativityDescriptor_Methoxyethylene() throws ClassNotFoundException, CDKException,
+    void testPiElectronegativityDescriptor_Methoxyethylene() throws
             java.lang.Exception {
         double[] testResult = {4.916, 5.7345, 3.971, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};/*
                                                                                          * from
@@ -488,10 +487,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //	        logger.debug("result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.5);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.5);
             }
         }
     }
@@ -500,7 +499,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with F[C+][C-]
      */
     @Test
-    public void testPiElectronegativity1() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPiElectronegativity1() throws java.lang.Exception {
         double[] testResult = {5.1788, 5.465, 5.2475, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};/*
                                                                                           * from
                                                                                           * Petra
@@ -543,10 +542,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //	        logger.debug(mol.getAtomAt(i).getSymbol()+"-result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 2.0);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 2.0);
             }
         }
     }
@@ -555,7 +554,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  A unit test for JUnit with CCOCCCO
      */
     @Test
-    public void testPiElectronegativity2() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testPiElectronegativity2() throws java.lang.Exception {
         double[] testResult = {0.0, 0.0, 3.2849, 0.0, 0.0, 0.0, 3.2849, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
                 0.0, 0.0, 0.0};/*
                                 * from Petra online:
@@ -577,10 +576,10 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
             double result = ((DoubleResult) descriptor.calculate(mol.getAtom(i), mol).getValue()).doubleValue();
             //	        logger.debug(mol.getAtom(i).getSymbol()+"-result: "+result);
             if (result == 0.0)
-                Assert.assertEquals(testResult[i], result, 0.0001);
+                Assertions.assertEquals(testResult[i], result, 0.0001);
             else {
-                Assert.assertTrue(result != 0.0);
-                Assert.assertEquals(testResult[i], result, 0.2);
+                Assertions.assertTrue(result != 0.0);
+                Assertions.assertEquals(testResult[i], result, 0.2);
             }
         }
     }
@@ -591,7 +590,7 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
      *  @cdk.inchi InChI=1/C3H7Cl/c1-2-3-4/h2-3H2,1H3
      */
     @Test
-    public void testCompareIonized() throws ClassNotFoundException, CDKException, java.lang.Exception {
+    void testCompareIonized() throws java.lang.Exception {
 
         IAtomContainer molA = builder.newInstance(IAtomContainer.class);
         molA.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -625,14 +624,14 @@ public class PiElectronegativityDescriptorTest extends AtomicDescriptorTest {
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molB);
         lpcheck.saturate(molB);
 
-        Assert.assertEquals(1, molB.getAtom(3).getFormalCharge(), 0.00001);
-        Assert.assertEquals(1, molB.getSingleElectronCount(), 0.00001);
-        Assert.assertEquals(2, molB.getLonePairCount(), 0.00001);
+        Assertions.assertEquals(1, molB.getAtom(3).getFormalCharge(), 0.00001);
+        Assertions.assertEquals(1, molB.getSingleElectronCount(), 0.00001);
+        Assertions.assertEquals(2, molB.getLonePairCount(), 0.00001);
 
         IAtomicDescriptor descriptor = new PiElectronegativityDescriptor();
         double resultB = ((DoubleResult) descriptor.calculate(molB.getAtom(3), molB).getValue()).doubleValue();
 
-        Assert.assertEquals(resultA, resultB, 0.00001);
+        Assertions.assertEquals(resultA, resultB, 0.00001);
     }
 
 }
