@@ -47,6 +47,21 @@ import org.openscience.cdk.qsar.result.IntegerArrayResult;
  * Small ring descriptors: these are based on enumeration of all the small rings (sizes 3 to 9) in a molecule,
  * which can be obtained quickly and deterministically.
  *
+ * Returns these values
+ * <ol>
+ * <li>nSmallRings - total number of small rings (of size 3 through 9)
+ * <li>nAromRings - total number of small aromatic rings
+ * <li>nRingBlocks - total number of distinct ring blocks
+ * <li>nAromBlocks - total number of aromatically connected components
+ * <li>nRings3 - total number of 3-membered rings
+ * <li>nRings4 - total number of 4-membered rings
+ * <li>nRings5 - total number of 5-membered rings
+ * <li>nRings6 - total number of 6-membered rings
+ * <li>nRings7 - total number of 7-membered rings
+ * <li>nRings8 - total number of 8-membered rings
+ * <li>nRings9 - total number of 9-membered rings
+ * </ol>
+ *
  * @cdk.module qsarmolecular
  * @cdk.githash
  *
@@ -273,9 +288,10 @@ public class SmallRingDescriptor implements IMolecularDescriptor {
         final int na = mol.getAtomCount();
         ringBlock = new int[na];
 
-        boolean visited[] = new boolean[na];
+        boolean[] visited = new boolean[na];
 
-        int path[] = new int[na + 1], plen = 0;
+        int[] path = new int[na + 1];
+        int plen = 0;
         while (true) {
             int last, current;
 
@@ -351,7 +367,7 @@ public class SmallRingDescriptor implements IMolecularDescriptor {
                         break;
                     }
                 if (!fnd) {
-                    int newPath[] = new int[capacity];
+                    int[] newPath = new int[capacity];
                     if (psize >= 0)
                         System.arraycopy(path, 0, newPath, 0, psize);
                     newPath[psize] = adj;
@@ -391,7 +407,7 @@ public class SmallRingDescriptor implements IMolecularDescriptor {
         int fm = (first - 1 + psize) % psize, fp = (first + 1) % psize;
         boolean flip = path[fm] < path[fp];
         if (first != 0 || flip) {
-            int newPath[] = new int[psize];
+            int[] newPath = new int[psize];
             for (int n = 0; n < psize; n++)
                 newPath[n] = path[(first + (flip ? psize - n : n)) % psize];
             path = newPath;
