@@ -2,8 +2,8 @@ package org.openscience.cdk.qsar.descriptors.molecular;
 
 import java.io.InputStream;
 
-import org.junit.Assert;
-import org.junit.Before;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.io.MDLV2000Reader;
@@ -13,18 +13,18 @@ import org.openscience.cdk.qsar.DescriptorValue;
  * @cdk.module test-qsarmolecular
  */
 
-public class AutocorrelationDescriptorPolarizabilityTest extends MolecularDescriptorTest {
+class AutocorrelationDescriptorPolarizabilityTest extends MolecularDescriptorTest {
 
-    public AutocorrelationDescriptorPolarizabilityTest() {
+    AutocorrelationDescriptorPolarizabilityTest() {
         super();
     }
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         setDescriptor(AutocorrelationDescriptorPolarizability.class);
     }
 
-    public void ignoreCalculate_IAtomContainer() throws Exception {
+    void ignoreCalculate_IAtomContainer() throws Exception {
         String filename = "data/mdl/chlorobenzene.mol";
         InputStream ins = this.getClass().getClassLoader().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
@@ -32,7 +32,7 @@ public class AutocorrelationDescriptorPolarizabilityTest extends MolecularDescri
         DescriptorValue count = descriptor.calculate(container);
         System.out.println(count.getValue());
 
-        Assert.fail("Not validated yet");
+        Assertions.fail("Not validated yet");
     }
 
 }
