@@ -26,14 +26,13 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Tag;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
-import org.openscience.cdk.test.SlowTest;
 import org.openscience.cdk.exception.InvalidSmilesException;
 import org.openscience.cdk.graph.AtomContainerAtomPermutor;
 import org.openscience.cdk.interfaces.IAtom;
@@ -50,7 +49,7 @@ import signature.AbstractVertexSignature;
  * @author maclean
  *
  */
-public class MoleculeSignatureTest extends CDKTestCase {
+class MoleculeSignatureTest extends CDKTestCase {
 
     private SmilesParser       parser;
 
@@ -60,8 +59,8 @@ public class MoleculeSignatureTest extends CDKTestCase {
 
     private MoleculeSignature  molSig;
 
-    @Before
-    public void setUp() {
+    @BeforeEach
+    void setUp() {
         this.parser = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         this.builder = DefaultChemObjectBuilder.getInstance();
         mol = builder.newInstance(IAtomContainer.class);
@@ -72,43 +71,43 @@ public class MoleculeSignatureTest extends CDKTestCase {
     }
 
     @Test
-    public void getVertexCountTest() {
-        Assert.assertEquals(mol.getAtomCount(), molSig.getVertexCount());
+    void getVertexCountTest() {
+        Assertions.assertEquals(mol.getAtomCount(), molSig.getVertexCount());
     }
 
     @Test
-    public void getSignatureStringForVertexTest() {
-        Assert.assertEquals("[C]([C])", molSig.signatureStringForVertex(0));
+    void getSignatureStringForVertexTest() {
+        Assertions.assertEquals("[C]([C])", molSig.signatureStringForVertex(0));
     }
 
     @Test
-    public void getSignatureStringForVertexTest_height() {
-        Assert.assertEquals("[C]", molSig.signatureStringForVertex(0, 0));
+    void getSignatureStringForVertexTest_height() {
+        Assertions.assertEquals("[C]", molSig.signatureStringForVertex(0, 0));
     }
 
     @Test
-    public void getSignatureForVertexTest() {
-        Assert.assertNotNull(molSig.getVertexSignatures());
+    void getSignatureForVertexTest() {
+        Assertions.assertNotNull(molSig.getVertexSignatures());
     }
 
     @Test
-    public void calculateOrbitsTest() {
-        Assert.assertEquals(1, molSig.calculateOrbits().size());
+    void calculateOrbitsTest() {
+        Assertions.assertEquals(1, molSig.calculateOrbits().size());
     }
 
     @Test
-    public void fromSignatureStringTest() {
+    void fromSignatureStringTest() {
         String signatureString = molSig.toCanonicalString();
         IAtomContainer reconstructed = MoleculeSignature.fromSignatureString(signatureString, builder);
-        Assert.assertEquals(mol.getAtomCount(), reconstructed.getAtomCount());
+        Assertions.assertEquals(mol.getAtomCount(), reconstructed.getAtomCount());
     }
 
     @Test
-    public void toCanonicalSignatureStringTest() {
-        Assert.assertEquals("[C]", molSig.toCanonicalSignatureString(0));
+    void toCanonicalSignatureStringTest() {
+        Assertions.assertEquals("[C]", molSig.toCanonicalSignatureString(0));
     }
 
-    public void fullPermutationTest(IAtomContainer mol) {
+    void fullPermutationTest(IAtomContainer mol) {
         AtomContainerAtomPermutor permutor = new AtomContainerAtomPermutor(mol);
         String expected = new MoleculeSignature(mol).toCanonicalString();
         int numberOfPermutationsTried = 0;
@@ -117,32 +116,32 @@ public class MoleculeSignatureTest extends CDKTestCase {
             String actual = new MoleculeSignature(permutation).toCanonicalString();
             numberOfPermutationsTried++;
             String msg = "Failed on permutation " + numberOfPermutationsTried;
-            Assert.assertEquals(msg, expected, actual);
+            Assertions.assertEquals(expected, actual, msg);
         }
     }
 
-    public String canonicalStringFromSmiles(String smiles) throws InvalidSmilesException {
+    String canonicalStringFromSmiles(String smiles) throws InvalidSmilesException {
         IAtomContainer mol = parser.parseSmiles(smiles);
         MoleculeSignature signature = new MoleculeSignature(mol);
         return signature.toCanonicalString();
     }
 
-    public String canonicalStringFromMolecule(IAtomContainer molecule) {
+    String canonicalStringFromMolecule(IAtomContainer molecule) {
         MoleculeSignature signature = new MoleculeSignature(molecule);
         return signature.getGraphSignature();
     }
 
-    public String fullStringFromMolecule(IAtomContainer molecule) {
+    String fullStringFromMolecule(IAtomContainer molecule) {
         MoleculeSignature molSig = new MoleculeSignature(molecule);
         return molSig.toFullString();
     }
 
-    public List<String> getAtomicSignatures(IAtomContainer molecule) {
+    List<String> getAtomicSignatures(IAtomContainer molecule) {
         MoleculeSignature signature = new MoleculeSignature(molecule);
         return signature.getVertexSignatureStrings();
     }
 
-    public void addHydrogens(IAtomContainer mol, IAtom atom, int n) {
+    void addHydrogens(IAtomContainer mol, IAtom atom, int n) {
         for (int i = 0; i < n; i++) {
             IAtom h = builder.newInstance(IAtom.class, "H");
             mol.addAtom(h);
@@ -151,87 +150,87 @@ public class MoleculeSignatureTest extends CDKTestCase {
     }
 
     @Test
-    public void testEmpty() throws Exception {
+    void testEmpty() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         MoleculeSignature signature = new MoleculeSignature(mol);
         String signatureString = signature.toCanonicalString();
         String expected = "";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testSingleNode() throws Exception {
+    void testSingleNode() throws Exception {
         String singleChild = "C";
         String signatureString = this.canonicalStringFromSmiles(singleChild);
         String expected = "[C]";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testSingleChild() throws Exception {
+    void testSingleChild() throws Exception {
         String singleChild = "CC";
         String signatureString = this.canonicalStringFromSmiles(singleChild);
         String expected = "[C]([C])";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testMultipleChildren() throws Exception {
+    void testMultipleChildren() throws Exception {
         String multipleChildren = "C(C)C";
         String signatureString = this.canonicalStringFromSmiles(multipleChildren);
         String expected = "[C]([C]([C]))";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testThreeCycle() throws Exception {
+    void testThreeCycle() throws Exception {
         String fourCycle = "C1CC1";
         String signatureString = this.canonicalStringFromSmiles(fourCycle);
         String expected = "[C]([C]([C,0])[C,0])";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testFourCycle() throws Exception {
+    void testFourCycle() throws Exception {
         String fourCycle = "C1CCC1";
         String signatureString = this.canonicalStringFromSmiles(fourCycle);
         String expected = "[C]([C]([C,0])[C]([C,0]))";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testMultipleFourCycles() throws Exception {
+    void testMultipleFourCycles() throws Exception {
         String bridgedRing = "C1C(C2)CC12";
         String signatureString = this.canonicalStringFromSmiles(bridgedRing);
         String expected = "[C]([C]([C,0])[C]([C,0])[C]([C,0]))";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testFiveCycle() throws Exception {
+    void testFiveCycle() throws Exception {
         String fiveCycle = "C1CCCC1";
         String signatureString = this.canonicalStringFromSmiles(fiveCycle);
         String expected = "[C]([C]([C]([C,0]))[C]([C,0]))";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testMultipleFiveCycles() throws Exception {
+    void testMultipleFiveCycles() throws Exception {
         String multipleFiveCycle = "C1C(CC2)CCC12";
         String signatureString = this.canonicalStringFromSmiles(multipleFiveCycle);
         String expected = "[C]([C]([C]([C,0]))[C]([C]([C,0]))[C]([C,0]))";
-        Assert.assertEquals(expected, signatureString);
+        Assertions.assertEquals(expected, signatureString);
     }
 
     @Test
-    public void testCubane() {
+    void testCubane() {
         String expected = "[C]([C]([C,3]([C,2])[C,1]([C,2]))[C]([C,3][C,0]" + "([C,2]))[C]([C,0][C,1]))";
         IAtomContainer mol = AbstractSignatureTest.makeCubane();
-        Assert.assertEquals(expected, this.canonicalStringFromMolecule(mol));
+        Assertions.assertEquals(expected, this.canonicalStringFromMolecule(mol));
     }
 
     @Test
-    public void testCage() {
+    void testCage() {
         String expectedA = "[C]([C]([C]([C,4][C,3]([C,1]))[C]([C,5][C,3]))"
                 + "[C]([C,4]([C]([C,2][C,1]))[C]([C,2]([C,0])[C,6]))" + "[C]([C,5]([C]([C,0][C,1]))[C,6]([C,0])))";
 
@@ -239,34 +238,34 @@ public class MoleculeSignatureTest extends CDKTestCase {
                 + "([C,4]([C,3])))[C]([C]([C,3]([C,0])[C,6])[C,7])" + "[C]([C,5]([C]([C,2][C,1]))[C,6]([C,2]([C,0]))))";
         IAtomContainer mol = AbstractSignatureTest.makeCage();
         String signature = this.canonicalStringFromMolecule(mol);
-        Assert.assertEquals(expectedA, signature);
+        Assertions.assertEquals(expectedA, signature);
         String fullSignature = fullStringFromMolecule(mol);
         String fullExpected = "8" + expectedA + " + 8" + expectedB;
-        Assert.assertEquals(fullExpected, fullSignature);
+        Assertions.assertEquals(fullExpected, fullSignature);
     }
 
     @Test
-    public void testPropellane() {
+    void testPropellane() {
         String expectedA = "[C]([C]([C,0])[C]([C,0])[C]([C,0])[C,0])";
         String expectedB = "[C]([C]([C,2][C,1][C,0])[C,2]([C,1][C,0]))";
         IAtomContainer mol = AbstractSignatureTest.makePropellane();
         String signature = this.canonicalStringFromMolecule(mol);
-        Assert.assertEquals(expectedA, signature);
+        Assertions.assertEquals(expectedA, signature);
         String fullExpected = "2" + expectedA + " + 3" + expectedB;
         String fullSignature = fullStringFromMolecule(mol);
-        Assert.assertEquals(fullExpected, fullSignature);
+        Assertions.assertEquals(fullExpected, fullSignature);
     }
 
     @Test
-    public void testBridgedCycloButane() {
+    void testBridgedCycloButane() {
         String expected = "[C]([C]([C,0])[C]([C,0])[C,0])";
         IAtomContainer mol = AbstractSignatureTest.makeBridgedCyclobutane();
         String signature = this.canonicalStringFromMolecule(mol);
-        Assert.assertEquals(expected, signature);
+        Assertions.assertEquals(expected, signature);
     }
 
     @Test
-    public void testCyclohexaneWithHydrogens() {
+    void testCyclohexaneWithHydrogens() {
         IAtomContainer cyclohexane = TestMoleculeFactory.makeCyclohexane();
         for (int i = 0; i < 6; i++) {
             addHydrogens(cyclohexane, cyclohexane.getAtom(i), 2);
@@ -274,11 +273,11 @@ public class MoleculeSignatureTest extends CDKTestCase {
         String expected = "[C]([C]([C]([C,0]([H][H])[H][H])[H][H])" + "[C]([C]([C,0][H][H])[H][H])[H][H])";
 
         String actual = this.canonicalStringFromMolecule(cyclohexane);
-        Assert.assertEquals(expected, actual);
+        Assertions.assertEquals(expected, actual);
     }
 
     @Test
-    public void testBenzeneWithDoubleBonds() {
+    void testBenzeneWithDoubleBonds() {
         IAtomContainer benzene = builder.newInstance(IAtomContainer.class);
         AbstractSignatureTest.addCarbons(benzene, 6);
         for (int i = 0; i < 6; i++) {
@@ -295,12 +294,12 @@ public class MoleculeSignatureTest extends CDKTestCase {
         String carbonSignature = signature.signatureStringForVertex(0);
         for (int i = 1; i < 6; i++) {
             String carbonSignatureI = signature.signatureStringForVertex(i);
-            Assert.assertEquals(carbonSignature, carbonSignatureI);
+            Assertions.assertEquals(carbonSignature, carbonSignatureI);
         }
     }
 
     @Test
-    public void getAromaticEdgeLabelTest() {
+    void getAromaticEdgeLabelTest() {
         IAtomContainer benzeneRing = builder.newInstance(IAtomContainer.class);
         for (int i = 0; i < 6; i++) {
             benzeneRing.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -317,13 +316,13 @@ public class MoleculeSignatureTest extends CDKTestCase {
         List<AbstractVertexSignature> signatures = molSignature.getVertexSignatures();
         for (AbstractVertexSignature signature : signatures) {
             for (int i = 0; i < 6; i++) {
-                Assert.assertEquals("Failed for " + i, "p", ((AtomSignature) signature).getEdgeLabel(i, (i + 1) % 6));
+                Assertions.assertEquals("p", ((AtomSignature) signature).getEdgeLabel(i, (i + 1) % 6), "Failed for " + i);
             }
         }
     }
 
     @Test
-    public void cyclobuteneTest() {
+    void cyclobuteneTest() {
         String expectedA = "[C]([C]([C,0])=[C]([C,0]))";
         String expectedB = "[C]([C]([C,0])[C](=[C,0]))";
         IAtomContainer cyclobutene = builder.newInstance(IAtomContainer.class);
@@ -332,15 +331,15 @@ public class MoleculeSignatureTest extends CDKTestCase {
         cyclobutene.addBond(0, 2, IBond.Order.SINGLE);
         cyclobutene.addBond(1, 3, IBond.Order.DOUBLE);
         cyclobutene.addBond(2, 3, IBond.Order.SINGLE);
-        Assert.assertEquals(expectedA, canonicalStringFromMolecule(cyclobutene));
+        Assertions.assertEquals(expectedA, canonicalStringFromMolecule(cyclobutene));
 
         String expectedFullString = "2" + expectedA + " + 2" + expectedB;
         String actualFullString = fullStringFromMolecule(cyclobutene);
-        Assert.assertEquals(expectedFullString, actualFullString);
+        Assertions.assertEquals(expectedFullString, actualFullString);
     }
 
     @Test
-    public void methyleneCyclopropeneTest() {
+    void methyleneCyclopropeneTest() {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         AbstractSignatureTest.addCarbons(mol, 4);
         AbstractSignatureTest.addHydrogens(mol, 1, 2);
@@ -354,17 +353,15 @@ public class MoleculeSignatureTest extends CDKTestCase {
 
         String sigFor2Height1 = molSig.signatureStringForVertex(2, 1);
         String sigFor3Height1 = molSig.signatureStringForVertex(3, 1);
-        Assert.assertTrue("Height 1 signatures for atoms 2 and 3" + " should be the same",
-                sigFor2Height1.equals(sigFor3Height1));
+        Assertions.assertTrue(sigFor2Height1.equals(sigFor3Height1), "Height 1 signatures for atoms 2 and 3" + " should be the same");
 
         String sigFor2Height2 = molSig.signatureStringForVertex(2, 1);
         String sigFor3Height2 = molSig.signatureStringForVertex(3, 1);
-        Assert.assertTrue("Height 2 signatures for atoms 2 and 3" + " should be the same",
-                sigFor2Height2.equals(sigFor3Height2));
+        Assertions.assertTrue(sigFor2Height2.equals(sigFor3Height2), "Height 2 signatures for atoms 2 and 3" + " should be the same");
     }
 
     @Test
-    public void fusedSquareMultipleBondTest() {
+    void fusedSquareMultipleBondTest() {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         String expected = "[C]([C]([C,1])[C]([C,0])[C](=[C,1])[C](=[C,0]))";
         AbstractSignatureTest.addCarbons(mol, 7);
@@ -378,10 +375,10 @@ public class MoleculeSignatureTest extends CDKTestCase {
         mol.addBond(4, 6, IBond.Order.DOUBLE);
         MoleculeSignature molSig = new MoleculeSignature(mol);
         String sigFor0 = molSig.signatureStringForVertex(0);
-        Assert.assertEquals(expected, sigFor0);
+        Assertions.assertEquals(expected, sigFor0);
     }
 
-    public int findFirstAtomIndexForSymbol(IAtomContainer container, String symbol) {
+    int findFirstAtomIndexForSymbol(IAtomContainer container, String symbol) {
         for (int i = 0; i < container.getAtomCount(); i++) {
             if (container.getAtom(i).getSymbol().equals(symbol)) {
                 return i;
@@ -391,7 +388,7 @@ public class MoleculeSignatureTest extends CDKTestCase {
     }
 
     @Test
-    public void methylFerroceneTest() throws Exception {
+    void methylFerroceneTest() throws Exception {
         String smiles = "CC12C3C4C5C1[Fe]23456789C%10C6C7C8C9%10";
         IAtomContainer mol = parser.parseSmiles(smiles);
         MoleculeSignature molSig = new MoleculeSignature(mol);
@@ -399,27 +396,27 @@ public class MoleculeSignatureTest extends CDKTestCase {
         String sigForIron = molSig.signatureStringForVertex(feIndex);
         String expected = "[Fe]([C]([C,3][C,4])[C,3]([C,1])[C,4]([C,0])" + "[C]([C,5][C,6])[C,5]([C,2])[C,6]([C,7])"
                 + "[C,7]([C][C,2])[C,0]([C,1])[C,1][C,2])";
-        Assert.assertEquals(expected, sigForIron);
+        Assertions.assertEquals(expected, sigForIron);
     }
 
     @Test
-    public void threeMethylSulphanylPropanal() throws Exception {
+    void threeMethylSulphanylPropanal() throws Exception {
         String smiles = "O=CCCSC";
         fullPermutationTest(parser.parseSmiles(smiles));
     }
 
     @Test
-    public void cycleWheelTest() {
+    void cycleWheelTest() {
         IAtomContainer mol = AbstractSignatureTest.makeCycleWheel(3, 3);
         String expected = "[C]([C]([C]([C,2])[C,2])" + "[C]([C]([C,1])[C,1])" + "[C]([C]([C,0])[C,0]))";
         MoleculeSignature molSig = new MoleculeSignature(mol);
         String centralSignature = molSig.signatureStringForVertex(0);
-        Assert.assertEquals(expected, centralSignature);
+        Assertions.assertEquals(expected, centralSignature);
     }
 
     @Test
-    @Category(SlowTest.class)
-    public void ttprTest() {
+    @Tag("SlowTest")
+    void ttprTest() {
         String expected = "[Rh]([P]([C]([C]([C]([C,6]))" + "[C]([C]([C,6])))[C]([C]([C]([C,3]))"
                 + "[C]([C]([C,3])))[C]([C]([C]([C,2]))" + "[C]([C]([C,2]))))[P]([C]([C]([C]([C,7]))"
                 + "[C]([C]([C,7])))[C]([C]([C]([C,4]))" + "[C]([C]([C,4])))[C]([C]([C]([C,1]))"
@@ -430,11 +427,11 @@ public class MoleculeSignatureTest extends CDKTestCase {
         IAtomContainer ttpr = AbstractSignatureTest.makeRhLikeStructure(phosphateCount, ringCount);
         MoleculeSignature molSig = new MoleculeSignature(ttpr);
         String centralSignature = molSig.signatureStringForVertex(0);
-        Assert.assertEquals(expected, centralSignature);
+        Assertions.assertEquals(expected, centralSignature);
     }
 
     @Test
-    public void napthaleneSkeletonHeightTest() {
+    void napthaleneSkeletonHeightTest() {
         IAtomContainer napthalene = builder.newInstance(IAtomContainer.class);
         for (int i = 0; i < 10; i++) {
             napthalene.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -453,7 +450,7 @@ public class MoleculeSignatureTest extends CDKTestCase {
 
         MoleculeSignature molSig = new MoleculeSignature(napthalene);
         int height = 2;
-        Map<String, Orbit> orbits = new HashMap<String, Orbit>();
+        Map<String, Orbit> orbits = new HashMap<>();
         for (int i = 0; i < napthalene.getAtomCount(); i++) {
             String signatureString = molSig.signatureStringForVertex(i, height);
             Orbit orbit;
@@ -465,11 +462,11 @@ public class MoleculeSignatureTest extends CDKTestCase {
             }
             orbit.addAtom(i);
         }
-        Assert.assertEquals(3, orbits.size());
+        Assertions.assertEquals(3, orbits.size());
     }
 
     @Test
-    public void napthaleneWithDoubleBondsAndHydrogenHeightTest() {
+    void napthaleneWithDoubleBondsAndHydrogenHeightTest() {
         IAtomContainer napthalene = builder.newInstance(IAtomContainer.class);
         for (int i = 0; i < 10; i++) {
             napthalene.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -505,8 +502,8 @@ public class MoleculeSignatureTest extends CDKTestCase {
 
         int height = 2;
         SignatureQuotientGraph mqg = new SignatureQuotientGraph(napthalene, height);
-        Assert.assertEquals(4, mqg.getVertexCount());
-        Assert.assertEquals(6, mqg.getEdgeCount());
-        Assert.assertEquals(2, mqg.numberOfLoopEdges());
+        Assertions.assertEquals(4, mqg.getVertexCount());
+        Assertions.assertEquals(6, mqg.getEdgeCount());
+        Assertions.assertEquals(2, mqg.numberOfLoopEdges());
     }
 }
