@@ -24,8 +24,8 @@ package org.openscience.cdk.renderer.color;
 
 import java.awt.Color;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.PseudoAtom;
@@ -34,25 +34,21 @@ import org.openscience.cdk.interfaces.IAtom;
 /**
  * @cdk.module test-render
  */
-public class JmolColorsTest extends CDKTestCase {
+class JmolColorsTest extends CDKTestCase {
 
     @Test
-    public void testGetAtomColor() {
+    void testGetAtomColor() {
     	IAtomColorer colors = new JmolColors();
-        Assert.assertNotNull(colors);
-        Assert.assertEquals(
-        	new Color(0xFFFFFF).getRGB(), colors.getAtomColor(new Atom("H")).getRGB()
-        );
+        Assertions.assertNotNull(colors);
+        Assertions.assertEquals(new Color(0xFFFFFF).getRGB(), colors.getAtomColor(new Atom("H")).getRGB());
     }
 
     @Test
-    public void testGetDefaultAtomColor() {
+    void testGetDefaultAtomColor() {
     	IAtomColorer colors = new JmolColors();
 
-        Assert.assertNotNull(colors);
+        Assertions.assertNotNull(colors);
         IAtom imaginary = new PseudoAtom("Ix");
-        Assert.assertEquals(
-           	new Color(0xB31FBA).getRGB(), colors.getAtomColor(imaginary).getRGB()
-        );
+        Assertions.assertEquals(new Color(0xB31FBA).getRGB(), colors.getAtomColor(imaginary).getRGB());
     }
 }
