@@ -22,8 +22,8 @@ package org.openscience.cdk.renderer.color;
 
 import java.awt.Color;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.test.CDKTestCase;
@@ -33,27 +33,27 @@ import org.openscience.cdk.interfaces.IAtom;
 /**
  * @cdk.module test-render
  */
-public class RasmolColorsTest extends CDKTestCase {
+class RasmolColorsTest extends CDKTestCase {
 
     @Test
-    public void testGetAtomColor() {
+    void testGetAtomColor() {
         RasmolColors colors = new RasmolColors();
 
-        Assert.assertNotNull(colors);
+        Assertions.assertNotNull(colors);
         IAtom sulfur = new Atom("S");
-        Assert.assertEquals(new Color(255, 200, 50), colors.getAtomColor(sulfur));
+        Assertions.assertEquals(new Color(255, 200, 50), colors.getAtomColor(sulfur));
 
         IAtom helium = new Atom("He");
-        Assert.assertEquals(new Color(255, 192, 203), colors.getAtomColor(helium));
+        Assertions.assertEquals(new Color(255, 192, 203), colors.getAtomColor(helium));
     }
 
     @Test
-    public void testGetDefaultAtomColor() {
+    void testGetDefaultAtomColor() {
         RasmolColors colors = new RasmolColors();
 
-        Assert.assertNotNull(colors);
+        Assertions.assertNotNull(colors);
         IAtom imaginary = new PseudoAtom("Ix");
-        Assert.assertEquals(Color.ORANGE, colors.getAtomColor(imaginary, Color.ORANGE));
+        Assertions.assertEquals(Color.ORANGE, colors.getAtomColor(imaginary, Color.ORANGE));
     }
 
 }
