@@ -23,15 +23,15 @@ package org.openscience.cdk.renderer.elements;
 
 import java.awt.Color;
 
-import org.junit.BeforeClass;
+import org.junit.jupiter.api.BeforeAll;
 
 /**
  * @cdk.module test-renderbasic
  */
-public class OvalElementTest extends AbstractElementTest {
+class OvalElementTest extends AbstractElementTest {
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         IRenderingElement element = new OvalElement(3, 4, Color.orange);
         setRenderingElement(element);
     }
