@@ -23,7 +23,8 @@
 
 package org.openscience.cdk.renderer.generators.standard;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -32,73 +33,71 @@ import java.util.List;
 import static org.hamcrest.CoreMatchers.hasItems;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
 
-public class AbbreviationLabelTest {
+class AbbreviationLabelTest {
 
     @Test
-    public void carboxylicacid() {
+    void carboxylicacid() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("COOH", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("COOH", tokens));
         assertThat(tokens.size(), is(4));
         assertThat(tokens, hasItems("C", "O", "O", "H"));
     }
 
     @Test
-    public void carboxylate() {
+    void carboxylate() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("COO-", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("COO-", tokens));
         assertThat(tokens.size(), is(4));
         assertThat(tokens, hasItems("C", "O", "O", "-"));
     }
 
     @Test
-    public void trifluromethyl() {
+    void trifluromethyl() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("CF3", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("CF3", tokens));
         assertThat(tokens.size(), is(2));
         assertThat(tokens, hasItems("C", "F3"));
     }
 
     @Test
-    public void triphenylmethyl() {
+    void triphenylmethyl() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("CPh3", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("CPh3", tokens));
         assertThat(tokens.size(), is(2));
         assertThat(tokens, hasItems("C", "Ph3"));
     }
 
     @Test
-    public void tertbutyls() {
+    void tertbutyls() {
         List<String> tokens = new ArrayList<>(1);
         for (String str : Arrays.asList("tBu", "tertBu", "t-Bu", "t-Butyl", "tertButyl")) {
             tokens.clear();
-            assertTrue(str, AbbreviationLabel.parse(str, tokens));
+            Assertions.assertTrue(AbbreviationLabel.parse(str, tokens), str);
             assertThat(tokens.size(), is(1));
         }
     }
 
     @Test
-    public void peglinker() {
+    void peglinker() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("CH2CH2OCH2CH2O", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("CH2CH2OCH2CH2O", tokens));
         assertThat(tokens.size(), is(10));
         assertThat(tokens, hasItems("C", "H2", "C", "H2", "O", "C", "H2", "C", "H2", "O"));
     }
 
     @Test
-    public void parseFeacac3() {
+    void parseFeacac3() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("Fe(acac)3", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("Fe(acac)3", tokens));
         assertThat(tokens.size(), is(5));
         assertThat(tokens, hasItems("Fe", "(", "acac", ")", "3"));
     }
 
     @Test
-    public void formatFeacac3() {
+    void formatFeacac3() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("Fe(acac)3", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("Fe(acac)3", tokens));
         List<AbbreviationLabel.FormattedText> formatted = AbbreviationLabel.format(tokens);
         AbbreviationLabel.reduce(formatted, 0, formatted.size());
         assertThat(formatted.get(0).text, is("Fe(acac)"));
@@ -108,9 +107,9 @@ public class AbbreviationLabelTest {
     }
 
     @Test
-    public void formatRubpy3Cl2() {
+    void formatRubpy3Cl2() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("Ru(bpy)3Cl2", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("Ru(bpy)3Cl2", tokens));
         List<AbbreviationLabel.FormattedText> formatted = AbbreviationLabel.format(tokens);
         AbbreviationLabel.reduce(formatted, 0, formatted.size());
         assertThat(formatted.get(0).text, is("Ru(bpy)"));
@@ -124,62 +123,62 @@ public class AbbreviationLabelTest {
     }
 
     @Test
-    public void CO2Et() {
+    void CO2Et() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("CO2Et", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("CO2Et", tokens));
         assertThat(tokens.size(), is(3));
         assertThat(tokens, hasItems("C", "O2", "Et"));
     }
 
     @Test
-    public void parseBrackets() {
+    void parseBrackets() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("N(CH2CH2O)CH2", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("N(CH2CH2O)CH2", tokens));
         assertThat(tokens.size(), is(10));
         assertThat(tokens, hasItems("N", "(", "C", "H2", "C", "H2", "O", ")", "C", "H2"));
     }
 
     @Test
-    public void reversingBrackets() {
+    void reversingBrackets() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("N(CH2CH2O)CH2", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("N(CH2CH2O)CH2", tokens));
         AbbreviationLabel.reverse(tokens);
         assertThat(String.join("", tokens), is("H2C(OH2CH2C)N"));
     }
 
     @Test
-    public void reversingFormatPOOHOEt() {
+    void reversingFormatPOOHOEt() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("PO(OH)OEt", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("PO(OH)OEt", tokens));
         AbbreviationLabel.reverse(tokens);
         AbbreviationLabel.format(tokens);
         assertThat(String.join("", tokens), is("EtO(HO)OP"));
     }
 
     @Test
-    public void reversingBracketsWithNumbers() {
+    void reversingBracketsWithNumbers() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("B(OH)2", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("B(OH)2", tokens));
         AbbreviationLabel.reverse(tokens);
         assertThat(String.join("", tokens), is("(HO)2B"));
     }
 
     @Test
-    public void hydrateFormatting() {
+    void hydrateFormatting() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("SnCl4.2H2O", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("SnCl4.2H2O", tokens));
         assertThat(tokens, is(Arrays.asList("Sn", "Cl4", ".", "2", "H2", "O")));
     }
 
     @Test
-    public void nonAbbreviationLabel() {
+    void nonAbbreviationLabel() {
         List<String> tokens = new ArrayList<>();
-        assertFalse(AbbreviationLabel.parse("A Random Label - Don't Reverse", tokens));
+        Assertions.assertFalse(AbbreviationLabel.parse("A Random Label - Don't Reverse", tokens));
         assertThat(tokens.size(), is(1));
     }
 
     @Test
-    public void formatOPO3() {
+    void formatOPO3() {
         List<String> tokens = Arrays.asList("O", "P", "O3", "-2");
         List<AbbreviationLabel.FormattedText> texts = AbbreviationLabel.format(tokens);
         AbbreviationLabel.reduce(texts, 0, texts.size());
@@ -193,7 +192,7 @@ public class AbbreviationLabelTest {
     }
 
     @Test
-    public void formatTBu() {
+    void formatTBu() {
         List<String> tokens = Arrays.asList("tBu");
         List<AbbreviationLabel.FormattedText> texts = AbbreviationLabel.format(tokens);
         assertThat(texts.size(), is(2));
@@ -204,9 +203,9 @@ public class AbbreviationLabelTest {
     }
 
     @Test
-    public void NEt3DotHCl() {
+    void NEt3DotHCl() {
         List<String> tokens = new ArrayList<>();
-        assertTrue(AbbreviationLabel.parse("NEt3·HCl", tokens));
+        Assertions.assertTrue(AbbreviationLabel.parse("NEt3·HCl", tokens));
         assertThat(tokens.size(), is(5));
         assertThat(tokens.get(0), is("N"));
         assertThat(tokens.get(1), is("Et3"));
@@ -225,7 +224,7 @@ public class AbbreviationLabelTest {
     }
 
     @Test
-    public void formatOPO3H2() {
+    void formatOPO3H2() {
         List<String> tokens = Arrays.asList("O", "P", "O3", "H2");
         List<AbbreviationLabel.FormattedText> texts = AbbreviationLabel.format(tokens);
         AbbreviationLabel.reduce(texts, 0, texts.size());
@@ -241,31 +240,31 @@ public class AbbreviationLabelTest {
     }
 
     @Test
-    public void hydrate() {
+    void hydrate() {
         List<String> tokens = new ArrayList<>();
         AbbreviationLabel.parse("•H2O", tokens);
         assertThat(tokens, is(Arrays.asList("•", "H2", "O")));
     }
 
     @Test
-    public void het() {
+    void het() {
         // 'Het' not 'He'lium and 't'erts
-        assertFalse(AbbreviationLabel.parse("Het", new ArrayList<String>()));
+        Assertions.assertFalse(AbbreviationLabel.parse("Het", new ArrayList<>()));
     }
 
     @Test
-    public void parseChargeOnly() {
-        assertFalse(AbbreviationLabel.parse("+", new ArrayList<String>()));
+    void parseChargeOnly() {
+        Assertions.assertFalse(AbbreviationLabel.parse("+", new ArrayList<>()));
     }
 
     @Test
-    public void parseNumberOnly() {
-        assertFalse(AbbreviationLabel.parse("1", new ArrayList<String>()));
+    void parseNumberOnly() {
+        Assertions.assertFalse(AbbreviationLabel.parse("1", new ArrayList<>()));
     }
 
     @Test
-    public void nonAsciiLabel() {
+    void nonAsciiLabel() {
         // phenyl
-        assertFalse(AbbreviationLabel.parse("苯基", new ArrayList<String>()));
+        Assertions.assertFalse(AbbreviationLabel.parse("苯基", new ArrayList<>()));
     }
 }
