@@ -42,12 +42,14 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IBond.Order;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.ILonePair;
 import org.openscience.cdk.interfaces.IPseudoAtom;
 import org.openscience.cdk.interfaces.IRing;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.ringsearch.AllRingsFinder;
+import org.openscience.cdk.tools.LoggingToolFactory;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 import org.openscience.cdk.tools.manipulator.AtomTypeManipulator;
 import org.openscience.cdk.tools.manipulator.RingSetManipulator;
@@ -135,7 +137,8 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
             // srs = s.findEssentialRings();
 
         } catch (Exception e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(ExtAtomContainerManipulator.class)
+                              .warn("Unexpected Error:", e);
         }
 
         try {
@@ -151,7 +154,8 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
             // figure out which simple (non cycles) rings are aromatic:
             // HueckelAromaticityDetector.detectAromaticity(atomContainer, srs);
         } catch (Exception e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(ExtAtomContainerManipulator.class)
+                              .warn("Unexpected Error:", e);
         }
 
         // only atoms in 6 membered rings are aromatic
@@ -189,7 +193,7 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
         int hCount = 0;
         for (IAtom iAtom : atomContainer.getConnectedAtomsList(atom)) {
             IAtom connectedAtom = iAtom;
-            if (connectedAtom.getSymbol().equals("H")) {
+            if (connectedAtom.getAtomicNumber() == IElement.H) {
                 hCount++;
             }
         }
@@ -223,9 +227,9 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
      * is atom Hydrogen then its not removed.
      */
     public static IAtomContainer removeHydrogensExceptSingleAndPreserveAtomID(IAtomContainer atomContainer) {
-        Map<IAtom, IAtom> map = new HashMap<IAtom, IAtom>(); // maps original atoms to clones.
-        List<IAtom> remove = new ArrayList<IAtom>(); // lists removed Hs.
-        IAtomContainer mol = null;
+        Map<IAtom, IAtom> map = new HashMap<>(); // maps original atoms to clones.
+        List<IAtom> remove = new ArrayList<>(); // lists removed Hs.
+        IAtomContainer mol;
         if (atomContainer.getBondCount() > 0) {
             // Clone atoms except those to be removed.
             mol = atomContainer.getBuilder().newInstance(IAtomContainer.class);
@@ -233,25 +237,23 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
             for (int i = 0; i < count; i++) {
                 // Clone/remove this atom?
                 IAtom atom = atomContainer.getAtom(i);
-                if (!atom.getSymbol().equals("H")) {
+                if (atom.getAtomicNumber() != IElement.H) {
                     IAtom clonedAtom = null;
                     try {
-                        clonedAtom = (IAtom) atom.clone();
+                        clonedAtom = atom.clone();
+                        //added by Asad to preserve the Atom ID for atom mapping without Hydrogen
+                        clonedAtom.setID(atom.getID());
+                        clonedAtom.setFlags(atom.getFlags());
+                        int countH = 0;
+                        if (atom.getImplicitHydrogenCount() != null) {
+                            countH = atom.getImplicitHydrogenCount();
+                        }
+                        clonedAtom.setImplicitHydrogenCount(countH);
+                        mol.addAtom(clonedAtom);
+                        map.put(atom, clonedAtom);
                     } catch (CloneNotSupportedException e) {
-                        // TODO Auto-generated catch block
-                        e.printStackTrace();
+                        throw new IllegalStateException("Atom could not be cloned", e);
                     }
-                    //added by Asad to preserve the Atom ID for atom mapping without Hydrogen
-                    clonedAtom.setID(atom.getID());
-                    clonedAtom.setFlags(atom.getFlags());
-                    int countH = 0;
-                    if (atom.getImplicitHydrogenCount() != null) {
-                        countH = atom.getImplicitHydrogenCount();
-                    }
-                    clonedAtom.setImplicitHydrogenCount(countH);
-                    mol.addAtom(clonedAtom);
-                    map.put(atom, clonedAtom);
-
                 } else {
                     remove.add(atom); // maintain list of removed H.
                 }
@@ -376,7 +378,7 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
             IBond.Stereo stereo = container.getBond(index).getStereo();
             bonds[index] = new Bond(atom1, atom2, order, stereo);
             if (container.getBond(index).getID() != null) {
-                bonds[index].setID(new String(container.getBond(index).getID()));
+                bonds[index].setID(container.getBond(index).getID());
             }
             newAtomContainer.addBond(bonds[index]);
 
@@ -432,10 +434,10 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
             {
                 IBond clone = null;
                 try {
-                    clone = (IBond) atomContainer.getBond(i).clone();
+                    clone = atomContainer.getBond(i).clone();
                 } catch (CloneNotSupportedException e) {
-                    // TODO Auto-generated catch block
-                    e.printStackTrace();
+                    LoggingToolFactory.createLoggingTool(ExtAtomContainerManipulator.class)
+                                      .warn("Unexpected Error:", e);
                 }
                 assert clone != null;
                 clone.setAtoms(new IAtom[]{map.get(bond.getBegin()), map.get(bond.getEnd())});
@@ -475,13 +477,13 @@ public class ExtAtomContainerManipulator extends AtomContainerManipulator {
 
     private static void setHydrogenCount(IAtomContainer container, int index, IAtom[] atoms) {
         if (container.getAtom(index).getImplicitHydrogenCount() != null) {
-            atoms[index].setImplicitHydrogenCount(Integer.valueOf(container.getAtom(index).getImplicitHydrogenCount()));
+            atoms[index].setImplicitHydrogenCount(container.getAtom(index).getImplicitHydrogenCount());
         }
     }
 
     private static void setCharge(IAtomContainer container, int index, IAtom[] atoms) {
         if (container.getAtom(index).getCharge() != null) {
-            atoms[index].setCharge(new Double(container.getAtom(index).getCharge()));
+            atoms[index].setCharge(container.getAtom(index).getCharge());
         }
     }
 }
