@@ -24,10 +24,12 @@
 package org.openscience.cdk.tools;
 
 import java.util.List;
+import java.util.Objects;
 
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.Element;
 import org.openscience.cdk.interfaces.IAtomContainer;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IRing;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.interfaces.IAtom;
@@ -100,12 +102,13 @@ public class DeAromatizationTool {
         if (ring.getBondCount() != 5) return false;
         for (int i = 0; i < ring.getAtomCount(); i++) {
             IAtom atom = ring.getAtom(i);
-            if (atom.getSymbol().equals("N")) {
+            if (atom.getAtomicNumber() == IElement.N) {
                 int done = 0;
                 IBond bond = null;
                 int count = 0;
                 while (done != 2) {
                     bond = getNextBond(atom, bond, ring);
+                    Objects.requireNonNull(bond, "Bond not connected to atom!");
                     if (bond.getBegin().equals(atom))
                         atom = bond.getEnd();
                     else
@@ -124,8 +127,9 @@ public class DeAromatizationTool {
 
     private static IBond getNextBond(IAtom atom, IBond bond, IRing ring) {
         List<IBond> bonds = ring.getConnectedBondsList(atom);
-        for (int i = 0; i < bonds.size(); i++)
-            if (!bonds.get(i).equals(bond)) return (IBond) bonds.get(i);
+        for (IBond iBond : bonds)
+            if (!iBond.equals(bond))
+                return iBond;
         return null;
     }
 
