@@ -23,10 +23,10 @@ import java.io.InputStreamReader;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
@@ -54,18 +54,18 @@ import org.openscience.cdk.tools.manipulator.AtomTypeManipulator;
  *
  * @see MMFF94AtomTypeMatcher
  */
-public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
+class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
 
-    private static ILoggingTool         logger          = LoggingToolFactory
+    private static final ILoggingTool         logger          = LoggingToolFactory
                                                                 .createLoggingTool(MMFF94AtomTypeMatcherTest.class);
     private final IChemObjectBuilder    builder         = DefaultChemObjectBuilder.getInstance();
 
     private static IAtomContainer       testMolecule    = null;
 
-    private static Map<String, Integer> testedAtomTypes = new HashMap<String, Integer>();
+    private static final Map<String, Integer> testedAtomTypes = new HashMap<>();
 
-    @BeforeClass
-    public static void setUpTestMolecule() throws Exception {
+    @BeforeAll
+    static void setUpTestMolecule() throws Exception {
         if (testMolecule == null) {
             //logger.debug("**** START ATOMTYPE TEST ******");
             AtomTypeTools att = new AtomTypeTools();
@@ -87,15 +87,15 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testMMFF94AtomTypeMatcher() throws Exception {
+    void testMMFF94AtomTypeMatcher() throws Exception {
         MMFF94AtomTypeMatcher matcher = new MMFF94AtomTypeMatcher();
-        Assert.assertNotNull(matcher);
+        Assertions.assertNotNull(matcher);
 
     }
 
     @Test
-    @Ignore("Old atom typing method - see new Mmff class")
-    public void testFindMatchingAtomType_IAtomContainer() throws Exception {
+    @Disabled("Old atom typing method - see new Mmff class")
+    void testFindMatchingAtomType_IAtomContainer() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("C");
         final IAtomType.Hybridization thisHybridization = IAtomType.Hybridization.SP3;
@@ -107,61 +107,61 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         IAtomType[] types = matcher.findMatchingAtomTypes(mol);
         for (int i = 0; i < types.length; i++) {
             IAtomType type = matcher.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertEquals(type.getAtomTypeName(), types[i].getAtomTypeName());
+            Assertions.assertEquals(type.getAtomTypeName(), types[i].getAtomTypeName());
         }
     }
 
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom() throws Exception {
         setUpTestMolecule();
         for (int i = 0; i < testMolecule.getAtomCount(); i++) {
-            Assert.assertNotNull(testMolecule.getAtom(i).getAtomTypeName());
-            Assert.assertTrue(testMolecule.getAtom(i).getAtomTypeName().length() > 0);
+            Assertions.assertNotNull(testMolecule.getAtom(i).getAtomTypeName());
+            Assertions.assertTrue(testMolecule.getAtom(i).getAtomTypeName().length() > 0);
         }
     }
 
     // FIXME: Below should be tests for *all* atom types in the MM2 atom type specificiation
 
     @Test
-    @Ignore("Old atom typing method - see new Mmff class")
-    public void testSthi() throws Exception {
+    @Disabled("Old atom typing method - see new Mmff class")
+    void testSthi() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "Sthi", testMolecule.getAtom(0));
     }
 
     @Test
-    public void testCsp2() throws Exception {
+    void testCsp2() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "Csp2", testMolecule.getAtom(7));
     }
 
     @Test
-    public void testCsp() throws Exception {
+    void testCsp() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "Csp", testMolecule.getAtom(51));
     }
 
     @Test
-    public void testNdbO() throws Exception {
+    void testNdbO() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "N=O", testMolecule.getAtom(148));
     }
 
     @Test
-    @Ignore("Old atom typing method - see new Mmff class")
-    public void testOar() throws Exception {
+    @Disabled("Old atom typing method - see new Mmff class")
+    void testOar() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "Oar", testMolecule.getAtom(198));
     }
 
     @Test
-    public void testN2OX() throws Exception {
+    void testN2OX() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "N2OX", testMolecule.getAtom(233));
     }
 
     @Test
-    public void testNAZT() throws Exception {
+    void testNAZT() throws Exception {
         setUpTestMolecule();
         assertAtomType(testedAtomTypes, "NAZT", testMolecule.getAtom(256));
     }
@@ -169,7 +169,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
     // Other tests
 
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Methanol() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Methanol() throws Exception {
 
         //		logger.debug("**** START ATOMTYPE Methanol TEST ******");
         //System.out.println("**** START ATOMTYPE Methanol TEST ******");
@@ -190,7 +190,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
         for (int i = 0; i < testResult.length; i++) {
@@ -204,8 +204,8 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      *  A unit test for JUnit with Methylamine
      */
     @Test
-    @Ignore("Old atom typing method - see new Mmff class")
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Methylamine() throws Exception {
+    @Disabled("Old atom typing method - see new Mmff class")
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Methylamine() throws Exception {
         //System.out.println("**** START ATOMTYPE Methylamine TEST ******");
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom carbon = builder.newInstance(IAtom.class, Elements.CARBON);
@@ -224,7 +224,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
         for (int i = 0; i < testResult.length; i++) {
@@ -237,7 +237,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      *  A unit test for JUnit with ethoxyethane
      */
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Ethoxyethane() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Ethoxyethane() throws Exception {
         //System.out.println("**** START ATOMTYPE Ethoxyethane TEST ******");
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom carbon = builder.newInstance(IAtom.class, Elements.CARBON);
@@ -259,7 +259,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
         for (int i = 0; i < testResult.length; i++) {
@@ -272,7 +272,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      *  A unit test for JUnit with Methanethiol
      */
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Methanethiol() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Methanethiol() throws Exception {
         //System.out.println("**** START ATOMTYPE Methanethiol TEST ******");
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom carbon = builder.newInstance(IAtom.class, Elements.CARBON);
@@ -291,7 +291,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
         for (int i = 0; i < testResult.length; i++) {
@@ -304,7 +304,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      *  A unit test for JUnit with Chloromethane
      */
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Chloromethane() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Chloromethane() throws Exception {
         //System.out.println("**** START ATOMTYPE Chlormethane TEST ******");
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom carbon = builder.newInstance(IAtom.class, Elements.CARBON);
@@ -323,7 +323,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
         for (int i = 0; i < testResult.length; i++) {
@@ -336,7 +336,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      *  A unit test for JUnit with Benzene
      */
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Benzene() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Benzene() throws Exception {
         //System.out.println("**** START ATOMTYPE Benzene TEST ******");
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         for (int i = 0; i < 6; i++) {
@@ -374,7 +374,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             //System.out.println("MatchedTypeID:"+matched.getID()+" "+matched.getSymbol()+" "+matched.getAtomTypeName());
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
@@ -390,7 +390,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      *  A unit test for JUnit with Water
      */
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom_Water() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom_Water() throws Exception {
         //System.out.println("**** START ATOMTYPE Water TEST ******");
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         IAtom oxygen = builder.newInstance(IAtom.class, Elements.OXYGEN);
@@ -405,7 +405,7 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
         for (int i = 0; i < mol.getAtomCount(); i++) {
             logger.debug("atomNr:" + mol.getAtom(i).toString());
             IAtomType matched = atm.findMatchingAtomType(mol, mol.getAtom(i));
-            Assert.assertNotNull(matched);
+            Assertions.assertNotNull(matched);
             AtomTypeManipulator.configure(mol.getAtom(i), matched);
         }
         for (int i = 0; i < testResult.length; i++) {
@@ -420,19 +420,19 @@ public class MMFF94AtomTypeMatcherTest extends AbstractAtomTypeTest {
      * method cannot Assert.assert anything.
      */
     @Test
-    @Ignore("Old atom typing method - see new Mmff class")
-    public void countTestedAtomTypes() {
+    @Disabled("Old atom typing method - see new Mmff class")
+    void countTestedAtomTypes() {
         AtomTypeFactory factory = AtomTypeFactory.getInstance("org/openscience/cdk/config/data/mmff94_atomtypes.xml",
                 SilentChemObjectBuilder.getInstance());
 
         IAtomType[] expectedTypes = factory.getAllAtomTypes();
         if (expectedTypes.length != testedAtomTypes.size()) {
             String errorMessage = "Atom types not tested:";
-            for (int i = 0; i < expectedTypes.length; i++) {
-                if (!testedAtomTypes.containsKey(expectedTypes[i].getAtomTypeName()))
-                    errorMessage += " " + expectedTypes[i].getAtomTypeName();
+            for (IAtomType expectedType : expectedTypes) {
+                if (!testedAtomTypes.containsKey(expectedType.getAtomTypeName()))
+                    errorMessage += " " + expectedType.getAtomTypeName();
             }
-            Assert.assertEquals(errorMessage, factory.getAllAtomTypes().length, testedAtomTypes.size());
+            Assertions.assertEquals(factory.getAllAtomTypes().length, testedAtomTypes.size(), errorMessage);
         }
     }
 
