@@ -22,20 +22,17 @@
  */
 package org.openscience.cdk.smsd;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.aromaticity.Aromaticity;
@@ -59,28 +56,28 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
  * @cdk.module test-smsd
  * @cdk.require java1.6+
  */
-public class SMSDTest {
+class SMSDTest {
 
     public SMSDTest() {}
 
-    @BeforeClass
-    public static void setUpClass() throws Exception {}
+    @BeforeAll
+    static void setUpClass() throws Exception {}
 
-    @AfterClass
-    public static void tearDownClass() throws Exception {}
+    @AfterAll
+    static void tearDownClass() throws Exception {}
 
-    @Before
-    public void setUp() {}
+    @BeforeEach
+    void setUp() {}
 
-    @After
-    public void tearDown() {}
+    @AfterEach
+    void tearDown() {}
 
     /**
      * Test of init method, of class Isomorphism.
      * @throws CDKException
      */
     @Test
-    public void testInit_3args_1() throws CDKException {
+    void testInit_3args_1() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/OCC=C");
         IAtomContainer queryac = sp.parseSmiles("CCCOCC(C)=C");
@@ -88,8 +85,8 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, false);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, false, false);
-        assertNotNull(smsd1.getReactantMolecule());
-        assertNotNull(smsd1.getProductMolecule());
+        Assertions.assertNotNull(smsd1.getReactantMolecule());
+        Assertions.assertNotNull(smsd1.getProductMolecule());
     }
 
     /**
@@ -97,7 +94,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testInit_3args_2() throws CDKException {
+    void testInit_3args_2() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/OCC=C");
         IAtomContainer queryac = sp.parseSmiles("CCCOCC(C)=C");
@@ -105,8 +102,8 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, false);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, false, false);
-        assertNotNull(smsd1.getReactantMolecule());
-        assertNotNull(smsd1.getProductMolecule());
+        Assertions.assertNotNull(smsd1.getReactantMolecule());
+        Assertions.assertNotNull(smsd1.getProductMolecule());
     }
 
     /**
@@ -114,11 +111,11 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testSearchMCS() throws CDKException {
+    void testSearchMCS() throws CDKException {
         try {
             SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
             sp.kekulise(false);
-            IAtomContainer target = null;
+            IAtomContainer target;
             target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
             AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(target);
             IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -128,9 +125,9 @@ public class SMSDTest {
             Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
             smsd1.init(queryac, target, true, true);
             smsd1.setChemFilters(true, true, true);
-            Assert.assertEquals(7, smsd1.getFirstAtomMapping().size());
-            Assert.assertEquals(2, smsd1.getAllAtomMapping().size());
-            assertNotNull(smsd1.getFirstMapping());
+            Assertions.assertEquals(7, smsd1.getFirstAtomMapping().size());
+            Assertions.assertEquals(2, smsd1.getAllAtomMapping().size());
+            Assertions.assertNotNull(smsd1.getFirstMapping());
         } catch (InvalidSmilesException ex) {
             Logger.getLogger(MCSPlusHandlerTest.class.getName()).log(Level.SEVERE, null, ex);
         }
@@ -141,7 +138,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testSet_IAtomContainer_IAtomContainer() throws CDKException {
+    void testSet_IAtomContainer_IAtomContainer() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -149,7 +146,7 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertNotNull(smsd1.getFirstMapping());
+        Assertions.assertNotNull(smsd1.getFirstMapping());
 
     }
 
@@ -159,7 +156,7 @@ public class SMSDTest {
      * @throws IOException
      */
     @Test
-    public void testSet_String_String() throws CDKException, IOException {
+    void testSet_String_String() throws CDKException, IOException {
         String molfile = "org/openscience/cdk/smsd/algorithm/decalin.mol";
         String queryfile = "org/openscience/cdk/smsd/algorithm/decalin.mol";
         IAtomContainer query = new AtomContainer();
@@ -176,7 +173,7 @@ public class SMSDTest {
         smsd1.init(query, target, true, true);
         smsd1.setChemFilters(true, true, true);
         double score = 1.0;
-        assertEquals(score, smsd1.getTanimotoSimilarity(), 0.0001);
+        Assertions.assertEquals(score, smsd1.getTanimotoSimilarity(), 0.0001);
     }
 
     /**
@@ -184,7 +181,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testSet_MolHandler_MolHandler() throws CDKException {
+    void testSet_MolHandler_MolHandler() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
 
         IAtomContainer target1 = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
@@ -194,7 +191,7 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
         smsd1.init(source.getMolecule(), target.getMolecule(), true, true);
         smsd1.setChemFilters(true, true, true);
-        assertNotNull(smsd1.getFirstMapping());
+        Assertions.assertNotNull(smsd1.getFirstMapping());
     }
 
     /**
@@ -202,7 +199,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetAllAtomMapping() throws CDKException {
+    void testGetAllAtomMapping() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         sp.kekulise(false);
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
@@ -223,8 +220,8 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertNotNull(smsd1.getFirstMapping());
-        assertEquals(2, smsd1.getAllAtomMapping().size());
+        Assertions.assertNotNull(smsd1.getFirstMapping());
+        Assertions.assertEquals(2, smsd1.getAllAtomMapping().size());
     }
 
     /**
@@ -232,7 +229,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetAllMapping() throws CDKException {
+    void testGetAllMapping() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         sp.kekulise(false);
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
@@ -245,9 +242,9 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertNotNull(smsd1.getFirstMapping());
+        Assertions.assertNotNull(smsd1.getFirstMapping());
 
-        assertEquals(2, smsd1.getAllMapping().size());
+        Assertions.assertEquals(2, smsd1.getAllMapping().size());
     }
 
     /**
@@ -255,7 +252,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetFirstAtomMapping() throws CDKException {
+    void testGetFirstAtomMapping() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -263,9 +260,9 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertNotNull(smsd1.getFirstMapping());
+        Assertions.assertNotNull(smsd1.getFirstMapping());
 
-        assertEquals(7, smsd1.getFirstAtomMapping().size());
+        Assertions.assertEquals(7, smsd1.getFirstAtomMapping().size());
     }
 
     /**
@@ -273,7 +270,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetFirstMapping() throws CDKException {
+    void testGetFirstMapping() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -281,9 +278,9 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, true);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertNotNull(smsd1.getFirstMapping());
+        Assertions.assertNotNull(smsd1.getFirstMapping());
 
-        assertEquals(7, smsd1.getFirstMapping().size());
+        Assertions.assertEquals(7, smsd1.getFirstMapping().size());
     }
 
     /**
@@ -291,7 +288,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testSetChemFilters() throws CDKException {
+    void testSetChemFilters() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/OCC=C");
         IAtomContainer queryac = sp.parseSmiles("CCCOCC(C)=C");
@@ -299,7 +296,7 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, false);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertEquals(1, smsd1.getAllAtomMapping().size());
+        Assertions.assertEquals(1, smsd1.getAllAtomMapping().size());
     }
 
     /**
@@ -307,7 +304,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetFragmentSize() throws CDKException {
+    void testGetFragmentSize() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -316,7 +313,7 @@ public class SMSDTest {
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(false, true, false);
         Integer score = 2;
-        assertEquals(score, smsd1.getFragmentSize(0));
+        Assertions.assertEquals(score, smsd1.getFragmentSize(0));
     }
 
     /**
@@ -324,7 +321,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetStereoScore() throws CDKException {
+    void testGetStereoScore() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/OCC=C");
         IAtomContainer queryac = sp.parseSmiles("CCCOCC(C)=C");
@@ -333,7 +330,7 @@ public class SMSDTest {
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, false, false);
         Integer score = 1048;
-        assertEquals(score, smsd1.getStereoScore(0));
+        Assertions.assertEquals(score, smsd1.getStereoScore(0));
     }
 
     /**
@@ -341,7 +338,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetEnergyScore() throws CDKException {
+    void testGetEnergyScore() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -350,7 +347,7 @@ public class SMSDTest {
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(false, false, true);
         Double score = 610.0;
-        assertEquals(score, smsd1.getEnergyScore(0));
+        Assertions.assertEquals(score, smsd1.getEnergyScore(0));
     }
 
     /**
@@ -358,7 +355,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetReactantMolecule() throws CDKException {
+    void testGetReactantMolecule() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -367,7 +364,7 @@ public class SMSDTest {
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
 
-        assertEquals(7, smsd1.getReactantMolecule().getAtomCount());
+        Assertions.assertEquals(7, smsd1.getReactantMolecule().getAtomCount());
     }
 
     /**
@@ -375,7 +372,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testGetProductMolecule() throws CDKException {
+    void testGetProductMolecule() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -384,7 +381,7 @@ public class SMSDTest {
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
 
-        assertEquals(20, smsd1.getProductMolecule().getAtomCount());
+        Assertions.assertEquals(20, smsd1.getProductMolecule().getAtomCount());
     }
 
     /**
@@ -392,7 +389,7 @@ public class SMSDTest {
      * @throws Exception
      */
     @Test
-    public void testGetTanimotoSimilarity() throws Exception {
+    void testGetTanimotoSimilarity() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -402,7 +399,7 @@ public class SMSDTest {
         smsd1.setChemFilters(true, true, true);
 
         double score = 0.35;
-        assertEquals(score, smsd1.getTanimotoSimilarity(), 0);
+        Assertions.assertEquals(score, smsd1.getTanimotoSimilarity(), 0);
     }
 
     /**
@@ -410,7 +407,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testIsStereoMisMatch() throws CDKException {
+    void testIsStereoMisMatch() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -418,7 +415,7 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.DEFAULT, false);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertEquals(false, smsd1.isStereoMisMatch());
+        Assertions.assertEquals(false, smsd1.isStereoMisMatch());
     }
 
     /**
@@ -426,7 +423,7 @@ public class SMSDTest {
      * @throws CDKException
      */
     @Test
-    public void testIsSubgraph() throws CDKException {
+    void testIsSubgraph() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -434,7 +431,7 @@ public class SMSDTest {
         Isomorphism smsd1 = new Isomorphism(Algorithm.SubStructure, false);
         smsd1.init(queryac, target, true, true);
         smsd1.setChemFilters(true, true, true);
-        assertEquals(true, smsd1.isSubgraph());
+        Assertions.assertEquals(true, smsd1.isSubgraph());
     }
 
     /**
@@ -442,7 +439,7 @@ public class SMSDTest {
      * @throws Exception
      */
     @Test
-    public void testGetEuclideanDistance() throws Exception {
+    void testGetEuclideanDistance() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("C\\C=C/Nc1cccc(c1)N(O)\\C=C\\C\\C=C\\C=C/C");
         IAtomContainer queryac = sp.parseSmiles("Nc1ccccc1");
@@ -452,17 +449,17 @@ public class SMSDTest {
         smsd1.setChemFilters(true, true, true);
 
         double score = 3.605;
-        assertEquals(score, smsd1.getEuclideanDistance(), 0.005);
+        Assertions.assertEquals(score, smsd1.getEuclideanDistance(), 0.005);
 
         Isomorphism smsd2 = new Isomorphism(Algorithm.VFLibMCS, true);
         smsd2.init(queryac, target, true, true);
         smsd2.setChemFilters(true, true, true);
 
-        assertEquals(score, smsd2.getEuclideanDistance(), 0.005);
+        Assertions.assertEquals(score, smsd2.getEuclideanDistance(), 0.005);
     }
 
     @Test
-    public void testQueryAtomContainerDefault() throws CDKException {
+    void testQueryAtomContainerDefault() throws CDKException {
         Isomorphism smsd = new Isomorphism(Algorithm.DEFAULT, true);
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
@@ -470,16 +467,16 @@ public class SMSDTest {
 
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
 
         IQueryAtomContainer queryContainer = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(query);
         smsd.init(queryContainer, target);
         foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
     }
 
     @Test
-    public void testQueryAtomContainerMCSPLUS() throws CDKException {
+    void testQueryAtomContainerMCSPLUS() throws CDKException {
         Isomorphism smsd = new Isomorphism(Algorithm.MCSPlus, true);
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
@@ -487,16 +484,16 @@ public class SMSDTest {
 
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
 
         IQueryAtomContainer queryContainer = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(query);
         smsd.init(queryContainer, target);
         foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
     }
 
     @Test
-    public void testQueryAtomContainerSubstructure() throws CDKException {
+    void testQueryAtomContainerSubstructure() throws CDKException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
         IAtomContainer target = sp.parseSmiles("C1CCC12CCCC2");
@@ -512,7 +509,7 @@ public class SMSDTest {
         Isomorphism smsd = new Isomorphism(Algorithm.SubStructure, true);
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
 
         //        IQueryAtomContainer queryContainer = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(query);
         //
@@ -523,7 +520,7 @@ public class SMSDTest {
         //        Assert.assertFalse(foundMatches);
     }
 
-    public void testQueryAtomCount() throws CDKException {
+    void testQueryAtomCount() throws CDKException {
         Isomorphism smsd = new Isomorphism(Algorithm.DEFAULT, true);
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
@@ -531,17 +528,17 @@ public class SMSDTest {
 
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertEquals(18, smsd.getAllAtomMapping().size());
-        Assert.assertTrue(foundMatches);
+        Assertions.assertEquals(18, smsd.getAllAtomMapping().size());
+        Assertions.assertTrue(foundMatches);
 
         IQueryAtomContainer queryContainer = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(query);
         smsd.init(queryContainer, target);
         foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
     }
 
     @Test
-    public void testMatchCount() throws CDKException {
+    void testMatchCount() throws CDKException {
         Isomorphism smsd = new Isomorphism(Algorithm.DEFAULT, true);
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
@@ -549,17 +546,17 @@ public class SMSDTest {
 
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertEquals(18, smsd.getAllAtomMapping().size());
-        Assert.assertTrue(foundMatches);
+        Assertions.assertEquals(18, smsd.getAllAtomMapping().size());
+        Assertions.assertTrue(foundMatches);
 
         IQueryAtomContainer queryContainer = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(query);
         smsd.init(queryContainer, target);
         foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
     }
 
     @Test
-    public void testMatchCountCDKMCS() throws CDKException {
+    void testMatchCountCDKMCS() throws CDKException {
         Isomorphism smsd = new Isomorphism(Algorithm.CDKMCS, true);
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
@@ -567,17 +564,17 @@ public class SMSDTest {
 
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertEquals(18, smsd.getAllAtomMapping().size());
-        Assert.assertTrue(foundMatches);
+        Assertions.assertEquals(18, smsd.getAllAtomMapping().size());
+        Assertions.assertTrue(foundMatches);
 
         IQueryAtomContainer queryContainer = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(query);
         smsd.init(queryContainer, target);
         foundMatches = smsd.isSubgraph();
-        Assert.assertTrue(foundMatches);
+        Assertions.assertTrue(foundMatches);
     }
 
     @Test
-    public void testImpossibleQuery() throws CDKException {
+    void testImpossibleQuery() throws CDKException {
         Isomorphism smsd = new Isomorphism(Algorithm.DEFAULT, true);
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer query = sp.parseSmiles("CC");
@@ -585,6 +582,6 @@ public class SMSDTest {
 
         smsd.init(query, target, false, true);
         boolean foundMatches = smsd.isSubgraph();
-        Assert.assertFalse(foundMatches);
+        Assertions.assertFalse(foundMatches);
     }
 }
