@@ -19,8 +19,8 @@
 package org.openscience.cdk.tools.diff;
 
 import org.hamcrest.MatcherAssert;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.tools.diff.tree.IDifference;
@@ -32,17 +32,17 @@ import static org.mockito.Mockito.when;
 /**
  * @cdk.module test-diff
  */
-public class BondDiffTest {
+class BondDiffTest {
 
     @Test
-    public void testMatchAgainstItself() {
+    void testMatchAgainstItself() {
         IBond bond1 = mock(IBond.class);
         String result = BondDiff.diff(bond1, bond1);
-        Assert.assertEquals("", result);
+        Assertions.assertEquals("", result);
     }
 
     @Test
-    public void testDiff() {
+    void testDiff() {
 
         IAtom carbon = mock(IAtom.class);
         IAtom oxygen = mock(IAtom.class);
@@ -68,8 +68,8 @@ public class BondDiffTest {
         bond2.setOrder(IBond.Order.DOUBLE);
 
         String result = BondDiff.diff(bond1, bond2);
-        Assert.assertNotNull(result);
-        Assert.assertNotSame(0, result.length());
+        Assertions.assertNotNull(result);
+        Assertions.assertNotSame(0, result.length());
         MatcherAssert.assertThat(result, containsString("BondDiff"));
         MatcherAssert.assertThat(result, containsString("SINGLE/DOUBLE"));
         MatcherAssert.assertThat(result, containsString("AtomDiff"));
@@ -77,7 +77,7 @@ public class BondDiffTest {
     }
 
     @Test
-    public void testDifference() {
+    void testDifference() {
         IAtom carbon = mock(IAtom.class);
         IAtom oxygen = mock(IAtom.class);
 
@@ -102,6 +102,6 @@ public class BondDiffTest {
         bond2.setOrder(IBond.Order.DOUBLE);
 
         IDifference difference = BondDiff.difference(bond1, bond2);
-        Assert.assertNotNull(difference);
+        Assertions.assertNotNull(difference);
     }
 }
