@@ -19,8 +19,8 @@
  */
 package org.openscience.cdk.config.isotopes;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.ChemObject;
 import org.openscience.cdk.test.CDKTestCase;
 
@@ -29,43 +29,43 @@ import org.openscience.cdk.test.CDKTestCase;
  *
  * @cdk.module test-extra
  */
-public class IsotopeHandlerTest extends CDKTestCase {
+class IsotopeHandlerTest extends CDKTestCase {
 
     // serious testing is done in IsotopeFactoryTest; the factory
     // requires this class to work properly. But nevertheless:
 
     @Test
-    public void testIsotopeHandler_IChemObjectBuilder() {
+    void testIsotopeHandler_IChemObjectBuilder() {
         IsotopeHandler handler = new IsotopeHandler(new ChemObject().getBuilder());
-        Assert.assertNotNull(handler);
+        Assertions.assertNotNull(handler);
     }
 
     @Test
-    public void testGetIsotopes() {
+    void testGetIsotopes() {
         IsotopeHandler handler = new IsotopeHandler(new ChemObject().getBuilder());
         // nothing is read
-        Assert.assertNotNull(handler);
-        Assert.assertNull(handler.getIsotopes());
+        Assertions.assertNotNull(handler);
+        Assertions.assertNull(handler.getIsotopes());
     }
 
     @Test
-    public void testStartDocument() {
+    void testStartDocument() {
         IsotopeHandler handler = new IsotopeHandler(new ChemObject().getBuilder());
         // nothing is read, but Vector is initialized
-        Assert.assertNotNull(handler);
-        Assert.assertNull(handler.getIsotopes());
+        Assertions.assertNotNull(handler);
+        Assertions.assertNull(handler.getIsotopes());
     }
 
     @Test
-    public void testCharacters_arraychar_int_int() {
+    void testCharacters_arraychar_int_int() {
         // nothing I can test here that IsotopeFactoryTest doesn't do
-        Assert.assertTrue(true);
+        Assertions.assertTrue(true);
     }
 
     @Test
-    public void testEndElement_String_String_String() {
+    void testEndElement_String_String_String() {
         // nothing I can test here that IsotopeFactoryTest doesn't do
-        Assert.assertTrue(true);
+        Assertions.assertTrue(true);
     }
 
 }
