@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.dict;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
@@ -29,14 +29,14 @@ import org.openscience.cdk.test.CDKTestCase;
  *
  * @see org.openscience.cdk.dict.DefaultHanlder
  */
-public class DictionaryTest extends CDKTestCase {
+class DictionaryTest extends CDKTestCase {
 
     @Test
-    public void testDefaultHanlder() {
+    void testDefaultHanlder() {
         DictionaryDatabase db = new DictionaryDatabase();
         Dictionary dict = db.getDictionary("chemical"); // this dictionary needs the DefaultHanlder
         Entry entry = dict.getEntry("ionPair".toLowerCase());
-        Assert.assertNotNull(entry);
+        Assertions.assertNotNull(entry);
     }
 
 }
