@@ -20,8 +20,8 @@
  */
 package org.openscience.cdk.graph.invariant;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.test.CDKTestCase;
@@ -45,14 +45,14 @@ import java.io.InputStream;
  * @cdk.created 2003-09-26
  * @cdk.module test-extra
  */
-public class EquivalentClassPartitionerTest extends CDKTestCase {
+class EquivalentClassPartitionerTest extends CDKTestCase {
 
     AtomContainer C40C3V = null;
     AtomContainer C24D6D = null;
     AtomContainer C28TD  = null;
 
     @Test
-    public void testEquivalent() throws Exception {
+    void testEquivalent() throws Exception {
         AtomContainer C40C3V = new org.openscience.cdk.AtomContainer();
         C40C3V.addAtom(new Atom("C")); // 1
         C40C3V.addAtom(new Atom("C")); // 2
@@ -156,19 +156,19 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
         C40C3V.addBond(31, 35, IBond.Order.SINGLE); // 59
         C40C3V.addBond(32, 38, IBond.Order.SINGLE); // 60
         EquivalentClassPartitioner it = new EquivalentClassPartitioner(C40C3V);
-        int equivalentClass[] = it.getTopoEquivClassbyHuXu(C40C3V);
+        int[] equivalentClass = it.getTopoEquivClassbyHuXu(C40C3V);
         char[] arrEquivalent = new char[39];
         for (int i = 1; i < equivalentClass.length - 1; i++)
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
-        Assert.assertNotNull(equivalentClass);
-        Assert.assertTrue(equivalentClass[0] == 10);//number of Class
-        Assert.assertTrue(equivalentClass[40] == 10);
-        Assert.assertEquals("111112221333444556667878222879995555444", strEquivalent);
+        Assertions.assertNotNull(equivalentClass);
+        Assertions.assertTrue(equivalentClass[0] == 10);//number of Class
+        Assertions.assertTrue(equivalentClass[40] == 10);
+        Assertions.assertEquals("111112221333444556667878222879995555444", strEquivalent);
     }
 
     @Test
-    public void testFullereneC24D6D() throws Exception {
+    void testFullereneC24D6D() throws Exception {
         AtomContainer C24D6D = new org.openscience.cdk.AtomContainer();
         C24D6D.addAtom(new Atom("C")); // 1
         C24D6D.addAtom(new Atom("C")); // 2
@@ -233,14 +233,14 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
         C24D6D.addBond(22, 23, IBond.Order.SINGLE); // 36
 
         EquivalentClassPartitioner it = new EquivalentClassPartitioner(C24D6D);
-        int equivalentClass[] = it.getTopoEquivClassbyHuXu(C24D6D);
+        int[] equivalentClass = it.getTopoEquivClassbyHuXu(C24D6D);
         char[] arrEquivalent = new char[24];
         for (int i = 1; i < equivalentClass.length; i++)
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
-        Assert.assertNotNull(equivalentClass);
-        Assert.assertTrue(equivalentClass[0] == 2);//number of Class
-        Assert.assertEquals("111111222222222222111111", strEquivalent);
+        Assertions.assertNotNull(equivalentClass);
+        Assertions.assertTrue(equivalentClass[0] == 2);//number of Class
+        Assertions.assertEquals("111111222222222222111111", strEquivalent);
     }
 
     /**
@@ -248,23 +248,23 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testPseudoAtoms() throws Exception {
+    void testPseudoAtoms() throws Exception {
         String filename = "pseudoatoms.sdf";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol = reader.read(mol);
-        Assert.assertNotNull(mol);
+        Assertions.assertNotNull(mol);
 
         // check that there are some pseudo-atoms
         boolean hasPseudo = false;
         for (IAtom atom : mol.atoms()) {
             if (atom instanceof IPseudoAtom) hasPseudo = true;
         }
-        Assert.assertTrue("The molecule should have one or more pseudo atoms", hasPseudo);
+        Assertions.assertTrue(hasPseudo, "The molecule should have one or more pseudo atoms");
 
         EquivalentClassPartitioner partitioner = new EquivalentClassPartitioner(mol);
-        Assert.assertNotNull(partitioner);
+        Assertions.assertNotNull(partitioner);
 
         int[] classes = partitioner.getTopoEquivClassbyHuXu(mol);
     }
@@ -279,10 +279,10 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
      * @cdk.bug 3562476
      */
     @Test
-    public void testAromaticSystem() throws Exception {
+    void testAromaticSystem() throws Exception {
 
         IAtomContainer mol = TestMoleculeFactory.makeAzulene();
-        Assert.assertNotNull("Created molecule was null", mol);
+        Assertions.assertNotNull(mol, "Created molecule was null");
 
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
@@ -293,10 +293,10 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
 
-        Assert.assertNotNull("Equivalent class was null", equivalentClass);
-        Assert.assertEquals("Unexpected equivalent class length", mol.getAtomCount() + 1, equivalentClass.length);
-        Assert.assertEquals("Wrong number of equivalent classes", 6, equivalentClass[0]);//number of Class
-        Assert.assertEquals("Wrong class assignment", "1232145654", strEquivalent);
+        Assertions.assertNotNull(equivalentClass, "Equivalent class was null");
+        Assertions.assertEquals(mol.getAtomCount() + 1, equivalentClass.length, "Unexpected equivalent class length");
+        Assertions.assertEquals(6, equivalentClass[0], "Wrong number of equivalent classes");//number of Class
+        Assertions.assertEquals("1232145654", strEquivalent, "Wrong class assignment");
     }
 
     /**
@@ -305,20 +305,20 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testAlphaPinene() throws Exception {
+    void testAlphaPinene() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeAlphaPinene();
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
-        Assert.assertNotNull("Created molecule was null", mol);
+        Assertions.assertNotNull(mol, "Created molecule was null");
         EquivalentClassPartitioner it = new EquivalentClassPartitioner(mol);
         int[] equivalentClass = it.getTopoEquivClassbyHuXu(mol);
         char[] arrEquivalent = new char[mol.getAtomCount()];
         for (int i = 1; i < equivalentClass.length; i++)
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
-        Assert.assertNotNull("Equivalent class was null", equivalentClass);
-        Assert.assertEquals("Wrong number of equivalent classes", 9, equivalentClass[0]);
-        Assert.assertEquals("Wrong class assignment", "1234567899", strEquivalent);
+        Assertions.assertNotNull(equivalentClass, "Equivalent class was null");
+        Assertions.assertEquals(9, equivalentClass[0], "Wrong number of equivalent classes");
+        Assertions.assertEquals("1234567899", strEquivalent, "Wrong class assignment");
     }
 
     /**
@@ -329,20 +329,20 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testPyrimidine() throws Exception {
+    void testPyrimidine() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makePyrimidine();
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
-        Assert.assertNotNull("Created molecule was null", mol);
+        Assertions.assertNotNull(mol, "Created molecule was null");
         EquivalentClassPartitioner it = new EquivalentClassPartitioner(mol);
         int[] equivalentClass = it.getTopoEquivClassbyHuXu(mol);
         char[] arrEquivalent = new char[mol.getAtomCount()];
         for (int i = 1; i < equivalentClass.length; i++)
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
-        Assert.assertNotNull("Equivalent class was null", equivalentClass);
-        Assert.assertEquals("Wrong number of equivalent classes", 4, equivalentClass[0]);
-        Assert.assertEquals("Wrong class assignment", "123214", strEquivalent);
+        Assertions.assertNotNull(equivalentClass, "Equivalent class was null");
+        Assertions.assertEquals(4, equivalentClass[0], "Wrong number of equivalent classes");
+        Assertions.assertEquals("123214", strEquivalent, "Wrong class assignment");
     }
 
     /**
@@ -352,20 +352,20 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testBiphenyl() throws Exception {
+    void testBiphenyl() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeBiphenyl();
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
-        Assert.assertNotNull("Created molecule was null", mol);
+        Assertions.assertNotNull(mol, "Created molecule was null");
         EquivalentClassPartitioner it = new EquivalentClassPartitioner(mol);
         int[] equivalentClass = it.getTopoEquivClassbyHuXu(mol);
         char[] arrEquivalent = new char[mol.getAtomCount()];
         for (int i = 1; i < equivalentClass.length; i++)
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
-        Assert.assertNotNull("Equivalent class was null", equivalentClass);
-        Assert.assertEquals("Wrong number of equivalent classes", 4, equivalentClass[0]);
-        Assert.assertEquals("Wrong class assignment", "123432123432", strEquivalent);
+        Assertions.assertNotNull(equivalentClass, "Equivalent class was null");
+        Assertions.assertEquals(4, equivalentClass[0], "Wrong number of equivalent classes");
+        Assertions.assertEquals("123432123432", strEquivalent, "Wrong class assignment");
     }
 
     /**
@@ -377,20 +377,20 @@ public class EquivalentClassPartitionerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testImidazole() throws Exception {
+    void testImidazole() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeImidazole();
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
-        Assert.assertNotNull("Created molecule was null", mol);
+        Assertions.assertNotNull(mol, "Created molecule was null");
         EquivalentClassPartitioner it = new EquivalentClassPartitioner(mol);
         int[] equivalentClass = it.getTopoEquivClassbyHuXu(mol);
         char[] arrEquivalent = new char[mol.getAtomCount()];
         for (int i = 1; i < equivalentClass.length; i++)
             arrEquivalent[i - 1] = Integer.toString(equivalentClass[i]).charAt(0);
         String strEquivalent = new String(arrEquivalent);
-        Assert.assertNotNull("Equivalent class was null", equivalentClass);
-        Assert.assertEquals("Wrong number of equivalent classes", 3, equivalentClass[0]);
-        Assert.assertEquals("Wrong class assignment", "12321", strEquivalent);
+        Assertions.assertNotNull(equivalentClass, "Equivalent class was null");
+        Assertions.assertEquals(3, equivalentClass[0], "Wrong number of equivalent classes");
+        Assertions.assertEquals("12321", strEquivalent, "Wrong class assignment");
     }
 
 }
