@@ -26,9 +26,9 @@ import java.io.InputStream;
 
 import javax.vecmath.Vector3d;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.ChemObject;
@@ -43,60 +43,60 @@ import org.openscience.cdk.tools.LoggingToolFactory;
  *
  * @see org.openscience.cdk.io.CrystClustReader
  */
-public class CrystClustReaderTest extends SimpleChemObjectReaderTest {
+class CrystClustReaderTest extends SimpleChemObjectReaderTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(CrystClustReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(CrystClustReaderTest.class);
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         setSimpleChemObjectReader(new CrystClustReader(), "estron.crystclust");
     }
 
     @Test
-    public void testAccepts() {
-        Assert.assertTrue(chemObjectIO.accepts(ChemFile.class));
-        Assert.assertFalse(chemObjectIO.accepts(AtomContainer.class));
+    void testAccepts() {
+        Assertions.assertTrue(chemObjectIO.accepts(ChemFile.class));
+        Assertions.assertFalse(chemObjectIO.accepts(AtomContainer.class));
     }
 
     @Test
-    public void testEstrone() throws Exception {
+    void testEstrone() throws Exception {
         String filename = "estron.crystclust";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         CrystClustReader reader = new CrystClustReader(ins);
         ChemFile chemFile = (ChemFile) reader.read((ChemObject) new ChemFile());
 
-        Assert.assertNotNull(chemFile);
-        Assert.assertEquals(1, chemFile.getChemSequenceCount());
+        Assertions.assertNotNull(chemFile);
+        Assertions.assertEquals(1, chemFile.getChemSequenceCount());
         org.openscience.cdk.interfaces.IChemSequence seq = chemFile.getChemSequence(0);
-        Assert.assertNotNull(seq);
-        Assert.assertEquals(2, seq.getChemModelCount());
+        Assertions.assertNotNull(seq);
+        Assertions.assertEquals(2, seq.getChemModelCount());
         org.openscience.cdk.interfaces.IChemModel model = seq.getChemModel(0);
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
 
         org.openscience.cdk.interfaces.ICrystal crystal = model.getCrystal();
-        Assert.assertNotNull(crystal);
-        Assert.assertEquals(42, crystal.getAtomCount());
-        Assert.assertEquals(1, crystal.getZ().intValue());
+        Assertions.assertNotNull(crystal);
+        Assertions.assertEquals(42, crystal.getAtomCount());
+        Assertions.assertEquals(1, crystal.getZ().intValue());
 
         // test reading of partial charges
         org.openscience.cdk.interfaces.IAtom atom = crystal.getAtom(0);
-        Assert.assertNotNull(atom);
-        Assert.assertEquals("O", atom.getSymbol());
-        Assert.assertEquals(-0.68264902, atom.getCharge(), 0.00000001);
+        Assertions.assertNotNull(atom);
+        Assertions.assertEquals("O", atom.getSymbol());
+        Assertions.assertEquals(-0.68264902, atom.getCharge(), 0.00000001);
 
         // test unit cell axes
         Vector3d a = crystal.getA();
-        Assert.assertEquals(7.971030, a.x, 0.000001);
-        Assert.assertEquals(0.0, a.y, 0.000001);
-        Assert.assertEquals(0.0, a.z, 0.000001);
+        Assertions.assertEquals(7.971030, a.x, 0.000001);
+        Assertions.assertEquals(0.0, a.y, 0.000001);
+        Assertions.assertEquals(0.0, a.z, 0.000001);
         Vector3d b = crystal.getB();
-        Assert.assertEquals(0.0, b.x, 0.000001);
-        Assert.assertEquals(18.772200, b.y, 0.000001);
-        Assert.assertEquals(0.0, b.z, 0.000001);
+        Assertions.assertEquals(0.0, b.x, 0.000001);
+        Assertions.assertEquals(18.772200, b.y, 0.000001);
+        Assertions.assertEquals(0.0, b.z, 0.000001);
         Vector3d c = crystal.getC();
-        Assert.assertEquals(0.0, c.x, 0.000001);
-        Assert.assertEquals(0.0, c.y, 0.000001);
-        Assert.assertEquals(10.262220, c.z, 0.000001);
+        Assertions.assertEquals(0.0, c.x, 0.000001);
+        Assertions.assertEquals(0.0, c.y, 0.000001);
+        Assertions.assertEquals(10.262220, c.z, 0.000001);
     }
 }
