@@ -6,10 +6,10 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.Reader;
 
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.ChemObject;
 import org.openscience.cdk.test.io.SimpleChemObjectReaderTest;
@@ -26,7 +26,7 @@ import org.openscience.cdk.test.io.SimpleChemObjectReaderTest;
  * @author Nathana&euml;l "M.Le_maudit" Mazuir
  */
 //TODO Update TestCase comments with appropriate information.
-public class GamessReaderTest extends SimpleChemObjectReaderTest {
+class GamessReaderTest extends SimpleChemObjectReaderTest {
 
     /**
      * The "BufferedReader" object used as input parameter for the "GamessReader" object.
@@ -57,8 +57,8 @@ public class GamessReaderTest extends SimpleChemObjectReaderTest {
      *
      * @see java.io.FileReader#FileReader(java.lang.String)
      */
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         String filename = "Cl2O.log";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         this.inputReader = new BufferedReader(new InputStreamReader(ins));
@@ -69,8 +69,8 @@ public class GamessReaderTest extends SimpleChemObjectReaderTest {
     /*
      * @see TestCase#tearDown()
      */
-    @After
-    public void tearDown() throws Exception {
+    @AfterEach
+    void tearDown() throws Exception {
         this.inputReader.close();
         this.gamessReaderUnderTest.close(); // TODO Answer the question : Is it necessary ?
     }
@@ -101,10 +101,10 @@ public class GamessReaderTest extends SimpleChemObjectReaderTest {
      */
     //TODO Update method comments with appropriate information.
     @Test
-    public void testGamessReader() {
-        Assert.assertNotNull("TEST: The inputReader is not null.", this.inputReader);
-        Assert.assertTrue("TEST: The inputReader is a Reader object.", this.inputReader instanceof Reader);
-        Assert.assertNotNull("TEST: The GamessReader object is constructed.", this.gamessReaderUnderTest);
+    void testGamessReader() {
+        Assertions.assertNotNull(this.inputReader, "TEST: The inputReader is not null.");
+        Assertions.assertTrue(this.inputReader instanceof Reader, "TEST: The inputReader is a Reader object.");
+        Assertions.assertNotNull(this.gamessReaderUnderTest, "TEST: The GamessReader object is constructed.");
         //		Assert.assertEquals("TEST: ", this.gr.input, this.inputReader);
     }
 
@@ -127,10 +127,9 @@ public class GamessReaderTest extends SimpleChemObjectReaderTest {
      */
     //TODO Update method comments with appropriate information.
     @Test
-    public void testAccepts() {
-        Assert.assertNotNull("The GamessReader object is not constructed", this.gamessReaderUnderTest);
-        Assert.assertTrue("GamessReader should accept an IChemFile object.",
-                gamessReaderUnderTest.accepts(ChemFile.class));
+    void testAccepts() {
+        Assertions.assertNotNull(this.gamessReaderUnderTest, "The GamessReader object is not constructed");
+        Assertions.assertTrue(gamessReaderUnderTest.accepts(ChemFile.class), "GamessReader should accept an IChemFile object.");
     }
 
     /**
@@ -156,10 +155,9 @@ public class GamessReaderTest extends SimpleChemObjectReaderTest {
      */
     //TODO Update method comments with appropriate information.
     @Test
-    public void testRead() throws Exception {
-        Assert.assertNotNull("TEST: The GamessReader object is constructed.", this.gamessReaderUnderTest);
-        Assert.assertTrue("TEST: read(IChemObject) returns a IChemObject.",
-                this.gamessReaderUnderTest.read(new ChemFile()) instanceof ChemObject);
+    void testRead() throws Exception {
+        Assertions.assertNotNull(this.gamessReaderUnderTest, "TEST: The GamessReader object is constructed.");
+        Assertions.assertTrue(this.gamessReaderUnderTest.read(new ChemFile()) instanceof ChemObject, "TEST: read(IChemObject) returns a IChemObject.");
     }
 
 }
