@@ -24,9 +24,9 @@ package org.openscience.cdk.io;
 
 import java.io.InputStream;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.test.io.SimpleChemObjectReaderTest;
 import org.openscience.cdk.tools.ILoggingTool;
@@ -35,39 +35,39 @@ import org.openscience.cdk.tools.LoggingToolFactory;
 /**
  * @cdk.module test-extra
  */
-public class VASPReaderTest extends SimpleChemObjectReaderTest {
+class VASPReaderTest extends SimpleChemObjectReaderTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(VASPReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(VASPReaderTest.class);
 
-    @BeforeClass
-    public static void setup() throws Exception {
+    @BeforeAll
+    static void setup() throws Exception {
         setSimpleChemObjectReader(new VASPReader(), "LiMoS2_optimisation_ISIF3.vasp");
     }
 
     @Test
-    public void testAccepts() {
+    void testAccepts() {
         VASPReader reader = new VASPReader();
-        Assert.assertTrue(reader.accepts(ChemFile.class));
+        Assertions.assertTrue(reader.accepts(ChemFile.class));
     }
 
     @Test
-    public void testReading() throws Exception {
+    void testReading() throws Exception {
         String filename = "LiMoS2_optimisation_ISIF3.vasp";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         VASPReader reader = new VASPReader(ins);
-        ChemFile chemFile = (ChemFile) reader.read(new ChemFile());
-        Assert.assertNotNull(chemFile);
+        ChemFile chemFile = reader.read(new ChemFile());
+        Assertions.assertNotNull(chemFile);
         org.openscience.cdk.interfaces.IChemSequence sequence = chemFile.getChemSequence(0);
-        Assert.assertNotNull(sequence);
-        Assert.assertEquals(6, sequence.getChemModelCount());
+        Assertions.assertNotNull(sequence);
+        Assertions.assertEquals(6, sequence.getChemModelCount());
         org.openscience.cdk.interfaces.IChemModel model = sequence.getChemModel(0);
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
         org.openscience.cdk.interfaces.ICrystal crystal = model.getCrystal();
-        Assert.assertNotNull(crystal);
-        Assert.assertEquals(16, crystal.getAtomCount());
+        Assertions.assertNotNull(crystal);
+        Assertions.assertEquals(16, crystal.getAtomCount());
         org.openscience.cdk.interfaces.IAtom atom = crystal.getAtom(0);
-        Assert.assertNotNull(atom);
-        Assert.assertNotNull(atom.getFractionalPoint3d());
+        Assertions.assertNotNull(atom);
+        Assertions.assertNotNull(atom.getFractionalPoint3d());
     }
 }
