@@ -18,10 +18,10 @@
  */
 package org.openscience.cdk.limitations.tools;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
@@ -47,13 +47,13 @@ import org.openscience.cdk.tools.SaturationChecker;
  *
  * @see org.openscience.cdk.tools.SaturationChecker
  */
-@Ignore("Limitations actually cause failing tests")
+@Disabled("Limitations actually cause failing tests")
 public class SaturationCheckerTest extends CDKTestCase {
 
     private static SaturationChecker satcheck = null;
 
-    @BeforeClass
-    public static void setup() throws Exception {
+    @BeforeAll
+    static void setup() throws Exception {
         satcheck = new SaturationChecker();
     }
 
@@ -61,7 +61,7 @@ public class SaturationCheckerTest extends CDKTestCase {
      * Tests the method saturate().
      */
     @Test
-    public void testSaturate_WithNitrate() throws Exception {
+    void testSaturate_WithNitrate() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom a1 = new Atom("O");
         mol.addAtom(a1);
@@ -128,15 +128,15 @@ public class SaturationCheckerTest extends CDKTestCase {
         Bond b16 = new Bond(a14, a16, IBond.Order.SINGLE);
         mol.addBond(b16);
         satcheck.saturate(mol);
-        Assert.assertEquals(IBond.Order.DOUBLE, b1.getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, b2.getOrder());
+        Assertions.assertEquals(IBond.Order.DOUBLE, b1.getOrder());
+        Assertions.assertEquals(IBond.Order.DOUBLE, b2.getOrder());
     }
 
     /**
      * Tests the method saturate().
      */
     @Test
-    public void testSaturation_S4AtomType() throws Exception {
+    void testSaturation_S4AtomType() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom a1 = new Atom("N");
         mol.addAtom(a1);
@@ -235,15 +235,15 @@ public class SaturationCheckerTest extends CDKTestCase {
         Bond b24 = new Bond(a22, a24, IBond.Order.SINGLE);
         mol.addBond(b24);
         satcheck.saturate(mol);
-        Assert.assertEquals(IBond.Order.DOUBLE, b6.getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, b7.getOrder());
+        Assertions.assertEquals(IBond.Order.DOUBLE, b6.getOrder());
+        Assertions.assertEquals(IBond.Order.DOUBLE, b7.getOrder());
     }
 
     /**
      * Tests the method saturate().
      */
     @Test
-    public void testSaturate_NumberingProblem() throws Exception {
+    void testSaturate_NumberingProblem() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom a1 = new Atom("C");
         mol.addAtom(a1);
@@ -282,28 +282,28 @@ public class SaturationCheckerTest extends CDKTestCase {
         Bond b9 = new Bond(a5, a9, IBond.Order.SINGLE);
         mol.addBond(b9);
         satcheck.saturate(mol);
-        Assert.assertEquals(IBond.Order.SINGLE, b1.getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, b2.getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, b6.getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, b8.getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, b4.getOrder());
+        Assertions.assertEquals(IBond.Order.SINGLE, b1.getOrder());
+        Assertions.assertEquals(IBond.Order.DOUBLE, b2.getOrder());
+        Assertions.assertEquals(IBond.Order.SINGLE, b6.getOrder());
+        Assertions.assertEquals(IBond.Order.SINGLE, b8.getOrder());
+        Assertions.assertEquals(IBond.Order.DOUBLE, b4.getOrder());
     }
 
     /**
      * Tests whether the saturation checker gets a proton right.
      */
     @Test
-    public void testIsSaturated_Proton() throws Exception {
+    void testIsSaturated_Proton() throws Exception {
         // test H+
         IAtomContainer m = new AtomContainer();
         Atom h = new Atom("H");
         h.setFormalCharge(+1);
         m.addAtom(h);
-        Assert.assertTrue(satcheck.isSaturated(h, m));
+        Assertions.assertTrue(satcheck.isSaturated(h, m));
     }
 
     @Test
-    public void testCalculateMissingHydrogens_Aromatic() throws Exception {
+    void testCalculateMissingHydrogens_Aromatic() throws Exception {
         IAtomContainer pyrrole = TestMoleculeFactory.makePyrrole();
         IAtom n = pyrrole.getAtom(1);
         IRingSet rs = Cycles.sssr(pyrrole).toRingSet();
@@ -311,8 +311,8 @@ public class SaturationCheckerTest extends CDKTestCase {
         for (int j = 0; j < ring.getBondCount(); j++) {
             ring.getBond(j).setFlag(CDKConstants.ISAROMATIC, true);
         }
-        Assert.assertEquals(5, ring.getBondCount());
-        Assert.assertEquals(1, satcheck.calculateNumberOfImplicitHydrogens(n, pyrrole));
+        Assertions.assertEquals(5, ring.getBondCount());
+        Assertions.assertEquals(1, satcheck.calculateNumberOfImplicitHydrogens(n, pyrrole));
     }
 
 }
