@@ -19,19 +19,21 @@
 package org.openscience.cdk.io;
 
 import org.openscience.cdk.CDKConstants;
-import org.openscience.cdk.config.IsotopeFactory;
-import org.openscience.cdk.config.Isotopes;
+import org.openscience.cdk.config.Elements;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IPseudoAtom;
 import org.openscience.cdk.interfaces.ISingleElectron;
 import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.io.formats.IResourceFormat;
 import org.openscience.cdk.io.formats.MDLV3000Format;
+import org.openscience.cdk.io.setting.BooleanIOSetting;
+import org.openscience.cdk.io.setting.IOSetting;
 import org.openscience.cdk.isomorphism.matchers.IQueryAtomContainer;
 import org.openscience.cdk.isomorphism.matchers.IQueryBond;
 import org.openscience.cdk.sgroup.Sgroup;
@@ -73,11 +75,16 @@ import java.util.regex.Pattern;
  */
 public class MDLV3000Reader extends DefaultChemObjectReader {
 
-    BufferedReader input = null;
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLV3000Reader.class);
+    private BooleanIOSetting optForce3d;
+    private BooleanIOSetting optHydIso;
+    private BooleanIOSetting optStereoPerc;
+    private BooleanIOSetting optStereo0d;
 
-    private Pattern keyValueTuple;
-    private Pattern keyValueTuple2;
+    BufferedReader input;
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLV3000Reader.class);
+
+    private final Pattern keyValueTuple;
+    private final Pattern keyValueTuple2;
 
     private int lineNumber;
 
@@ -130,8 +137,8 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
     @Override
     public boolean accepts(Class<? extends IChemObject> classObject) {
         Class<?>[] interfaces = classObject.getInterfaces();
-        for (int i = 0; i < interfaces.length; i++) {
-            if (IAtomContainer.class.equals(interfaces[i])) return true;
+        for (Class<?> anInterface : interfaces) {
+            if (IAtomContainer.class.equals(anInterface)) return true;
         }
         if (IAtomContainer.class.equals(classObject)) return true;
         Class superClass = classObject.getSuperclass();
@@ -147,19 +154,28 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
         throw new CDKException("Only supports AtomContainer objects.");
     }
 
+    private static final class ReadState {
+        IAtomContainer mol;
+        int dimensions = 0; // 0D (undef/no coordinates), 2D, 3D
+        boolean chiral;
+        Map<Integer,Integer> stereoflags = null;
+        final Map<IAtom,Integer> stereo0d = new HashMap<>();
+    }
+
     public IAtomContainer readMolecule(IChemObjectBuilder builder) throws CDKException {
         return readConnectionTable(builder);
     }
 
     public IAtomContainer readConnectionTable(IChemObjectBuilder builder) throws CDKException {
 
-        boolean chiral = false;
-        Map<Integer,Integer> stereoflags = null;
-
         logger.info("Reading CTAB block");
+        ReadState state = new ReadState();
         IAtomContainer readData = builder.newAtomContainer();
+        state.mol = readData;
+        state.chiral = false;
+
         boolean foundEND = false;
-        String lastLine = readHeader(readData);
+        String lastLine = readHeader(state);
         while (isReady() && !foundEND) {
             String command = readCommand(lastLine);
             logger.debug("command found: " + command);
@@ -170,27 +186,33 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
             } else if (command.startsWith("COUNTS ")) {
                 // COUNTS <natom> <nbond> <nsgroup> <n3dquery> <chiral> [REGNO=<regno>]
                 String[] counts = command.split(" ");
-                chiral = counts.length >= 6 && counts[5].equals("1");
+                state.chiral = counts.length >= 6 && counts[5].equals("1");
             } else if ("BEGIN ATOM".equals(command)) {
-                readAtomBlock(readData);
+                readAtomBlock(state);
             } else if ("BEGIN BOND".equals(command)) {
                 readBondBlock(readData);
             } else if ("BEGIN SGROUP".equals(command)) {
                 readSGroup(readData);
             } else if ("BEGIN COLLECTION".equals(command)) {
-                if (stereoflags == null)
-                    stereoflags = new HashMap<>();
-                readCollection(readData, stereoflags);
+                readCollection(state);
             } else {
                 logger.warn("Unrecognized command: " + command);
             }
             lastLine = readLine();
         }
 
+        finalizeMol(state);
+
+        return readData;
+    }
+
+    private void finalizeMol(ReadState state) {
+        finalizeDimensions(state);
+
+        IAtomContainer readData = state.mol;
         boolean isQuery = readData instanceof IQueryAtomContainer;
 
         for (IAtom atom : readData.atoms()) {
-            // XXX: slow method is slow
             int valence = 0;
             for (IBond bond : readData.getConnectedBondsList(atom)) {
                 if (bond instanceof IQueryBond || bond.getOrder() == IBond.Order.UNSET) {
@@ -209,31 +231,40 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
             }
         }
 
-        if (!isQuery) {
+        if (!isQuery)
+            finalizeStereochemistry(state, readData);
+    }
 
-            /* Add stereo information */
-            boolean is3d = true;
-            for (IAtom atom : readData.atoms()) {
-                if (atom.getPoint3d() == null)
-                    is3d = false;
-            }
-            if (is3d) { // has 3D coordinates
+    private void finalizeStereochemistry(ReadState state, IAtomContainer readData) {
+        if (optStereoPerc.isSet()) {
+
+            if (state.dimensions == 3) { // has 3D coordinates
                 readData.setStereoElements(StereoElementFactory.using3DCoordinates(readData)
-                        .createAll());
-            } else { // has 2D coordinates (set as 2D coordinates)
+                                                               .createAll());
+            } else if (state.dimensions == 2) { // has 2D coordinates (set as 2D coordinates)
                 readData.setStereoElements(StereoElementFactory.using2DCoordinates(readData)
-                        .createAll());
+                                                               .createAll());
+            } else if (state.dimensions == 0 && optStereo0d.isSet()) {
+                // technically if a molecule is 2D/3D and has the CFG=1 or CFG=2
+                // specified this gives us hints information but it's safer to
+                // just use the coordinates or wedge bonds
+                for (Map.Entry<IAtom, Integer> e : state.stereo0d.entrySet()) {
+                    IStereoElement<IAtom,IAtom> stereoElement
+                            = MDLV2000Reader.createStereo0d(state.mol, e.getKey(), e.getValue());
+                    if (stereoElement != null)
+                        state.mol.addStereoElement(stereoElement);
+                }
             }
 
-            if (stereoflags != null && !stereoflags.isEmpty()) {
+            if (state.stereoflags != null && !state.stereoflags.isEmpty()) {
 
                 // work out the next available group, if we have &1, &2, etc then we choose &3
                 // this is only needed if
                 int defaultRacGrp = 0;
-                if (!chiral) {
+                if (!state.chiral) {
                     int max = 0;
-                    for (Integer val : stereoflags.values()) {
-                        if ((val&IStereoElement.GRP_TYPE_MASK) == IStereoElement.GRP_RAC) {
+                    for (Integer val : state.stereoflags.values()) {
+                        if ((val & IStereoElement.GRP_TYPE_MASK) == IStereoElement.GRP_RAC) {
                             int num = val >>> IStereoElement.GRP_NUM_SHIFT;
                             if (num > max)
                                 max = num;
@@ -249,13 +280,13 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                     int idx = readData.indexOf(focus);
                     if (idx < 0)
                         continue;
-                    Integer grpinfo = stereoflags.get(idx);
+                    Integer grpinfo = state.stereoflags.get(idx);
                     if (grpinfo != null)
                         se.setGroupInfo(grpinfo);
-                    else if (!chiral)
+                    else if (!state.chiral)
                         se.setGroupInfo(defaultRacGrp);
                 }
-            } else if (!chiral) {
+            } else if (!state.chiral) {
                 // chiral flag not set which means this molecule is this stereoisomer "and" the enantiomer, mark all
                 // Tetrahedral stereo as AND1 (&1)
                 for (IStereoElement<?, ?> se : readData.stereoElements()) {
@@ -265,9 +296,42 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                 }
             }
         }
+    }
 
+    // the parser will read all coords as 3D, then given information
+    // in the header and the x,y,z values of each atom we work out
+    // whether we are 0D, 2D (Point2D) or 3D (Point3D)
+    private void finalizeDimensions(ReadState state) {
+        // all ready done
+        if (state.dimensions == 3 || optForce3d.isSet())
+            return;
+        int dimensions = 0;
+        for (IAtom atom : state.mol.atoms()) {
+            Point3d p3d = atom.getPoint3d();
+            if (p3d.z != 0d) {
+                dimensions = 3; // 3D
+                break;
+            } else if (dimensions == 0 && p3d.x != 0 && p3d.y != 0) {
+                dimensions = 2; // 2D (if not 3D)
+            }
+        }
+        // check the global header
+        if (dimensions == 0)
+            dimensions = state.dimensions;
+        state.dimensions = dimensions;
 
-        return readData;
+        if (dimensions == 0) {
+            // remove all coords we set
+            for (IAtom atom : state.mol.atoms())
+                atom.setPoint3d(null);
+        } else if (dimensions == 2) {
+            // convert 3d to 2d
+            for (IAtom atom : state.mol.atoms()) {
+                Point3d p3d = atom.getPoint3d();
+                atom.setPoint2d(new Point2d(p3d.x, p3d.y));
+                atom.setPoint3d(null);
+            }
+        }
     }
 
     boolean isDigit(char ch) {
@@ -319,31 +383,43 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
     /**
      * Read collection information: highlights (no currently supported) and abs, rac, rel stereo groups
      *
-     * @param flags the stereo flags
-     * @param mol the molecule
+     * @param state the read state
      * @return true if stereo group info was set - this is to override the chiral flag
      */
-    private void readCollection(IAtomContainer mol, Map<Integer,Integer> flags) throws CDKException {
+    private void readCollection(ReadState state) throws CDKException {
+        if (state.stereoflags == null)
+            state.stereoflags = new HashMap<>();
         String line;
         while ((line = readLine()) != null) {
             String command = readCommand(line);
             if (command.startsWith("END COLLECTION"))
                 break;
             else if (command.startsWith("MDLV30/STERAC")) {
-                parseStereoGroup(flags, command, IStereoElement.GRP_RAC);
+                parseStereoGroup(state.stereoflags, command, IStereoElement.GRP_RAC);
             } else if (command.startsWith("MDLV30/STEREL")) {
-                parseStereoGroup(flags, command, IStereoElement.GRP_REL);
+                parseStereoGroup(state.stereoflags, command, IStereoElement.GRP_REL);
             } else if (command.startsWith("MDLV30/STEABS")) {
-                parseStereoGroup(flags, command, IStereoElement.GRP_ABS);
+                parseStereoGroup(state.stereoflags, command, IStereoElement.GRP_ABS);
             }
         }
     }
 
+    // read info from the info header
+    //'  CDK     09251712073D'
+    // 0123456789012345678901
+    private static int parseDimensions(String info) {
+        if (info.startsWith("2D", 20))
+            return 2;
+        if (info.startsWith("3D", 20))
+            return 3;
+        return 0;
+    }
+
     /**
      * @return Last line read
      * @throws CDKException when no file content is detected
      */
-    public String readHeader(IAtomContainer readData) throws CDKException {
+    public String readHeader(ReadState state) throws CDKException {
         // read four lines
         String line1 = readLine();
         if (line1 == null) {
@@ -354,11 +430,13 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                 // no header
                 return line1;
             }
-            readData.setTitle(line1);
+            state.mol.setTitle(line1);
         }
-        readLine();
+        String infoLine = readLine();
+        state.dimensions = parseDimensions(infoLine);
         String line3 = readLine();
-        if (line3.length() > 0) readData.setProperty(CDKConstants.COMMENT, line3);
+        if (line3.length() > 0)
+            state.mol.setProperty(CDKConstants.COMMENT, line3);
         String line4 = readLine();
         if (!line4.contains("3000")) {
             throw new CDKException("This file is not a MDL V3000 molfile.");
@@ -371,18 +449,13 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
      *
      * <p>IMPORTANT: it does not support the atom list and its negation!
      */
-    public void readAtomBlock(IAtomContainer readData) throws CDKException {
+    public void readAtomBlock(ReadState state) throws CDKException {
+        IAtomContainer readData = state.mol;
         logger.info("Reading ATOM block");
-        IsotopeFactory isotopeFactory;
-        try {
-            isotopeFactory = Isotopes.getInstance();
-        } catch (IOException exception) {
-            throw new CDKException("Could not initiate the IsotopeFactory.", exception);
-        }
 
         int RGroupCounter = 1;
-        int Rnumber = 0;
-        String[] rGroup = null;
+        int Rnumber;
+        String[] rGroup;
 
         boolean foundEND = false;
         while (isReady() && !foundEND) {
@@ -405,9 +478,15 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                 }
                 // parse the element
                 String element = tokenizer.nextToken();
-                if (isotopeFactory.isElement(element)) {
-                    atom.setSymbol(element);
-                    isotopeFactory.configure(atom); // ?
+                Elements e = Elements.ofString(element);
+                if (e != Elements.Unknown) {
+                    atom.setAtomicNumber(e.number());
+                } else if ("D".equals(element) && optHydIso.isSet()) {
+                    atom.setMassNumber(2);
+                    atom.setAtomicNumber(IElement.H);
+                } else if ("T".equals(element) && optHydIso.isSet()) {
+                    atom.setMassNumber(3);
+                    atom.setAtomicNumber(IElement.H);
                 } else if ("A".equals(element)) {
                     atom = readData.getBuilder().newInstance(IPseudoAtom.class, element);
                 } else if ("Q".equals(element)) {
@@ -424,7 +503,7 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                     rGroup = element.split("^R");
                     if (rGroup.length > 1) {
                         try {
-                            Rnumber = Integer.valueOf(rGroup[(rGroup.length - 1)]).intValue();
+                            Rnumber = Integer.parseInt(rGroup[(rGroup.length - 1)]);
                             RGroupCounter = Rnumber;
                         } catch (Exception ex) {
                             Rnumber = RGroupCounter;
@@ -451,7 +530,6 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                     double y = Double.parseDouble(yString);
                     double z = Double.parseDouble(zString);
                     atom.setPoint3d(new Point3d(x, y, z));
-                    atom.setPoint2d(new Point2d(x, y)); // FIXME: dirty!
                 } catch (Exception exception) {
                     String error = "Error while parsing atom coordinates";
                     logger.error(error);
@@ -467,12 +545,17 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                 // the rest are key value things
                 if (command.indexOf('=') != -1) {
                     Map<String, String> options = parseOptions(exhaustStringTokenizer(tokenizer));
-                    Iterator<String> keys = options.keySet().iterator();
-                    while (keys.hasNext()) {
-                        String key = keys.next();
+                    for (String key : options.keySet()) {
                         String value = options.get(key);
                         try {
                             switch (key) {
+                                case "CFG":
+                                    int cfg = Integer.parseInt(value);
+                                    if (cfg != 0) {
+                                        atom.setStereoParity(cfg);
+                                        state.stereo0d.put(atom, cfg);
+                                    }
+                                    break;
                                 case "CHG":
                                     int charge = Integer.parseInt(value);
                                     if (charge != 0) { // zero is no charge specified
@@ -484,9 +567,13 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                                     int numElectons = spinMultiplicity.getSingleElectrons();
                                     atom.setProperty(CDKConstants.SPIN_MULTIPLICITY, spinMultiplicity);
                                     while (numElectons-- > 0) {
-                                        readData.addSingleElectron(readData.getBuilder().newInstance(ISingleElectron.class, atom));
+                                        readData.addSingleElectron(readData.getBuilder()
+                                                                           .newInstance(ISingleElectron.class, atom));
                                     }
                                     break;
+                                case "MASS":
+                                    atom.setMassNumber(Integer.parseInt(value));
+                                    break;
                                 case "VAL":
                                     if (!(atom instanceof IPseudoAtom)) {
                                         try {
@@ -558,7 +645,7 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                         bond.setOrder(IBond.Order.UNSET);
                         logger.warn("Query order types are not supported (yet). File a bug if you need it");
                     } else {
-                        bond.setOrder(BondManipulator.createBondOrder((double) order));
+                        bond.setOrder(BondManipulator.createBondOrder(order));
                     }
                 } catch (Exception exception) {
                     String error = "Error while parsing bond index";
@@ -682,7 +769,7 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
                 logger.warn("Skipping external index: " + externalIndexString);
 
                 // the rest are key=value fields
-                Map<String, String> options = new Hashtable<String, String>();
+                Map<String, String> options = new Hashtable<>();
                 if (command.indexOf('=') != -1) {
                     options = parseOptions(exhaustStringTokenizer(tokenizer));
                 }
@@ -758,7 +845,7 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
     }
 
     private Map<String, String> parseOptions(String string) throws CDKException {
-        Map<String, String> keyValueTuples = new Hashtable<String, String>();
+        Map<String, String> keyValueTuples = new Hashtable<>();
         while (string.length() >= 3) {
             logger.debug("Matching remaining option string: " + string);
             Matcher tuple1Matcher = keyValueTuple2.matcher(string);
@@ -788,7 +875,7 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
     }
 
     public String exhaustStringTokenizer(StringTokenizer tokenizer) {
-        StringBuffer buffer = new StringBuffer();
+        StringBuilder buffer = new StringBuilder();
         buffer.append(' ');
         while (tokenizer.hasMoreTokens()) {
             buffer.append(tokenizer.nextToken());
@@ -798,7 +885,7 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
     }
 
     public String readLine() throws CDKException {
-        String line = null;
+        String line;
         try {
             line = input.readLine();
             lineNumber++;
@@ -829,6 +916,15 @@ public class MDLV3000Reader extends DefaultChemObjectReader {
     }
 
     private void initIOSettings() {
+        optForce3d = addSetting(new BooleanIOSetting("ForceReadAs3DCoordinates", IOSetting.Importance.LOW,
+                "Should coordinates always be read as 3D?", "false"));
+        optHydIso = addSetting(new BooleanIOSetting("InterpretHydrogenIsotopes",
+                IOSetting.Importance.LOW, "Should D and T be interpreted as hydrogen isotopes?", "true"));
+        optStereoPerc = addSetting(new BooleanIOSetting("AddStereoElements", IOSetting.Importance.LOW,
+                "Detect and create IStereoElements for the input.", "true"));
+        optStereo0d = addSetting(new BooleanIOSetting("AddStereo0d", IOSetting.Importance.LOW,
+                "Allow stereo created from parity value when no coordinates", "true"));
+
     }
 
     /**
