@@ -26,9 +26,9 @@ import java.io.InputStream;
 import java.io.StringReader;
 import java.util.Iterator;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.ChemModel;
 import org.openscience.cdk.Reaction;
@@ -52,47 +52,47 @@ import static org.hamcrest.MatcherAssert.assertThat;
  *
  * @see org.openscience.cdk.io.MDLRXNReader
  */
-public class MDLRXNV2000ReaderTest extends SimpleChemObjectReaderTest {
+class MDLRXNV2000ReaderTest extends SimpleChemObjectReaderTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLRXNV2000ReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLRXNV2000ReaderTest.class);
 
-    @BeforeClass
-    public static void setup() throws Exception {
+    @BeforeAll
+    static void setup() throws Exception {
         setSimpleChemObjectReader(new MDLRXNV2000Reader(), "0024.stg02.rxn");
     }
 
     @Test
-    public void testAccepts() {
+    void testAccepts() {
         MDLRXNV2000Reader reader = new MDLRXNV2000Reader();
-        Assert.assertTrue(reader.accepts(ChemFile.class));
-        Assert.assertTrue(reader.accepts(ChemModel.class));
-        Assert.assertTrue(reader.accepts(Reaction.class));
+        Assertions.assertTrue(reader.accepts(ChemFile.class));
+        Assertions.assertTrue(reader.accepts(ChemModel.class));
+        Assertions.assertTrue(reader.accepts(Reaction.class));
     }
 
     /**
      * @cdk.bug 1849923
      */
     @Test
-    public void testReadReactions1() throws Exception {
+    void testReadReactions1() throws Exception {
         String filename1 = "0024.stg02.rxn";
         logger.info("Testing: " + filename1);
         InputStream ins1 = this.getClass().getResourceAsStream(filename1);
         MDLRXNV2000Reader reader1 = new MDLRXNV2000Reader(ins1, Mode.STRICT);
         IReaction reaction1 = new Reaction();
-        reaction1 = (IReaction) reader1.read(reaction1);
+        reaction1 = reader1.read(reaction1);
         reader1.close();
 
-        Assert.assertNotNull(reaction1);
-        Assert.assertEquals(1, reaction1.getReactantCount());
-        Assert.assertEquals(1, reaction1.getProductCount());
+        Assertions.assertNotNull(reaction1);
+        Assertions.assertEquals(1, reaction1.getReactantCount());
+        Assertions.assertEquals(1, reaction1.getProductCount());
         IAtomContainer reactant = reaction1.getReactants().getAtomContainer(0);
-        Assert.assertNotNull(reactant);
-        Assert.assertEquals(46, reactant.getAtomCount());
-        Assert.assertEquals(44, reactant.getBondCount());
+        Assertions.assertNotNull(reactant);
+        Assertions.assertEquals(46, reactant.getAtomCount());
+        Assertions.assertEquals(44, reactant.getBondCount());
         IAtomContainer product = reaction1.getProducts().getAtomContainer(0);
-        Assert.assertNotNull(product);
-        Assert.assertEquals(46, product.getAtomCount());
-        Assert.assertEquals(43, product.getBondCount());
+        Assertions.assertNotNull(product);
+        Assertions.assertEquals(46, product.getAtomCount());
+        Assertions.assertEquals(43, product.getBondCount());
 
     }
 
@@ -100,55 +100,56 @@ public class MDLRXNV2000ReaderTest extends SimpleChemObjectReaderTest {
      * @cdk.bug 1851202
      */
     @Test
-    public void testBug1851202() throws Exception {
+    void testBug1851202() throws Exception {
         String filename1 = "0002.stg01.rxn";
         logger.info("Testing: " + filename1);
         InputStream ins1 = this.getClass().getResourceAsStream(filename1);
         MDLRXNV2000Reader reader1 = new MDLRXNV2000Reader(ins1, Mode.STRICT);
         IReaction reaction1 = new Reaction();
-        reaction1 = (IReaction) reader1.read(reaction1);
+        reaction1 = reader1.read(reaction1);
         reader1.close();
 
-        Assert.assertNotNull(reaction1);
-        Assert.assertEquals(1, reaction1.getReactantCount());
-        Assert.assertEquals(1, reaction1.getProductCount());
+        Assertions.assertNotNull(reaction1);
+        Assertions.assertEquals(1, reaction1.getReactantCount());
+        Assertions.assertEquals(1, reaction1.getProductCount());
         IAtomContainer reactant = reaction1.getReactants().getAtomContainer(0);
-        Assert.assertNotNull(reactant);
-        Assert.assertEquals(30, reactant.getAtomCount());
-        Assert.assertEquals(25, reactant.getBondCount());
+        Assertions.assertNotNull(reactant);
+        Assertions.assertEquals(30, reactant.getAtomCount());
+        Assertions.assertEquals(25, reactant.getBondCount());
         IAtomContainer product = reaction1.getProducts().getAtomContainer(0);
-        Assert.assertNotNull(product);
-        Assert.assertEquals(30, product.getAtomCount());
-        Assert.assertEquals(26, product.getBondCount());
+        Assertions.assertNotNull(product);
+        Assertions.assertEquals(30, product.getAtomCount());
+        Assertions.assertEquals(26, product.getBondCount());
 
     }
 
     @Test
-    public void testReadMapping() throws Exception {
+    void testReadMapping() throws Exception {
         String filename2 = "mappingTest.rxn";
         logger.info("Testing: " + filename2);
         InputStream ins2 = this.getClass().getResourceAsStream(filename2);
         MDLRXNV2000Reader reader2 = new MDLRXNV2000Reader(ins2);
         IReaction reaction2 = new Reaction();
-        reaction2 = (IReaction) reader2.read(reaction2);
+        reaction2 = reader2.read(reaction2);
         reader2.close();
 
-        Assert.assertNotNull(reaction2);
+        Assertions.assertNotNull(reaction2);
         Iterator<IMapping> maps = reaction2.mappings().iterator();
         maps.next();
-        Assert.assertTrue(maps.hasNext());
+        Assertions.assertTrue(maps.hasNext());
     }
 
     @Test
-    public void testAgentParts() throws Exception {
+    void testAgentParts() throws Exception {
         try (InputStream in = this.getClass().getResourceAsStream("ethylesterification.mol");
-             MDLRXNV2000Reader rdr = new MDLRXNV2000Reader(in);) {
+             MDLRXNV2000Reader rdr = new MDLRXNV2000Reader(in)) {
             IReaction reaction = rdr.read(new Reaction());
             assertThat(reaction.getAgents().getAtomContainerCount(), is(1));
         }
     }
 
-    @Test public void optionalSdfSeparator() throws Exception {
+    @Test
+    void optionalSdfSeparator() throws Exception {
         String dummyRecord = "ethanol\n" +
                        "  Mrv1810 09251921392D          \n" +
                        "\n" +
