@@ -27,9 +27,9 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.StringReader;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.ChemModel;
 import org.openscience.cdk.Reaction;
 import org.openscience.cdk.exception.CDKException;
@@ -49,50 +49,51 @@ import org.openscience.cdk.tools.LoggingToolFactory;
  *
  * @see org.openscience.cdk.io.MDLRXNReader
  */
-public class MDLRXNV3000ReaderTest extends SimpleChemObjectReaderTest {
+class MDLRXNV3000ReaderTest extends SimpleChemObjectReaderTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLRXNV3000ReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDLRXNV3000ReaderTest.class);
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         setSimpleChemObjectReader(new MDLRXNV3000Reader(), "reaction_v3.rxn");
     }
 
     @Test
-    public void testAccepts() {
+    void testAccepts() {
         MDLRXNV3000Reader reader = new MDLRXNV3000Reader();
-        Assert.assertTrue(reader.accepts(ChemModel.class));
-        Assert.assertTrue(reader.accepts(Reaction.class));
+        Assertions.assertTrue(reader.accepts(ChemModel.class));
+        Assertions.assertTrue(reader.accepts(Reaction.class));
     }
 
     /**
      * @cdk.bug 1849925
      */
     @Test
-    public void testReadReactions1() throws Exception {
+    void testReadReactions1() throws Exception {
         String filename1 = "reaction_v3.rxn";
         logger.info("Testing: " + filename1);
         InputStream ins1 = this.getClass().getResourceAsStream(filename1);
         MDLRXNV3000Reader reader1 = new MDLRXNV3000Reader(ins1, Mode.STRICT);
         IReaction reaction1 = new Reaction();
-        reaction1 = (IReaction) reader1.read(reaction1);
+        reaction1 = reader1.read(reaction1);
         reader1.close();
 
-        Assert.assertNotNull(reaction1);
-        Assert.assertEquals(1, reaction1.getReactantCount());
-        Assert.assertEquals(1, reaction1.getProductCount());
+        Assertions.assertNotNull(reaction1);
+        Assertions.assertEquals(1, reaction1.getReactantCount());
+        Assertions.assertEquals(1, reaction1.getProductCount());
         IAtomContainer reactant = reaction1.getReactants().getAtomContainer(0);
-        Assert.assertNotNull(reactant);
-        Assert.assertEquals(32, reactant.getAtomCount());
-        Assert.assertEquals(29, reactant.getBondCount());
+        Assertions.assertNotNull(reactant);
+        Assertions.assertEquals(32, reactant.getAtomCount());
+        Assertions.assertEquals(29, reactant.getBondCount());
         IAtomContainer product = reaction1.getProducts().getAtomContainer(0);
-        Assert.assertNotNull(product);
-        Assert.assertEquals(32, product.getAtomCount());
-        Assert.assertEquals(29, product.getBondCount());
+        Assertions.assertNotNull(product);
+        Assertions.assertEquals(32, product.getAtomCount());
+        Assertions.assertEquals(29, product.getBondCount());
 
     }
 
-    @Test public void readAgents() throws IOException, CDKException {
+    @Test
+    void readAgents() throws IOException, CDKException {
         String rxnfile = "$RXN V3000\n" +
                 "\n" +
                 "  Mrv1810      020601212219\n" +
@@ -211,9 +212,9 @@ public class MDLRXNV3000ReaderTest extends SimpleChemObjectReaderTest {
         try (MDLRXNV3000Reader mdlr = new MDLRXNV3000Reader(new StringReader(rxnfile))) {
             IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
             IReaction reaction = mdlr.read(bldr.newInstance(IReaction.class));
-            Assert.assertEquals(2, reaction.getReactantCount());
-            Assert.assertEquals(1, reaction.getProductCount());
-            Assert.assertEquals(2, reaction.getAgents().getAtomContainerCount());
+            Assertions.assertEquals(2, reaction.getReactantCount());
+            Assertions.assertEquals(1, reaction.getProductCount());
+            Assertions.assertEquals(2, reaction.getAgents().getAtomContainerCount());
         }
     }
 }
