@@ -27,8 +27,8 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.util.Properties;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.exception.CDKException;
@@ -48,12 +48,12 @@ import org.openscience.cdk.tools.LoggingToolFactory;
  * @cdk.module test-io
  * @see org.openscience.cdk.io.MDLReader
  */
-public class IteratingSDFReaderTest extends CDKTestCase {
+class IteratingSDFReaderTest extends CDKTestCase {
 
-    private ILoggingTool logger = LoggingToolFactory.createLoggingTool(IteratingSDFReaderTest.class);
+    private final ILoggingTool logger = LoggingToolFactory.createLoggingTool(IteratingSDFReaderTest.class);
 
     @Test
-    public void testSDF() throws Exception {
+    void testSDF() throws Exception {
         String filename = "test2.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -62,19 +62,18 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
-            Assert.assertEquals("Molecule # was not in MDL V2000 format: " + molCount, MDLV2000Format.getInstance(),
-                    reader.getFormat());
+            Assertions.assertEquals(MDLV2000Format.getInstance(), reader.getFormat(), "Molecule # was not in MDL V2000 format: " + molCount);
         }
 
-        Assert.assertEquals(6, molCount);
+        Assertions.assertEquals(6, molCount);
         reader.close();
     }
 
     @Test
-    public void testSDF_broken_stream() throws Exception {
+    void testSDF_broken_stream() throws Exception {
         String filename = "test2.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -91,67 +90,66 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
-            Assert.assertEquals("Molecule # was not in MDL V2000 format: " + molCount, MDLV2000Format.getInstance(),
-                    reader.getFormat());
+            Assertions.assertEquals(MDLV2000Format.getInstance(), reader.getFormat(), "Molecule # was not in MDL V2000 format: " + molCount);
         }
 
-        Assert.assertEquals(6, molCount);
+        Assertions.assertEquals(6, molCount);
         reader.close();
     }
 
     @Test
-    public void testReadTitle() throws Exception {
+    void testReadTitle() throws Exception {
         String filename = "test.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         IteratingSDFReader reader = new IteratingSDFReader(ins, DefaultChemObjectBuilder.getInstance());
 
         //int molCount = 0;
-        Assert.assertTrue(reader.hasNext());
+        Assertions.assertTrue(reader.hasNext());
         Object object = reader.next();
-        Assert.assertNotNull(object);
-        Assert.assertTrue(object instanceof IAtomContainer);
-        Assert.assertEquals("2-methylbenzo-1,4-quinone", ((IAtomContainer) object).getTitle());
-        Assert.assertEquals(MDLV2000Format.getInstance(), reader.getFormat());
+        Assertions.assertNotNull(object);
+        Assertions.assertTrue(object instanceof IAtomContainer);
+        Assertions.assertEquals("2-methylbenzo-1,4-quinone", ((IAtomContainer) object).getTitle());
+        Assertions.assertEquals(MDLV2000Format.getInstance(), reader.getFormat());
         reader.close();
     }
 
     @Test
-    public void testReadDataItems() throws Exception {
+    void testReadDataItems() throws Exception {
         String filename = "test.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         IteratingSDFReader reader = new IteratingSDFReader(ins, DefaultChemObjectBuilder.getInstance());
 
         //int molCount = 0;
-        Assert.assertTrue(reader.hasNext());
+        Assertions.assertTrue(reader.hasNext());
         Object object = reader.next();
-        Assert.assertNotNull(object);
-        Assert.assertTrue(object instanceof IAtomContainer);
+        Assertions.assertNotNull(object);
+        Assertions.assertTrue(object instanceof IAtomContainer);
         IAtomContainer m = (IAtomContainer) object;
-        Assert.assertEquals("1", m.getProperty("E_NSC"));
-        Assert.assertEquals("553-97-9", m.getProperty("E_CAS"));
+        Assertions.assertEquals("1", m.getProperty("E_NSC"));
+        Assertions.assertEquals("553-97-9", m.getProperty("E_CAS"));
         reader.close();
     }
 
     @Test
-    public void testMultipleEntryFields() throws Exception {
+    void testMultipleEntryFields() throws Exception {
         String filename = "test.sdf";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         IteratingSDFReader reader = new IteratingSDFReader(ins, DefaultChemObjectBuilder.getInstance());
 
-        IAtomContainer m = (IAtomContainer) reader.next();
-        Assert.assertEquals("553-97-9", m.getProperty("E_CAS"));
+        IAtomContainer m = reader.next();
+        Assertions.assertEquals("553-97-9", m.getProperty("E_CAS"));
         m = reader.next();
-        Assert.assertEquals("120-78-5", m.getProperty("E_CAS"));
+        Assertions.assertEquals("120-78-5", m.getProperty("E_CAS"));
         reader.close();
     }
 
     @Test
-    public void testOnMDLMolfile() throws Exception {
+    void testOnMDLMolfile() throws Exception {
         String filename = "bug682233.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -160,17 +158,17 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
         }
 
-        Assert.assertEquals(1, molCount);
+        Assertions.assertEquals(1, molCount);
         reader.close();
     }
 
     @Test
-    public void testOnSingleEntrySDFile() throws Exception {
+    void testOnSingleEntrySDFile() throws Exception {
         String filename = "singleMol.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -179,17 +177,17 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
         }
 
-        Assert.assertEquals(1, molCount);
+        Assertions.assertEquals(1, molCount);
         reader.close();
     }
 
     @Test
-    public void testEmptyEntryIteratingReader() throws IOException {
+    void testEmptyEntryIteratingReader() throws IOException {
         String filename = "emptyStructures.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -197,18 +195,18 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
 
             if (molCount == 2) {
                 IAtomContainer mol = (IAtomContainer) object;
-                String s = (String) mol.getProperty("Species");
-                Assert.assertEquals("rat", s);
+                String s = mol.getProperty("Species");
+                Assertions.assertEquals("rat", s);
             }
         }
 
-        Assert.assertEquals(2, molCount);
+        Assertions.assertEquals(2, molCount);
         reader.close();
     }
 
@@ -216,7 +214,7 @@ public class IteratingSDFReaderTest extends CDKTestCase {
      * @cdk.bug 2692107
      */
     @Test
-    public void testZeroZCoordinates() throws Exception {
+    void testZeroZCoordinates() throws Exception {
         String filename = "nozcoord.sdf";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -229,18 +227,18 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         int molCount = 0;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
             boolean has3d = GeometryUtil.has3DCoordinates((IAtomContainer) object);
-            Assert.assertTrue(has3d);
+            Assertions.assertTrue(has3d);
         }
-        Assert.assertNotSame(0, molCount);
+        Assertions.assertNotSame(0, molCount);
         reader.close();
     }
 
     @Test
-    public void testNo3DCoordsButForcedAs() throws IOException {
+    void testNo3DCoordsButForcedAs() throws IOException {
         // First test unforced 3D coordinates
         String filename = "no3dStructures.sdf";
         logger.info("Testing: " + filename);
@@ -250,15 +248,15 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         IAtomContainer mol = null;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
             mol = (IAtomContainer) object;
         }
 
-        Assert.assertEquals(2, molCount);
-        Assert.assertNotNull(mol.getAtom(0).getPoint2d());
-        Assert.assertNull(mol.getAtom(0).getPoint3d());
+        Assertions.assertEquals(2, molCount);
+        Assertions.assertNotNull(mol.getAtom(0).getPoint2d());
+        Assertions.assertNull(mol.getAtom(0).getPoint3d());
         reader.close();
 
         // Now test forced 3D coordinates
@@ -271,15 +269,15 @@ public class IteratingSDFReaderTest extends CDKTestCase {
         mol = null;
         while (reader.hasNext()) {
             Object object = reader.next();
-            Assert.assertNotNull(object);
-            Assert.assertTrue(object instanceof IAtomContainer);
+            Assertions.assertNotNull(object);
+            Assertions.assertTrue(object instanceof IAtomContainer);
             molCount++;
             mol = (IAtomContainer) object;
         }
 
-        Assert.assertEquals(2, molCount);
-        Assert.assertNull(mol.getAtom(0).getPoint2d());
-        Assert.assertNotNull(mol.getAtom(0).getPoint3d());
+        Assertions.assertEquals(2, molCount);
+        Assertions.assertNull(mol.getAtom(0).getPoint2d());
+        Assertions.assertNotNull(mol.getAtom(0).getPoint3d());
         reader.close();
     }
 
@@ -303,7 +301,7 @@ public class IteratingSDFReaderTest extends CDKTestCase {
      * @cdk.bug 3488307
      */
     @Test
-    public void testBrokenSDF() throws IOException, CDKException {
+    void testBrokenSDF() throws IOException, CDKException {
 
         String path = "bug3488307.sdf";
         InputStream in = getClass().getResourceAsStream(path);
@@ -321,12 +319,12 @@ public class IteratingSDFReaderTest extends CDKTestCase {
 
         reader.close();
 
-        Assert.assertEquals(3, count);
+        Assertions.assertEquals(3, count);
 
     }
 
     @Test
-    public void testV3000MolfileFormat() throws IOException, CDKException {
+    void testV3000MolfileFormat() throws IOException, CDKException {
 
         String path = "molV3000.mol";
         InputStream in = getClass().getResourceAsStream(path);
@@ -344,7 +342,7 @@ public class IteratingSDFReaderTest extends CDKTestCase {
 
         reader.close();
 
-        Assert.assertEquals(1, count);
+        Assertions.assertEquals(1, count);
 
     }
 
