@@ -24,9 +24,9 @@
 
 package org.openscience.cdk.smiles;
 
-import org.junit.Assert;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
@@ -40,10 +40,10 @@ import static org.hamcrest.CoreMatchers.is;
  * @author John May
  * @cdk.module test-inchi
  */
-public class AbsoluteSMILESTest {
+class AbsoluteSMILESTest {
 
     @Test
-    public void myo_inositol() throws Exception {
+    void myo_inositol() throws Exception {
         test("O[C@H]1[C@H](O)[C@@H](O)[C@H](O)[C@H](O)[C@@H]1O", "O[C@H]1[C@H](O)[C@@H](O)[C@H](O)[C@@H](O)[C@H]1O",
                 "O[C@@H]1[C@@H](O)[C@H](O)[C@@H](O)[C@H](O)[C@@H]1O",
                 "[C@@H]1(O)[C@H](O)[C@@H](O)[C@H](O)[C@@H](O)[C@@H]1O",
@@ -65,7 +65,7 @@ public class AbsoluteSMILESTest {
     }
 
     @Test
-    public void _1_3_diethylidenecyclobutane() throws Exception {
+    void _1_3_diethylidenecyclobutane() throws Exception {
         test("C/C=C1/CC(=C/C)/C1", "C/C=C/1C\\C(=C/C)C1", "C/1(C\\C(C1)=C/C)=C\\C", "C\\1C(/CC1=C/C)=C\\C",
                 "C/C=C1/CC(=C/C)/C1", "C1(=C/C)/CC(=C\\C)/C1", "C\\C=C1/CC(=C\\C)/C1", "C(\\C)=C1/CC(=C/C)/C1",
                 "C1\\C(C\\C1=C\\C)=C/C", "C/1(C\\C(=C/C)C1)=C\\C", "C(/C)=C1/CC(=C\\C)/C1", "C/1(C\\C(C1)=C\\C)=C/C",
@@ -74,7 +74,7 @@ public class AbsoluteSMILESTest {
     }
 
     @Test
-    public void bispropenyloctatriene() throws Exception {
+    void bispropenyloctatriene() throws Exception {
         test("C(=C/C)/C(=C(\\C=C/C)/C=C/C)/C=C/C", "C(=C/C)/C(/C=C/C)=C(\\C=C/C)/C=C/C",
                 "C\\C=C\\C(=C(/C=C/C)\\C=C/C)\\C=C/C", "C(=C/C)/C(/C=C/C)=C(/C=C/C)\\C=C/C",
                 "C(/C=C/C)(=C(/C=C/C)\\C=C/C)\\C=C/C", "C\\C=C\\C(\\C=C/C)=C(/C=C/C)\\C=C/C",
@@ -90,7 +90,7 @@ public class AbsoluteSMILESTest {
 
     // 2,4,6,8-tetramethyl-1,3,5,7-tetraazatricyclo[5.1.0.0³,⁵]octane
     @Test
-    public void tetramethyltetraazatricyclooctane() throws Exception {
+    void tetramethyltetraazatricyclooctane() throws Exception {
         test("C[C@H]1N2N([C@@H](C)N3[C@H](C)N13)[C@H]2C", "N12N([C@H](C)N3[C@@H](C)N3[C@@H]1C)[C@@H]2C",
                 "C[C@H]1N2[C@@H](N3[C@H](N3[C@H](C)N21)C)C", "C[C@@H]1N2[C@@H](C)N3[C@H](C)N3[C@@H](C)N12",
                 "N12N([C@H](N3N([C@H]1C)[C@H]3C)C)[C@H]2C", "C[C@@H]1N2N1[C@@H](N3[C@H](N3[C@@H]2C)C)C",
@@ -103,29 +103,30 @@ public class AbsoluteSMILESTest {
                 "N12[C@H](C)N3N([C@@H]3C)[C@H](C)N1[C@H]2C", "N12N([C@@H](C)N3N([C@H]3C)[C@H]1C)[C@H]2C");
     }
 
-    @Ignore("Random failure: to be resolved https://github.com/cdk/cdk/issues/336")
-    public void dbStereoCanonGeneration() throws Exception {
+    @Disabled("Random failure: to be resolved https://github.com/cdk/cdk/issues/336")
+    void dbStereoCanonGeneration() throws Exception {
         String in = "Oc1ccc(cc1O)C(\\C([O-])=O)=c1/cc(O)\\c(cc1O)=C(/C([O-])=O)c1ccccc1";
         SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         final IAtomContainer mol = smipar.parseSmiles(in);
         final SmilesGenerator cansmi = SmilesGenerator.absolute();
-        Assert.assertEquals(cansmi.create(mol),
-                            cansmi.create(smipar.parseSmiles(cansmi.create(mol))));
+        Assertions.assertEquals(cansmi.create(mol), cansmi.create(smipar.parseSmiles(cansmi.create(mol))));
     }
 
     @Test
-    public void smilesWithUnknownElem() throws Exception {
+    void smilesWithUnknownElem() throws Exception {
         test("*CC", "CC*");
     }
 
     @Test
-    public void rfElement() throws Exception {
+    void rfElement() throws Exception {
         test("[Rf]");
     }
 
-    @Test(expected = CDKException.class)
-    public void problematic() throws Exception {
-        test("*[Rf]");
+    @Test
+    void problematic() throws Exception {
+        Assertions.assertThrows(CDKException.class, () -> {
+            test("*[Rf]");
+        });
     }
 
     static void test(String... inputs) throws Exception {
@@ -133,7 +134,7 @@ public class AbsoluteSMILESTest {
         SmilesParser sp = new SmilesParser(SilentChemObjectBuilder.getInstance());
         SmilesGenerator sg = SmilesGenerator.absolute();
 
-        Set<String> output = new HashSet<String>();
+        Set<String> output = new HashSet<>();
 
         for (String input : inputs)
             output.add(sg.create(sp.parseSmiles(input)));
