@@ -22,8 +22,8 @@
  *  */
 package org.openscience.cdk.io.cml;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.dict.DictRef;
@@ -55,85 +55,85 @@ import java.util.Iterator;
  *
  * @author Egon Willighagen &lt;egonw@sci.kun.nl&gt;
  */
-public class CML23FragmentsTest extends CDKTestCase {
+class CML23FragmentsTest extends CDKTestCase {
 
     @Test
-    public void testAtomId() throws Exception {
+    void testAtomId() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1'/></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("a1", atom.getID());
+        Assertions.assertEquals("a1", atom.getID());
     }
 
     @Test
-    public void testAtomId3() throws Exception {
+    void testAtomId3() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2 a3'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(3, mol.getAtomCount());
+        Assertions.assertEquals(3, mol.getAtomCount());
         IAtom atom = mol.getAtom(1);
-        Assert.assertEquals("a2", atom.getID());
+        Assertions.assertEquals("a2", atom.getID());
     }
 
     @Test
-    public void testAtomElementType3() throws Exception {
+    void testAtomElementType3() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1' elementType='C'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("C", atom.getSymbol());
+        Assertions.assertEquals("C", atom.getSymbol());
     }
 
     @Test
-    public void testMassNumber() throws Exception {
+    void testMassNumber() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1' elementType='C' isotopeNumber='12'/></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("C", atom.getSymbol());
-        Assert.assertEquals(12, atom.getMassNumber().intValue());
+        Assertions.assertEquals("C", atom.getSymbol());
+        Assertions.assertEquals(12, atom.getMassNumber().intValue());
     }
 
     @Test
-    public void testAtomicNumber() throws Exception {
+    void testAtomicNumber() throws Exception {
         String cmlString = "<molecule><atomArray><atom id='a1' elementType=\"C\"><scalar dataType=\"xsd:integer\" dictRef=\"cdk:atomicNumber\">6</scalar></atom></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("C", atom.getSymbol());
-        Assert.assertEquals(6, atom.getAtomicNumber().intValue());
+        Assertions.assertEquals("C", atom.getSymbol());
+        Assertions.assertEquals(6, atom.getAtomicNumber().intValue());
     }
 
     @Test
-    public void testIsotopicMass() throws Exception {
+    void testIsotopicMass() throws Exception {
         String cmlString = "<molecule><atomArray><atom id='a1' elementType=\"C\"><scalar dataType=\"xsd:float\" dictRef=\"cdk:isotopicMass\">12.0</scalar></atom></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("C", atom.getSymbol());
-        Assert.assertEquals(12.0, atom.getExactMass().doubleValue(), 0.01);
+        Assertions.assertEquals("C", atom.getSymbol());
+        Assertions.assertEquals(12.0, atom.getExactMass(), 0.01);
     }
 
     @Test
-    public void testAtomParity() throws Exception {
+    void testAtomParity() throws Exception {
         String cmlString = "<molecule><atomArray><atom id='a1' elementType='C'><atomParity atomRefs4='a2 a3 a5 a4'>1</atomParity></atom>"
                 + "<atom id='a2' elementType='Br'/><atom id='a3' elementType='Cl'/><atom id='a4' elementType='F'/><atom id='a5' elementType='I'/></atomArray>"
                 + "<bondArray><bond atomRefs2='a1 a2' order='1'/><bond atomRefs2='a1 a3' order='1'/><bond atomRefs2='a1 a4' order='1'/><bond atomRefs2='a1 a5' order='1'/></bondArray></molecule>";
@@ -141,126 +141,126 @@ public class CML23FragmentsTest extends CDKTestCase {
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(5, mol.getAtomCount());
+        Assertions.assertEquals(5, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertEquals("C", atom.getSymbol());
+        Assertions.assertEquals("C", atom.getSymbol());
         IStereoElement stereo = mol.stereoElements().iterator().next();
-        Assert.assertTrue(stereo instanceof TetrahedralChirality);
-        Assert.assertEquals(((TetrahedralChirality) stereo).getChiralAtom().getID(), "a1");
+        Assertions.assertTrue(stereo instanceof TetrahedralChirality);
+        Assertions.assertEquals(((TetrahedralChirality) stereo).getChiralAtom().getID(), "a1");
         IAtom[] ligandAtoms = ((TetrahedralChirality) stereo).getLigands();
-        Assert.assertEquals(4, ligandAtoms.length);
-        Assert.assertEquals(ligandAtoms[0].getID(), "a2");
-        Assert.assertEquals(ligandAtoms[1].getID(), "a3");
-        Assert.assertEquals(ligandAtoms[2].getID(), "a5");
-        Assert.assertEquals(ligandAtoms[3].getID(), "a4");
-        Assert.assertEquals(((TetrahedralChirality) stereo).getStereo(), Stereo.CLOCKWISE);
+        Assertions.assertEquals(4, ligandAtoms.length);
+        Assertions.assertEquals(ligandAtoms[0].getID(), "a2");
+        Assertions.assertEquals(ligandAtoms[1].getID(), "a3");
+        Assertions.assertEquals(ligandAtoms[2].getID(), "a5");
+        Assertions.assertEquals(ligandAtoms[3].getID(), "a4");
+        Assertions.assertEquals(((TetrahedralChirality) stereo).getStereo(), Stereo.CLOCKWISE);
     }
 
     @Test
-    public void testBond() throws Exception {
+    void testBond() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1'/><atom id='a2'/></atomArray><bondArray><bond id='b1' atomRefs2='a1 a2'/></bondArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
-        Assert.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(2, bond.getAtomCount());
         IAtom atom1 = bond.getBegin();
         IAtom atom2 = bond.getEnd();
-        Assert.assertEquals("a1", atom1.getID());
-        Assert.assertEquals("a2", atom2.getID());
+        Assertions.assertEquals("a1", atom1.getID());
+        Assertions.assertEquals("a2", atom2.getID());
     }
 
     @Test
-    public void testBond4() throws Exception {
+    void testBond4() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2 a3'/><bondArray atomRef1='a1 a1' atomRef2='a2 a3' bondID='b1 b2'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(3, mol.getAtomCount());
-        Assert.assertEquals(2, mol.getBondCount());
+        Assertions.assertEquals(3, mol.getAtomCount());
+        Assertions.assertEquals(2, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
-        Assert.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(2, bond.getAtomCount());
         IAtom atom1 = bond.getBegin();
         IAtom atom2 = bond.getEnd();
-        Assert.assertEquals("a1", atom1.getID());
-        Assert.assertEquals("a2", atom2.getID());
-        Assert.assertEquals("b2", mol.getBond(1).getID());
+        Assertions.assertEquals("a1", atom1.getID());
+        Assertions.assertEquals("a2", atom2.getID());
+        Assertions.assertEquals("b2", mol.getBond(1).getID());
     }
 
     @Test
-    public void testBond5() throws Exception {
+    void testBond5() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2 a3'/><bondArray atomRef1='a1 a1' atomRef2='a2 a3' order='1 1'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(3, mol.getAtomCount());
-        Assert.assertEquals(2, mol.getBondCount());
+        Assertions.assertEquals(3, mol.getAtomCount());
+        Assertions.assertEquals(2, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
-        Assert.assertEquals(2, bond.getAtomCount());
-        Assert.assertEquals(IBond.Order.SINGLE, bond.getOrder());
+        Assertions.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(Order.SINGLE, bond.getOrder());
         bond = mol.getBond(1);
-        Assert.assertEquals(2, bond.getAtomCount());
-        Assert.assertEquals(IBond.Order.SINGLE, bond.getOrder());
+        Assertions.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(Order.SINGLE, bond.getOrder());
     }
 
     @Test
-    public void testBondId() throws Exception {
+    void testBondId() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1'/><atom id='a2'/></atomArray><bondArray><bond id='b1' atomRefs2='a1 a2'/></bondArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
-        Assert.assertEquals("b1", bond.getID());
+        Assertions.assertEquals("b1", bond.getID());
     }
 
     @Test
-    public void testBondStereo() throws Exception {
+    void testBondStereo() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1'/><atom id='a2'/></atomArray><bondArray><bond id='b1' atomRefs2='a1 a2'><bondStereo dictRef='cml:H'/></bond></bondArray></molecule>";
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         IBond bond = mol.getBond(0);
-        Assert.assertEquals(IBond.Stereo.DOWN, bond.getStereo());
+        Assertions.assertEquals(IBond.Stereo.DOWN, bond.getStereo());
     }
 
     @Test
-    public void testBondAromatic() throws Exception {
+    void testBondAromatic() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2'/><bondArray atomRef1='a1' atomRef2='a2' order='A'/></molecule>";
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
-        Assert.assertEquals(Order.SINGLE, bond.getOrder());
-        Assert.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+        Assertions.assertEquals(Order.SINGLE, bond.getOrder());
+        Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
     }
 
     @Test
-    public void testBondAromatic2() throws Exception {
+    void testBondAromatic2() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2'/><bondArray><bond atomRefs='a1 a2' order='2'><bondType dictRef='cdk:aromaticBond'/></bond></bondArray></molecule>";
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertEquals(1, mol.getBondCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getBondCount());
         org.openscience.cdk.interfaces.IBond bond = mol.getBond(0);
-        Assert.assertEquals(Order.DOUBLE, bond.getOrder());
-        Assert.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
+        Assertions.assertEquals(Order.DOUBLE, bond.getOrder());
+        Assertions.assertTrue(bond.getFlag(CDKConstants.ISAROMATIC));
     }
 
     @Test
-    public void testList() throws Exception {
+    void testList() throws Exception {
         String cmlString = "<list>"
                 + "<molecule id='m1'><atomArray><atom id='a1'/><atom id='a2'/></atomArray><bondArray><bond id='b1' atomRefs2='a1 a2'/></bondArray></molecule>"
                 + "<molecule id='m2'><atomArray><atom id='a1'/><atom id='a2'/></atomArray><bondArray><bond id='b1' atomRefs2='a1 a2'/></bondArray></molecule>"
@@ -271,123 +271,123 @@ public class CML23FragmentsTest extends CDKTestCase {
     }
 
     @Test
-    public void testCoordinates2D() throws Exception {
+    void testCoordinates2D() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2' x2='0.0 0.1' y2='1.2 1.3'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertNotNull(mol.getAtom(0).getPoint2d());
-        Assert.assertNotNull(mol.getAtom(1).getPoint2d());
-        Assert.assertNull(mol.getAtom(0).getPoint3d());
-        Assert.assertNull(mol.getAtom(1).getPoint3d());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertNotNull(mol.getAtom(0).getPoint2d());
+        Assertions.assertNotNull(mol.getAtom(1).getPoint2d());
+        Assertions.assertNull(mol.getAtom(0).getPoint3d());
+        Assertions.assertNull(mol.getAtom(1).getPoint3d());
     }
 
     @Test
-    public void testCoordinates3D() throws Exception {
+    void testCoordinates3D() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2' x3='0.0 0.1' y3='1.2 1.3' z3='2.1 2.5'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertNull(mol.getAtom(0).getPoint2d());
-        Assert.assertNull(mol.getAtom(1).getPoint2d());
-        Assert.assertNotNull(mol.getAtom(0).getPoint3d());
-        Assert.assertNotNull(mol.getAtom(1).getPoint3d());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertNull(mol.getAtom(0).getPoint2d());
+        Assertions.assertNull(mol.getAtom(1).getPoint2d());
+        Assertions.assertNotNull(mol.getAtom(0).getPoint3d());
+        Assertions.assertNotNull(mol.getAtom(1).getPoint3d());
     }
 
     @Test
-    public void testFractional3D() throws Exception {
+    void testFractional3D() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray atomID='a1 a2' xFract='0.0 0.1' yFract='1.2 1.3' zFract='2.1 2.5'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
-        Assert.assertNull(mol.getAtom(0).getPoint3d());
-        Assert.assertNull(mol.getAtom(1).getPoint3d());
-        Assert.assertNotNull(mol.getAtom(0).getFractionalPoint3d());
-        Assert.assertNotNull(mol.getAtom(1).getFractionalPoint3d());
+        Assertions.assertEquals(2, mol.getAtomCount());
+        Assertions.assertNull(mol.getAtom(0).getPoint3d());
+        Assertions.assertNull(mol.getAtom(1).getPoint3d());
+        Assertions.assertNotNull(mol.getAtom(0).getFractionalPoint3d());
+        Assertions.assertNotNull(mol.getAtom(1).getFractionalPoint3d());
     }
 
     @Test
-    public void testMissing2DCoordinates() throws Exception {
+    void testMissing2DCoordinates() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1' xy2='0.0 0.1'/><atom id='a2'/><atom id='a3' xy2='0.1 0.0'/></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(3, mol.getAtomCount());
+        Assertions.assertEquals(3, mol.getAtomCount());
         IAtom atom1 = mol.getAtom(0);
         IAtom atom2 = mol.getAtom(1);
         IAtom atom3 = mol.getAtom(2);
 
-        Assert.assertNotNull(atom1.getPoint2d());
-        Assert.assertNull(atom2.getPoint2d());
-        Assert.assertNotNull(atom3.getPoint2d());
+        Assertions.assertNotNull(atom1.getPoint2d());
+        Assertions.assertNull(atom2.getPoint2d());
+        Assertions.assertNotNull(atom3.getPoint2d());
     }
 
     @Test
-    public void testMissing3DCoordinates() throws Exception {
+    void testMissing3DCoordinates() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1' xyz3='0.0 0.1 0.2'/><atom id='a2'/><atom id='a3' xyz3='0.1 0.0 0.2'/></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(3, mol.getAtomCount());
+        Assertions.assertEquals(3, mol.getAtomCount());
         IAtom atom1 = mol.getAtom(0);
         IAtom atom2 = mol.getAtom(1);
         IAtom atom3 = mol.getAtom(2);
 
-        Assert.assertNotNull(atom1.getPoint3d());
-        Assert.assertNull(atom2.getPoint3d());
-        Assert.assertNotNull(atom3.getPoint3d());
+        Assertions.assertNotNull(atom1.getPoint3d());
+        Assertions.assertNull(atom2.getPoint3d());
+        Assertions.assertNotNull(atom3.getPoint3d());
     }
 
     @Test
-    public void testMoleculeId() throws Exception {
+    void testMoleculeId() throws Exception {
         String cmlString = "<molecule id='m1'><atomArray><atom id='a1'/></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals("m1", mol.getID());
+        Assertions.assertEquals("m1", mol.getID());
     }
 
     @Test
-    public void testName() throws Exception {
+    void testName() throws Exception {
         String cmlString = "<molecule id='m1'><name>acetic acid</name><atomArray atomID='a1 a2 a3'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals("acetic acid", mol.getTitle());
+        Assertions.assertEquals("acetic acid", mol.getTitle());
     }
 
     /**
      * @cdk.bug 2142400
      */
     @Test
-    public void testHydrogenCount1() throws Exception {
+    void testHydrogenCount1() throws Exception {
         String cmlString = "<molecule><atomArray><atom id='a1' elementType='C' hydrogenCount='4'/></atomArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(1, mol.getAtomCount());
+        Assertions.assertEquals(1, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertNotNull(atom);
-        Assert.assertNotNull(atom.getImplicitHydrogenCount());
-        Assert.assertEquals(4, atom.getImplicitHydrogenCount().intValue());
+        Assertions.assertNotNull(atom);
+        Assertions.assertNotNull(atom.getImplicitHydrogenCount());
+        Assertions.assertEquals(4, atom.getImplicitHydrogenCount().intValue());
     }
 
     /**
      * @cdk.bug 2142400
      */
     @Test
-    public void testHydrogenCount2() throws Exception {
+    void testHydrogenCount2() throws Exception {
         String cmlString = "<molecule><atomArray>" + "<atom id='a1' elementType='C' hydrogenCount='4'/>"
                 + "<atom id='a2' elementType='H'/>" + "<atom id='a3' elementType='H'/>"
                 + "<atom id='a4' elementType='H'/>" + "<atom id='a5' elementType='H'/>" + "</atomArray>"
@@ -398,19 +398,19 @@ public class CML23FragmentsTest extends CDKTestCase {
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(5, mol.getAtomCount());
+        Assertions.assertEquals(5, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertNotNull(atom);
-        Assert.assertEquals("C", atom.getSymbol());
-        Assert.assertNotNull(atom.getImplicitHydrogenCount());
-        Assert.assertEquals(0, atom.getImplicitHydrogenCount().intValue());
+        Assertions.assertNotNull(atom);
+        Assertions.assertEquals("C", atom.getSymbol());
+        Assertions.assertNotNull(atom.getImplicitHydrogenCount());
+        Assertions.assertEquals(0, atom.getImplicitHydrogenCount().intValue());
     }
 
     /**
      * @cdk.bug 2142400
      */
     @Test
-    public void testHydrogenCount3() throws Exception {
+    void testHydrogenCount3() throws Exception {
         String cmlString = "<molecule>" + "<atomArray>" + "<atom id='a1' elementType='C' hydrogenCount='4'/>"
                 + "<atom id='a2' elementType='H'/>" + "</atomArray>" + "<bondArray>"
                 + "<bond id='b1' atomRefs2='a1 a2' order='S'/>" + "</bondArray>" + "</molecule>";
@@ -418,25 +418,25 @@ public class CML23FragmentsTest extends CDKTestCase {
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals(2, mol.getAtomCount());
+        Assertions.assertEquals(2, mol.getAtomCount());
         IAtom atom = mol.getAtom(0);
-        Assert.assertNotNull(atom);
-        Assert.assertNotNull(atom.getImplicitHydrogenCount());
-        Assert.assertEquals(3, atom.getImplicitHydrogenCount().intValue());
+        Assertions.assertNotNull(atom);
+        Assertions.assertNotNull(atom.getImplicitHydrogenCount());
+        Assertions.assertEquals(3, atom.getImplicitHydrogenCount().intValue());
     }
 
     @Test
-    public void testInChI() throws Exception {
+    void testInChI() throws Exception {
         String cmlString = "<molecule id='m1'><identifier convention='iupac:inchi' value='InChI=1/CH2O2/c2-1-3/h1H,(H,2,3)'/><atomArray atomID='a1 a2 a3'/></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertEquals("InChI=1/CH2O2/c2-1-3/h1H,(H,2,3)", mol.getProperty(CDKConstants.INCHI));
+        Assertions.assertEquals("InChI=1/CH2O2/c2-1-3/h1H,(H,2,3)", mol.getProperty(CDKConstants.INCHI));
     }
 
     @Test
-    public void testDictRef() throws Exception {
+    void testDictRef() throws Exception {
         String cmlString = "<molecule id=\"alanine\" dictRef=\"pdb:aminoAcid\"><name>alanine</name><name dictRef=\"pdb:residueName\">Ala</name><name dictRef=\"pdb:oneLetterCode\">A</name><scalar dictRef=\"pdb:id\">3</scalar><atomArray><atom id=\"a1\" elementType=\"C\" x2=\"265.0\" y2=\"989.0\"/><atom id=\"a2\" elementType=\"N\" x2=\"234.0\" y2=\"972.0\" dictRef=\"pdb:nTerminus\"/><atom id=\"a3\" elementType=\"C\" x2=\"265.0\" y2=\"1025.0\"/><atom id=\"a4\" elementType=\"C\" x2=\"296.0\" y2=\"971.0\" dictRef=\"pdb:cTerminus\"/><atom id=\"a5\" elementType=\"O\" x2=\"296.0\" y2=\"935.0\"/><atom id=\"a6\" elementType=\"O\" x2=\"327.0\" y2=\"988.0\"/></atomArray><bondArray><bond id=\"b1\" atomRefs2=\"a2 a1\" order=\"S\"/><bond id=\"b2\" atomRefs2=\"a1 a3\" order=\"S\"/><bond id=\"b3\" atomRefs2=\"a1 a4\" order=\"S\"/><bond id=\"b4\" atomRefs2=\"a4 a5\" order=\"D\"/><bond id=\"b5\" atomRefs2=\"a4 a6\" order=\"S\"/></bondArray></molecule>";
 
         IChemFile chemFile = parseCMLString(cmlString);
@@ -448,11 +448,11 @@ public class CML23FragmentsTest extends CDKTestCase {
             Object next = props.next();
             if (next instanceof DictRef) foundDictRefs = true;
         }
-        Assert.assertTrue(foundDictRefs);
+        Assertions.assertTrue(foundDictRefs);
     }
 
     @Test
-    public void testQSAROutput() throws Exception {
+    void testQSAROutput() throws Exception {
         String specificationReference = "qsar:weight";
         String implementationTitle = "org.openscience.cdk.qsar.descriptors.molecular.WeightDescriptor";
         String implementationIdentifier = "$Id$";
@@ -487,30 +487,30 @@ public class CML23FragmentsTest extends CDKTestCase {
         IChemFile chemFile = parseCMLString(cmlString);
         IAtomContainer mol = checkForSingleMoleculeFile(chemFile);
 
-        Assert.assertNotNull(mol);
-        Assert.assertEquals(1, mol.getProperties().size());
+        Assertions.assertNotNull(mol);
+        Assertions.assertEquals(1, mol.getProperties().size());
         Object key = mol.getProperties().keySet().toArray()[0];
-        Assert.assertNotNull(key);
-        Assert.assertTrue(key instanceof DescriptorSpecification);
+        Assertions.assertNotNull(key);
+        Assertions.assertTrue(key instanceof DescriptorSpecification);
         DescriptorSpecification spec = (DescriptorSpecification) key;
-        Assert.assertEquals(specificationReference, spec.getSpecificationReference());
-        Assert.assertEquals(implementationTitle, spec.getImplementationTitle());
-        Assert.assertEquals(implementationIdentifier, spec.getImplementationIdentifier());
-        Assert.assertEquals(implementationVendor, spec.getImplementationVendor());
+        Assertions.assertEquals(specificationReference, spec.getSpecificationReference());
+        Assertions.assertEquals(implementationTitle, spec.getImplementationTitle());
+        Assertions.assertEquals(implementationIdentifier, spec.getImplementationIdentifier());
+        Assertions.assertEquals(implementationVendor, spec.getImplementationVendor());
 
-        Assert.assertNotNull(mol.getProperty(key));
-        Assert.assertTrue(mol.getProperty(key) instanceof DescriptorValue);
-        DescriptorValue value = (DescriptorValue) mol.getProperty(key);
+        Assertions.assertNotNull(mol.getProperty(key));
+        Assertions.assertTrue(mol.getProperty(key) instanceof DescriptorValue);
+        DescriptorValue value = mol.getProperty(key);
         IDescriptorResult result = value.getValue();
-        Assert.assertNotNull(result);
-        Assert.assertTrue(result instanceof DoubleResult);
-        Assert.assertEquals(72.0, ((DoubleResult) result).doubleValue(), 0.001);
+        Assertions.assertNotNull(result);
+        Assertions.assertTrue(result instanceof DoubleResult);
+        Assertions.assertEquals(72.0, ((DoubleResult) result).doubleValue(), 0.001);
     }
 
     private IChemFile parseCMLString(String cmlString) throws Exception {
-        IChemFile chemFile = null;
+        IChemFile chemFile;
         CMLReader reader = new CMLReader(new ByteArrayInputStream(cmlString.getBytes()));
-        chemFile = (IChemFile) reader.read(new org.openscience.cdk.ChemFile());
+        chemFile = reader.read(new org.openscience.cdk.ChemFile());
         reader.close();
         return chemFile;
     }
@@ -523,24 +523,24 @@ public class CML23FragmentsTest extends CDKTestCase {
     }
 
     private IAtomContainer checkForXMoleculeFile(IChemFile chemFile, int numberOfMolecules) {
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
 
-        Assert.assertEquals(chemFile.getChemSequenceCount(), 1);
+        Assertions.assertEquals(chemFile.getChemSequenceCount(), 1);
         org.openscience.cdk.interfaces.IChemSequence seq = chemFile.getChemSequence(0);
-        Assert.assertNotNull(seq);
+        Assertions.assertNotNull(seq);
 
-        Assert.assertEquals(seq.getChemModelCount(), 1);
+        Assertions.assertEquals(seq.getChemModelCount(), 1);
         org.openscience.cdk.interfaces.IChemModel model = seq.getChemModel(0);
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
 
         IAtomContainerSet moleculeSet = model.getMoleculeSet();
-        Assert.assertNotNull(moleculeSet);
+        Assertions.assertNotNull(moleculeSet);
 
-        Assert.assertEquals(moleculeSet.getAtomContainerCount(), numberOfMolecules);
+        Assertions.assertEquals(moleculeSet.getAtomContainerCount(), numberOfMolecules);
         IAtomContainer mol = null;
         for (int i = 0; i < numberOfMolecules; i++) {
             mol = moleculeSet.getAtomContainer(i);
-            Assert.assertNotNull(mol);
+            Assertions.assertNotNull(mol);
         }
         return mol;
     }
@@ -563,7 +563,7 @@ public class CML23FragmentsTest extends CDKTestCase {
     //    }
 
     @Test
-    public void testReaction() throws Exception {
+    void testReaction() throws Exception {
         String cmlString = "<reaction>" + "<reactantList><reactant><molecule id='react'/></reactant></reactantList>"
                 + "<productList><product><molecule id='product'/></product></productList>"
                 + "<substanceList><substance><molecule id='water'/></substance></substanceList>" + "</reaction>";
@@ -571,12 +571,12 @@ public class CML23FragmentsTest extends CDKTestCase {
         IChemFile chemFile = parseCMLString(cmlString);
         IReaction reaction = checkForSingleReactionFile(chemFile);
 
-        Assert.assertEquals(1, reaction.getReactantCount());
-        Assert.assertEquals(1, reaction.getProductCount());
-        Assert.assertEquals(1, reaction.getAgents().getAtomContainerCount());
-        Assert.assertEquals("react", reaction.getReactants().getAtomContainer(0).getID());
-        Assert.assertEquals("product", reaction.getProducts().getAtomContainer(0).getID());
-        Assert.assertEquals("water", reaction.getAgents().getAtomContainer(0).getID());
+        Assertions.assertEquals(1, reaction.getReactantCount());
+        Assertions.assertEquals(1, reaction.getProductCount());
+        Assertions.assertEquals(1, reaction.getAgents().getAtomContainerCount());
+        Assertions.assertEquals("react", reaction.getReactants().getAtomContainer(0).getID());
+        Assertions.assertEquals("product", reaction.getProducts().getAtomContainer(0).getID());
+        Assertions.assertEquals("water", reaction.getAgents().getAtomContainer(0).getID());
     }
 
     /**
@@ -587,24 +587,24 @@ public class CML23FragmentsTest extends CDKTestCase {
     }
 
     private IReaction checkForXReactionFile(IChemFile chemFile, int numberOfReactions) {
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
 
-        Assert.assertEquals(chemFile.getChemSequenceCount(), 1);
+        Assertions.assertEquals(chemFile.getChemSequenceCount(), 1);
         org.openscience.cdk.interfaces.IChemSequence seq = chemFile.getChemSequence(0);
-        Assert.assertNotNull(seq);
+        Assertions.assertNotNull(seq);
 
-        Assert.assertEquals(seq.getChemModelCount(), 1);
+        Assertions.assertEquals(seq.getChemModelCount(), 1);
         org.openscience.cdk.interfaces.IChemModel model = seq.getChemModel(0);
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
 
         IReactionSet reactionSet = model.getReactionSet();
-        Assert.assertNotNull(reactionSet);
+        Assertions.assertNotNull(reactionSet);
 
-        Assert.assertEquals(reactionSet.getReactionCount(), numberOfReactions);
+        Assertions.assertEquals(reactionSet.getReactionCount(), numberOfReactions);
         IReaction reaction = null;
         for (int i = 0; i < numberOfReactions; i++) {
             reaction = reactionSet.getReaction(i);
-            Assert.assertNotNull(reaction);
+            Assertions.assertNotNull(reaction);
         }
         return reaction;
     }
