@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class CacaoInternalFormatTest extends ChemFormatTest {
+class CacaoInternalFormatTest extends ChemFormatTest {
 
-    public CacaoInternalFormatTest() {
+    CacaoInternalFormatTest() {
         super.setChemFormat((IChemFormat) CacaoInternalFormat.getInstance());
     }
 
