@@ -26,6 +26,13 @@ package org.openscience.cdk.libio.jena;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.jena.rdf.model.Model;
+import org.apache.jena.rdf.model.ModelFactory;
+import org.apache.jena.rdf.model.ResIterator;
+import org.apache.jena.rdf.model.Resource;
+import org.apache.jena.rdf.model.Statement;
+import org.apache.jena.rdf.model.StmtIterator;
+import org.apache.jena.vocabulary.RDF;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -40,14 +47,6 @@ import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IIsotope;
 import org.openscience.cdk.interfaces.IPseudoAtom;
 
-import com.hp.hpl.jena.rdf.model.Model;
-import com.hp.hpl.jena.rdf.model.ModelFactory;
-import com.hp.hpl.jena.rdf.model.ResIterator;
-import com.hp.hpl.jena.rdf.model.Resource;
-import com.hp.hpl.jena.rdf.model.Statement;
-import com.hp.hpl.jena.rdf.model.StmtIterator;
-import com.hp.hpl.jena.vocabulary.RDF;
-
 /**
  * Helper class that converts a CDK {@link IChemObject} into RDF using a
  * Jena model and the CDK data model ontology.
@@ -72,7 +71,7 @@ public class Convertor {
         Model model = createCDKModel();
         Resource subject = model.createResource(createIdentifier(model, molecule));
         model.add(subject, RDF.type, CDK.MOLECULE);
-        Map<IAtom, Resource> cdkToRDFAtomMap = new HashMap<IAtom, Resource>();
+        Map<IAtom, Resource> cdkToRDFAtomMap = new HashMap<>();
         for (IAtom atom : molecule.atoms()) {
             Resource rdfAtom = model.createResource(createIdentifier(model, atom));
             cdkToRDFAtomMap.put(atom, rdfAtom);
@@ -233,7 +232,7 @@ public class Convertor {
         }
         Statement order = rdfObject.getProperty(CDK.HASMAXBONDORDER);
         if (order != null) {
-            Resource maxOrder = (Resource) order.getResource();
+            Resource maxOrder = order.getResource();
             element.setMaxBondOrder(resource2Order(maxOrder));
         }
         Statement formalCharge = rdfObject.getProperty(CDK.HASFORMALCHARGE);
@@ -316,7 +315,7 @@ public class Convertor {
         if (mols.hasNext()) {
             Resource rdfMol = mols.next();
             mol = builder.newInstance(IAtomContainer.class);
-            Map<Resource, IAtom> rdfToCDKAtomMap = new HashMap<Resource, IAtom>();
+            Map<Resource, IAtom> rdfToCDKAtomMap = new HashMap<>();
             StmtIterator atoms = rdfMol.listProperties(CDK.HASATOM);
             while (atoms.hasNext()) {
                 Resource rdfAtom = atoms.nextStatement().getResource();
