@@ -22,9 +22,9 @@
  */
 package org.openscience.cdk.io.rdf;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
@@ -38,15 +38,15 @@ import java.io.StringWriter;
  *
  * @cdk.module test-iordf
  */
-public class CDKOWLWriterTest extends ChemObjectWriterTest {
+class CDKOWLWriterTest extends ChemObjectWriterTest {
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         setChemObjectWriter(new CDKOWLWriter());
     }
 
     @Test
-    public void testWriteMolecule() throws Exception {
+    void testWriteMolecule() throws Exception {
         StringWriter output = new StringWriter();
         CDKOWLWriter writer = new CDKOWLWriter(output);
 
@@ -57,6 +57,6 @@ public class CDKOWLWriterTest extends ChemObjectWriterTest {
         writer.write(mol);
         writer.close();
         String outputString = output.toString();
-        Assert.assertTrue(outputString.contains("http://cdk.sourceforge.net/model.owl#"));
+        Assertions.assertTrue(outputString.contains("http://cdk.sourceforge.net/model.owl#"));
     }
 }
