@@ -28,10 +28,10 @@ import java.util.Iterator;
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.AtomContainerSet;
@@ -66,31 +66,31 @@ import org.openscience.cdk.tools.manipulator.ChemFileManipulator;
  * @cdk.require xom-1.0.jar
  * @cdk.require java1.5+
  */
-public class CMLRoundTripTest extends CDKTestCase {
+class CMLRoundTripTest extends CDKTestCase {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(CMLRoundTripTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(CMLRoundTripTest.class);
     private static Convertor    convertor;
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         convertor = new Convertor(false, "");
     }
 
     @Test
-    public void testAtom() throws Exception {
+    void testAtom() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         mol.addAtom(atom);
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getSymbol(), roundTrippedAtom.getSymbol());
+        Assertions.assertEquals(atom.getSymbol(), roundTrippedAtom.getSymbol());
     }
 
     @Test
-    public void testAtomId() throws Exception {
+    void testAtomId() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         atom.setID("N1");
@@ -98,13 +98,13 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getID(), roundTrippedAtom.getID());
+        Assertions.assertEquals(atom.getID(), roundTrippedAtom.getID());
     }
 
     @Test
-    public void testAtom2D() throws Exception {
+    void testAtom2D() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         Point2d p2d = new Point2d(1.3, 1.4);
@@ -113,13 +113,13 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
         assertEquals(atom.getPoint2d(), roundTrippedAtom.getPoint2d(), 0.00001);
     }
 
     @Test
-    public void testAtom3D() throws Exception {
+    void testAtom3D() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         Point3d p3d = new Point3d(1.3, 1.4, 0.9);
@@ -128,13 +128,13 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
         assertEquals(atom.getPoint3d(), roundTrippedAtom.getPoint3d(), 0.00001);
     }
 
     @Test
-    public void testAtom2DAnd3D() throws Exception {
+    void testAtom2DAnd3D() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         Point2d p2d = new Point2d(1.3, 1.4);
@@ -145,14 +145,14 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
         assertEquals(atom.getPoint2d(), roundTrippedAtom.getPoint2d(), 0.00001);
         assertEquals(atom.getPoint3d(), roundTrippedAtom.getPoint3d(), 0.00001);
     }
 
     @Test
-    public void testAtomFract3D() throws Exception {
+    void testAtomFract3D() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         Point3d p3d = new Point3d(0.3, 0.4, 0.9);
@@ -161,13 +161,13 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
         assertEquals(atom.getFractionalPoint3d(), roundTrippedAtom.getFractionalPoint3d(), 0.00001);
     }
 
     @Test
-    public void testPseudoAtom() throws Exception {
+    void testPseudoAtom() throws Exception {
         IAtomContainer mol = new AtomContainer();
         PseudoAtom atom = new PseudoAtom("N");
         atom.setLabel("Glu55");
@@ -175,18 +175,18 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertNotNull(roundTrippedAtom);
-        Assert.assertTrue(roundTrippedAtom instanceof IPseudoAtom);
-        Assert.assertEquals("Glu55", ((IPseudoAtom) roundTrippedAtom).getLabel());
+        Assertions.assertNotNull(roundTrippedAtom);
+        Assertions.assertTrue(roundTrippedAtom instanceof IPseudoAtom);
+        Assertions.assertEquals("Glu55", ((IPseudoAtom) roundTrippedAtom).getLabel());
     }
 
     /**
      * @cdk.bug 1455346
      */
     @Test
-    public void testChemModel() throws Exception {
+    void testChemModel() throws Exception {
         ChemModel model = new ChemModel();
         IAtomContainerSet moleculeSet = new AtomContainerSet();
         IAtomContainer mol = new AtomContainer();
@@ -198,15 +198,15 @@ public class CMLRoundTripTest extends CDKTestCase {
         IChemModel roundTrippedModel = CMLRoundTripTool.roundTripChemModel(convertor, model);
 
         IAtomContainerSet roundTrippedMolSet = roundTrippedModel.getMoleculeSet();
-        Assert.assertNotNull(roundTrippedMolSet);
-        Assert.assertEquals(1, roundTrippedMolSet.getAtomContainerCount());
+        Assertions.assertNotNull(roundTrippedMolSet);
+        Assertions.assertEquals(1, roundTrippedMolSet.getAtomContainerCount());
         IAtomContainer roundTrippedMolecule = roundTrippedMolSet.getAtomContainer(0);
-        Assert.assertNotNull(roundTrippedMolecule);
-        Assert.assertEquals(1, roundTrippedMolecule.getAtomCount());
+        Assertions.assertNotNull(roundTrippedMolecule);
+        Assertions.assertEquals(1, roundTrippedMolecule.getAtomCount());
     }
 
     @Test
-    public void testAtomFormalCharge() throws Exception {
+    void testAtomFormalCharge() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         int formalCharge = +1;
@@ -215,16 +215,16 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getFormalCharge(), roundTrippedAtom.getFormalCharge());
+        Assertions.assertEquals(atom.getFormalCharge(), roundTrippedAtom.getFormalCharge());
     }
 
     /**
      * @cdk.bug 1713398
      */
     @Test
-    public void testHydrogenCount() throws Exception {
+    void testHydrogenCount() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         atom.setImplicitHydrogenCount(3);
@@ -232,16 +232,16 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getImplicitHydrogenCount(), roundTrippedAtom.getImplicitHydrogenCount());
+        Assertions.assertEquals(atom.getImplicitHydrogenCount(), roundTrippedAtom.getImplicitHydrogenCount());
     }
 
     /**
      * @cdk.bug 1713398
      */
     @Test
-    public void testHydrogenCount_UNSET() throws Exception {
+    void testHydrogenCount_UNSET() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         atom.setImplicitHydrogenCount((Integer) CDKConstants.UNSET);
@@ -249,13 +249,13 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(CDKConstants.UNSET, roundTrippedAtom.getImplicitHydrogenCount());
+        Assertions.assertEquals(CDKConstants.UNSET, roundTrippedAtom.getImplicitHydrogenCount());
     }
 
-    @Ignore("Have to figure out how to store partial charges in CML2")
-    public void testAtomPartialCharge() throws Exception {
+    @Disabled("Have to figure out how to store partial charges in CML2")
+    void testAtomPartialCharge() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         double partialCharge = 0.5;
@@ -264,13 +264,13 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getCharge(), roundTrippedAtom.getCharge(), 0.0001);
+        Assertions.assertEquals(atom.getCharge(), roundTrippedAtom.getCharge(), 0.0001);
     }
 
-    @Ignore("Have to figure out how to store atom parity in CML2")
-    public void testAtomStereoParity() throws Exception {
+    @Disabled("Have to figure out how to store atom parity in CML2")
+    void testAtomStereoParity() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         int stereo = CDKConstants.STEREO_ATOM_PARITY_PLUS;
@@ -279,58 +279,58 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getStereoParity(), roundTrippedAtom.getStereoParity());
+        Assertions.assertEquals(atom.getStereoParity(), roundTrippedAtom.getStereoParity());
     }
 
     @Test
-    public void testIsotope() throws Exception {
+    void testIsotope() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         atom.setMassNumber(13);
         mol.addAtom(atom);
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getMassNumber(), roundTrippedAtom.getMassNumber());
+        Assertions.assertEquals(atom.getMassNumber(), roundTrippedAtom.getMassNumber());
     }
 
     /**
      * @cdk.bug 1014344
      */
-    @Ignore("Functionality not yet implemented - exact mass can not be written/read")
-    public void testIsotope_ExactMass() throws Exception {
+    @Disabled("Functionality not yet implemented - exact mass can not be written/read")
+    void testIsotope_ExactMass() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         atom.setExactMass(13.0);
         mol.addAtom(atom);
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertNotNull(atom.getExactMass());
-        Assert.assertNotNull(roundTrippedAtom.getExactMass());
-        Assert.assertEquals(atom.getExactMass(), roundTrippedAtom.getExactMass(), 0.01);
+        Assertions.assertNotNull(atom.getExactMass());
+        Assertions.assertNotNull(roundTrippedAtom.getExactMass());
+        Assertions.assertEquals(atom.getExactMass(), roundTrippedAtom.getExactMass(), 0.01);
     }
 
     /**
      * @cdk.bug 1014344
      */
-    @Ignore("Functionality not yet implemented - natural abundance can not be written/read")
-    public void testIsotope_Abundance() throws Exception {
+    @Disabled("Functionality not yet implemented - natural abundance can not be written/read")
+    void testIsotope_Abundance() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         atom.setNaturalAbundance(1.0);
         mol.addAtom(atom);
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertNotNull(atom.getNaturalAbundance());
-        Assert.assertNotNull(roundTrippedAtom.getNaturalAbundance());
-        Assert.assertEquals(atom.getNaturalAbundance(), roundTrippedAtom.getNaturalAbundance(), 0.01);
+        Assertions.assertNotNull(atom.getNaturalAbundance());
+        Assertions.assertNotNull(roundTrippedAtom.getNaturalAbundance());
+        Assertions.assertEquals(atom.getNaturalAbundance(), roundTrippedAtom.getNaturalAbundance(), 0.01);
     }
 
     /**
@@ -338,22 +338,22 @@ public class CMLRoundTripTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testMassNumber() throws Exception {
+    void testMassNumber() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
-        atom.setMassNumber(new Integer(12));
+        atom.setMassNumber(12);
         mol.addAtom(atom);
-        Assert.assertEquals(12, atom.getMassNumber().intValue());
+        Assertions.assertEquals(12, atom.getMassNumber().intValue());
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(atom.getMassNumber(), roundTrippedAtom.getMassNumber());
+        Assertions.assertEquals(atom.getMassNumber(), roundTrippedAtom.getMassNumber());
     }
 
     @Test
-    public void testBond() throws Exception {
+    void testBond() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         Atom atom2 = new Atom("O");
@@ -364,17 +364,17 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(2, roundTrippedMol.getAtomCount());
-        Assert.assertEquals(1, roundTrippedMol.getBondCount());
+        Assertions.assertEquals(2, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getBondCount());
         IBond roundTrippedBond = roundTrippedMol.getBond(0);
-        Assert.assertEquals(2, roundTrippedBond.getAtomCount());
-        Assert.assertEquals("C", roundTrippedBond.getBegin().getSymbol()); // preserved direction?
-        Assert.assertEquals("O", roundTrippedBond.getEnd().getSymbol());
-        Assert.assertEquals(bond.getOrder(), roundTrippedBond.getOrder());
+        Assertions.assertEquals(2, roundTrippedBond.getAtomCount());
+        Assertions.assertEquals("C", roundTrippedBond.getBegin().getSymbol()); // preserved direction?
+        Assertions.assertEquals("O", roundTrippedBond.getEnd().getSymbol());
+        Assertions.assertEquals(bond.getOrder(), roundTrippedBond.getOrder());
     }
 
     @Test
-    public void testBondID() throws Exception {
+    void testBondID() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         Atom atom2 = new Atom("O");
@@ -386,11 +386,11 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
         IBond roundTrippedBond = roundTrippedMol.getBond(0);
-        Assert.assertEquals(bond.getID(), roundTrippedBond.getID());
+        Assertions.assertEquals(bond.getID(), roundTrippedBond.getID());
     }
 
     @Test
-    public void testBondStereo() throws Exception {
+    void testBondStereo() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         Atom atom2 = new Atom("O");
@@ -403,14 +403,14 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(2, roundTrippedMol.getAtomCount());
-        Assert.assertEquals(1, roundTrippedMol.getBondCount());
+        Assertions.assertEquals(2, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getBondCount());
         IBond roundTrippedBond = roundTrippedMol.getBond(0);
-        Assert.assertEquals(bond.getStereo(), roundTrippedBond.getStereo());
+        Assertions.assertEquals(bond.getStereo(), roundTrippedBond.getStereo());
     }
 
     @Test
-    public void testBondAromatic() throws Exception {
+    void testBondAromatic() throws Exception {
         IAtomContainer mol = new AtomContainer();
         // surely, this bond is not aromatic... but fortunately, file formats do not care about chemistry
         Atom atom = new Atom("C");
@@ -423,18 +423,18 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(2, roundTrippedMol.getAtomCount());
-        Assert.assertEquals(1, roundTrippedMol.getBondCount());
+        Assertions.assertEquals(2, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getBondCount());
         IBond roundTrippedBond = roundTrippedMol.getBond(0);
-        Assert.assertEquals(bond.getFlag(CDKConstants.ISAROMATIC), roundTrippedBond.getFlag(CDKConstants.ISAROMATIC));
-        Assert.assertEquals(bond.getOrder(), roundTrippedBond.getOrder());
+        Assertions.assertEquals(bond.getFlag(CDKConstants.ISAROMATIC), roundTrippedBond.getFlag(CDKConstants.ISAROMATIC));
+        Assertions.assertEquals(bond.getOrder(), roundTrippedBond.getOrder());
     }
 
     /**
      * @cdk.bug 1713398
      */
     @Test
-    public void testBondAromatic_Double() throws Exception {
+    void testBondAromatic_Double() throws Exception {
         IAtomContainer mol = new AtomContainer();
         // surely, this bond is not aromatic... but fortunately, file formats do not care about chemistry
         Atom atom = new Atom("C");
@@ -447,15 +447,15 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(2, roundTrippedMol.getAtomCount());
-        Assert.assertEquals(1, roundTrippedMol.getBondCount());
+        Assertions.assertEquals(2, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getBondCount());
         IBond roundTrippedBond = roundTrippedMol.getBond(0);
-        Assert.assertEquals(bond.getFlag(CDKConstants.ISAROMATIC), roundTrippedBond.getFlag(CDKConstants.ISAROMATIC));
-        Assert.assertEquals(bond.getOrder(), roundTrippedBond.getOrder());
+        Assertions.assertEquals(bond.getFlag(CDKConstants.ISAROMATIC), roundTrippedBond.getFlag(CDKConstants.ISAROMATIC));
+        Assertions.assertEquals(bond.getOrder(), roundTrippedBond.getOrder());
     }
 
     @Test
-    public void testPartialCharge() throws Exception {
+    void testPartialCharge() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         mol.addAtom(atom);
@@ -464,25 +464,25 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(charge, roundTrippedAtom.getCharge(), 0.0001);
+        Assertions.assertEquals(charge, roundTrippedAtom.getCharge(), 0.0001);
     }
 
     @Test
-    public void testInChI() throws Exception {
+    void testInChI() throws Exception {
         IAtomContainer mol = new AtomContainer();
         String inchi = "InChI=1/CH2O2/c2-1-3/h1H,(H,2,3)";
         mol.setProperty(CDKConstants.INCHI, inchi);
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
-        Assert.assertNotNull(roundTrippedMol);
+        Assertions.assertNotNull(roundTrippedMol);
 
-        Assert.assertEquals(inchi, roundTrippedMol.getProperty(CDKConstants.INCHI));
+        Assertions.assertEquals(inchi, roundTrippedMol.getProperty(CDKConstants.INCHI));
     }
 
     @Test
-    public void testSpinMultiplicity() throws Exception {
+    void testSpinMultiplicity() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         mol.addAtom(atom);
@@ -490,14 +490,14 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
-        Assert.assertEquals(1, roundTrippedMol.getElectronContainerCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getElectronContainerCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertEquals(1, roundTrippedMol.getConnectedSingleElectronsCount(roundTrippedAtom));
+        Assertions.assertEquals(1, roundTrippedMol.getConnectedSingleElectronsCount(roundTrippedAtom));
     }
 
     @Test
-    public void testReaction() throws Exception {
+    void testReaction() throws Exception {
         logger.debug("********** TEST REACTION **********");
         IReaction reaction = new Reaction();
         reaction.setID("reaction.1");
@@ -520,34 +520,34 @@ public class CMLRoundTripTest extends CDKTestCase {
         reaction.addAgent(agent);
 
         IReaction roundTrippedReaction = CMLRoundTripTool.roundTripReaction(convertor, reaction);
-        Assert.assertNotNull(roundTrippedReaction);
-        Assert.assertEquals("reaction.1", roundTrippedReaction.getID());
+        Assertions.assertNotNull(roundTrippedReaction);
+        Assertions.assertEquals("reaction.1", roundTrippedReaction.getID());
 
-        Assert.assertNotNull(roundTrippedReaction);
+        Assertions.assertNotNull(roundTrippedReaction);
         IAtomContainerSet reactants = roundTrippedReaction.getReactants();
-        Assert.assertNotNull(reactants);
-        Assert.assertEquals(1, reactants.getAtomContainerCount());
+        Assertions.assertNotNull(reactants);
+        Assertions.assertEquals(1, reactants.getAtomContainerCount());
         IAtomContainer roundTrippedReactant = reactants.getAtomContainer(0);
-        Assert.assertEquals("react", roundTrippedReactant.getID());
-        Assert.assertEquals(1, roundTrippedReactant.getAtomCount());
+        Assertions.assertEquals("react", roundTrippedReactant.getID());
+        Assertions.assertEquals(1, roundTrippedReactant.getAtomCount());
 
         IAtomContainerSet products = roundTrippedReaction.getProducts();
-        Assert.assertNotNull(products);
-        Assert.assertEquals(1, products.getAtomContainerCount());
+        Assertions.assertNotNull(products);
+        Assertions.assertEquals(1, products.getAtomContainerCount());
         IAtomContainer roundTrippedProduct = products.getAtomContainer(0);
-        Assert.assertEquals("product", roundTrippedProduct.getID());
-        Assert.assertEquals(1, roundTrippedProduct.getAtomCount());
+        Assertions.assertEquals("product", roundTrippedProduct.getID());
+        Assertions.assertEquals(1, roundTrippedProduct.getAtomCount());
 
         IAtomContainerSet agents = roundTrippedReaction.getAgents();
-        Assert.assertNotNull(agents);
-        Assert.assertEquals(1, agents.getAtomContainerCount());
+        Assertions.assertNotNull(agents);
+        Assertions.assertEquals(1, agents.getAtomContainerCount());
         IAtomContainer roundTrippedAgent = agents.getAtomContainer(0);
-        Assert.assertEquals("water", roundTrippedAgent.getID());
-        Assert.assertEquals(1, roundTrippedAgent.getAtomCount());
+        Assertions.assertEquals("water", roundTrippedAgent.getID());
+        Assertions.assertEquals(1, roundTrippedAgent.getAtomCount());
     }
 
     @Test
-    public void testDescriptorValue() throws Exception {
+    void testDescriptorValue() throws Exception {
         IAtomContainer molecule = TestMoleculeFactory.makeBenzene();
 
         String[] propertyName = {"testKey1", "testKey2"};
@@ -558,8 +558,8 @@ public class CMLRoundTripTest extends CDKTestCase {
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, molecule);
 
         for (int i = 0; i < propertyName.length; i++) {
-            Assert.assertNotNull(roundTrippedMol.getProperty(propertyName[i]));
-            Assert.assertEquals(propertyValue[i], roundTrippedMol.getProperty(propertyName[i]));
+            Assertions.assertNotNull(roundTrippedMol.getProperty(propertyName[i]));
+            Assertions.assertEquals(propertyValue[i], roundTrippedMol.getProperty(propertyName[i]));
         }
     }
 
@@ -569,7 +569,7 @@ public class CMLRoundTripTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testAromaticity() throws Exception {
+    void testAromaticity() throws Exception {
         IAtomContainer molecule = TestMoleculeFactory.makeBenzene();
         for (IBond bond : molecule.bonds()) {
             bond.setFlag(CDKConstants.ISAROMATIC, true);
@@ -579,13 +579,13 @@ public class CMLRoundTripTest extends CDKTestCase {
         Iterator<IBond> bonds = roundTrippedMol.bonds().iterator();
         double orderSum = BondManipulator.getSingleBondEquivalentSum(bonds);
         while (bonds.hasNext()) {
-            Assert.assertTrue(bonds.next().getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(bonds.next().getFlag(CDKConstants.ISAROMATIC));
         }
-        Assert.assertEquals(9.0, orderSum, 0.001);
+        Assertions.assertEquals(9.0, orderSum, 0.001);
     }
 
     @Test
-    public void testAtomAromaticity() throws Exception {
+    void testAtomAromaticity() throws Exception {
         IAtomContainer molecule = TestMoleculeFactory.makeBenzene();
         for (IAtom atom : molecule.atoms()) {
             atom.setFlag(CDKConstants.ISAROMATIC, true);
@@ -593,7 +593,7 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, molecule);
         for (IAtom atom : roundTrippedMol.atoms()) {
-            Assert.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
+            Assertions.assertTrue(atom.getFlag(CDKConstants.ISAROMATIC));
         }
     }
 
@@ -604,13 +604,12 @@ public class CMLRoundTripTest extends CDKTestCase {
      * @cdk.bug 1930029
      */
     @Test
-    public void testAtomProperty() throws Exception {
+    void testAtomProperty() throws Exception {
         String[] key = {"customAtomProperty1", "customAtomProperty2"};
         String[] value = {"true", "false"};
 
         IAtomContainer mol = TestMoleculeFactory.makeBenzene();
-        for (Iterator<IAtom> it = mol.atoms().iterator(); it.hasNext();) {
-            IAtom a = it.next();
+        for (IAtom a : mol.atoms()) {
             for (int i = 0; i < key.length; i++)
                 a.setProperty(key[i], value[i]);
         }
@@ -619,12 +618,11 @@ public class CMLRoundTripTest extends CDKTestCase {
         //Assert.assertEquals(convertor.cdkMoleculeToCMLMolecule(mol).toXML(),
         //	   convertor.cdkMoleculeToCMLMolecule(roundTrippedMol).toXML());
 
-        for (Iterator<IAtom> it = roundTrippedMol.atoms().iterator(); it.hasNext();) {
-            IAtom a = it.next();
+        for (IAtom a : roundTrippedMol.atoms()) {
             for (int i = 0; i < key.length; i++) {
                 Object actual = a.getProperty(key[i]);
-                Assert.assertNotNull(actual);
-                Assert.assertEquals(value[i], actual);
+                Assertions.assertNotNull(actual);
+                Assertions.assertEquals(value[i], actual);
             }
         }
     }
@@ -636,12 +634,11 @@ public class CMLRoundTripTest extends CDKTestCase {
      * @cdk.bug 1930029
      */
     @Test
-    public void testBondProperty() throws Exception {
+    void testBondProperty() throws Exception {
         String[] key = {"customBondProperty1", "customBondProperty2"};
         String[] value = {"true", "false"};
         IAtomContainer mol = TestMoleculeFactory.makeBenzene();
-        for (Iterator<IBond> it = mol.bonds().iterator(); it.hasNext();) {
-            IBond b = it.next();
+        for (IBond b : mol.bonds()) {
             for (int i = 0; i < key.length; i++)
                 b.setProperty(key[i], value[i]);
         }
@@ -650,12 +647,11 @@ public class CMLRoundTripTest extends CDKTestCase {
         //Assert.assertEquals(convertor.cdkMoleculeToCMLMolecule(mol).toXML(),
         //	   convertor.cdkMoleculeToCMLMolecule(roundTrippedMol).toXML());
 
-        for (Iterator<IBond> it = roundTrippedMol.bonds().iterator(); it.hasNext();) {
-            IBond b = it.next();
+        for (IBond b : roundTrippedMol.bonds()) {
             for (int i = 0; i < key.length; i++) {
                 Object actual = b.getProperty(key[i]);
-                Assert.assertNotNull(actual);
-                Assert.assertEquals(value[i], actual);
+                Assertions.assertNotNull(actual);
+                Assertions.assertEquals(value[i], actual);
             }
         }
     }
@@ -667,7 +663,7 @@ public class CMLRoundTripTest extends CDKTestCase {
      * @cdk.bug 1930029
      */
     @Test
-    public void testMoleculeProperty() throws Exception {
+    void testMoleculeProperty() throws Exception {
         String[] key = {"customMoleculeProperty1", "customMoleculeProperty2"};
         String[] value = {"true", "false"};
 
@@ -680,13 +676,13 @@ public class CMLRoundTripTest extends CDKTestCase {
         //	   convertor.cdkMoleculeToCMLMolecule(roundTrippedMol).toXML());
         for (int i = 0; i < key.length; i++) {
             Object actual = roundTrippedMol.getProperty(key[i]);
-            Assert.assertNotNull(actual);
-            Assert.assertEquals(value[i], actual);
+            Assertions.assertNotNull(actual);
+            Assertions.assertEquals(value[i], actual);
         }
     }
 
     @Test
-    public void testMoleculeSet() throws Exception {
+    void testMoleculeSet() throws Exception {
         IAtomContainerSet list = new AtomContainerSet();
         list.addAtomContainer(new AtomContainer());
         list.addAtomContainer(new AtomContainer());
@@ -695,26 +691,26 @@ public class CMLRoundTripTest extends CDKTestCase {
 
         IChemModel roundTripped = CMLRoundTripTool.roundTripChemModel(convertor, model);
         IAtomContainerSet newList = roundTripped.getMoleculeSet();
-        Assert.assertNotNull(newList);
-        Assert.assertEquals(2, newList.getAtomContainerCount());
-        Assert.assertNotNull(newList.getAtomContainer(0));
-        Assert.assertNotNull(newList.getAtomContainer(1));
+        Assertions.assertNotNull(newList);
+        Assertions.assertEquals(2, newList.getAtomContainerCount());
+        Assertions.assertNotNull(newList.getAtomContainer(0));
+        Assertions.assertNotNull(newList.getAtomContainer(1));
     }
 
     /**
      * @cdk.bug 1930029
      */
     @Test
-    public void testAtomProperties() throws Exception {
+    void testAtomProperties() throws Exception {
         String filename = "custompropertiestest.cml";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         CMLReader reader = new CMLReader(ins);
-        ChemFile chemFile = (ChemFile) reader.read((ChemFile) new ChemFile());
+        ChemFile chemFile = reader.read(new ChemFile());
         reader.close();
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
         IAtomContainer container = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
         for (int i = 0; i < container.getAtomCount(); i++) {
-            Assert.assertEquals(2, container.getAtom(i).getProperties().size());
+            Assertions.assertEquals(2, container.getAtom(i).getProperties().size());
         }
     }
 
@@ -723,18 +719,18 @@ public class CMLRoundTripTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testUnsetHydrogenCount() throws Exception {
+    void testUnsetHydrogenCount() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         atom.setImplicitHydrogenCount(null);
-        Assert.assertNull(atom.getImplicitHydrogenCount());
+        Assertions.assertNull(atom.getImplicitHydrogenCount());
         mol.addAtom(atom);
 
         IAtomContainer roundTrippedMol = CMLRoundTripTool.roundTripMolecule(convertor, mol);
 
-        Assert.assertEquals(1, roundTrippedMol.getAtomCount());
+        Assertions.assertEquals(1, roundTrippedMol.getAtomCount());
         IAtom roundTrippedAtom = roundTrippedMol.getAtom(0);
-        Assert.assertNull(roundTrippedAtom.getImplicitHydrogenCount());
+        Assertions.assertNull(roundTrippedAtom.getImplicitHydrogenCount());
     }
 
 }
