@@ -24,7 +24,6 @@
 package org.openscience.cdk.smiles;
 
 import org.openscience.cdk.interfaces.IStereoElement;
-import org.openscience.cdk.sgroup.Sgroup;
 import org.openscience.cdk.smiles.CxSmilesState.CxDataSgroup;
 import org.openscience.cdk.smiles.CxSmilesState.CxPolymerSgroup;
 import org.openscience.cdk.smiles.CxSmilesState.CxSgroup;
@@ -32,16 +31,11 @@ import org.openscience.cdk.smiles.CxSmilesState.CxSgroup;
 import java.text.DecimalFormat;
 import java.text.DecimalFormatSymbols;
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
 import java.util.Comparator;
-import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
-import java.util.Set;
 import java.util.TreeMap;
 
 public class CxSmilesGenerator {
@@ -133,8 +127,8 @@ public class CxSmilesGenerator {
 
             List<List<Integer>> fragGroupCpy = new ArrayList<>(state.fragGroups);
             for (List<Integer> idxs : fragGroupCpy)
-                Collections.sort(idxs, compComp);
-            Collections.sort(fragGroupCpy, new Comparator<List<Integer>>() {
+                idxs.sort(compComp);
+            fragGroupCpy.sort(new Comparator<List<Integer>>() {
                 @Override
                 public int compare(List<Integer> a, List<Integer> b) {
                     return CxSmilesGenerator.compare(compComp, a, b);
@@ -331,14 +325,14 @@ public class CxSmilesGenerator {
             for (CxSgroup polysgroup : state.mysgroups) {
                 if (polysgroup instanceof CxPolymerSgroup) {
                     polysgroups.add((CxPolymerSgroup) polysgroup);
-                    Collections.sort(polysgroup.atoms, comp);
+                    polysgroup.atoms.sort(comp);
                 }
             }
 
-            Collections.sort(polysgroups, new Comparator<CxPolymerSgroup>() {
+            polysgroups.sort(new Comparator<CxPolymerSgroup>() {
                 @Override
                 public int compare(CxPolymerSgroup a, CxPolymerSgroup b) {
-                    int cmp = 0;
+                    int cmp;
                     cmp = a.type.compareTo(b.type);
                     if (cmp != 0) return cmp;
                     cmp = CxSmilesGenerator.compare(comp, a.atoms, b.atoms);
@@ -368,14 +362,14 @@ public class CxSmilesGenerator {
             for (CxSgroup datasgroup : state.mysgroups) {
                 if (datasgroup instanceof CxDataSgroup) {
                     datasgroups.add((CxDataSgroup)datasgroup);
-                    Collections.sort(datasgroup.atoms, comp);
+                    datasgroup.atoms.sort(comp);
                 }
             }
 
-            Collections.sort(datasgroups, new Comparator<CxDataSgroup>() {
+            datasgroups.sort(new Comparator<CxDataSgroup>() {
                 @Override
                 public int compare(CxDataSgroup a, CxDataSgroup b) {
-                    int cmp = 0;
+                    int cmp;
                     cmp = a.field.compareTo(b.field);
                     if (cmp != 0) return cmp;
                     cmp = a.value.compareTo(b.value);
@@ -442,7 +436,7 @@ public class CxSmilesGenerator {
             for (Map.Entry<Integer, CxSmilesState.Radical> e : state.atomRads.entrySet()) {
                 List<Integer> idxs = radinv.get(e.getValue());
                 if (idxs == null)
-                    radinv.put(e.getValue(), idxs = new ArrayList<Integer>());
+                    radinv.put(e.getValue(), idxs = new ArrayList<>());
                 idxs.add(e.getKey());
             }
             for (Map.Entry<CxSmilesState.Radical, List<Integer>> e : radinv.entrySet()) {
@@ -450,7 +444,7 @@ public class CxSmilesGenerator {
                 sb.append('^');
                 sb.append(e.getKey().ordinal() + 1);
                 sb.append(':');
-                Collections.sort(e.getValue(), comp);
+                e.getValue().sort(comp);
                 appendIntegers(ordering, ',', sb, e.getValue());
             }
         }
