@@ -51,7 +51,6 @@ import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -129,7 +128,7 @@ import java.util.Set;
  */
 public final class SmilesParser {
 
-    private ILoggingTool logger = LoggingToolFactory.createLoggingTool(SmilesParser.class);
+    private final ILoggingTool logger = LoggingToolFactory.createLoggingTool(SmilesParser.class);
 
     /**
      * The builder determines which CDK domain objects to create.
@@ -235,8 +234,7 @@ public final class SmilesParser {
             // CXSMILES layer
             parseRxnCXSMILES(title, reaction);
         } catch (Exception e) {
-            e.printStackTrace();
-            throw new InvalidSmilesException("Error parsing CXSMILES:" + e.getMessage());
+            throw new InvalidSmilesException("Error parsing CXSMILES", e);
         }
 
         return reaction;
@@ -271,8 +269,7 @@ public final class SmilesParser {
                     // CXSMILES layer
                     parseMolCXSMILES(g.getTitle(), mol);
                 } catch (Exception e) {
-                    e.printStackTrace();
-                    throw new InvalidSmilesException("Error parsing CXSMILES:" + e.getMessage());
+                    throw new InvalidSmilesException("Error parsing CXSMILES", e);
                 }
             }
 
@@ -497,7 +494,18 @@ public final class SmilesParser {
                     continue;
 
                 IAtom old = atoms.get(e.getKey());
-                IPseudoAtom pseudo = bldr.newInstance(IPseudoAtom.class);
+                IPseudoAtom pseudo;
+                if (old instanceof IPseudoAtom) {
+                    pseudo = (IPseudoAtom) old;
+                } else {
+                    // possibly a warning, is "CCO |$R$|" valid?
+                    pseudo = bldr.newInstance(IPseudoAtom.class);
+                    IAtomContainer mol = atomToMol.get(old);
+                    AtomContainerManipulator.replaceAtomByAtom(mol, old, pseudo);
+                    atomToMol.put(pseudo, mol);
+                    atoms.set(e.getKey(), mol.getAtom(old.getIndex()));
+                }
+
                 String val = e.getValue();
 
                 // specialised label handling
@@ -509,10 +517,6 @@ public final class SmilesParser {
                 pseudo.setLabel(val);
                 pseudo.setAtomicNumber(0);
                 pseudo.setImplicitHydrogenCount(0);
-                IAtomContainer mol = atomToMol.get(old);
-                AtomContainerManipulator.replaceAtomByAtom(mol, old, pseudo);
-                atomToMol.put(pseudo, mol);
-                atoms.set(e.getKey(), mol.getAtom(old.getIndex()));
             }
         }
 
@@ -645,8 +649,24 @@ public final class SmilesParser {
 
                 for (IAtom atom : atomset) {
                     for (IBond bond : mol.getConnectedBondsList(atom)) {
-                        if (!atomset.contains(bond.getOther(atom)))
-                            sgroup.addBond(bond);
+                        IAtom nbor = bond.getOther(atom);
+                        if (!atomset.contains(nbor)) {
+                            boolean crossing = true;
+
+                            // check for variable attachments see https://github.com/cdk/depict/issues/36
+                            if (cxstate.positionVar != null) {
+                                List<Integer> ends = cxstate.positionVar.get(mol.indexOf(nbor));
+                                if (ends != null) {
+                                    for (Integer end : ends) {
+                                        if (atomset.contains(mol.getAtom(end)))
+                                            crossing = false;
+                                    }
+                                }
+                            }
+
+                            if (crossing)
+                                sgroup.addBond(bond);
+                        }
                     }
                     sgroup.addAtom(atom);
                 }
