@@ -24,11 +24,11 @@
 package org.openscience.cdk.smiles;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.exception.InvalidSmilesException;
-import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
@@ -48,15 +48,14 @@ import java.util.List;
 
 import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertNotNull;
 import static org.hamcrest.MatcherAssert.assertThat;
 
-public class CxSmilesTest {
+class CxSmilesTest {
 
     private final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
 
     @Test
-    public void fragmentGroupingReactants() throws InvalidSmilesException {
+    void fragmentGroupingReactants() throws InvalidSmilesException {
         IReaction reaction = smipar.parseReactionSmiles("CC1=NC2=C(O)C=CC=C2C=C1.CC(Cl)=O.[Al+3].[Cl-].[Cl-].[Cl-]>[O-][N+](=O)C1=CC=CC=C1>CC(=O)C1=C2C=CC(C)=NC2=C(O)C=C1 |f:2.3.4.5|");
         assertThat(reaction.getReactantCount(), is(3));
         assertThat(reaction.getAgents().getAtomContainerCount(), is(1));
@@ -66,7 +65,7 @@ public class CxSmilesTest {
 
     // grouping is invalid as we group 4 in two separate fragments
     @Test
-    public void fragmentGroupingInvalid() throws InvalidSmilesException {
+    void fragmentGroupingInvalid() throws InvalidSmilesException {
         IReaction reaction = smipar.parseReactionSmiles("CC1=NC2=C(O)C=CC=C2C=C1.CC(Cl)=O.[Al+3].[Cl-].[Cl-].[Cl-]>[O-][N+](=O)C1=CC=CC=C1>CC(=O)C1=C2C=CC(C)=NC2=C(O)C=C1 |f:2.3.4.5,4.6|");
         assertThat(reaction.getReactantCount(), is(6));
         assertThat(reaction.getAgents().getAtomContainerCount(), is(1));
@@ -75,7 +74,7 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void fragmentGroupingAgents() throws InvalidSmilesException {
+    void fragmentGroupingAgents() throws InvalidSmilesException {
         IReaction reaction = smipar.parseReactionSmiles("CC1=NC2=C(O)C=CC=C2C=C1.CC(Cl)=O>[Al+3].[Cl-].[Cl-].[Cl-].[O-][N+](=O)C1=CC=CC=C1>CC(=O)C1=C2C=CC(C)=NC2=C(O)C=C1 |f:2.3.4.5|");
         assertThat(reaction.getReactantCount(), is(2));
         assertThat(reaction.getAgents().getAtomContainerCount(), is(2));
@@ -84,13 +83,13 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void emptyCXSMILES() throws InvalidSmilesException {
+    void emptyCXSMILES() throws InvalidSmilesException {
         IReaction reaction = smipar.parseReactionSmiles("CC1=NC2=C(O)C=CC=C2C=C1.CC(Cl)=O>[Al+3].[Cl-].[Cl-].[Cl-].[O-][N+](=O)C1=CC=CC=C1>CC(=O)C1=C2C=CC(C)=NC2=C(O)C=C1 ||");
         assertThat(reaction.getProperty(CDKConstants.TITLE, String.class), is(""));
     }
 
     @Test
-    public void fragmentGroupingProducts() throws InvalidSmilesException {
+    void fragmentGroupingProducts() throws InvalidSmilesException {
         IReaction reaction = smipar.parseReactionSmiles("CC1=NC2=C(O)C=CC=C2C=C1.CC(Cl)=O>[O-][N+](=O)C1=CC=CC=C1>CC(=O)C1=C2C=CC(C)=NC2=C(O)C=C1.[Al+3].[Cl-].[Cl-].[Cl-] |f:3.4.5.6|");
         assertThat(reaction.getReactantCount(), is(2));
         assertThat(reaction.getAgents().getAtomContainerCount(), is(1));
@@ -99,42 +98,42 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void nonCXSMILESLayer() throws InvalidSmilesException {
+    void nonCXSMILESLayer() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("c1ccccc1 |<benzene>|");
-        assertNotNull(mol);
+        Assertions.assertNotNull(mol);
         assertThat(mol.getTitle(), is("|<benzene>|"));
     }
 
     @Test
-    public void truncatedCXSMILES() throws InvalidSmilesException {
+    void truncatedCXSMILES() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("c1ccccc1 |");
-        assertNotNull(mol);
+        Assertions.assertNotNull(mol);
         assertThat(mol.getTitle(), is("|"));
     }
 
     @Test
-    public void correctTitle() throws InvalidSmilesException {
+    void correctTitle() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("c1ccccc1 |c:1,3,4| benzene");
-        assertNotNull(mol);
+        Assertions.assertNotNull(mol);
         assertThat(mol.getTitle(), is("benzene"));
     }
 
     @Test
-    public void atomLabels() throws InvalidSmilesException {
+    void atomLabels() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("**.c1ccccc1CC |$R'$|");
         assertThat(mol.getAtom(0), is(instanceOf(IPseudoAtom.class)));
         assertThat(((IPseudoAtom) mol.getAtom(0)).getLabel(), is("R'"));
     }
 
     @Test
-    public void attachPoints() throws InvalidSmilesException {
+    void attachPoints() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("**.c1ccccc1CC |$;;;;;;;;;_AP1$|");
         assertThat(mol.getAtom(9), is(instanceOf(IPseudoAtom.class)));
         assertThat(((IPseudoAtom) mol.getAtom(9)).getAttachPointNum(), is(1));
     }
 
     @Test
-    public void positionalVariation() throws InvalidSmilesException {
+    void positionalVariation() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("**.c1ccccc1CC |m:1:2.3.4.5.6.7|");
         List<Sgroup> sgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
         assertThat(sgroups.size(), is(1));
@@ -144,7 +143,7 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void structuralRepeatUnit() throws InvalidSmilesException {
+    void structuralRepeatUnit() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("**.c1ccccc1CC |Sg:n:8:m:ht|");
         List<Sgroup> sgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
         assertThat(sgroups.size(), is(1));
@@ -156,7 +155,7 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void markushFragment() throws InvalidSmilesException {
+    void markushFragment() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("**.c1ccccc1CC |m:1:2.3.4.5.6.7,Sg:n:8:m:ht,$R';;;;;;;;;_AP1$|");
         List<Sgroup> sgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
         // P-var and F-var
@@ -171,7 +170,7 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void atomCoordinates2D() throws InvalidSmilesException {
+    void atomCoordinates2D() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("CCC |(0,1,;0,2,;0,3,)|");
         assertThat(mol.getAtom(0).getPoint2d(), is(new Point2d(0, 1)));
         assertThat(mol.getAtom(1).getPoint2d(), is(new Point2d(0, 2)));
@@ -179,7 +178,7 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void atomCoordinates3D() throws InvalidSmilesException {
+    void atomCoordinates3D() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("CCC |(0,1,1;0,2,1;0,3,1)|");
         assertThat(mol.getAtom(0).getPoint3d(), is(new Point3d(0, 1, 1)));
         assertThat(mol.getAtom(1).getPoint3d(), is(new Point3d(0, 2, 1)));
@@ -187,27 +186,31 @@ public class CxSmilesTest {
     }
 
     @Test
-    public void atomValues() throws InvalidSmilesException {
+    void atomValues() throws InvalidSmilesException {
         IAtomContainer mol = smipar.parseSmiles("N1CN=CC1 |$_AV:HydDonor;;HydAcceptor$|");
         assertThat(mol.getAtom(0).getProperty(CDKConstants.COMMENT, String.class), is("HydDonor"));
         assertThat(mol.getAtom(2).getProperty(CDKConstants.COMMENT, String.class), is("HydAcceptor"));
     }
 
-    @Test public void monovalentRadical() throws Exception {
+    @Test
+    void monovalentRadical() throws Exception {
         IAtomContainer mol = smipar.parseSmiles("[N]1C=CC=C1 |c:1,3,^1:0|");
         assertThat(mol.getConnectedSingleElectronsCount(mol.getAtom(0)), is(1));
     }
 
-    @Test public void divalentRadical() throws Exception {
+    @Test
+    void divalentRadical() throws Exception {
         IAtomContainer mol = smipar.parseSmiles("[C]1C2=CC=CC=C2C2=CC=CC=C12 |c:3,5,10,t:1,8,12,^3:0|");
         assertThat(mol.getConnectedSingleElectronsCount(mol.getAtom(0)), is(2));
     }
 
-    @Test public void genericReaction() throws Exception {
+    @Test
+    void genericReaction() throws Exception {
         IReaction rxn = smipar.parseReactionSmiles("C1=CC(=CC=C1)C(CC(N)=O)=O.*C>C1(=CC=CC=C1)N.C*.C1=CC(=CC=C1)C=2C=C(C3=C(N2)C=CC=C3)O.C*.C*> |$;;;;;;;;;;;;R22;;;;;;;;;;;;;;;;;;;;;;;;;;;;;R22$,f:0.1,2.3,4.5.6,m:13:0.1.2.3.4.5,21:14.15.16.17.18.19,40:23.24.25.26.27.28,42:29.30.31.32.33.34.35.36.37.38|");
     }
 
-    @Test public void trailingAtomLabelSemiColonAndAtomValues() throws Exception {
+    @Test
+    void trailingAtomLabelSemiColonAndAtomValues() throws Exception {
         IAtomContainer mol = smipar.parseSmiles("[H]C1=C([H])N2C(=O)C(=C([O-])[N+](CC3=CN=C(Cl)S3)=C2C(C)=C1[H])C1=CC(*)=CC=C1.** |$;;;;;;;;;;;;;;;;;;;;;;;;;;R;;;;RA;$,$_AV:;;;;;;;;;;;;;;;;;;;;;;;;2;;;4;5;6;;$,c:1,18,22,29,31,t:7,12,14,26,m:31:29.28.27.25.24.23|");
         List<Sgroup> sgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
         assertThat(mol.getAtom(26), is(instanceOf(IPseudoAtom.class)));
@@ -221,7 +224,8 @@ public class CxSmilesTest {
         assertThat(sgroups.size(), is(1));
     }
 
-    @Test public void generateLabelledSmiles() throws CDKException {
+    @Test
+    void generateLabelledSmiles() throws CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.getAtom(0).setImplicitHydrogenCount(3);
@@ -236,7 +240,8 @@ public class CxSmilesTest {
         assertThat(smi, is("CC* |$;;R1$|"));
     }
 
-    @Test public void generateCanonLabelledSmiles() throws CDKException {
+    @Test
+    void generateCanonLabelledSmiles() throws CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.getAtom(0).setImplicitHydrogenCount(3);
@@ -252,7 +257,8 @@ public class CxSmilesTest {
         assertThat(smi, is("*CC |$R1$|"));
     }
 
-    @Test public void roundTripMulticenter() throws CDKException {
+    @Test
+    void roundTripMulticenter() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("c1ccccc1.*Cl |m:6:0.1.2.3.4.5|");
@@ -262,7 +268,8 @@ public class CxSmilesTest {
         assertThat(smi, is("c1ccccc1.*Cl |m:6:0.1.2.3.4.5|"));
     }
 
-    @Test public void canonMulticenter() throws CDKException {
+    @Test
+    void canonMulticenter() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("c1ccccc1.*Cl |m:6:0.1.2.3.4.5|");
@@ -274,7 +281,8 @@ public class CxSmilesTest {
     }
 
 
-    @Test public void roundTripPEGn() throws CDKException {
+    @Test
+    void roundTripPEGn() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CCCOCCO |Sg:n:1,2,3::ht|");
@@ -283,7 +291,8 @@ public class CxSmilesTest {
         assertThat(smi, is("CCCOCCO |Sg:n:1,2,3:n:ht|"));
     }
 
-    @Test public void canonPEGn() throws CDKException {
+    @Test
+    void canonPEGn() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CCCOCCO |Sg:n:1,2,3::ht|");
@@ -293,7 +302,8 @@ public class CxSmilesTest {
         assertThat(smi, is("OCCOCCC |Sg:n:3,4,5:n:ht|"));
     }
 
-    @Test public void coordsEtOH() throws CDKException {
+    @Test
+    void coordsEtOH() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CCO |(,,;1,1,;2,2,)|");
@@ -302,7 +312,8 @@ public class CxSmilesTest {
         assertThat(smi, is("CCO |(,,;1,1,;2,2,)|"));
     }
 
-    @Test public void canonCoordsEtOH() throws CDKException {
+    @Test
+    void canonCoordsEtOH() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CCO |(,,;1,1,;2,2,)|");
@@ -312,7 +323,8 @@ public class CxSmilesTest {
         assertThat(smi, is("OCC |(2,2,;1,1,;,,)|"));
     }
 
-    @Test public void noCoordsOptEtOH() throws CDKException {
+    @Test
+    void noCoordsOptEtOH() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CCO |(,,;1,1,;2,2,)|");
@@ -321,7 +333,8 @@ public class CxSmilesTest {
         assertThat(smi, is("CCO"));
     }
 
-    @Test public void noCoordsInEtOH() throws CDKException {
+    @Test
+    void noCoordsInEtOH() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CCO");
@@ -330,7 +343,8 @@ public class CxSmilesTest {
         assertThat(smi, is("CCO"));
     }
 
-    @Test public void roundTripRadicals() throws CDKException {
+    @Test
+    void roundTripRadicals() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("[C]1C[CH][CH]OC1 |^1:2,3,^2:0|");
@@ -339,7 +353,8 @@ public class CxSmilesTest {
         assertThat(smi, is("[C]1C[CH][CH]OC1 |^1:2,3,^2:0|"));
     }
 
-    @Test public void canonRadicals() throws CDKException {
+    @Test
+    void canonRadicals() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("[C]1C[CH][CH]OC1 |^1:2,3,^2:0|");
@@ -349,7 +364,8 @@ public class CxSmilesTest {
         assertThat(smi, is("[C]1CO[CH][CH]C1 |^1:3,4,^2:0|"));
     }
 
-    @Test public void roundTripReactionAtomLabelsAndFragmentGroups() throws CDKException {
+    @Test
+    void roundTripReactionAtomLabelsAndFragmentGroups() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IReaction rxn = smipar.parseReactionSmiles("CC(C)c1ccccc1.ClC([*])=O>ClCCl.[Al+3].[Cl-].[Cl-].[Cl-]>CC(C)c1ccc(cc1)C([*])=O |$;;;;;;;;;;;R1;;;;;;;;;;;;;;;;;;;R1;$,f:3.4.5.6|");
@@ -359,7 +375,8 @@ public class CxSmilesTest {
                    is("CC(C)C1=CC=CC=C1.ClC(*)=O>ClCCl.[Al+3].[Cl-].[Cl-].[Cl-]>CC(C)C1=CC=C(C=C1)C(*)=O |f:3.4.5.6,$;;;;;;;;;;;R1;;;;;;;;;;;;;;;;;;;R1$|"));
     }
 
-    @Test public void canonicalReactionAtomLabelsAndFragmentGroups() throws CDKException {
+    @Test
+    void canonicalReactionAtomLabelsAndFragmentGroups() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IReaction rxn1 = smipar.parseReactionSmiles("CC(C)c1ccccc1.ClC([*])=O>[Al+3].[Cl-].[Cl-].[Cl-].ClCCl>CC(C)c1ccc(cc1)C([*])=O |$;;;;;;;;;;;R1;;;;;;;;;;;;;;;;;;;R1;$,f:2.3.4.5|");
@@ -371,7 +388,8 @@ public class CxSmilesTest {
                    is(smigen.create(rxn2)));
     }
 
-    @Test public void canonAtomLabels() throws CDKException {
+    @Test
+    void canonAtomLabels() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("c1ccccc1O |$_AV:0;1;2;3;4;5;6$|");
@@ -380,7 +398,8 @@ public class CxSmilesTest {
     }
 
 
-    @Test public void roundTripLigandOrdering() throws CDKException {
+    @Test
+    void roundTripLigandOrdering() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("Cl[*](Br)I |$;_R1;;$,LO:1:0.2.3|");
@@ -388,7 +407,8 @@ public class CxSmilesTest {
         assertThat(smigen.create(mol), is("Cl*(Br)I |$;R1$,LO:1:0.2.3|"));
     }
 
-    @Test public void canonLigandOrdering() throws CDKException {
+    @Test
+    void canonLigandOrdering() throws CDKException {
         IChemObjectBuilder bldr   = SilentChemObjectBuilder.getInstance();
         SmilesParser       smipar = new SmilesParser(bldr);
         IAtomContainer     mol    = smipar.parseSmiles("Cl[*](I)Br |$;_R1;;$,LO:1:0.2.3|");
@@ -396,7 +416,8 @@ public class CxSmilesTest {
         assertThat(smigen.create(mol), is("Cl*(Br)I |$;R1$,LO:1:0.3.2|"));
     }
 
-    @Test public void roundTripSgroupParents() throws CDKException {
+    @Test
+    void roundTripSgroupParents() throws CDKException {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         SmilesParser smipar = new SmilesParser(bldr);
         IAtomContainer mol = smipar.parseSmiles("CN1CCCCC1.CO.O |Sg:c:0,1,2,3,4,5,6::,Sg:c:7,8::,Sg:c:9::,Sg:mix:0,1,2,3,4,5,6,7,8,9::,Sg:mix:7,8,9::,SgH:3:4.0,4:2.1|");
