@@ -20,13 +20,12 @@
 package org.openscience.cdk.fragment;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Tag;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
-import org.openscience.cdk.test.SlowTest;
 import org.openscience.cdk.aromaticity.Aromaticity;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -49,89 +48,89 @@ import static org.hamcrest.MatcherAssert.assertThat;
  *
  * @cdk.module test-fragment
  */
-public class MurckoFragmenterTest extends CDKTestCase {
+class MurckoFragmenterTest extends CDKTestCase {
 
-    static MurckoFragmenter fragmenter;
-    static SmilesParser     smilesParser;
+    private static MurckoFragmenter fragmenter;
+    private static SmilesParser     smilesParser;
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         fragmenter = new MurckoFragmenter(false, 5);
         smilesParser = new SmilesParser(DefaultChemObjectBuilder.getInstance());
     }
 
     @Test
-    public void testNoFramework() throws CDKException {
+    void testNoFramework() throws CDKException {
         IAtomContainer mol = smilesParser.parseSmiles("CCO[C@@H](C)C(=O)C(O)O");
         fragmenter.generateFragments(mol);
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(0, frameworks.length);
+        Assertions.assertEquals(0, frameworks.length);
     }
 
     @Test
-    public void testOnlyRingSystem() throws CDKException {
+    void testOnlyRingSystem() throws CDKException {
         IAtomContainer mol = smilesParser.parseSmiles("c1ccccc1CCCCC");
         fragmenter.generateFragments(mol);
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(0, frameworks.length);
+        Assertions.assertEquals(0, frameworks.length);
         String[] rings = fragmenter.getRingSystems();
-        Assert.assertEquals(1, rings.length);
+        Assertions.assertEquals(1, rings.length);
     }
 
     @Test
-    public void testMF3() throws Exception {
+    void testMF3() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("C(CC1=C2C=CC=CC2=CC2=C1C=CC=C2)C1CCCCC1");
         fragmenter.generateFragments(mol);
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(1, frameworks.length);
+        Assertions.assertEquals(1, frameworks.length);
     }
 
     @Test
-    public void testMF3_Container() throws Exception {
+    void testMF3_Container() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("C(CC1=C2C=CC=CC2=CC2=C1C=CC=C2)C1CCCCC1");
         fragmenter.generateFragments(mol);
         IAtomContainer[] frameworks = fragmenter.getFrameworksAsContainers();
-        Assert.assertEquals(1, frameworks.length);
+        Assertions.assertEquals(1, frameworks.length);
     }
 
     @Test
-    public void testMF1() throws Exception {
+    void testMF1() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("c1ccccc1PP(B)c1cccc(N(N)N)c1SC1CCC1");
         MurckoFragmenter fragmenter = new MurckoFragmenter(false, 2);
 
         fragmenter.generateFragments(mol);
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(3, frameworks.length);
+        Assertions.assertEquals(3, frameworks.length);
 
         String[] rings = fragmenter.getRingSystems();
-        Assert.assertEquals(2, rings.length);
+        Assertions.assertEquals(2, rings.length);
     }
 
     @Test
-    public void testMF1_Container() throws Exception {
+    void testMF1_Container() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("c1ccccc1PP(B)c1cccc(N(N)N)c1SC1CCC1");
         MurckoFragmenter fragmenter = new MurckoFragmenter(false, 2);
 
         fragmenter.generateFragments(mol);
         IAtomContainer[] frameworks = fragmenter.getFrameworksAsContainers();
-        Assert.assertEquals(3, frameworks.length);
+        Assertions.assertEquals(3, frameworks.length);
 
         IAtomContainer[] rings = fragmenter.getRingSystemsAsContainers();
-        Assert.assertEquals(2, rings.length);
+        Assertions.assertEquals(2, rings.length);
     }
 
     @Test
-    public void testMF2() throws Exception {
+    void testMF2() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("C1(c2ccccc2)(CC(CC1)CCc1ccccc1)CC1C=CC=C1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
         fragmenter.generateFragments(mol);
 
         String[] rings = fragmenter.getRingSystems();
-        Assert.assertEquals(3, rings.length);
+        Assertions.assertEquals(3, rings.length);
 
         List<String> frameworks = Arrays.asList(fragmenter.getFrameworks());
-        Assert.assertEquals(7, frameworks.size());
+        Assertions.assertEquals(7, frameworks.size());
 
         assertThat(
                 frameworks,
@@ -141,60 +140,60 @@ public class MurckoFragmenterTest extends CDKTestCase {
     }
 
     @Test
-    public void testSingleFramework() throws Exception {
+    void testSingleFramework() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("C1(c2ccccc2)(CC(CC1)CCc1ccccc1)CC1C=CC=C1");
         MurckoFragmenter fragmenter = new MurckoFragmenter(true, 6);
         fragmenter.generateFragments(mol);
 
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(1, frameworks.length);
+        Assertions.assertEquals(1, frameworks.length);
 
     }
 
     @Test
-    public void testMF4() throws Exception {
+    void testMF4() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("c1ccc(cc1)c2c(oc(n2)N(CCO)CCO)c3ccccc3");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         fragmenter.generateFragments(mol);
 
         List<String> frameworks = Arrays.asList(fragmenter.getFrameworks());
-        Assert.assertEquals(3, frameworks.size());
+        Assertions.assertEquals(3, frameworks.size());
         assertThat(frameworks, hasItems("n1coc(c1)-c2ccccc2", "n1coc(-c2ccccc2)c1-c3ccccc3", "n1cocc1-c2ccccc2"));
     }
 
     @Test
-    public void testMF5() throws Exception {
+    void testMF5() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("c1cc(ccc1C(=O)Nc2ccc3c(c2)nc(o3)c4ccncc4)F");
         fragmenter.generateFragments(mol);
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(3, frameworks.length);
+        Assertions.assertEquals(3, frameworks.length);
 
         String[] rings = fragmenter.getRingSystems();
-        Assert.assertEquals(3, rings.length);
+        Assertions.assertEquals(3, rings.length);
     }
 
     @Test
-    public void testMF6() throws Exception {
+    void testMF6() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("COc1ccc(cc1OCc2ccccc2)C(=S)N3CCOCC3");
         fragmenter.generateFragments(mol);
 
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(3, frameworks.length);
+        Assertions.assertEquals(3, frameworks.length);
 
         String[] rings = fragmenter.getRingSystems();
-        Assert.assertEquals(2, rings.length);
+        Assertions.assertEquals(2, rings.length);
     }
 
     @Test
-    public void testMF7() throws Exception {
+    void testMF7() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("Cc1nnc(s1)N[C@H](C(=O)c2ccccc2)NC(=O)c3ccco3");
         fragmenter.generateFragments(mol);
 
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(4, frameworks.length);
+        Assertions.assertEquals(4, frameworks.length);
 
         String[] rings = fragmenter.getRingSystems();
-        Assert.assertEquals(3, rings.length);
+        Assertions.assertEquals(3, rings.length);
     }
 
     /**
@@ -202,21 +201,21 @@ public class MurckoFragmenterTest extends CDKTestCase {
      * @cdk.bug 1848591
      */
     @Test
-    public void testBug1848591() throws Exception {
+    void testBug1848591() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("c1(ccc(cc1C)CCC(C(CCC)C2C(C2)CC)C3C=C(C=C3)CC)C");
         MurckoFragmenter fragmenter = new MurckoFragmenter(true, 6);
         fragmenter.generateFragments(mol);
 
         String[] frameworks = fragmenter.getFrameworks();
-        Assert.assertEquals(1, frameworks.length);
-        Assert.assertEquals("c1ccc(cc1)CCC(CC2CC2)C3C=CC=C3", frameworks[0]);
+        Assertions.assertEquals(1, frameworks.length);
+        Assertions.assertEquals("c1ccc(cc1)CCC(CC2CC2)C3C=CC=C3", frameworks[0]);
     }
 
     /**
      * @cdk.bug 3088164
      */
     @Test
-    public void testCarbinoxamine_Bug3088164() throws Exception {
+    void testCarbinoxamine_Bug3088164() throws Exception {
         IAtomContainer mol = smilesParser.parseSmiles("CN(C)CCOC(C1=CC=C(Cl)C=C1)C1=CC=CC=N1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         Aromaticity.cdkLegacy().apply(mol);
@@ -225,15 +224,15 @@ public class MurckoFragmenterTest extends CDKTestCase {
 
         String[] f = fragmenter.getFrameworks();
         IAtomContainer[] fc = fragmenter.getFrameworksAsContainers();
-        Assert.assertEquals(1, f.length);
-        Assert.assertEquals(f.length, fc.length);
-        Assert.assertEquals("n1ccccc1Cc2ccccc2", f[0]);
+        Assertions.assertEquals(1, f.length);
+        Assertions.assertEquals(f.length, fc.length);
+        Assertions.assertEquals("n1ccccc1Cc2ccccc2", f[0]);
 
         SmilesGenerator sg = SmilesGenerator.unique().aromatic();
         for (int i = 0; i < f.length; i++) {
             Aromaticity.cdkLegacy().apply(fc[i]);
             String newsmiles = sg.create(fc[i]);
-            Assert.assertTrue(f[i] + " did not match the container, " + newsmiles, f[i].equals(newsmiles));
+            Assertions.assertTrue(f[i].equals(newsmiles), f[i] + " did not match the container, " + newsmiles);
         }
     }
 
@@ -241,7 +240,7 @@ public class MurckoFragmenterTest extends CDKTestCase {
      * @cdk.bug 3088164
      */
     @Test
-    public void testPirenperone_Bug3088164() throws Exception {
+    void testPirenperone_Bug3088164() throws Exception {
         SmilesGenerator sg = SmilesGenerator.unique().aromatic();
 
         IAtomContainer mol = smilesParser.parseSmiles("Fc1ccc(cc1)C(=O)C4CCN(CCC\\3=C(\\N=C2\\C=C/C=C\\N2C/3=O)C)CC4");
@@ -254,19 +253,19 @@ public class MurckoFragmenterTest extends CDKTestCase {
         String[] f = fragmenter.getFrameworks();
         IAtomContainer[] fc = fragmenter.getFrameworksAsContainers();
 
-        Assert.assertEquals(1, f.length);
-        Assert.assertEquals(f.length, fc.length);
+        Assertions.assertEquals(1, f.length);
+        Assertions.assertEquals(f.length, fc.length);
 
         AtomContainerManipulator.clearAtomConfigurations(mol);
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         CDKHydrogenAdder.getInstance(mol.getBuilder()).addImplicitHydrogens(mol);
         Aromaticity.cdkLegacy().apply(mol);
 
-        Assert.assertEquals("N=1C=C(CN2C=CC=CC12)CCN3CCC(Cc4ccccc4)CC3", f[0]);
+        Assertions.assertEquals("N=1C=C(CN2C=CC=CC12)CCN3CCC(Cc4ccccc4)CC3", f[0]);
 
         for (int i = 0; i < f.length; i++) {
             String newsmiles = sg.create(fc[i]);
-            Assert.assertTrue(f[i] + " did not match the container, " + newsmiles, f[i].equals(newsmiles));
+            Assertions.assertTrue(f[i].equals(newsmiles), f[i] + " did not match the container, " + newsmiles);
         }
     }
 
@@ -274,7 +273,7 @@ public class MurckoFragmenterTest extends CDKTestCase {
      * @cdk.bug 3088164
      */
     @Test
-    public void testIsomoltane_Bug3088164() throws Exception {
+    void testIsomoltane_Bug3088164() throws Exception {
         SmilesGenerator sg = SmilesGenerator.unique().aromatic();
 
         IAtomContainer mol = smilesParser.parseSmiles("CC(C)NCC(O)COC1=C(C=CC=C1)N1C=CC=C1");
@@ -285,19 +284,19 @@ public class MurckoFragmenterTest extends CDKTestCase {
 
         String[] f = fragmenter.getFrameworks();
         IAtomContainer[] fc = fragmenter.getFrameworksAsContainers();
-        Assert.assertEquals(1, f.length);
-        Assert.assertEquals(f.length, fc.length);
-        Assert.assertEquals("c1ccc(cc1)-n2cccc2", f[0]);
+        Assertions.assertEquals(1, f.length);
+        Assertions.assertEquals(f.length, fc.length);
+        Assertions.assertEquals("c1ccc(cc1)-n2cccc2", f[0]);
 
         for (int i = 0; i < f.length; i++) {
             Aromaticity.cdkLegacy().apply(fc[i]);
             String newsmiles = sg.create(fc[i]);
-            Assert.assertTrue(f[i] + " did not match the container, " + newsmiles, f[i].equals(newsmiles));
+            Assertions.assertTrue(f[i].equals(newsmiles), f[i] + " did not match the container, " + newsmiles);
         }
     }
 
     @Test
-    public void testGetFragmentsAsContainers() throws Exception {
+    void testGetFragmentsAsContainers() throws Exception {
 
         IAtomContainer biphenyl = TestMoleculeFactory.makeBiphenyl();
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(biphenyl);
@@ -319,8 +318,8 @@ public class MurckoFragmenterTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    @Category(SlowTest.class)
-    public void testMacrocycle() throws Exception {
+    @Tag("SlowTest")
+    void testMacrocycle() throws Exception {
         IAtomContainer mol = smilesParser
                 .parseSmiles("C1=C(C=C(C(=C1O)O)O)C(=O)OC2=CC(=CC(=C2O)O)C(=O)OCC3C(C(C(C(O3)OC(=O)C4=CC(=C(C(=C4)OC(=O)C5=CC(=C(C(=C5)O)O)O)O)O)OC(=O)C6=CC(=C(C(=C6)OC(=O)C7=CC(=C(C(=C7)O)O)O)O)O)OC(=O)C8=CC(=C(C(=C8)OC(=O)C9=CC(=C(C(=C9)O)O)O)O)O)OC(=O)C1=CC(=C(C(=C1)OC(=O)C1=CC(=C(C(=C1)O)O)O)O)O");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -340,7 +339,7 @@ public class MurckoFragmenterTest extends CDKTestCase {
      * @see <a href="https://github.com/cdk/cdk/issues/263">GitHub Issue #263</a>
      */
     @Test
-    public void testCHEMBL529226() throws CDKException {
+    void testCHEMBL529226() throws CDKException {
         String smiles = "CC1=CN([C@@H]2O[C@@]3(COP(=S)(O)O[C@H]4[C@H]5OC[C@]4(COP(=S)(O)O[C@H]6C[C@@H](O[C@@H]6COP(=S)(O)O[C@H]7[C@@H](O)[C@@H](O[C@@H]7COP(=S)(O)O[C@H]8[C@@H](O)[C@@H](O[C@@H]8COP(=S)(O)O[C@H]9[C@@H](O)[C@@H](O[C@@H]9COP(=S)(O)O[C@H]%10[C@@H](O)[C@@H](O[C@@H]%10COP(=S)(O)O[C@H]%11[C@@H](O)[C@@H](O[C@@H]%11COP(=S)(O)O[C@H]%12[C@@H](O)[C@@H](O[C@@H]%12COP(=S)(O)O[C@H]%13[C@@H](O)[C@@H](O[C@@H]%13COP(=S)(O)O[C@H]%14[C@@H](O)[C@@H](O[C@@H]%14COP(=S)(O)O[C@H]%15[C@@H](O)[C@@H](O[C@@H]%15COP(=S)(O)O[C@H]%16[C@H]%17OC[C@]%16(COP(=S)(O)O[C@H]%18[C@H]%19OC[C@]%18(CO)O[C@H]%19N%20C=C(C)C(=O)NC%20=O)O[C@H]%17N%21C=C(C)C(=NC%21=O)N)N%22C=CC(=NC%22=O)N)n%23cnc%24C(=O)NC(=Nc%23%24)N)n%25cnc%26C(=O)NC(=Nc%25%26)N)N%27C=C(C)C(=O)NC%27=O)N%28C=CC(=NC%28=O)N)n%29cnc%30c(N)ncnc%29%30)N%31C=CC(=NC%31=O)N)n%32cnc%33C(=O)NC(=Nc%32%33)N)n%34cnc%35C(N)NC=Nc%34%35)N%36C=C(C)C(=O)NC%36=O)O[C@H]5N%37C=C(C)C(=O)NC%37=O)CO[C@@H]2[C@@H]3O)C(=O)N=C1N";
         SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         IAtomContainer mol = smipar.parseSmiles(smiles);
