@@ -25,8 +25,8 @@
 package org.openscience.cdk.hash;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.DefaultChemObjectBuilder;
@@ -37,7 +37,6 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
-import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.interfaces.ITetrahedralChirality;
 import org.openscience.cdk.io.iterator.IteratingSDFReader;
 import org.openscience.cdk.stereo.DoubleBondStereochemistry;
@@ -54,7 +53,6 @@ import java.util.Set;
 import static org.hamcrest.CoreMatchers.hasItem;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
-import static org.junit.Assert.assertNotNull;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.openscience.cdk.interfaces.IDoubleBondStereochemistry.Conformation.OPPOSITE;
 import static org.openscience.cdk.interfaces.IDoubleBondStereochemistry.Conformation.TOGETHER;
@@ -66,14 +64,14 @@ import static org.openscience.cdk.interfaces.IDoubleBondStereochemistry.Conforma
  * @author John May
  * @cdk.module test-hash
  */
-public class HashCodeScenariosTest {
+class HashCodeScenariosTest {
 
     /**
      * Two molecules with identical Racid identification numbers, these hash
      * codes should be different.
      */
     @Test
-    public void figure2a() {
+    void figure2a() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-2a.sdf", 2);
 
@@ -93,7 +91,7 @@ public class HashCodeScenariosTest {
      * codes should be different.
      */
     @Test
-    public void figure2b() {
+    void figure2b() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-2b.sdf", 2);
 
@@ -113,7 +111,7 @@ public class HashCodeScenariosTest {
      * codes should be different.
      */
     @Test
-    public void figure2c() {
+    void figure2c() {
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-2c.sdf", 2);
 
         IAtomContainer a = mols.get(0);
@@ -133,7 +131,7 @@ public class HashCodeScenariosTest {
      * different using this method.
      */
     @Test
-    public void figure3() {
+    void figure3() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-3.sdf", 2);
 
@@ -154,7 +152,7 @@ public class HashCodeScenariosTest {
      * demonstrates the size the molecule is considered when hashing.
      */
     @Test
-    public void figure7() {
+    void figure7() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-7.sdf", 2);
 
@@ -175,7 +173,7 @@ public class HashCodeScenariosTest {
      * hash code identifies that the two molecules are the same.
      */
     @Test
-    public void figure10() {
+    void figure10() {
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-10.sdf", 2);
 
         IAtomContainer a = mols.get(0);
@@ -196,7 +194,7 @@ public class HashCodeScenariosTest {
      * used. Please refer to the original article for the exact method.
      */
     @Test
-    public void figure11() {
+    void figure11() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-11.sdf", 1);
 
@@ -220,13 +218,13 @@ public class HashCodeScenariosTest {
      * configuration  and (S)- configuration values are invariant
      */
     @Test
-    public void figure12() {
+    void figure12() {
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-12.sdf", 2);
 
         MoleculeHashGenerator stereo = new HashGeneratorMaker().elemental().depth(1).chiral().molecular();
 
-        Set<Long> sHashes = new HashSet<Long>();
-        Set<Long> rHashes = new HashSet<Long>();
+        Set<Long> sHashes = new HashSet<>();
+        Set<Long> rHashes = new HashSet<>();
 
         AtomContainerAtomPermutor rpermutor = new AtomContainerAtomPermutor(mols.get(0));
         AtomContainerAtomPermutor spermutor = new AtomContainerAtomPermutor(mols.get(1));
@@ -252,7 +250,7 @@ public class HashCodeScenariosTest {
      * codes.
      */
     @Test
-    public void figure13a() {
+    void figure13a() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-13a.sdf", 2);
 
@@ -273,7 +271,7 @@ public class HashCodeScenariosTest {
      * codes.
      */
     @Test
-    public void figure13b() {
+    void figure13b() {
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-13b.sdf", 2);
 
         IAtomContainer a = mols.get(0);
@@ -291,7 +289,7 @@ public class HashCodeScenariosTest {
      * two molecules are in fact the same and generate the same hash code.
      */
     @Test
-    public void figure14() {
+    void figure14() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-14.sdf", 2);
 
@@ -312,7 +310,7 @@ public class HashCodeScenariosTest {
      * code.
      */
     @Test
-    public void figure15() {
+    void figure15() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-15.sdf", 2);
 
@@ -338,7 +336,7 @@ public class HashCodeScenariosTest {
      * hash code, allows us to discriminate them.
      */
     @Test
-    public void figure16a() {
+    void figure16a() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-16a.sdf", 2);
 
@@ -365,7 +363,7 @@ public class HashCodeScenariosTest {
     }
 
     private Set<Long> toSet(long[] xs) {
-        Set<Long> set = new HashSet<Long>();
+        Set<Long> set = new HashSet<>();
         for (long x : xs) {
             set.add(x);
         }
@@ -378,7 +376,7 @@ public class HashCodeScenariosTest {
      * apart as well as the 3 different chlorination locations on the cuneane
      */
     @Test
-    public void figure16b() {
+    void figure16b() {
 
         List<IAtomContainer> mols = sdf("ihlenfeldt93-figure-16b.sdf", 4);
 
@@ -411,7 +409,7 @@ public class HashCodeScenariosTest {
      * propagate  the environments from the ends of both chains.
      */
     @Test
-    public void aminotetracosanone() {
+    void aminotetracosanone() {
 
         List<IAtomContainer> aminotetracosanones = sdf("aminotetracosanones.sdf", 2);
 
@@ -440,14 +438,14 @@ public class HashCodeScenariosTest {
      *      Isomers</a>
      */
     @Test
-    public void inositols() {
+    void inositols() {
 
         List<IAtomContainer> inositols = sdf("inositols.sdf", 9);
 
         // non-stereo non-perturbed hash generator
         MoleculeHashGenerator basic = new HashGeneratorMaker().elemental().depth(6).molecular();
 
-        Set<Long> hashes = new HashSet<Long>(5);
+        Set<Long> hashes = new HashSet<>(5);
 
         for (IAtomContainer inositol : inositols) {
             long hash = basic.generate(inositol);
@@ -482,7 +480,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void allenesWithImplicitHydrogens() {
+    void allenesWithImplicitHydrogens() {
 
         List<IAtomContainer> allenes = sdf("allene-implicit-h.sdf", 2);
 
@@ -517,7 +515,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void allenesWithExplicitHydrogens() {
+    void allenesWithExplicitHydrogens() {
 
         List<IAtomContainer> allenes = sdf("allene-explicit-h.sdf", 2);
 
@@ -552,7 +550,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void allenes2Dand3D() {
+    void allenes2Dand3D() {
 
         List<IAtomContainer> allenes2D = sdf("allene-explicit-h.sdf", 2);
         List<IAtomContainer> allenes3D = sdf("allene-explicit-3d-h.sdf", 2);
@@ -587,7 +585,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void allenesWithUnspecifiedConfiguration() {
+    void allenesWithUnspecifiedConfiguration() {
         List<IAtomContainer> allenes = sdf("allene-implicit-h.sdf", 2);
         List<IAtomContainer> unspecified = sdf("allene-unspecified.sdf", 2);
 
@@ -616,7 +614,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void cumulenes() {
+    void cumulenes() {
 
         List<IAtomContainer> cumulenes = sdf("cumulenes.sdf", 2);
 
@@ -635,7 +633,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void suppressedHydrogens() {
+    void suppressedHydrogens() {
 
         List<IAtomContainer> implicits = sdf("butan-2-ols.sdf", 2);
         List<IAtomContainer> explicits = sdf("butan-2-ols-explicit-hydrogens.sdf", 2);
@@ -654,7 +652,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void suppressedHydrogens_chiral() {
+    void suppressedHydrogens_chiral() {
 
         List<IAtomContainer> implicits = sdf("butan-2-ols.sdf", 2);
         List<IAtomContainer> explicits = sdf("butan-2-ols-explicit-hydrogens.sdf", 2);
@@ -683,7 +681,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void inositols_suppressedHydrogens() {
+    void inositols_suppressedHydrogens() {
 
         List<IAtomContainer> implicits = sdf("inositols.sdf", 9);
         List<IAtomContainer> explicits = sdf("inositols-explicit-hydrogens.sdf", 9);
@@ -711,7 +709,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void inositols_suppressedHydrogens_chiral() {
+    void inositols_suppressedHydrogens_chiral() {
 
         List<IAtomContainer> implicits = sdf("inositols.sdf", 9);
         List<IAtomContainer> explicits = sdf("inositols-explicit-hydrogens.sdf", 9);
@@ -743,7 +741,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void suppressedHydrogens_dicholorethenes() {
+    void suppressedHydrogens_dicholorethenes() {
 
         List<IAtomContainer> implicits = sdf("dichloroethenes.sdf", 2);
         List<IAtomContainer> explicits = sdf("dichloroethenes-explicit-hydrogens.sdf", 2);
@@ -775,7 +773,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void suppressedHydrogens_allenes() {
+    void suppressedHydrogens_allenes() {
 
         List<IAtomContainer> implicits = sdf("allene-implicit-h.sdf", 2);
         List<IAtomContainer> explicits = sdf("allene-explicit-h.sdf", 2);
@@ -807,7 +805,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void butan2ol_UsingStereoElement() {
+    void butan2ol_UsingStereoElement() {
 
         // C[CH](O)CC
         IAtomContainer butan2ol = new AtomContainer();
@@ -833,7 +831,7 @@ public class HashCodeScenariosTest {
         long rConfiguration = generator.generate(butan2ol);
 
         // C[C@H](O)CC  (2S)-butan-2-ol
-        butan2ol.setStereoElements(new ArrayList<IStereoElement>(1));
+        butan2ol.setStereoElements(new ArrayList<>(1));
         butan2ol.addStereoElement(new TetrahedralChirality(butan2ol.getAtom(1), new IAtom[]{butan2ol.getAtom(0),
                 butan2ol.getAtom(1), // represents implicit H
                 butan2ol.getAtom(2), butan2ol.getAtom(3),}, ITetrahedralChirality.Stereo.ANTI_CLOCKWISE));
@@ -856,7 +854,7 @@ public class HashCodeScenariosTest {
         // okay now let's move around the atoms in the stereo element
 
         // [C@H](C)(O)CC (2R)-butan-2-ol
-        butan2ol.setStereoElements(new ArrayList<IStereoElement>(1));
+        butan2ol.setStereoElements(new ArrayList<>(1));
         butan2ol.addStereoElement(new TetrahedralChirality(butan2ol.getAtom(1), new IAtom[]{butan2ol.getAtom(1), // represents implicit H
                 butan2ol.getAtom(0), butan2ol.getAtom(2), butan2ol.getAtom(3),},
                 ITetrahedralChirality.Stereo.ANTI_CLOCKWISE));
@@ -865,7 +863,7 @@ public class HashCodeScenariosTest {
         assertThat(generator.generate(butan2ol), is(generator.generate(butan2ols.get(0))));
 
         // [C@@H](C)(O)CC (2S)-butan-2-ol
-        butan2ol.setStereoElements(new ArrayList<IStereoElement>(1));
+        butan2ol.setStereoElements(new ArrayList<>(1));
         butan2ol.addStereoElement(new TetrahedralChirality(butan2ol.getAtom(1), new IAtom[]{butan2ol.getAtom(1), // represents implicit H
                 butan2ol.getAtom(0), butan2ol.getAtom(2), butan2ol.getAtom(3),}, ITetrahedralChirality.Stereo.CLOCKWISE));
 
@@ -875,7 +873,7 @@ public class HashCodeScenariosTest {
     }
 
     @Test
-    public void dichloroethenes_stereoElements() {
+    void dichloroethenes_stereoElements() {
 
         // CLC=CCL
         IAtomContainer dichloroethene = new AtomContainer();
@@ -890,14 +888,14 @@ public class HashCodeScenariosTest {
         MoleculeHashGenerator generator = new HashGeneratorMaker().elemental().depth(4).chiral().molecular();
 
         // set E configuration
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), dichloroethene.getBond(2)}, OPPOSITE));
 
         long eConfiguration = generator.generate(dichloroethene);
 
         // set Z configuration
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), dichloroethene.getBond(2)}, TOGETHER));
         long zConfiguration = generator.generate(dichloroethene);
@@ -916,7 +914,7 @@ public class HashCodeScenariosTest {
      * hydrogens)
      */
     @Test
-    public void dichloroethenes_stereoElements_explicitH() {
+    void dichloroethenes_stereoElements_explicitH() {
 
         // CLC=CCL
         IAtomContainer dichloroethene = new AtomContainer();
@@ -934,8 +932,8 @@ public class HashCodeScenariosTest {
 
         MoleculeHashGenerator generator = new HashGeneratorMaker().elemental().depth(4).chiral().molecular();
 
-        Set<Long> eConfigurations = new HashSet<Long>();
-        Set<Long> zConfigurations = new HashSet<Long>();
+        Set<Long> eConfigurations = new HashSet<>();
+        Set<Long> zConfigurations = new HashSet<>();
 
         // set E configurations - we can specify using the C-CL bonds or the C-H
         // bonds so there are four possible combinations it's easiest to think
@@ -948,27 +946,27 @@ public class HashCodeScenariosTest {
         // ClC(/[H])=C([H])/Cl
         // ClC(/[H])=C(\[H])Cl
         // Cl/C([H])=C(\[H])Cl
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), // CL1-C2
                 dichloroethene.getBond(2)}, // CL4-C3
                 OPPOSITE));
         eConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), // C2-H5
                 dichloroethene.getBond(2)}, TOGETHER));
         eConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), // C2-H5
                 dichloroethene.getBond(4)}, // C3-H6
                 OPPOSITE));
         eConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), // CL1-C2
                 dichloroethene.getBond(4)}, // C3-H6
@@ -977,22 +975,22 @@ public class HashCodeScenariosTest {
 
         // set Z configurations - we can specify using the C-CL bonds or the
         // C-H bonds so there are four possible combinations
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), dichloroethene.getBond(2)}, TOGETHER));
         zConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), dichloroethene.getBond(2)}, OPPOSITE));
         zConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), dichloroethene.getBond(4)}, TOGETHER));
         zConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), dichloroethene.getBond(4)}, OPPOSITE));
         zConfigurations.add(generator.generate(dichloroethene));
@@ -1014,7 +1012,7 @@ public class HashCodeScenariosTest {
      * using 2D coordinates (implicit hydrogens)
      */
     @Test
-    public void dichloroethenes_stereoElements_explicitH_suppressed() {
+    void dichloroethenes_stereoElements_explicitH_suppressed() {
 
         // CLC=CCL
         IAtomContainer dichloroethene = new AtomContainer();
@@ -1033,8 +1031,8 @@ public class HashCodeScenariosTest {
         MoleculeHashGenerator generator = new HashGeneratorMaker().elemental().depth(4).chiral().suppressHydrogens()
                 .molecular();
 
-        Set<Long> eConfigurations = new HashSet<Long>();
-        Set<Long> zConfigurations = new HashSet<Long>();
+        Set<Long> eConfigurations = new HashSet<>();
+        Set<Long> zConfigurations = new HashSet<>();
 
         // set E configurations - we can specify using the C-CL bonds or the C-H
         // bonds so there are four possible combinations it's easiest to think
@@ -1047,27 +1045,27 @@ public class HashCodeScenariosTest {
         // ClC(/[H])=C([H])/Cl
         // ClC(/[H])=C(\[H])Cl
         // Cl/C([H])=C(\[H])Cl
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), // CL1-C2
                 dichloroethene.getBond(2)}, // CL4-C3
                 OPPOSITE));
         eConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), // C2-H5
                 dichloroethene.getBond(2)}, TOGETHER));
         eConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), // C2-H5
                 dichloroethene.getBond(4)}, // C3-H6
                 OPPOSITE));
         eConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), // CL1-C2
                 dichloroethene.getBond(4)}, // C3-H6
@@ -1076,22 +1074,22 @@ public class HashCodeScenariosTest {
 
         // set Z configurations - we can specify using the C-CL bonds or the
         // C-H bonds so there are four possible combinations
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), dichloroethene.getBond(2)}, TOGETHER));
         zConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), dichloroethene.getBond(2)}, OPPOSITE));
         zConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(3), dichloroethene.getBond(4)}, TOGETHER));
         zConfigurations.add(generator.generate(dichloroethene));
 
-        dichloroethene.setStereoElements(new ArrayList<IStereoElement>());
+        dichloroethene.setStereoElements(new ArrayList<>());
         dichloroethene.addStereoElement(new DoubleBondStereochemistry(dichloroethene.getBond(1), new IBond[]{
                 dichloroethene.getBond(0), dichloroethene.getBond(4)}, OPPOSITE));
         zConfigurations.add(generator.generate(dichloroethene));
@@ -1128,11 +1126,11 @@ public class HashCodeScenariosTest {
     private List<IAtomContainer> sdf(String path, int exp) {
         InputStream in = getClass().getResourceAsStream(path);
 
-        assertNotNull(path + " could not be found in classpath", in);
+        Assertions.assertNotNull(in, path + " could not be found in classpath");
 
         IChemObjectBuilder builder = DefaultChemObjectBuilder.getInstance();
         IteratingSDFReader sdf = new IteratingSDFReader(in, builder, false);
-        List<IAtomContainer> structures = new ArrayList<IAtomContainer>(exp);
+        List<IAtomContainer> structures = new ArrayList<>(exp);
         while (sdf.hasNext()) {
             IAtomContainer mol = sdf.next();
             try {
