@@ -180,7 +180,7 @@ final class IdentityTemplateLibrary {
             }
         }
 
-        String smi = null;
+        String smi;
         try {
             smi = smigen.create(mol, ordering);
         } finally {
@@ -219,7 +219,7 @@ final class IdentityTemplateLibrary {
                 points[ordering[i]] = point;
             }
 
-            return new SimpleEntry<String, Point2d[]>(smiles, points);
+            return new SimpleEntry<>(smiles, points);
 
         } catch (CDKException e) {
             logger.warn("Could not encode container as SMILES: ", e);
@@ -239,7 +239,7 @@ final class IdentityTemplateLibrary {
     static Entry<String, Point2d[]> decodeEntry(String str) {
         final int i = str.indexOf(' ');
         if (i < 0) throw new IllegalArgumentException();
-        return new SimpleEntry<String, Point2d[]>(str.substring(0, i), decodeCoordinates(str.substring(i + 1)));
+        return new SimpleEntry<>(str.substring(0, i), decodeCoordinates(str.substring(i + 1)));
     }
 
     /**
@@ -350,7 +350,9 @@ final class IdentityTemplateLibrary {
             String smiles = cansmi(container, ordering);
 
             // find the points in the library
-            for (Point2d[] points : templateMap.getOrDefault(smiles, Collections.emptyList())) {
+            List<Point2d[]> templatePoints = templateMap.get(smiles);
+            if (templatePoints != null && !templatePoints.isEmpty()) {
+                Point2d[] points = templatePoints.get(0);
                 // set the points
                 for (int i = 0; i < n; i++) {
                     container.getAtom(i).setPoint2d(new Point2d(points[ordering[i]]));
@@ -432,7 +434,7 @@ final class IdentityTemplateLibrary {
      */
     static IdentityTemplateLibrary load(InputStream in) throws IOException {
         BufferedReader br = new BufferedReader(new InputStreamReader(in));
-        String line = null;
+        String line;
         IdentityTemplateLibrary library = new IdentityTemplateLibrary();
         while ((line = br.readLine()) != null) {
             // skip comments
