@@ -484,9 +484,9 @@ final class NonplanarBonds {
     }
 
 
-    private static int SPIRO_REJECT = 0;
-    private static int SPIRO_ACCEPT = 1;
-    private static int SPIRO_MIRROR = 2;
+    private static final int SPIRO_REJECT = 0;
+    private static final int SPIRO_ACCEPT = 1;
+    private static final int SPIRO_MIRROR = 2;
 
     /**
      * This is complicated, we have a set of bonds and the rings they belong to. We move the bonds around such that
@@ -592,7 +592,9 @@ final class NonplanarBonds {
             if ((!rnums.get(0).equals(0) && rnums.get(0).equals(rnums.get(4))) ||
                 (!rnums.get(1).equals(0) && rnums.get(1).equals(rnums.get(5)))) {
                 swap(bonds, 1, 4);
+                swap(bonds, 2, 3);
                 swap(rnums, 1, 4);
+                swap(rnums, 2, 3);
                 return SPIRO_MIRROR;
             }
 
