@@ -54,6 +54,7 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.util.ArrayList;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -118,7 +119,7 @@ public final class TemplateHandler {
      * template filename to org/openscience/cdk/layout/templates/template.list
      */
     public void loadTemplates(IChemObjectBuilder builder) {
-        String line = null;
+        String line;
         try {
             InputStream ins = this.getClass().getClassLoader()
                                   .getResourceAsStream("org/openscience/cdk/layout/templates/templates.list");
@@ -130,10 +131,9 @@ public final class TemplateHandler {
                 try {
                     CMLReader structureReader = new CMLReader(this.getClass().getClassLoader()
                                                                   .getResourceAsStream(line));
-                    IChemFile file = (IChemFile) structureReader.read(builder.newInstance(IChemFile.class));
+                    IChemFile file = structureReader.read(builder.newInstance(IChemFile.class));
                     List<IAtomContainer> files = ChemFileManipulator.getAllAtomContainers(file);
-                    for (int i = 0; i < files.size(); i++)
-                        addMolecule(files.get(i));
+                    for (IAtomContainer container : files) addMolecule(container);
                     LOGGER.debug("Successfully read template ", line);
                 } catch (CDKException | IllegalArgumentException e) {
                     LOGGER.warn("Could not read template ", line, ", reason: ", e.getMessage());
@@ -331,8 +331,9 @@ public final class TemplateHandler {
      */
     public static TemplateHandler createFromSubstructure(Pattern ptrn, Iterable<IAtomContainer> mols) {
         for (IAtomContainer mol : mols) {
-            for (IAtomContainer template : ptrn.matchAll(mol).toSubstructures())
-                return createSingleton(template);
+            Iterator<IAtomContainer> matched = ptrn.matchAll(mol).toSubstructures().iterator();
+            if (matched.hasNext())
+                return createSingleton(matched.next());
         }
         throw new IllegalArgumentException("Pattern does not match any provided molecules");
     }
@@ -346,8 +347,9 @@ public final class TemplateHandler {
      * @return new template handler
      */
     public static TemplateHandler createFromSubstructure(Pattern ptrn, IAtomContainer mol) {
-        for (IAtomContainer template : ptrn.matchAll(mol).toSubstructures())
-            return createSingleton(template);
+        Iterator<IAtomContainer> matched = ptrn.matchAll(mol).toSubstructures().iterator();
+        if (matched.hasNext())
+            return createSingleton(matched.next());
         throw new IllegalArgumentException("Pattern does not match any provided molecules");
     }
 
