@@ -24,7 +24,8 @@
 
 package org.openscience.cdk.isomorphism;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.mockito.ArgumentMatchers;
 import org.openscience.cdk.interfaces.*;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
@@ -40,8 +41,6 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.CoreMatchers.sameInstance;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.atMost;
 import static org.mockito.Mockito.doCallRealMethod;
 import static org.mockito.Mockito.mock;
@@ -52,11 +51,11 @@ import static org.mockito.Mockito.when;
  * @author John May
  * @cdk.module test-smarts
  */
-public class MappingsTest {
+class MappingsTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void filter() throws Exception {
+    void filter() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -82,7 +81,7 @@ public class MappingsTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void map() throws Exception {
+    void map() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -106,24 +105,24 @@ public class MappingsTest {
         Iterable<String> strings = ms.map(f);
         Iterator<String> stringIt = strings.iterator();
 
-        verify(f, atMost(0)).apply(ArgumentMatchers.<int[]> any());
+        verify(f, atMost(0)).apply(ArgumentMatchers.any());
 
-        assertTrue(stringIt.hasNext());
+        Assertions.assertTrue(stringIt.hasNext());
         assertThat(stringIt.next(), is("p1"));
-        assertTrue(stringIt.hasNext());
+        Assertions.assertTrue(stringIt.hasNext());
         assertThat(stringIt.next(), is("p2"));
-        assertTrue(stringIt.hasNext());
+        Assertions.assertTrue(stringIt.hasNext());
         assertThat(stringIt.next(), is("p3"));
-        assertTrue(stringIt.hasNext());
+        Assertions.assertTrue(stringIt.hasNext());
         assertThat(stringIt.next(), is("p4"));
-        assertFalse(stringIt.hasNext());
+        Assertions.assertFalse(stringIt.hasNext());
 
-        verify(f, atMost(4)).apply(ArgumentMatchers.<int[]> any());
+        verify(f, atMost(4)).apply(ArgumentMatchers.any());
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void limit() throws Exception {
+    void limit() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -136,23 +135,23 @@ public class MappingsTest {
     }
 
     @Test
-    public void stereochemistry() throws Exception {
+    void stereochemistry() throws Exception {
         // tested by filter() + StereoMatchTest
     }
 
     @Test
-    public void uniqueAtoms() throws Exception {
+    void uniqueAtoms() throws Exception {
         // tested by filter() + MappingPredicatesTest
     }
 
     @Test
-    public void uniqueBonds() throws Exception {
+    void uniqueBonds() throws Exception {
         // tested by filter() + MappingPredicatesTest
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void toArray() throws Exception {
+    void toArray() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -170,7 +169,7 @@ public class MappingsTest {
     }
 
     @Test
-    public void toAtomMap() throws Exception {
+    void toAtomMap() throws Exception {
 
         IAtomContainer query = smi("CC");
         IAtomContainer target = smi("CC");
@@ -178,63 +177,63 @@ public class MappingsTest {
         Iterable<Map<IAtom, IAtom>> iterable = Pattern.findIdentical(query).matchAll(target).toAtomMap();
         Iterator<Map<IAtom, IAtom>> iterator = iterable.iterator();
 
-        assertTrue(iterator.hasNext());
+        Assertions.assertTrue(iterator.hasNext());
         Map<IAtom, IAtom> m1 = iterator.next();
         assertThat(m1.get(query.getAtom(0)), is(target.getAtom(0)));
         assertThat(m1.get(query.getAtom(1)), is(target.getAtom(1)));
-        assertTrue(iterator.hasNext());
+        Assertions.assertTrue(iterator.hasNext());
         Map<IAtom, IAtom> m2 = iterator.next();
         assertThat(m2.get(query.getAtom(0)), is(target.getAtom(1)));
         assertThat(m2.get(query.getAtom(1)), is(target.getAtom(0)));
-        assertFalse(iterator.hasNext());
+        Assertions.assertFalse(iterator.hasNext());
     }
 
     @Test
-    public void toBondMap() throws Exception {
+    void toBondMap() throws Exception {
         IAtomContainer query = smi("CCC");
         IAtomContainer target = smi("CCC");
 
         Iterable<Map<IBond, IBond>> iterable = Pattern.findIdentical(query).matchAll(target).toBondMap();
         Iterator<Map<IBond, IBond>> iterator = iterable.iterator();
 
-        assertTrue(iterator.hasNext());
+        Assertions.assertTrue(iterator.hasNext());
         Map<IBond, IBond> m1 = iterator.next();
         assertThat(m1.get(query.getBond(0)), is(target.getBond(0)));
         assertThat(m1.get(query.getBond(1)), is(target.getBond(1)));
-        assertTrue(iterator.hasNext());
+        Assertions.assertTrue(iterator.hasNext());
         Map<IBond, IBond> m2 = iterator.next();
         assertThat(m2.get(query.getBond(0)), is(target.getBond(1)));
         assertThat(m2.get(query.getBond(1)), is(target.getBond(0)));
-        assertFalse(iterator.hasNext());
+        Assertions.assertFalse(iterator.hasNext());
     }
 
     @Test
-    public void toAtomBondMap() throws Exception {
+    void toAtomBondMap() throws Exception {
         IAtomContainer query = smi("CCC");
         IAtomContainer target = smi("CCC");
 
         Iterable<Map<IChemObject, IChemObject>> iterable = Pattern.findIdentical(query).matchAll(target).toAtomBondMap();
         Iterator<Map<IChemObject, IChemObject>> iterator = iterable.iterator();
 
-        assertTrue(iterator.hasNext());
+        Assertions.assertTrue(iterator.hasNext());
         Map<IChemObject, IChemObject> m1 = iterator.next();
-        assertThat(m1.get(query.getAtom(0)), is((IChemObject)target.getAtom(0)));
-        assertThat(m1.get(query.getAtom(1)), is((IChemObject)target.getAtom(1)));
-        assertThat(m1.get(query.getAtom(2)), is((IChemObject)target.getAtom(2)));
-        assertThat(m1.get(query.getBond(0)), is((IChemObject)target.getBond(0)));
-        assertThat(m1.get(query.getBond(1)), is((IChemObject)target.getBond(1)));
-        assertTrue(iterator.hasNext());
+        assertThat(m1.get(query.getAtom(0)), is(target.getAtom(0)));
+        assertThat(m1.get(query.getAtom(1)), is(target.getAtom(1)));
+        assertThat(m1.get(query.getAtom(2)), is(target.getAtom(2)));
+        assertThat(m1.get(query.getBond(0)), is(target.getBond(0)));
+        assertThat(m1.get(query.getBond(1)), is(target.getBond(1)));
+        Assertions.assertTrue(iterator.hasNext());
         Map<IChemObject, IChemObject> m2 = iterator.next();
-        assertThat(m2.get(query.getAtom(0)), is((IChemObject)target.getAtom(2)));
-        assertThat(m2.get(query.getAtom(1)), is((IChemObject)target.getAtom(1)));
-        assertThat(m2.get(query.getAtom(2)), is((IChemObject)target.getAtom(0)));
-        assertThat(m2.get(query.getBond(0)), is((IChemObject)target.getBond(1)));
-        assertThat(m2.get(query.getBond(1)), is((IChemObject)target.getBond(0)));
-        assertFalse(iterator.hasNext());
+        assertThat(m2.get(query.getAtom(0)), is(target.getAtom(2)));
+        assertThat(m2.get(query.getAtom(1)), is(target.getAtom(1)));
+        assertThat(m2.get(query.getAtom(2)), is(target.getAtom(0)));
+        assertThat(m2.get(query.getBond(0)), is(target.getBond(1)));
+        assertThat(m2.get(query.getBond(1)), is(target.getBond(0)));
+        Assertions.assertFalse(iterator.hasNext());
     }
 
     @Test
-    public void toSubstructures() throws Exception {
+    void toSubstructures() throws Exception {
         IAtomContainer query  = smi("O1CC1");
         IAtomContainer target = smi("C1OC1CCC");
 
@@ -244,7 +243,7 @@ public class MappingsTest {
                                                    .toSubstructures();
         Iterator<IAtomContainer> iterator = iterable.iterator();
 
-        assertTrue(iterator.hasNext());
+        Assertions.assertTrue(iterator.hasNext());
         IAtomContainer submol = iterator.next();
         assertThat(submol, is(not(query)));
         // note that indices are mapped from query to target
@@ -254,12 +253,12 @@ public class MappingsTest {
         assertThat(submol.getBond(0), is(target.getBond(0))); // C-O bond
         assertThat(submol.getBond(1), is(target.getBond(2))); // O-C bond
         assertThat(submol.getBond(2), is(target.getBond(1))); // C-C bond
-        assertFalse(iterator.hasNext());
+        Assertions.assertFalse(iterator.hasNext());
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void atLeast() throws Exception {
+    void atLeast() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -267,13 +266,13 @@ public class MappingsTest {
         when(iterator.next()).thenReturn(new int[0]);
 
         Mappings ms = new Mappings(mock(IAtomContainer.class), mock(IAtomContainer.class), iterable);
-        assertTrue(ms.atLeast(2));
+        Assertions.assertTrue(ms.atLeast(2));
         verify(iterator, atMost(2)).next(); // was only called twice
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void first() throws Exception {
+    void first() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -290,7 +289,7 @@ public class MappingsTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void count() throws Exception {
+    void count() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -304,7 +303,7 @@ public class MappingsTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void countUnique() throws Exception {
+    void countUnique() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -325,7 +324,70 @@ public class MappingsTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void iterator() throws Exception {
+    void countUnique2() throws Exception {
+        Iterable<int[]> iterable = mock(Iterable.class);
+        Iterator<int[]> iterator = mock(Iterator.class);
+        when(iterable.iterator()).thenReturn(iterator);
+        when(iterator.hasNext()).thenReturn(true, true, true, true, false);
+        doCallRealMethod().when(iterator)
+                          .forEachRemaining(ArgumentMatchers.any(Consumer.class));
+
+        int[] p1 = {0, 1};
+        int[] p2 = {0, 2};
+        int[] p3 = {0, 3};
+        int[] p4 = {0, 4};
+
+        when(iterator.next()).thenReturn(p1, p2, p3, p4);
+
+        Mappings ms = new Mappings(mock(IAtomContainer.class), mock(IAtomContainer.class), iterable);
+        assertThat(ms.countUnique(), is(4));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    void countExclusive() throws Exception {
+        Iterable<int[]> iterable = mock(Iterable.class);
+        Iterator<int[]> iterator = mock(Iterator.class);
+        when(iterable.iterator()).thenReturn(iterator);
+        when(iterator.hasNext()).thenReturn(true, true, true, true, false);
+        doCallRealMethod().when(iterator)
+                          .forEachRemaining(ArgumentMatchers.any(Consumer.class));
+
+        int[] p1 = {0, 1, 2};
+        int[] p2 = {0, 2, 1};
+        int[] p3 = {0, 3, 4};
+        int[] p4 = {0, 4, 3};
+
+        when(iterator.next()).thenReturn(p1, p2, p3, p4);
+
+        Mappings ms = new Mappings(mock(IAtomContainer.class), mock(IAtomContainer.class), iterable);
+        assertThat(ms.exclusiveAtoms().count(), is(1));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    void countExclusive2() throws Exception {
+        Iterable<int[]> iterable = mock(Iterable.class);
+        Iterator<int[]> iterator = mock(Iterator.class);
+        when(iterable.iterator()).thenReturn(iterator);
+        when(iterator.hasNext()).thenReturn(true, true, true, true, false);
+        doCallRealMethod().when(iterator)
+                          .forEachRemaining(ArgumentMatchers.any(Consumer.class));
+
+        int[] p1 = {0, 1, 2};
+        int[] p2 = {0, 2, 1};
+        int[] p3 = {5, 3, 4};
+        int[] p4 = {5, 4, 3};
+
+        when(iterator.next()).thenReturn(p1, p2, p3, p4);
+
+        Mappings ms = new Mappings(mock(IAtomContainer.class), mock(IAtomContainer.class), iterable);
+        assertThat(ms.exclusiveAtoms().count(), is(2));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    void iterator() throws Exception {
         Iterable<int[]> iterable = mock(Iterable.class);
         Iterator<int[]> iterator = mock(Iterator.class);
         when(iterable.iterator()).thenReturn(iterator);
@@ -333,8 +395,8 @@ public class MappingsTest {
         assertThat(ms.iterator(), is(sameInstance(iterator)));
     }
 
-    IChemObjectBuilder bldr   = SilentChemObjectBuilder.getInstance();
-    SmilesParser       smipar = new SmilesParser(bldr);
+    private final IChemObjectBuilder bldr   = SilentChemObjectBuilder.getInstance();
+    private final SmilesParser       smipar = new SmilesParser(bldr);
 
     IAtomContainer smi(String smi) throws Exception {
         return smipar.parseSmiles(smi);
